import assert from 'assert';

// `fast-text-encoding` pollutes the global namespace. The following is an attempt to circumvent that.
let textEncoder = undefined, textDecoder = undefined;
if (typeof TextEncoder !== "undefined" || typeof TextDecoder !== "undefined") {
    textEncoder = TextEncoder;
    textDecoder = TextDecoder;
}
else {
    // This is a horrible hack, but I don't know a better way to avoid polluting the global
    // namespace.
    const ctx = (0, eval)("this");
    require("fast-text-encoding");
    textEncoder = TextEncoder;
    textDecoder = TextDecoder;
    delete ctx.TextEncoder;
    delete ctx.TextDecoder;
    // FIXME: add an unassert build-step
    assert(typeof TextEncoder === "undefined");
    assert(typeof TextDecoder === "undefined");
}
assert(typeof textEncoder !== "undefined");
assert(typeof textDecoder !== "undefined");
// This function is intended to be called on JavaScript strings (possibly containing Unicode
// characters outside the ASCII range) that need to be passed to OCaml functions; it
// ‘double-encodes’ those strings such that they will be perceived by BuckleScript-compiled OCaml
// as UTF-8-encoded `char`-arrays.
//
// #### Rationale
//
// Required reading: Mathias Bynens' [JavaScript has a Unicode problem](https://mathiasbynens.be/notes/javascript-unicode) and then [JavaScript's internal character encoding](https://mathiasbynens.be/notes/javascript-encoding).
//
// BuckleScript, at least as of `4.0.6`, treats JavaScript primitive `String`s as, basically, uint
// `char`-arrays. At the boundaries of BuckleScript-compiled code, especially when the OCaml code
// treats `char`-arrays as UTF-8, we need to massage those back into valid JavaScript UCS-2
// strings. This function, paired with `fromFakeUTF8String`, handle these transformations.
//
// (See the README for more information.)
//
// #### Input
//
// This function takes one argument, a ‘standard’ JavaScript `String`; that is, one with Unicode
// characters outside the ASCII range (but still within the BMP!) encoded as single, 16-bit
// code-units; and [higher-plane characters][] encoded as UTF-16-style [surrogate pairs][].
//
// - Example, as a UCS-2 sequence of 16-bit code-units:
//
//   ```js
//   [102, 111, 111, 183, 98, 97, 114]
//   ```
//
// - Example, as typed into a UTF-8 JavaScript source-file:
//
//   ```js
//   "foo·bar"
//   ```
//
// #### Output
//
// An abomination. This produces a JavaScript `String` (that is still technically encoded as UCS-2,
// mind you!) *containing a series of UTF-8 bytes, as interpreted as UCS-2 codepoints*.
//
// - Example, as a UCS-2 sequence of 16-bit code-units:
//
//   ```js
//   [102, 111, 111, 194, 183, 98, 97, 114]
//   ```
//
// - Example, as typed into a UTF-8 JavaScript source-file:
//
//   ```js
//   "foo\xC2\xB7bar" // or "fooÂ·bar", if you're a heathen
//   ```
//
// See that in this example, the non-ASCII character U+00B7 “MIDDLE DOT”, which is one code-unit
// (literally `\u00B7`) in the original input-string, is encoded as *two* JavaScript / UCS-2
// code-units, `\xC2\xB7` — C2-B7 being the UTF-8 encoding of U+00B7.
//
// Finally, note that I mint a nominal type for the return-value of this function; I prefer to
// attempt to track encoding at the type-level if at all possible. It's trivial, though I'd assert
// a bad idea, to discard this additional information if it's giving you type-errors you don't care
// about:
//
// ```typescript
// let this_has_a_simple_type = toFakeUTF8String(some_input) as string
// ```
//
// [higher-plane characters]: <https://en.wikipedia.org/wiki/Plane_(Unicode)>
// [surrogate pairs]: <https://unicodebook.readthedocs.io/unicode_encodings.html#utf-16-surrogate-pairs>
//
//---
// FIXME: The original implementation of this was fast, but broken. Currently, I've resorted to
//        simply iterating over the *entire string* an extra time on *both* encoding and decoding,
//        which I hate and don't want to do ...
function toFakeUTF8String(js_string) {
    const byte_arr = new textEncoder("utf-8").encode(js_string);
    let result = new String();
    for (var i = 0; i < byte_arr.length; i++) {
        // FIXME: I'm not clear on the performance of string-concatenation in JavaScript; all the
        //        references I find claim that it's not slower than a single join-operation, but that
        //        seems ... impossible? Oh well.
        result = result + String.fromCharCode(byte_arr[i]);
    }
    return result;
}
// Given a double-encoded (effectively, mis-encoded) BuckleScript ‘string’ that's been manipulated
// as if it's a UTF-8 `char`-array, this function will decode (effectively, re-encode) that value
// into a functional, correct JavaScript (i.e. UCS-2) string. See {@link toFakeUTF8String} for
// in-depth details.
//
// Takes a `String`, containing a series of UTF-8 bytes encoded as Unicode codepoints (in
// JavaScript's standard UCS-2, that is); returns a standard JavaScript `String` with those Unicode
// scalars properly represented in UCS-2 code units, ready for standard JavaScript manipulation.
//
// Finally, if you're using TypeScript, this expects a value known at compile-time to contain UTF-8
// text; this is tracked in the type-system via the minted `string_as_utf_8_buffer` type. Idiomatic
// usage would be to tag every stringish return-value from a BuckleScript module with this type:
//
// ```typescript
// import { toFakeUTF8String, fromFakeUTF8String } from 'ocaml-string-convert'
// import $AModule from './aModule.bs'
//
// let $yuck = $AModule.returns_a_string() as string_as_utf_8_buffer
// // ... manipulation ...
// let str = fromFakeUTF8String($yuck)
// ```
//
//---
// FIXME: This ends up iterating over the string *twice*. Not great; but I also don't have access
// to the internals of the UTF-8 decoder if it's built into the JavaScript engine, sooooo ... and
// this is becoming a mantra now ... forgive me. /=
function fromFakeUTF8String(eldritch_horror) {
    const utf8_arr = new Uint8Array(eldritch_horror.length);
    for (var i = 0; i < eldritch_horror.length; i++) {
        utf8_arr[i] = eldritch_horror.charCodeAt(i);
    }
    return new textDecoder("utf-8").decode(utf8_arr);
}

var out_of_memory = /* tuple */[
  "Out_of_memory",
  0
];

var sys_error = /* tuple */[
  "Sys_error",
  -1
];

var failure = /* tuple */[
  "Failure",
  -2
];

var invalid_argument = /* tuple */[
  "Invalid_argument",
  -3
];

var end_of_file = /* tuple */[
  "End_of_file",
  -4
];

var division_by_zero = /* tuple */[
  "Division_by_zero",
  -5
];

var not_found = /* tuple */[
  "Not_found",
  -6
];

var match_failure = /* tuple */[
  "Match_failure",
  -7
];

var stack_overflow = /* tuple */[
  "Stack_overflow",
  -8
];

var sys_blocked_io = /* tuple */[
  "Sys_blocked_io",
  -9
];

var assert_failure = /* tuple */[
  "Assert_failure",
  -10
];

var undefined_recursive_module = /* tuple */[
  "Undefined_recursive_module",
  -11
];

out_of_memory.tag = 248;

sys_error.tag = 248;

failure.tag = 248;

invalid_argument.tag = 248;

end_of_file.tag = 248;

division_by_zero.tag = 248;

not_found.tag = 248;

match_failure.tag = 248;

stack_overflow.tag = 248;

sys_blocked_io.tag = 248;

assert_failure.tag = 248;

undefined_recursive_module.tag = 248;
/*  Not a pure module */

function caml_array_sub(x, offset, len) {
  var result = new Array(len);
  var j = 0;
  var i = offset;
  while(j < len) {
    result[j] = x[i];
    j = j + 1 | 0;
    i = i + 1 | 0;
  }  return result;
}

function caml_array_set(xs, index, newval) {
  if (index < 0 || index >= xs.length) {
    throw [
          invalid_argument,
          "index out of bounds"
        ];
  }
  xs[index] = newval;
  return /* () */0;
}

function caml_array_get(xs, index) {
  if (index < 0 || index >= xs.length) {
    throw [
          invalid_argument,
          "index out of bounds"
        ];
  }
  return xs[index];
}

function caml_make_vect(len, init) {
  var b = new Array(len);
  for(var i = 0 ,i_finish = len - 1 | 0; i <= i_finish; ++i){
    b[i] = init;
  }
  return b;
}

function caml_array_blit(a1, i1, a2, i2, len) {
  if (i2 <= i1) {
    for(var j = 0 ,j_finish = len - 1 | 0; j <= j_finish; ++j){
      a2[j + i2 | 0] = a1[j + i1 | 0];
    }
    return /* () */0;
  } else {
    for(var j$1 = len - 1 | 0; j$1 >= 0; --j$1){
      a2[j$1 + i2 | 0] = a1[j$1 + i1 | 0];
    }
    return /* () */0;
  }
}
/* No side effect */

function app(_f, _args) {
  while(true) {
    var args = _args;
    var f = _f;
    var init_arity = f.length;
    var arity = init_arity === 0 ? 1 : init_arity;
    var len = args.length;
    var d = arity - len | 0;
    if (d === 0) {
      return f.apply(null, args);
    } else if (d < 0) {
      _args = caml_array_sub(args, arity, -d | 0);
      _f = f.apply(null, caml_array_sub(args, 0, arity));
      continue ;
    } else {
      return (function(f,args){
      return function (x) {
        return app(f, args.concat(/* array */[x]));
      }
      }(f,args));
    }
  }}

function curry_1(o, a0, arity) {
  switch (arity) {
    case 1 :
        return o(a0);
    case 2 :
        return (function (param) {
            return o(a0, param);
          });
    case 3 :
        return (function (param, param$1) {
            return o(a0, param, param$1);
          });
    case 4 :
        return (function (param, param$1, param$2) {
            return o(a0, param, param$1, param$2);
          });
    case 5 :
        return (function (param, param$1, param$2, param$3) {
            return o(a0, param, param$1, param$2, param$3);
          });
    case 6 :
        return (function (param, param$1, param$2, param$3, param$4) {
            return o(a0, param, param$1, param$2, param$3, param$4);
          });
    case 7 :
        return (function (param, param$1, param$2, param$3, param$4, param$5) {
            return o(a0, param, param$1, param$2, param$3, param$4, param$5);
          });
    default:
      return app(o, /* array */[a0]);
  }
}

function _1(o, a0) {
  var arity = o.length;
  if (arity === 1) {
    return o(a0);
  } else {
    return curry_1(o, a0, arity);
  }
}

function curry_2(o, a0, a1, arity) {
  switch (arity) {
    case 1 :
        return app(o(a0), /* array */[a1]);
    case 2 :
        return o(a0, a1);
    case 3 :
        return (function (param) {
            return o(a0, a1, param);
          });
    case 4 :
        return (function (param, param$1) {
            return o(a0, a1, param, param$1);
          });
    case 5 :
        return (function (param, param$1, param$2) {
            return o(a0, a1, param, param$1, param$2);
          });
    case 6 :
        return (function (param, param$1, param$2, param$3) {
            return o(a0, a1, param, param$1, param$2, param$3);
          });
    case 7 :
        return (function (param, param$1, param$2, param$3, param$4) {
            return o(a0, a1, param, param$1, param$2, param$3, param$4);
          });
    default:
      return app(o, /* array */[
                  a0,
                  a1
                ]);
  }
}

function _2(o, a0, a1) {
  var arity = o.length;
  if (arity === 2) {
    return o(a0, a1);
  } else {
    return curry_2(o, a0, a1, arity);
  }
}

function __2(o) {
  var arity = o.length;
  if (arity === 2) {
    return o;
  } else {
    return (function (a0, a1) {
        return _2(o, a0, a1);
      });
  }
}

function curry_3(o, a0, a1, a2, arity) {
  switch (arity) {
    case 1 :
        return app(o(a0), /* array */[
                    a1,
                    a2
                  ]);
    case 2 :
        return app(o(a0, a1), /* array */[a2]);
    case 3 :
        return o(a0, a1, a2);
    case 4 :
        return (function (param) {
            return o(a0, a1, a2, param);
          });
    case 5 :
        return (function (param, param$1) {
            return o(a0, a1, a2, param, param$1);
          });
    case 6 :
        return (function (param, param$1, param$2) {
            return o(a0, a1, a2, param, param$1, param$2);
          });
    case 7 :
        return (function (param, param$1, param$2, param$3) {
            return o(a0, a1, a2, param, param$1, param$2, param$3);
          });
    default:
      return app(o, /* array */[
                  a0,
                  a1,
                  a2
                ]);
  }
}

function _3(o, a0, a1, a2) {
  var arity = o.length;
  if (arity === 3) {
    return o(a0, a1, a2);
  } else {
    return curry_3(o, a0, a1, a2, arity);
  }
}

function curry_4(o, a0, a1, a2, a3, arity) {
  switch (arity) {
    case 1 :
        return app(o(a0), /* array */[
                    a1,
                    a2,
                    a3
                  ]);
    case 2 :
        return app(o(a0, a1), /* array */[
                    a2,
                    a3
                  ]);
    case 3 :
        return app(o(a0, a1, a2), /* array */[a3]);
    case 4 :
        return o(a0, a1, a2, a3);
    case 5 :
        return (function (param) {
            return o(a0, a1, a2, a3, param);
          });
    case 6 :
        return (function (param, param$1) {
            return o(a0, a1, a2, a3, param, param$1);
          });
    case 7 :
        return (function (param, param$1, param$2) {
            return o(a0, a1, a2, a3, param, param$1, param$2);
          });
    default:
      return app(o, /* array */[
                  a0,
                  a1,
                  a2,
                  a3
                ]);
  }
}

function _4(o, a0, a1, a2, a3) {
  var arity = o.length;
  if (arity === 4) {
    return o(a0, a1, a2, a3);
  } else {
    return curry_4(o, a0, a1, a2, a3, arity);
  }
}

function curry_5(o, a0, a1, a2, a3, a4, arity) {
  switch (arity) {
    case 1 :
        return app(o(a0), /* array */[
                    a1,
                    a2,
                    a3,
                    a4
                  ]);
    case 2 :
        return app(o(a0, a1), /* array */[
                    a2,
                    a3,
                    a4
                  ]);
    case 3 :
        return app(o(a0, a1, a2), /* array */[
                    a3,
                    a4
                  ]);
    case 4 :
        return app(o(a0, a1, a2, a3), /* array */[a4]);
    case 5 :
        return o(a0, a1, a2, a3, a4);
    case 6 :
        return (function (param) {
            return o(a0, a1, a2, a3, a4, param);
          });
    case 7 :
        return (function (param, param$1) {
            return o(a0, a1, a2, a3, a4, param, param$1);
          });
    default:
      return app(o, /* array */[
                  a0,
                  a1,
                  a2,
                  a3,
                  a4
                ]);
  }
}

function _5(o, a0, a1, a2, a3, a4) {
  var arity = o.length;
  if (arity === 5) {
    return o(a0, a1, a2, a3, a4);
  } else {
    return curry_5(o, a0, a1, a2, a3, a4, arity);
  }
}

function curry_7(o, a0, a1, a2, a3, a4, a5, a6, arity) {
  switch (arity) {
    case 1 :
        return app(o(a0), /* array */[
                    a1,
                    a2,
                    a3,
                    a4,
                    a5,
                    a6
                  ]);
    case 2 :
        return app(o(a0, a1), /* array */[
                    a2,
                    a3,
                    a4,
                    a5,
                    a6
                  ]);
    case 3 :
        return app(o(a0, a1, a2), /* array */[
                    a3,
                    a4,
                    a5,
                    a6
                  ]);
    case 4 :
        return app(o(a0, a1, a2, a3), /* array */[
                    a4,
                    a5,
                    a6
                  ]);
    case 5 :
        return app(o(a0, a1, a2, a3, a4), /* array */[
                    a5,
                    a6
                  ]);
    case 6 :
        return app(o(a0, a1, a2, a3, a4, a5), /* array */[a6]);
    case 7 :
        return o(a0, a1, a2, a3, a4, a5, a6);
    default:
      return app(o, /* array */[
                  a0,
                  a1,
                  a2,
                  a3,
                  a4,
                  a5,
                  a6
                ]);
  }
}

function _7(o, a0, a1, a2, a3, a4, a5, a6) {
  var arity = o.length;
  if (arity === 7) {
    return o(a0, a1, a2, a3, a4, a5, a6);
  } else {
    return curry_7(o, a0, a1, a2, a3, a4, a5, a6, arity);
  }
}
/* No side effect */

function __(tag, block) {
  block.tag = tag;
  return block;
}
/* No side effect */

function caml_int_compare(x, y) {
  if (x < y) {
    return -1;
  } else if (x === y) {
    return 0;
  } else {
    return 1;
  }
}

function caml_bool_compare(x, y) {
  if (x) {
    if (y) {
      return 0;
    } else {
      return 1;
    }
  } else if (y) {
    return -1;
  } else {
    return 0;
  }
}

function caml_string_compare(s1, s2) {
  if (s1 === s2) {
    return 0;
  } else if (s1 < s2) {
    return -1;
  } else {
    return 1;
  }
}

function caml_int_min(x, y) {
  if (x < y) {
    return x;
  } else {
    return y;
  }
}

function caml_int_max(x, y) {
  if (x > y) {
    return x;
  } else {
    return y;
  }
}

function caml_float_max(x, y) {
  if (x > y) {
    return x;
  } else {
    return y;
  }
}
/* No side effect */

function caml_lazy_make(fn) {
  var block = /* array */[fn];
  block.tag = 246;
  return block;
}

function caml_update_dummy(x, y) {
  var len = y.length | 0;
  for(var i = 0 ,i_finish = len - 1 | 0; i <= i_finish; ++i){
    x[i] = y[i];
  }
  var y_tag = y.tag | 0;
  if (y_tag !== 0) {
    x.tag = y_tag;
    return /* () */0;
  } else {
    return 0;
  }
}

function for_in (o,foo){
        for (var x in o) { foo(x); }
      }
function caml_compare(_a, _b) {
  while(true) {
    var b = _b;
    var a = _a;
    if (a === b) {
      return 0;
    } else {
      var a_type = typeof a;
      var b_type = typeof b;
      switch (a_type) {
        case "boolean" :
            if (b_type === "boolean") {
              return caml_bool_compare(a, b);
            }
            break;
        case "function" :
            if (b_type === "function") {
              throw [
                    invalid_argument,
                    "compare: functional value"
                  ];
            }
            break;
        case "number" :
            if (b_type === "number") {
              return caml_int_compare(a, b);
            }
            break;
        case "string" :
            if (b_type === "string") {
              return caml_string_compare(a, b);
            } else {
              return 1;
            }
        case "undefined" :
            return -1;
          
      }
      switch (b_type) {
        case "string" :
            return -1;
        case "undefined" :
            return 1;
        default:
          if (a_type === "boolean") {
            return 1;
          } else if (b_type === "boolean") {
            return -1;
          } else if (a_type === "function") {
            return 1;
          } else if (b_type === "function") {
            return -1;
          } else if (a_type === "number") {
            if (b === null || b.tag === 256) {
              return 1;
            } else {
              return -1;
            }
          } else if (b_type === "number") {
            if (a === null || a.tag === 256) {
              return -1;
            } else {
              return 1;
            }
          } else if (a === null) {
            if (b.tag === 256) {
              return 1;
            } else {
              return -1;
            }
          } else if (b === null) {
            if (a.tag === 256) {
              return -1;
            } else {
              return 1;
            }
          } else {
            var tag_a = a.tag | 0;
            var tag_b = b.tag | 0;
            if (tag_a === 250) {
              _a = a[0];
              continue ;
            } else if (tag_b === 250) {
              _b = b[0];
              continue ;
            } else if (tag_a === 256) {
              if (tag_b === 256) {
                return caml_int_compare(a[1], b[1]);
              } else {
                return -1;
              }
            } else if (tag_a === 248) {
              return caml_int_compare(a[1], b[1]);
            } else {
              if (tag_a === 251) {
                throw [
                      invalid_argument,
                      "equal: abstract value"
                    ];
              }
              if (tag_a !== tag_b) {
                if (tag_a < tag_b) {
                  return -1;
                } else {
                  return 1;
                }
              } else {
                var len_a = a.length | 0;
                var len_b = b.length | 0;
                if (len_a === len_b) {
                  if (Array.isArray(a)) {
                    var a$1 = a;
                    var b$1 = b;
                    var _i = 0;
                    var same_length = len_a;
                    while(true) {
                      var i = _i;
                      if (i === same_length) {
                        return 0;
                      } else {
                        var res = caml_compare(a$1[i], b$1[i]);
                        if (res !== 0) {
                          return res;
                        } else {
                          _i = i + 1 | 0;
                          continue ;
                        }
                      }
                    }                  } else if ((a instanceof Date && b instanceof Date)) {
                    return (a - b);
                  } else {
                    var a$2 = a;
                    var b$2 = b;
                    var min_key_lhs = /* record */[/* contents */undefined];
                    var min_key_rhs = /* record */[/* contents */undefined];
                    var do_key = function (param, key) {
                      var min_key = param[2];
                      var b = param[1];
                      if (!b.hasOwnProperty(key) || caml_compare(param[0][key], b[key]) > 0) {
                        var match = min_key[0];
                        if (match !== undefined && key >= match) {
                          return 0;
                        } else {
                          min_key[0] = key;
                          return /* () */0;
                        }
                      } else {
                        return 0;
                      }
                    };
                    var partial_arg = /* tuple */[
                      a$2,
                      b$2,
                      min_key_rhs
                    ];
                    var do_key_a = (function(partial_arg){
                    return function do_key_a(param) {
                      return do_key(partial_arg, param);
                    }
                    }(partial_arg));
                    var partial_arg$1 = /* tuple */[
                      b$2,
                      a$2,
                      min_key_lhs
                    ];
                    var do_key_b = (function(partial_arg$1){
                    return function do_key_b(param) {
                      return do_key(partial_arg$1, param);
                    }
                    }(partial_arg$1));
                    for_in(a$2, do_key_a);
                    for_in(b$2, do_key_b);
                    var match = min_key_lhs[0];
                    var match$1 = min_key_rhs[0];
                    if (match !== undefined) {
                      if (match$1 !== undefined) {
                        return caml_string_compare(match, match$1);
                      } else {
                        return -1;
                      }
                    } else if (match$1 !== undefined) {
                      return 1;
                    } else {
                      return 0;
                    }
                  }
                } else if (len_a < len_b) {
                  var a$3 = a;
                  var b$3 = b;
                  var _i$1 = 0;
                  var short_length = len_a;
                  while(true) {
                    var i$1 = _i$1;
                    if (i$1 === short_length) {
                      return -1;
                    } else {
                      var res$1 = caml_compare(a$3[i$1], b$3[i$1]);
                      if (res$1 !== 0) {
                        return res$1;
                      } else {
                        _i$1 = i$1 + 1 | 0;
                        continue ;
                      }
                    }
                  }                } else {
                  var a$4 = a;
                  var b$4 = b;
                  var _i$2 = 0;
                  var short_length$1 = len_b;
                  while(true) {
                    var i$2 = _i$2;
                    if (i$2 === short_length$1) {
                      return 1;
                    } else {
                      var res$2 = caml_compare(a$4[i$2], b$4[i$2]);
                      if (res$2 !== 0) {
                        return res$2;
                      } else {
                        _i$2 = i$2 + 1 | 0;
                        continue ;
                      }
                    }
                  }                }
              }
            }
          }
      }
    }
  }}

function caml_equal(_a, _b) {
  while(true) {
    var b = _b;
    var a = _a;
    if (a === b) {
      return true;
    } else {
      var a_type = typeof a;
      if (a_type === "string" || a_type === "number" || a_type === "boolean" || a_type === "undefined" || a === null) {
        return false;
      } else {
        var b_type = typeof b;
        if (a_type === "function" || b_type === "function") {
          throw [
                invalid_argument,
                "equal: functional value"
              ];
        }
        if (b_type === "number" || b_type === "undefined" || b === null) {
          return false;
        } else {
          var tag_a = a.tag | 0;
          var tag_b = b.tag | 0;
          if (tag_a === 250) {
            _a = a[0];
            continue ;
          } else if (tag_b === 250) {
            _b = b[0];
            continue ;
          } else if (tag_a === 248) {
            return a[1] === b[1];
          } else {
            if (tag_a === 251) {
              throw [
                    invalid_argument,
                    "equal: abstract value"
                  ];
            }
            if (tag_a !== tag_b) {
              return false;
            } else if (tag_a === 256) {
              return a[1] === b[1];
            } else {
              var len_a = a.length | 0;
              var len_b = b.length | 0;
              if (len_a === len_b) {
                if (Array.isArray(a)) {
                  var a$1 = a;
                  var b$1 = b;
                  var _i = 0;
                  var same_length = len_a;
                  while(true) {
                    var i = _i;
                    if (i === same_length) {
                      return true;
                    } else if (caml_equal(a$1[i], b$1[i])) {
                      _i = i + 1 | 0;
                      continue ;
                    } else {
                      return false;
                    }
                  }                } else if ((a instanceof Date && b instanceof Date)) {
                  return !(a > b || a < b);
                } else {
                  var a$2 = a;
                  var b$2 = b;
                  var result = /* record */[/* contents */true];
                  var do_key_a = (function(b$2,result){
                  return function do_key_a(key) {
                    if (b$2.hasOwnProperty(key)) {
                      return 0;
                    } else {
                      result[0] = false;
                      return /* () */0;
                    }
                  }
                  }(b$2,result));
                  var do_key_b = (function(a$2,b$2,result){
                  return function do_key_b(key) {
                    if (!a$2.hasOwnProperty(key) || !caml_equal(b$2[key], a$2[key])) {
                      result[0] = false;
                      return /* () */0;
                    } else {
                      return 0;
                    }
                  }
                  }(a$2,b$2,result));
                  for_in(a$2, do_key_a);
                  if (result[0]) {
                    for_in(b$2, do_key_b);
                  }
                  return result[0];
                }
              } else {
                return false;
              }
            }
          }
        }
      }
    }
  }}

function caml_notequal(a, b) {
  return !caml_equal(a, b);
}

function caml_greaterequal(a, b) {
  return caml_compare(a, b) >= 0;
}

function caml_lessthan(a, b) {
  return caml_compare(a, b) < 0;
}

function caml_obj_set_tag(prim, prim$1) {
  prim.tag = prim$1;
  return /* () */0;
}
/* No side effect */

var stdout = /* record */[
  /* buffer */"",
  /* output */(function (param, s) {
      var v = s.length - 1 | 0;
      if (( (typeof process !== "undefined") && process.stdout && process.stdout.write)) {
        return ( process.stdout.write )(s);
      } else if (s[v] === "\n") {
        console.log(s.slice(0, v));
        return /* () */0;
      } else {
        console.log(s);
        return /* () */0;
      }
    })
];

var stderr = /* record */[
  /* buffer */"",
  /* output */(function (param, s) {
      var v = s.length - 1 | 0;
      if (s[v] === "\n") {
        console.log(s.slice(0, v));
        return /* () */0;
      } else {
        console.log(s);
        return /* () */0;
      }
    })
];

function caml_ml_flush(oc) {
  if (oc[/* buffer */0] !== "") {
    _2(oc[/* output */1], oc, oc[/* buffer */0]);
    oc[/* buffer */0] = "";
    return /* () */0;
  } else {
    return 0;
  }
}

function caml_ml_output(oc, str, offset, len) {
  var str$1 = offset === 0 && len === str.length ? str : str.slice(offset, len);
  if (( (typeof process !== "undefined") && process.stdout && process.stdout.write ) && oc === stdout) {
    return ( process.stdout.write )(str$1);
  } else {
    var id = str$1.lastIndexOf("\n");
    if (id < 0) {
      oc[/* buffer */0] = oc[/* buffer */0] + str$1;
      return /* () */0;
    } else {
      oc[/* buffer */0] = oc[/* buffer */0] + str$1.slice(0, id + 1 | 0);
      caml_ml_flush(oc);
      oc[/* buffer */0] = oc[/* buffer */0] + str$1.slice(id + 1 | 0);
      return /* () */0;
    }
  }
}

function caml_ml_output_char(oc, $$char) {
  return caml_ml_output(oc, String.fromCharCode($$char), 0, 1);
}

function caml_ml_out_channels_list(param) {
  return /* :: */[
          stdout,
          /* :: */[
            stderr,
            /* [] */0
          ]
        ];
}
/* No side effect */

function caml_sys_random_seed(param) {
  return /* array */[((Date.now() | 0) ^ 4294967295) * Math.random() | 0];
}

function caml_sys_get_argv(param) {
  if (typeof process === "undefined") {
    return /* tuple */[
            "",
            /* array */[""]
          ];
  } else {
    var argv = (process.argv);
    if (argv == null) {
      return /* tuple */[
              "",
              /* array */[""]
            ];
    } else {
      return /* tuple */[
              argv[0],
              argv
            ];
    }
  }
}
/* No side effect */

function caml_fill_bytes(s, i, l, c) {
  if (l > 0) {
    for(var k = i ,k_finish = (l + i | 0) - 1 | 0; k <= k_finish; ++k){
      s[k] = c;
    }
    return /* () */0;
  } else {
    return 0;
  }
}

function caml_create_bytes(len) {
  if (len < 0) {
    throw [
          invalid_argument,
          "String.create"
        ];
  }
  var result = new Array(len);
  for(var i = 0 ,i_finish = len - 1 | 0; i <= i_finish; ++i){
    result[i] = /* "\000" */0;
  }
  return result;
}

function caml_blit_bytes(s1, i1, s2, i2, len) {
  if (len > 0) {
    if (s1 === s2) {
      var s1$1 = s1;
      var i1$1 = i1;
      var i2$1 = i2;
      var len$1 = len;
      if (i1$1 < i2$1) {
        var range_a = (s1$1.length - i2$1 | 0) - 1 | 0;
        var range_b = len$1 - 1 | 0;
        var range = range_a > range_b ? range_b : range_a;
        for(var j = range; j >= 0; --j){
          s1$1[i2$1 + j | 0] = s1$1[i1$1 + j | 0];
        }
        return /* () */0;
      } else if (i1$1 > i2$1) {
        var range_a$1 = (s1$1.length - i1$1 | 0) - 1 | 0;
        var range_b$1 = len$1 - 1 | 0;
        var range$1 = range_a$1 > range_b$1 ? range_b$1 : range_a$1;
        for(var k = 0; k <= range$1; ++k){
          s1$1[i2$1 + k | 0] = s1$1[i1$1 + k | 0];
        }
        return /* () */0;
      } else {
        return 0;
      }
    } else {
      var off1 = s1.length - i1 | 0;
      if (len <= off1) {
        for(var i = 0 ,i_finish = len - 1 | 0; i <= i_finish; ++i){
          s2[i2 + i | 0] = s1[i1 + i | 0];
        }
        return /* () */0;
      } else {
        for(var i$1 = 0 ,i_finish$1 = off1 - 1 | 0; i$1 <= i_finish$1; ++i$1){
          s2[i2 + i$1 | 0] = s1[i1 + i$1 | 0];
        }
        for(var i$2 = off1 ,i_finish$2 = len - 1 | 0; i$2 <= i_finish$2; ++i$2){
          s2[i2 + i$2 | 0] = /* "\000" */0;
        }
        return /* () */0;
      }
    }
  } else {
    return 0;
  }
}

function bytes_to_string(a) {
  var bytes = a;
  var len = a.length;
  var s = "";
  var s_len = len;
  if ( len <= 4096 && len === bytes.length) {
    return String.fromCharCode.apply(null, bytes);
  } else {
    var offset = 0;
    while(s_len > 0) {
      var next = s_len < 1024 ? s_len : 1024;
      var tmp_bytes = new Array(next);
      caml_blit_bytes(bytes, offset, tmp_bytes, 0, next);
      s = s + String.fromCharCode.apply(null, tmp_bytes);
      s_len = s_len - next | 0;
      offset = offset + next | 0;
    }    return s;
  }
}

function caml_blit_string(s1, i1, s2, i2, len) {
  if (len > 0) {
    var off1 = s1.length - i1 | 0;
    if (len <= off1) {
      for(var i = 0 ,i_finish = len - 1 | 0; i <= i_finish; ++i){
        s2[i2 + i | 0] = s1.charCodeAt(i1 + i | 0);
      }
      return /* () */0;
    } else {
      for(var i$1 = 0 ,i_finish$1 = off1 - 1 | 0; i$1 <= i_finish$1; ++i$1){
        s2[i2 + i$1 | 0] = s1.charCodeAt(i1 + i$1 | 0);
      }
      for(var i$2 = off1 ,i_finish$2 = len - 1 | 0; i$2 <= i_finish$2; ++i$2){
        s2[i2 + i$2 | 0] = /* "\000" */0;
      }
      return /* () */0;
    }
  } else {
    return 0;
  }
}

function bytes_of_string(s) {
  var len = s.length;
  var res = new Array(len);
  for(var i = 0 ,i_finish = len - 1 | 0; i <= i_finish; ++i){
    res[i] = s.charCodeAt(i);
  }
  return res;
}
/* No side effect */

var imul = ( Math.imul || function (x,y) {
  y |= 0; return ((((x >> 16) * y) << 16) + (x & 0xffff) * y)|0; 
}
);
/* imul Not a pure module */

function repeat (count,self){
    if (self.repeat){
        return self.repeat(count)
    }
    if (self.length == 0 || count == 0) {
            return '';
        }
    // Ensuring count is a 31-bit integer allows us to heavily optimize the
    // main part. But anyway, most current (August 2014) browsers can't handle
    // strings 1 << 28 chars or longer, so:
    if (self.length * count >= 1 << 28) {
            throw new RangeError('repeat count must not overflow maximum string size');
    }
    var rpt = '';
    for (;;) {
            if ((count & 1) == 1) {
                rpt += self;
            }
            count >>>= 1;
            if (count == 0) {
                break;
            }
            self += self;
    }
    return rpt;

}/* No side effect */

var min_int = /* record */[
  /* hi */-2147483648,
  /* lo */0
];

var max_int = /* record */[
  /* hi */2147483647,
  /* lo */1
];

var one = /* record */[
  /* hi */0,
  /* lo */1
];

var zero = /* record */[
  /* hi */0,
  /* lo */0
];

var neg_one = /* record */[
  /* hi */-1,
  /* lo */4294967295
];

function neg_signed(x) {
  return (x & 2147483648) !== 0;
}

function add(param, param$1) {
  var other_low_ = param$1[/* lo */1];
  var this_low_ = param[/* lo */1];
  var lo = this_low_ + other_low_ & 4294967295;
  var overflow = neg_signed(this_low_) && (neg_signed(other_low_) || !neg_signed(lo)) || neg_signed(other_low_) && !neg_signed(lo) ? 1 : 0;
  var hi = param[/* hi */0] + param$1[/* hi */0] + overflow & 4294967295;
  return /* record */[
          /* hi */hi,
          /* lo */(lo >>> 0)
        ];
}

function not(param) {
  var hi = param[/* hi */0] ^ -1;
  var lo = param[/* lo */1] ^ -1;
  return /* record */[
          /* hi */hi,
          /* lo */(lo >>> 0)
        ];
}

function eq(x, y) {
  if (x[/* hi */0] === y[/* hi */0]) {
    return x[/* lo */1] === y[/* lo */1];
  } else {
    return false;
  }
}

function neg(x) {
  if (eq(x, min_int)) {
    return min_int;
  } else {
    return add(not(x), one);
  }
}

function sub(x, y) {
  return add(x, neg(y));
}

function lsl_(x, numBits) {
  if (numBits === 0) {
    return x;
  } else {
    var lo = x[/* lo */1];
    if (numBits >= 32) {
      return /* record */[
              /* hi */(lo << (numBits - 32 | 0)),
              /* lo */0
            ];
    } else {
      var hi = (lo >>> (32 - numBits | 0)) | (x[/* hi */0] << numBits);
      return /* record */[
              /* hi */hi,
              /* lo */((lo << numBits) >>> 0)
            ];
    }
  }
}

function asr_(x, numBits) {
  if (numBits === 0) {
    return x;
  } else {
    var hi = x[/* hi */0];
    if (numBits < 32) {
      var hi$1 = (hi >> numBits);
      var lo = (hi << (32 - numBits | 0)) | (x[/* lo */1] >>> numBits);
      return /* record */[
              /* hi */hi$1,
              /* lo */(lo >>> 0)
            ];
    } else {
      var lo$1 = (hi >> (numBits - 32 | 0));
      return /* record */[
              /* hi */hi >= 0 ? 0 : -1,
              /* lo */(lo$1 >>> 0)
            ];
    }
  }
}

function is_zero(param) {
  if (param[/* hi */0] !== 0 || param[/* lo */1] !== 0) {
    return false;
  } else {
    return true;
  }
}

function mul(_this, _other) {
  while(true) {
    var other = _other;
    var $$this = _this;
    var lo;
    var this_hi = $$this[/* hi */0];
    var exit = 0;
    var exit$1 = 0;
    var exit$2 = 0;
    if (this_hi !== 0 || $$this[/* lo */1] !== 0) {
      exit$2 = 4;
    } else {
      return zero;
    }
    if (exit$2 === 4) {
      if (other[/* hi */0] !== 0 || other[/* lo */1] !== 0) {
        exit$1 = 3;
      } else {
        return zero;
      }
    }
    if (exit$1 === 3) {
      if (this_hi !== -2147483648 || $$this[/* lo */1] !== 0) {
        exit = 2;
      } else {
        lo = other[/* lo */1];
      }
    }
    if (exit === 2) {
      var other_hi = other[/* hi */0];
      var lo$1 = $$this[/* lo */1];
      var exit$3 = 0;
      if (other_hi !== -2147483648 || other[/* lo */1] !== 0) {
        exit$3 = 3;
      } else {
        lo = lo$1;
      }
      if (exit$3 === 3) {
        var other_lo = other[/* lo */1];
        if (this_hi < 0) {
          if (other_hi < 0) {
            _other = neg(other);
            _this = neg($$this);
            continue ;
          } else {
            return neg(mul(neg($$this), other));
          }
        } else if (other_hi < 0) {
          return neg(mul($$this, neg(other)));
        } else {
          var a48 = (this_hi >>> 16);
          var a32 = this_hi & 65535;
          var a16 = (lo$1 >>> 16);
          var a00 = lo$1 & 65535;
          var b48 = (other_hi >>> 16);
          var b32 = other_hi & 65535;
          var b16 = (other_lo >>> 16);
          var b00 = other_lo & 65535;
          var c48 = 0;
          var c32 = 0;
          var c16 = 0;
          var c00 = a00 * b00;
          c16 = (c00 >>> 16) + a16 * b00;
          c32 = (c16 >>> 16);
          c16 = (c16 & 65535) + a00 * b16;
          c32 = c32 + (c16 >>> 16) + a32 * b00;
          c48 = (c32 >>> 16);
          c32 = (c32 & 65535) + a16 * b16;
          c48 += (c32 >>> 16);
          c32 = (c32 & 65535) + a00 * b32;
          c48 += (c32 >>> 16);
          c32 = c32 & 65535;
          c48 = c48 + (a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48) & 65535;
          var hi = c32 | (c48 << 16);
          var lo$2 = c00 & 65535 | ((c16 & 65535) << 16);
          return /* record */[
                  /* hi */hi,
                  /* lo */(lo$2 >>> 0)
                ];
        }
      }
      
    }
    if ((lo & 1) === 0) {
      return zero;
    } else {
      return min_int;
    }
  }}

function or_(param, param$1) {
  return /* record */[
          /* hi */param[/* hi */0] | param$1[/* hi */0],
          /* lo */((param[/* lo */1] | param$1[/* lo */1]) >>> 0)
        ];
}

function ge(param, param$1) {
  var other_hi = param$1[/* hi */0];
  var hi = param[/* hi */0];
  if (hi > other_hi) {
    return true;
  } else if (hi < other_hi) {
    return false;
  } else {
    return param[/* lo */1] >= param$1[/* lo */1];
  }
}

function neq(x, y) {
  return !eq(x, y);
}

function lt(x, y) {
  return !ge(x, y);
}

function gt(x, y) {
  if (x[/* hi */0] > y[/* hi */0]) {
    return true;
  } else if (x[/* hi */0] < y[/* hi */0]) {
    return false;
  } else {
    return x[/* lo */1] > y[/* lo */1];
  }
}

function le(x, y) {
  return !gt(x, y);
}

function to_float(param) {
  return param[/* hi */0] * (0x100000000) + param[/* lo */1];
}

function of_float(x) {
  if (isNaN(x) || !isFinite(x)) {
    return zero;
  } else if (x <= -9.22337203685477581e+18) {
    return min_int;
  } else if (x + 1 >= 9.22337203685477581e+18) {
    return max_int;
  } else if (x < 0) {
    return neg(of_float(-x));
  } else {
    var hi = x / 4294967296 | 0;
    var lo = x % 4294967296 | 0;
    return /* record */[
            /* hi */hi,
            /* lo */(lo >>> 0)
          ];
  }
}

function div(_self, _other) {
  while(true) {
    var other = _other;
    var self = _self;
    var self_hi = self[/* hi */0];
    var exit = 0;
    var exit$1 = 0;
    if (other[/* hi */0] !== 0 || other[/* lo */1] !== 0) {
      exit$1 = 2;
    } else {
      throw division_by_zero;
    }
    if (exit$1 === 2) {
      if (self_hi !== -2147483648) {
        if (self_hi !== 0 || self[/* lo */1] !== 0) {
          exit = 1;
        } else {
          return zero;
        }
      } else if (self[/* lo */1] !== 0) {
        exit = 1;
      } else if (eq(other, one) || eq(other, neg_one)) {
        return self;
      } else if (eq(other, min_int)) {
        return one;
      } else {
        var other_hi = other[/* hi */0];
        var half_this = asr_(self, 1);
        var approx = lsl_(div(half_this, other), 1);
        if (approx[/* hi */0] === 0 && approx[/* lo */1] === 0) {
          if (other_hi < 0) {
            return one;
          } else {
            return neg(one);
          }
        }
        var y = mul(other, approx);
        var rem = add(self, neg(y));
        return add(approx, div(rem, other));
      }
    }
    if (exit === 1) {
      var other_hi$1 = other[/* hi */0];
      if (other_hi$1 === -2147483648 && other[/* lo */1] === 0) {
        return zero;
      }
      if (self_hi < 0) {
        if (other_hi$1 < 0) {
          _other = neg(other);
          _self = neg(self);
          continue ;
        } else {
          return neg(div(neg(self), other));
        }
      } else if (other_hi$1 < 0) {
        return neg(div(self, neg(other)));
      } else {
        var res = zero;
        var rem$1 = self;
        while(ge(rem$1, other)) {
          var approx$1 = caml_float_max(1, Math.floor(to_float(rem$1) / to_float(other)));
          var log2 = Math.ceil(Math.log(approx$1) / Math.LN2);
          var delta = log2 <= 48 ? 1 : Math.pow(2, log2 - 48);
          var approxRes = of_float(approx$1);
          var approxRem = mul(approxRes, other);
          while(approxRem[/* hi */0] < 0 || gt(approxRem, rem$1)) {
            approx$1 -= delta;
            approxRes = of_float(approx$1);
            approxRem = mul(approxRes, other);
          }          if (is_zero(approxRes)) {
            approxRes = one;
          }
          res = add(res, approxRes);
          rem$1 = add(rem$1, neg(approxRem));
        }        return res;
      }
    }
    
  }}

function mod_(self, other) {
  var y = mul(div(self, other), other);
  return add(self, neg(y));
}

function div_mod(self, other) {
  var quotient = div(self, other);
  var y = mul(quotient, other);
  return /* tuple */[
          quotient,
          add(self, neg(y))
        ];
}

function of_int32(lo) {
  return /* record */[
          /* hi */lo < 0 ? -1 : 0,
          /* lo */(lo >>> 0)
        ];
}

function to_hex(x) {
  var x_lo = x[/* lo */1];
  var x_hi = x[/* hi */0];
  var aux = function (v) {
    return (v >>> 0).toString(16);
  };
  if (x_hi === 0 && x_lo === 0) {
    return "0";
  }
  if (x_lo !== 0) {
    if (x_hi !== 0) {
      var lo = aux(x_lo);
      var pad = 8 - lo.length | 0;
      if (pad <= 0) {
        return aux(x_hi) + lo;
      } else {
        return aux(x_hi) + (repeat(pad, "0") + lo);
      }
    } else {
      return aux(x_lo);
    }
  } else {
    return aux(x_hi) + "00000000";
  }
}

function discard_sign(x) {
  return /* record */[
          /* hi */2147483647 & x[/* hi */0],
          /* lo */x[/* lo */1]
        ];
}
/* Caml_int32 Not a pure module */

function parse_digit(c) {
  if (c >= 65) {
    if (c >= 97) {
      if (c >= 123) {
        return -1;
      } else {
        return c - 87 | 0;
      }
    } else if (c >= 91) {
      return -1;
    } else {
      return c - 55 | 0;
    }
  } else if (c > 57 || c < 48) {
    return -1;
  } else {
    return c - /* "0" */48 | 0;
  }
}

function int_of_string_base(param) {
  switch (param) {
    case /* Oct */0 :
        return 8;
    case /* Hex */1 :
        return 16;
    case /* Dec */2 :
        return 10;
    case /* Bin */3 :
        return 2;
    
  }
}

function parse_sign_and_base(s) {
  var sign = 1;
  var base = /* Dec */2;
  var i = 0;
  var match = s.charCodeAt(i);
  switch (match) {
    case 43 :
        i = i + 1 | 0;
        break;
    case 44 :
        break;
    case 45 :
        sign = -1;
        i = i + 1 | 0;
        break;
      
  }
  if (s[i] === "0") {
    var match$1 = s.charCodeAt(i + 1 | 0);
    if (match$1 >= 89) {
      if (match$1 >= 111) {
        if (match$1 < 121) {
          switch (match$1 - 111 | 0) {
            case 0 :
                base = /* Oct */0;
                i = i + 2 | 0;
                break;
            case 6 :
                i = i + 2 | 0;
                break;
            case 1 :
            case 2 :
            case 3 :
            case 4 :
            case 5 :
            case 7 :
            case 8 :
                break;
            case 9 :
                base = /* Hex */1;
                i = i + 2 | 0;
                break;
            
          }
        }
        
      } else if (match$1 === 98) {
        base = /* Bin */3;
        i = i + 2 | 0;
      }
      
    } else if (match$1 !== 66) {
      if (match$1 >= 79) {
        switch (match$1 - 79 | 0) {
          case 0 :
              base = /* Oct */0;
              i = i + 2 | 0;
              break;
          case 6 :
              i = i + 2 | 0;
              break;
          case 1 :
          case 2 :
          case 3 :
          case 4 :
          case 5 :
          case 7 :
          case 8 :
              break;
          case 9 :
              base = /* Hex */1;
              i = i + 2 | 0;
              break;
          
        }
      }
      
    } else {
      base = /* Bin */3;
      i = i + 2 | 0;
    }
  }
  return /* tuple */[
          i,
          sign,
          base
        ];
}

function caml_int_of_string(s) {
  var match = parse_sign_and_base(s);
  var i = match[0];
  var base = int_of_string_base(match[2]);
  var threshold = 4294967295;
  var len = s.length;
  var c = i < len ? s.charCodeAt(i) : /* "\000" */0;
  var d = parse_digit(c);
  if (d < 0 || d >= base) {
    throw [
          failure,
          "int_of_string"
        ];
  }
  var aux = function (_acc, _k) {
    while(true) {
      var k = _k;
      var acc = _acc;
      if (k === len) {
        return acc;
      } else {
        var a = s.charCodeAt(k);
        if (a === /* "_" */95) {
          _k = k + 1 | 0;
          continue ;
        } else {
          var v = parse_digit(a);
          if (v < 0 || v >= base) {
            throw [
                  failure,
                  "int_of_string"
                ];
          }
          var acc$1 = base * acc + v;
          if (acc$1 > threshold) {
            throw [
                  failure,
                  "int_of_string"
                ];
          }
          _k = k + 1 | 0;
          _acc = acc$1;
          continue ;
        }
      }
    }  };
  var res = match[1] * aux(d, i + 1 | 0);
  var or_res = res | 0;
  if (base === 10 && res !== or_res) {
    throw [
          failure,
          "int_of_string"
        ];
  }
  return or_res;
}

function int_of_base(param) {
  switch (param) {
    case /* Oct */0 :
        return 8;
    case /* Hex */1 :
        return 16;
    case /* Dec */2 :
        return 10;
    
  }
}

function lowercase(c) {
  if (c >= /* "A" */65 && c <= /* "Z" */90 || c >= /* "\192" */192 && c <= /* "\214" */214 || c >= /* "\216" */216 && c <= /* "\222" */222) {
    return c + 32 | 0;
  } else {
    return c;
  }
}

function parse_format(fmt) {
  var len = fmt.length;
  if (len > 31) {
    throw [
          invalid_argument,
          "format_int: format too long"
        ];
  }
  var f = /* record */[
    /* justify */"+",
    /* signstyle */"-",
    /* filter */" ",
    /* alternate */false,
    /* base : Dec */2,
    /* signedconv */false,
    /* width */0,
    /* uppercase */false,
    /* sign */1,
    /* prec */-1,
    /* conv */"f"
  ];
  var _i = 0;
  while(true) {
    var i = _i;
    if (i >= len) {
      return f;
    } else {
      var c = fmt.charCodeAt(i);
      var exit = 0;
      if (c >= 69) {
        if (c >= 88) {
          if (c >= 121) {
            exit = 1;
          } else {
            switch (c - 88 | 0) {
              case 0 :
                  f[/* base */4] = /* Hex */1;
                  f[/* uppercase */7] = true;
                  _i = i + 1 | 0;
                  continue ;
              case 13 :
              case 14 :
              case 15 :
                  exit = 5;
                  break;
              case 12 :
              case 17 :
                  exit = 4;
                  break;
              case 23 :
                  f[/* base */4] = /* Oct */0;
                  _i = i + 1 | 0;
                  continue ;
              case 29 :
                  f[/* base */4] = /* Dec */2;
                  _i = i + 1 | 0;
                  continue ;
              case 1 :
              case 2 :
              case 3 :
              case 4 :
              case 5 :
              case 6 :
              case 7 :
              case 8 :
              case 9 :
              case 10 :
              case 11 :
              case 16 :
              case 18 :
              case 19 :
              case 20 :
              case 21 :
              case 22 :
              case 24 :
              case 25 :
              case 26 :
              case 27 :
              case 28 :
              case 30 :
              case 31 :
                  exit = 1;
                  break;
              case 32 :
                  f[/* base */4] = /* Hex */1;
                  _i = i + 1 | 0;
                  continue ;
              
            }
          }
        } else if (c >= 72) {
          exit = 1;
        } else {
          f[/* signedconv */5] = true;
          f[/* uppercase */7] = true;
          f[/* conv */10] = String.fromCharCode(lowercase(c));
          _i = i + 1 | 0;
          continue ;
        }
      } else {
        switch (c) {
          case 35 :
              f[/* alternate */3] = true;
              _i = i + 1 | 0;
              continue ;
          case 32 :
          case 43 :
              exit = 2;
              break;
          case 45 :
              f[/* justify */0] = "-";
              _i = i + 1 | 0;
              continue ;
          case 46 :
              f[/* prec */9] = 0;
              var j = i + 1 | 0;
              while((function(j){
                  return function () {
                    var w = fmt.charCodeAt(j) - /* "0" */48 | 0;
                    return w >= 0 && w <= 9;
                  }
                  }(j))()) {
                f[/* prec */9] = (imul(f[/* prec */9], 10) + fmt.charCodeAt(j) | 0) - /* "0" */48 | 0;
                j = j + 1 | 0;
              }              _i = j;
              continue ;
          case 33 :
          case 34 :
          case 36 :
          case 37 :
          case 38 :
          case 39 :
          case 40 :
          case 41 :
          case 42 :
          case 44 :
          case 47 :
              exit = 1;
              break;
          case 48 :
              f[/* filter */2] = "0";
              _i = i + 1 | 0;
              continue ;
          case 49 :
          case 50 :
          case 51 :
          case 52 :
          case 53 :
          case 54 :
          case 55 :
          case 56 :
          case 57 :
              exit = 3;
              break;
          default:
            exit = 1;
        }
      }
      switch (exit) {
        case 1 :
            _i = i + 1 | 0;
            continue ;
        case 2 :
            f[/* signstyle */1] = String.fromCharCode(c);
            _i = i + 1 | 0;
            continue ;
        case 3 :
            f[/* width */6] = 0;
            var j$1 = i;
            while((function(j$1){
                return function () {
                  var w = fmt.charCodeAt(j$1) - /* "0" */48 | 0;
                  return w >= 0 && w <= 9;
                }
                }(j$1))()) {
              f[/* width */6] = (imul(f[/* width */6], 10) + fmt.charCodeAt(j$1) | 0) - /* "0" */48 | 0;
              j$1 = j$1 + 1 | 0;
            }            _i = j$1;
            continue ;
        case 4 :
            f[/* signedconv */5] = true;
            f[/* base */4] = /* Dec */2;
            _i = i + 1 | 0;
            continue ;
        case 5 :
            f[/* signedconv */5] = true;
            f[/* conv */10] = String.fromCharCode(c);
            _i = i + 1 | 0;
            continue ;
        
      }
    }
  }}

function finish_formatting(config, rawbuffer) {
  var justify = config[/* justify */0];
  var signstyle = config[/* signstyle */1];
  var filter = config[/* filter */2];
  var alternate = config[/* alternate */3];
  var base = config[/* base */4];
  var signedconv = config[/* signedconv */5];
  var width = config[/* width */6];
  var uppercase = config[/* uppercase */7];
  var sign = config[/* sign */8];
  var len = rawbuffer.length;
  if (signedconv && (sign < 0 || signstyle !== "-")) {
    len = len + 1 | 0;
  }
  if (alternate) {
    if (base === /* Oct */0) {
      len = len + 1 | 0;
    } else if (base === /* Hex */1) {
      len = len + 2 | 0;
    }
    
  }
  var buffer = "";
  if (justify === "+" && filter === " ") {
    for(var i = len ,i_finish = width - 1 | 0; i <= i_finish; ++i){
      buffer = buffer + filter;
    }
  }
  if (signedconv) {
    if (sign < 0) {
      buffer = buffer + "-";
    } else if (signstyle !== "-") {
      buffer = buffer + signstyle;
    }
    
  }
  if (alternate && base === /* Oct */0) {
    buffer = buffer + "0";
  }
  if (alternate && base === /* Hex */1) {
    buffer = buffer + "0x";
  }
  if (justify === "+" && filter === "0") {
    for(var i$1 = len ,i_finish$1 = width - 1 | 0; i$1 <= i_finish$1; ++i$1){
      buffer = buffer + filter;
    }
  }
  buffer = uppercase ? buffer + rawbuffer.toUpperCase() : buffer + rawbuffer;
  if (justify === "-") {
    for(var i$2 = len ,i_finish$2 = width - 1 | 0; i$2 <= i_finish$2; ++i$2){
      buffer = buffer + " ";
    }
  }
  return buffer;
}

function caml_format_int(fmt, i) {
  if (fmt === "%d") {
    return String(i);
  } else {
    var f = parse_format(fmt);
    var f$1 = f;
    var i$1 = i;
    var i$2 = i$1 < 0 ? (
        f$1[/* signedconv */5] ? (f$1[/* sign */8] = -1, -i$1) : (i$1 >>> 0)
      ) : i$1;
    var s = i$2.toString(int_of_base(f$1[/* base */4]));
    if (f$1[/* prec */9] >= 0) {
      f$1[/* filter */2] = " ";
      var n = f$1[/* prec */9] - s.length | 0;
      if (n > 0) {
        s = repeat(n, "0") + s;
      }
      
    }
    return finish_formatting(f$1, s);
  }
}

function caml_int64_format(fmt, x) {
  var f = parse_format(fmt);
  var x$1 = f[/* signedconv */5] && lt(x, /* int64 */[
        /* hi */0,
        /* lo */0
      ]) ? (f[/* sign */8] = -1, neg(x)) : x;
  var s = "";
  var match = f[/* base */4];
  switch (match) {
    case /* Oct */0 :
        var wbase = /* int64 */[
          /* hi */0,
          /* lo */8
        ];
        var cvtbl = "01234567";
        if (lt(x$1, /* int64 */[
                /* hi */0,
                /* lo */0
              ])) {
          var y = discard_sign(x$1);
          var match$1 = div_mod(y, wbase);
          var quotient = add(/* int64 */[
                /* hi */268435456,
                /* lo */0
              ], match$1[0]);
          var modulus = match$1[1];
          s = String.fromCharCode(cvtbl.charCodeAt(modulus[1] | 0)) + s;
          while(neq(quotient, /* int64 */[
                  /* hi */0,
                  /* lo */0
                ])) {
            var match$2 = div_mod(quotient, wbase);
            quotient = match$2[0];
            modulus = match$2[1];
            s = String.fromCharCode(cvtbl.charCodeAt(modulus[1] | 0)) + s;
          }        } else {
          var match$3 = div_mod(x$1, wbase);
          var quotient$1 = match$3[0];
          var modulus$1 = match$3[1];
          s = String.fromCharCode(cvtbl.charCodeAt(modulus$1[1] | 0)) + s;
          while(neq(quotient$1, /* int64 */[
                  /* hi */0,
                  /* lo */0
                ])) {
            var match$4 = div_mod(quotient$1, wbase);
            quotient$1 = match$4[0];
            modulus$1 = match$4[1];
            s = String.fromCharCode(cvtbl.charCodeAt(modulus$1[1] | 0)) + s;
          }        }
        break;
    case /* Hex */1 :
        s = to_hex(x$1) + s;
        break;
    case /* Dec */2 :
        var wbase$1 = /* int64 */[
          /* hi */0,
          /* lo */10
        ];
        var cvtbl$1 = "0123456789";
        if (lt(x$1, /* int64 */[
                /* hi */0,
                /* lo */0
              ])) {
          var y$1 = discard_sign(x$1);
          var match$5 = div_mod(y$1, wbase$1);
          var match$6 = div_mod(add(/* int64 */[
                    /* hi */0,
                    /* lo */8
                  ], match$5[1]), wbase$1);
          var quotient$2 = add(add(/* int64 */[
                    /* hi */214748364,
                    /* lo */3435973836
                  ], match$5[0]), match$6[0]);
          var modulus$2 = match$6[1];
          s = String.fromCharCode(cvtbl$1.charCodeAt(modulus$2[1] | 0)) + s;
          while(neq(quotient$2, /* int64 */[
                  /* hi */0,
                  /* lo */0
                ])) {
            var match$7 = div_mod(quotient$2, wbase$1);
            quotient$2 = match$7[0];
            modulus$2 = match$7[1];
            s = String.fromCharCode(cvtbl$1.charCodeAt(modulus$2[1] | 0)) + s;
          }        } else {
          var match$8 = div_mod(x$1, wbase$1);
          var quotient$3 = match$8[0];
          var modulus$3 = match$8[1];
          s = String.fromCharCode(cvtbl$1.charCodeAt(modulus$3[1] | 0)) + s;
          while(neq(quotient$3, /* int64 */[
                  /* hi */0,
                  /* lo */0
                ])) {
            var match$9 = div_mod(quotient$3, wbase$1);
            quotient$3 = match$9[0];
            modulus$3 = match$9[1];
            s = String.fromCharCode(cvtbl$1.charCodeAt(modulus$3[1] | 0)) + s;
          }        }
        break;
    
  }
  if (f[/* prec */9] >= 0) {
    f[/* filter */2] = " ";
    var n = f[/* prec */9] - s.length | 0;
    if (n > 0) {
      s = repeat(n, "0") + s;
    }
    
  }
  return finish_formatting(f, s);
}

function caml_format_float(fmt, x) {
  var f = parse_format(fmt);
  var prec = f[/* prec */9] < 0 ? 6 : f[/* prec */9];
  var x$1 = x < 0 ? (f[/* sign */8] = -1, -x) : x;
  var s = "";
  if (isNaN(x$1)) {
    s = "nan";
    f[/* filter */2] = " ";
  } else if (isFinite(x$1)) {
    var match = f[/* conv */10];
    switch (match) {
      case "e" :
          s = x$1.toExponential(prec);
          var i = s.length;
          if (s[i - 3 | 0] === "e") {
            s = s.slice(0, i - 1 | 0) + ("0" + s.slice(i - 1 | 0));
          }
          break;
      case "f" :
          s = x$1.toFixed(prec);
          break;
      case "g" :
          var prec$1 = prec !== 0 ? prec : 1;
          s = x$1.toExponential(prec$1 - 1 | 0);
          var j = s.indexOf("e");
          var exp = Number(s.slice(j + 1 | 0)) | 0;
          if (exp < -4 || x$1 >= 1e21 || x$1.toFixed().length > prec$1) {
            var i$1 = j - 1 | 0;
            while(s[i$1] === "0") {
              i$1 = i$1 - 1 | 0;
            }            if (s[i$1] === ".") {
              i$1 = i$1 - 1 | 0;
            }
            s = s.slice(0, i$1 + 1 | 0) + s.slice(j);
            var i$2 = s.length;
            if (s[i$2 - 3 | 0] === "e") {
              s = s.slice(0, i$2 - 1 | 0) + ("0" + s.slice(i$2 - 1 | 0));
            }
            
          } else {
            var p = prec$1;
            if (exp < 0) {
              p = p - (exp + 1 | 0) | 0;
              s = x$1.toFixed(p);
            } else {
              while((function () {
                      s = x$1.toFixed(p);
                      return s.length > (prec$1 + 1 | 0);
                    })()) {
                p = p - 1 | 0;
              }            }
            if (p !== 0) {
              var k = s.length - 1 | 0;
              while(s[k] === "0") {
                k = k - 1 | 0;
              }              if (s[k] === ".") {
                k = k - 1 | 0;
              }
              s = s.slice(0, k + 1 | 0);
            }
            
          }
          break;
        
    }
  } else {
    s = "inf";
    f[/* filter */2] = " ";
  }
  return finish_formatting(f, s);
}

var caml_nativeint_format = caml_format_int;

var caml_int32_format = caml_format_int;
/* No side effect */

function get(s, i) {
  if (i < 0 || i >= s.length) {
    throw [
          invalid_argument,
          "index out of bounds"
        ];
  }
  return s.charCodeAt(i);
}
/* No side effect */

var id = /* record */[/* contents */0];

function caml_fresh_oo_id(param) {
  id[0] += 1;
  return id[0];
}

function create(str) {
  var v_001 = caml_fresh_oo_id();
  var v = /* tuple */[
    str,
    v_001
  ];
  v.tag = 248;
  return v;
}

function caml_is_extension(e) {
  if (e === undefined) {
    return false;
  } else if (e.tag === 248) {
    return true;
  } else {
    var slot = e[0];
    if (slot !== undefined) {
      return slot.tag === 248;
    } else {
      return false;
    }
  }
}
/* No side effect */

function getGlobalThis (){
  if (typeof globalThis !== 'undefined') return globalThis;
	if (typeof self !== 'undefined') return self;
	if (typeof window !== 'undefined') return window;
	if (typeof global !== 'undefined') return global;
	if (typeof this !== 'undefined') return this;
	throw new Error('Unable to locate global `this`');
}
function resolve (s){
  var myGlobal = getGlobalThis();
  if (myGlobal[s] === undefined){
    throw new Error(s + " not polyfilled by BuckleScript yet\n")
  }
  return myGlobal[s]
}/* No side effect */

function erase_rel(param) {
  if (typeof param === "number") {
    return /* End_of_fmtty */0;
  } else {
    switch (param.tag | 0) {
      case /* Char_ty */0 :
          return /* Char_ty */__(0, [erase_rel(param[0])]);
      case /* String_ty */1 :
          return /* String_ty */__(1, [erase_rel(param[0])]);
      case /* Int_ty */2 :
          return /* Int_ty */__(2, [erase_rel(param[0])]);
      case /* Int32_ty */3 :
          return /* Int32_ty */__(3, [erase_rel(param[0])]);
      case /* Nativeint_ty */4 :
          return /* Nativeint_ty */__(4, [erase_rel(param[0])]);
      case /* Int64_ty */5 :
          return /* Int64_ty */__(5, [erase_rel(param[0])]);
      case /* Float_ty */6 :
          return /* Float_ty */__(6, [erase_rel(param[0])]);
      case /* Bool_ty */7 :
          return /* Bool_ty */__(7, [erase_rel(param[0])]);
      case /* Format_arg_ty */8 :
          return /* Format_arg_ty */__(8, [
                    param[0],
                    erase_rel(param[1])
                  ]);
      case /* Format_subst_ty */9 :
          var ty1 = param[0];
          return /* Format_subst_ty */__(9, [
                    ty1,
                    ty1,
                    erase_rel(param[2])
                  ]);
      case /* Alpha_ty */10 :
          return /* Alpha_ty */__(10, [erase_rel(param[0])]);
      case /* Theta_ty */11 :
          return /* Theta_ty */__(11, [erase_rel(param[0])]);
      case /* Any_ty */12 :
          return /* Any_ty */__(12, [erase_rel(param[0])]);
      case /* Reader_ty */13 :
          return /* Reader_ty */__(13, [erase_rel(param[0])]);
      case /* Ignored_reader_ty */14 :
          return /* Ignored_reader_ty */__(14, [erase_rel(param[0])]);
      
    }
  }
}

function concat_fmtty(fmtty1, fmtty2) {
  if (typeof fmtty1 === "number") {
    return fmtty2;
  } else {
    switch (fmtty1.tag | 0) {
      case /* Char_ty */0 :
          return /* Char_ty */__(0, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* String_ty */1 :
          return /* String_ty */__(1, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Int_ty */2 :
          return /* Int_ty */__(2, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Int32_ty */3 :
          return /* Int32_ty */__(3, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Nativeint_ty */4 :
          return /* Nativeint_ty */__(4, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Int64_ty */5 :
          return /* Int64_ty */__(5, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Float_ty */6 :
          return /* Float_ty */__(6, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Bool_ty */7 :
          return /* Bool_ty */__(7, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Format_arg_ty */8 :
          return /* Format_arg_ty */__(8, [
                    fmtty1[0],
                    concat_fmtty(fmtty1[1], fmtty2)
                  ]);
      case /* Format_subst_ty */9 :
          return /* Format_subst_ty */__(9, [
                    fmtty1[0],
                    fmtty1[1],
                    concat_fmtty(fmtty1[2], fmtty2)
                  ]);
      case /* Alpha_ty */10 :
          return /* Alpha_ty */__(10, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Theta_ty */11 :
          return /* Theta_ty */__(11, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Any_ty */12 :
          return /* Any_ty */__(12, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Reader_ty */13 :
          return /* Reader_ty */__(13, [concat_fmtty(fmtty1[0], fmtty2)]);
      case /* Ignored_reader_ty */14 :
          return /* Ignored_reader_ty */__(14, [concat_fmtty(fmtty1[0], fmtty2)]);
      
    }
  }
}

function concat_fmt(fmt1, fmt2) {
  if (typeof fmt1 === "number") {
    return fmt2;
  } else {
    switch (fmt1.tag | 0) {
      case /* Char */0 :
          return /* Char */__(0, [concat_fmt(fmt1[0], fmt2)]);
      case /* Caml_char */1 :
          return /* Caml_char */__(1, [concat_fmt(fmt1[0], fmt2)]);
      case /* String */2 :
          return /* String */__(2, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Caml_string */3 :
          return /* Caml_string */__(3, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Int */4 :
          return /* Int */__(4, [
                    fmt1[0],
                    fmt1[1],
                    fmt1[2],
                    concat_fmt(fmt1[3], fmt2)
                  ]);
      case /* Int32 */5 :
          return /* Int32 */__(5, [
                    fmt1[0],
                    fmt1[1],
                    fmt1[2],
                    concat_fmt(fmt1[3], fmt2)
                  ]);
      case /* Nativeint */6 :
          return /* Nativeint */__(6, [
                    fmt1[0],
                    fmt1[1],
                    fmt1[2],
                    concat_fmt(fmt1[3], fmt2)
                  ]);
      case /* Int64 */7 :
          return /* Int64 */__(7, [
                    fmt1[0],
                    fmt1[1],
                    fmt1[2],
                    concat_fmt(fmt1[3], fmt2)
                  ]);
      case /* Float */8 :
          return /* Float */__(8, [
                    fmt1[0],
                    fmt1[1],
                    fmt1[2],
                    concat_fmt(fmt1[3], fmt2)
                  ]);
      case /* Bool */9 :
          return /* Bool */__(9, [concat_fmt(fmt1[0], fmt2)]);
      case /* Flush */10 :
          return /* Flush */__(10, [concat_fmt(fmt1[0], fmt2)]);
      case /* String_literal */11 :
          return /* String_literal */__(11, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Char_literal */12 :
          return /* Char_literal */__(12, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Format_arg */13 :
          return /* Format_arg */__(13, [
                    fmt1[0],
                    fmt1[1],
                    concat_fmt(fmt1[2], fmt2)
                  ]);
      case /* Format_subst */14 :
          return /* Format_subst */__(14, [
                    fmt1[0],
                    fmt1[1],
                    concat_fmt(fmt1[2], fmt2)
                  ]);
      case /* Alpha */15 :
          return /* Alpha */__(15, [concat_fmt(fmt1[0], fmt2)]);
      case /* Theta */16 :
          return /* Theta */__(16, [concat_fmt(fmt1[0], fmt2)]);
      case /* Formatting_lit */17 :
          return /* Formatting_lit */__(17, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Formatting_gen */18 :
          return /* Formatting_gen */__(18, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Reader */19 :
          return /* Reader */__(19, [concat_fmt(fmt1[0], fmt2)]);
      case /* Scan_char_set */20 :
          return /* Scan_char_set */__(20, [
                    fmt1[0],
                    fmt1[1],
                    concat_fmt(fmt1[2], fmt2)
                  ]);
      case /* Scan_get_counter */21 :
          return /* Scan_get_counter */__(21, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Scan_next_char */22 :
          return /* Scan_next_char */__(22, [concat_fmt(fmt1[0], fmt2)]);
      case /* Ignored_param */23 :
          return /* Ignored_param */__(23, [
                    fmt1[0],
                    concat_fmt(fmt1[1], fmt2)
                  ]);
      case /* Custom */24 :
          return /* Custom */__(24, [
                    fmt1[0],
                    fmt1[1],
                    concat_fmt(fmt1[2], fmt2)
                  ]);
      
    }
  }
}
/* No side effect */

function failwith(s) {
  throw [
        failure,
        s
      ];
}

function invalid_arg(s) {
  throw [
        invalid_argument,
        s
      ];
}

var Exit = create("Pervasives.Exit");

function abs(x) {
  if (x >= 0) {
    return x;
  } else {
    return -x | 0;
  }
}

function lnot(x) {
  return x ^ -1;
}

function classify_float(x) {
  if (isFinite(x)) {
    if (Math.abs(x) >= 2.2250738585072014e-308) {
      return /* FP_normal */0;
    } else if (x !== 0) {
      return /* FP_subnormal */1;
    } else {
      return /* FP_zero */2;
    }
  } else if (isNaN(x)) {
    return /* FP_nan */4;
  } else {
    return /* FP_infinite */3;
  }
}

function valid_float_lexem(s) {
  var l = s.length;
  var _i = 0;
  while(true) {
    var i = _i;
    if (i >= l) {
      return s + ".";
    } else {
      var match = get(s, i);
      if (match >= 48) {
        if (match >= 58) {
          return s;
        } else {
          _i = i + 1 | 0;
          continue ;
        }
      } else if (match !== 45) {
        return s;
      } else {
        _i = i + 1 | 0;
        continue ;
      }
    }
  }}

function string_of_float(f) {
  return valid_float_lexem(caml_format_float("%.12g", f));
}

function $at(l1, l2) {
  if (l1) {
    return /* :: */[
            l1[0],
            $at(l1[1], l2)
          ];
  } else {
    return l2;
  }
}

var stdout$1 = stdout;

var stderr$1 = stderr;

function flush_all(param) {
  var _param = caml_ml_out_channels_list();
  while(true) {
    var param$1 = _param;
    if (param$1) {
      try {
        caml_ml_flush(param$1[0]);
      }
      catch (exn){
        
      }
      _param = param$1[1];
      continue ;
    } else {
      return /* () */0;
    }
  }}

function output_string(oc, s) {
  return caml_ml_output(oc, s, 0, s.length);
}

function output_substring(oc, s, ofs, len) {
  if (ofs < 0 || len < 0 || ofs > (s.length - len | 0)) {
    throw [
          invalid_argument,
          "output_substring"
        ];
  }
  return caml_ml_output(oc, s, ofs, len);
}

function input(ic, s, ofs, len) {
  if (ofs < 0 || len < 0 || ofs > (s.length - len | 0)) {
    throw [
          invalid_argument,
          "input"
        ];
  }
  return resolve("caml_ml_input")(ic, s, ofs, len);
}

var exit_function = /* record */[/* contents */flush_all];

function at_exit(f) {
  var g = exit_function[0];
  exit_function[0] = (function (param) {
      _1(f, /* () */0);
      return _1(g, /* () */0);
    });
  return /* () */0;
}

var max_int$1 = 2147483647;

function input_char(prim) {
  return resolve("caml_ml_input_char")(prim);
}
/* No side effect */

function hd(param) {
  if (param) {
    return param[0];
  } else {
    throw [
          failure,
          "hd"
        ];
  }
}

function rev_append(_l1, _l2) {
  while(true) {
    var l2 = _l2;
    var l1 = _l1;
    if (l1) {
      _l2 = /* :: */[
        l1[0],
        l2
      ];
      _l1 = l1[1];
      continue ;
    } else {
      return l2;
    }
  }}

function rev(l) {
  return rev_append(l, /* [] */0);
}

function map(f, param) {
  if (param) {
    var r = _1(f, param[0]);
    return /* :: */[
            r,
            map(f, param[1])
          ];
  } else {
    return /* [] */0;
  }
}

function iter(f, _param) {
  while(true) {
    var param = _param;
    if (param) {
      _1(f, param[0]);
      _param = param[1];
      continue ;
    } else {
      return /* () */0;
    }
  }}

function iteri(f, l) {
  var _i = 0;
  var f$1 = f;
  var _param = l;
  while(true) {
    var param = _param;
    var i = _i;
    if (param) {
      _2(f$1, i, param[0]);
      _param = param[1];
      _i = i + 1 | 0;
      continue ;
    } else {
      return /* () */0;
    }
  }}

function exists(p, _param) {
  while(true) {
    var param = _param;
    if (param) {
      if (_1(p, param[0])) {
        return true;
      } else {
        _param = param[1];
        continue ;
      }
    } else {
      return false;
    }
  }}

function assoc(x, _param) {
  while(true) {
    var param = _param;
    if (param) {
      var match = param[0];
      if (caml_equal(match[0], x)) {
        return match[1];
      } else {
        _param = param[1];
        continue ;
      }
    } else {
      throw not_found;
    }
  }}
/* No side effect */

var undefinedHeader = /* array */[];

function some(x) {
  if (x === undefined) {
    var block = /* tuple */[
      undefinedHeader,
      0
    ];
    block.tag = 256;
    return block;
  } else if (x !== null && x[0] === undefinedHeader) {
    var nid = x[1] + 1 | 0;
    var block$1 = /* tuple */[
      undefinedHeader,
      nid
    ];
    block$1.tag = 256;
    return block$1;
  } else {
    return x;
  }
}

function undefined_to_opt(x) {
  if (x === undefined) {
    return ;
  } else {
    return some(x);
  }
}

function valFromOption(x) {
  if (x !== null && x[0] === undefinedHeader) {
    var depth = x[1];
    if (depth === 0) {
      return ;
    } else {
      return /* tuple */[
              undefinedHeader,
              depth - 1 | 0
            ];
    }
  } else {
    return x;
  }
}
/* No side effect */

var $$Error = create("Caml_js_exceptions.Error");

function internalToOCamlException(e) {
  if (caml_is_extension(e)) {
    return e;
  } else {
    return [
            $$Error,
            e
          ];
  }
}
/* No side effect */

function init(l, f) {
  if (l === 0) {
    return /* array */[];
  } else {
    if (l < 0) {
      throw [
            invalid_argument,
            "Array.init"
          ];
    }
    var res = caml_make_vect(l, _1(f, 0));
    for(var i = 1 ,i_finish = l - 1 | 0; i <= i_finish; ++i){
      res[i] = _1(f, i);
    }
    return res;
  }
}

function blit(a1, ofs1, a2, ofs2, len) {
  if (len < 0 || ofs1 < 0 || ofs1 > (a1.length - len | 0) || ofs2 < 0 || ofs2 > (a2.length - len | 0)) {
    throw [
          invalid_argument,
          "Array.blit"
        ];
  }
  return caml_array_blit(a1, ofs1, a2, ofs2, len);
}

function iter$1(f, a) {
  for(var i = 0 ,i_finish = a.length - 1 | 0; i <= i_finish; ++i){
    _1(f, a[i]);
  }
  return /* () */0;
}

function map$1(f, a) {
  var l = a.length;
  if (l === 0) {
    return /* array */[];
  } else {
    var r = caml_make_vect(l, _1(f, a[0]));
    for(var i = 1 ,i_finish = l - 1 | 0; i <= i_finish; ++i){
      r[i] = _1(f, a[i]);
    }
    return r;
  }
}

function list_length(_accu, _param) {
  while(true) {
    var param = _param;
    var accu = _accu;
    if (param) {
      _param = param[1];
      _accu = accu + 1 | 0;
      continue ;
    } else {
      return accu;
    }
  }}

function of_list(l) {
  if (l) {
    var a = caml_make_vect(list_length(0, l), l[0]);
    var _i = 1;
    var _param = l[1];
    while(true) {
      var param = _param;
      var i = _i;
      if (param) {
        a[i] = param[0];
        _param = param[1];
        _i = i + 1 | 0;
        continue ;
      } else {
        return a;
      }
    }  } else {
    return /* array */[];
  }
}

var Bottom = create("Array.Bottom");
/* No side effect */

function chr(n) {
  if (n < 0 || n > 255) {
    throw [
          invalid_argument,
          "Char.chr"
        ];
  }
  return n;
}

function escaped(c) {
  var exit = 0;
  if (c >= 40) {
    if (c !== 92) {
      exit = c >= 127 ? 1 : 2;
    } else {
      return "\\\\";
    }
  } else if (c >= 32) {
    if (c >= 39) {
      return "\\'";
    } else {
      exit = 2;
    }
  } else if (c >= 14) {
    exit = 1;
  } else {
    switch (c) {
      case 8 :
          return "\\b";
      case 9 :
          return "\\t";
      case 10 :
          return "\\n";
      case 0 :
      case 1 :
      case 2 :
      case 3 :
      case 4 :
      case 5 :
      case 6 :
      case 7 :
      case 11 :
      case 12 :
          exit = 1;
          break;
      case 13 :
          return "\\r";
      
    }
  }
  switch (exit) {
    case 1 :
        var s = [
          0,
          0,
          0,
          0
        ];
        s[0] = /* "\\" */92;
        s[1] = 48 + (c / 100 | 0) | 0;
        s[2] = 48 + (c / 10 | 0) % 10 | 0;
        s[3] = 48 + c % 10 | 0;
        return bytes_to_string(s);
    case 2 :
        var s$1 = [0];
        s$1[0] = c;
        return bytes_to_string(s$1);
    
  }
}
/* No side effect */

function make(n, c) {
  var s = caml_create_bytes(n);
  caml_fill_bytes(s, 0, n, c);
  return s;
}

function copy(s) {
  var len = s.length;
  var r = caml_create_bytes(len);
  caml_blit_bytes(s, 0, r, 0, len);
  return r;
}

function of_string(s) {
  return copy(bytes_of_string(s));
}

function sub$1(s, ofs, len) {
  if (ofs < 0 || len < 0 || ofs > (s.length - len | 0)) {
    throw [
          invalid_argument,
          "String.sub / Bytes.sub"
        ];
  }
  var r = caml_create_bytes(len);
  caml_blit_bytes(s, ofs, r, 0, len);
  return r;
}

function sub_string(b, ofs, len) {
  return bytes_to_string(sub$1(b, ofs, len));
}

function blit$1(s1, ofs1, s2, ofs2, len) {
  if (len < 0 || ofs1 < 0 || ofs1 > (s1.length - len | 0) || ofs2 < 0 || ofs2 > (s2.length - len | 0)) {
    throw [
          invalid_argument,
          "Bytes.blit"
        ];
  }
  return caml_blit_bytes(s1, ofs1, s2, ofs2, len);
}

function blit_string(s1, ofs1, s2, ofs2, len) {
  if (len < 0 || ofs1 < 0 || ofs1 > (s1.length - len | 0) || ofs2 < 0 || ofs2 > (s2.length - len | 0)) {
    throw [
          invalid_argument,
          "String.blit / Bytes.blit_string"
        ];
  }
  return caml_blit_string(s1, ofs1, s2, ofs2, len);
}

function escaped$1(s) {
  var n = 0;
  for(var i = 0 ,i_finish = s.length - 1 | 0; i <= i_finish; ++i){
    var match = s[i];
    var tmp;
    if (match >= 32) {
      var switcher = match - 34 | 0;
      tmp = switcher > 58 || switcher < 0 ? (
          switcher >= 93 ? 4 : 1
        ) : (
          switcher > 57 || switcher < 1 ? 2 : 1
        );
    } else {
      tmp = match >= 11 ? (
          match !== 13 ? 4 : 2
        ) : (
          match >= 8 ? 2 : 4
        );
    }
    n = n + tmp | 0;
  }
  if (n === s.length) {
    return copy(s);
  } else {
    var s$prime = caml_create_bytes(n);
    n = 0;
    for(var i$1 = 0 ,i_finish$1 = s.length - 1 | 0; i$1 <= i_finish$1; ++i$1){
      var c = s[i$1];
      var exit = 0;
      if (c >= 35) {
        if (c !== 92) {
          if (c >= 127) {
            exit = 1;
          } else {
            s$prime[n] = c;
          }
        } else {
          exit = 2;
        }
      } else if (c >= 32) {
        if (c >= 34) {
          exit = 2;
        } else {
          s$prime[n] = c;
        }
      } else if (c >= 14) {
        exit = 1;
      } else {
        switch (c) {
          case 8 :
              s$prime[n] = /* "\\" */92;
              n = n + 1 | 0;
              s$prime[n] = /* "b" */98;
              break;
          case 9 :
              s$prime[n] = /* "\\" */92;
              n = n + 1 | 0;
              s$prime[n] = /* "t" */116;
              break;
          case 10 :
              s$prime[n] = /* "\\" */92;
              n = n + 1 | 0;
              s$prime[n] = /* "n" */110;
              break;
          case 0 :
          case 1 :
          case 2 :
          case 3 :
          case 4 :
          case 5 :
          case 6 :
          case 7 :
          case 11 :
          case 12 :
              exit = 1;
              break;
          case 13 :
              s$prime[n] = /* "\\" */92;
              n = n + 1 | 0;
              s$prime[n] = /* "r" */114;
              break;
          
        }
      }
      switch (exit) {
        case 1 :
            s$prime[n] = /* "\\" */92;
            n = n + 1 | 0;
            s$prime[n] = 48 + (c / 100 | 0) | 0;
            n = n + 1 | 0;
            s$prime[n] = 48 + (c / 10 | 0) % 10 | 0;
            n = n + 1 | 0;
            s$prime[n] = 48 + c % 10 | 0;
            break;
        case 2 :
            s$prime[n] = /* "\\" */92;
            n = n + 1 | 0;
            s$prime[n] = c;
            break;
        
      }
      n = n + 1 | 0;
    }
    return s$prime;
  }
}
/* No side effect */

function make$1(n, c) {
  return bytes_to_string(make(n, c));
}

function copy$1(s) {
  return bytes_to_string(copy(bytes_of_string(s)));
}

function sub$2(s, ofs, len) {
  return bytes_to_string(sub$1(bytes_of_string(s), ofs, len));
}

function concat(sep, l) {
  if (l) {
    var hd = l[0];
    var num = /* record */[/* contents */0];
    var len = /* record */[/* contents */0];
    iter((function (s) {
            num[0] = num[0] + 1 | 0;
            len[0] = len[0] + s.length | 0;
            return /* () */0;
          }), l);
    var r = caml_create_bytes(len[0] + imul(sep.length, num[0] - 1 | 0) | 0);
    caml_blit_string(hd, 0, r, 0, hd.length);
    var pos = /* record */[/* contents */hd.length];
    iter((function (s) {
            caml_blit_string(sep, 0, r, pos[0], sep.length);
            pos[0] = pos[0] + sep.length | 0;
            caml_blit_string(s, 0, r, pos[0], s.length);
            pos[0] = pos[0] + s.length | 0;
            return /* () */0;
          }), l[1]);
    return bytes_to_string(r);
  } else {
    return "";
  }
}

function escaped$2(s) {
  var needs_escape = function (_i) {
    while(true) {
      var i = _i;
      if (i >= s.length) {
        return false;
      } else {
        var match = s.charCodeAt(i);
        if (match >= 32) {
          var switcher = match - 34 | 0;
          if (switcher > 58 || switcher < 0) {
            if (switcher >= 93) {
              return true;
            } else {
              _i = i + 1 | 0;
              continue ;
            }
          } else if (switcher > 57 || switcher < 1) {
            return true;
          } else {
            _i = i + 1 | 0;
            continue ;
          }
        } else {
          return true;
        }
      }
    }  };
  if (needs_escape(0)) {
    return bytes_to_string(escaped$1(bytes_of_string(s)));
  } else {
    return s;
  }
}

var blit$2 = blit_string;
/* No side effect */

function create$1(n) {
  var n$1 = n < 1 ? 1 : n;
  var s = caml_create_bytes(n$1);
  return /* record */[
          /* buffer */s,
          /* position */0,
          /* length */n$1,
          /* initial_buffer */s
        ];
}

function contents(b) {
  return sub_string(b[/* buffer */0], 0, b[/* position */1]);
}

function sub$3(b, ofs, len) {
  if (ofs < 0 || len < 0 || ofs > (b[/* position */1] - len | 0)) {
    throw [
          invalid_argument,
          "Buffer.sub"
        ];
  }
  return sub_string(b[/* buffer */0], ofs, len);
}

function reset(b) {
  b[/* position */1] = 0;
  b[/* buffer */0] = b[/* initial_buffer */3];
  b[/* length */2] = b[/* buffer */0].length;
  return /* () */0;
}

function resize(b, more) {
  var len = b[/* length */2];
  var new_len = len;
  while((b[/* position */1] + more | 0) > new_len) {
    new_len = (new_len << 1);
  }  var new_buffer = caml_create_bytes(new_len);
  blit$1(b[/* buffer */0], 0, new_buffer, 0, b[/* position */1]);
  b[/* buffer */0] = new_buffer;
  b[/* length */2] = new_len;
  return /* () */0;
}

function add_char(b, c) {
  var pos = b[/* position */1];
  if (pos >= b[/* length */2]) {
    resize(b, 1);
  }
  b[/* buffer */0][pos] = c;
  b[/* position */1] = pos + 1 | 0;
  return /* () */0;
}

function add_substring(b, s, offset, len) {
  if (offset < 0 || len < 0 || (offset + len | 0) > s.length) {
    throw [
          invalid_argument,
          "Buffer.add_substring/add_subbytes"
        ];
  }
  var new_position = b[/* position */1] + len | 0;
  if (new_position > b[/* length */2]) {
    resize(b, len);
  }
  blit_string(s, offset, b[/* buffer */0], b[/* position */1], len);
  b[/* position */1] = new_position;
  return /* () */0;
}

function add_string(b, s) {
  var len = s.length;
  var new_position = b[/* position */1] + len | 0;
  if (new_position > b[/* length */2]) {
    resize(b, len);
  }
  blit_string(s, 0, b[/* buffer */0], b[/* position */1], len);
  b[/* position */1] = new_position;
  return /* () */0;
}
/* No side effect */

function buffer_check_size(buf, overhead) {
  var len = buf[/* bytes */1].length;
  var min_len = buf[/* ind */0] + overhead | 0;
  if (min_len > len) {
    var new_len = caml_int_max((len << 1), min_len);
    var new_str = caml_create_bytes(new_len);
    blit$1(buf[/* bytes */1], 0, new_str, 0, len);
    buf[/* bytes */1] = new_str;
    return /* () */0;
  } else {
    return 0;
  }
}

function buffer_add_char(buf, c) {
  buffer_check_size(buf, 1);
  buf[/* bytes */1][buf[/* ind */0]] = c;
  buf[/* ind */0] = buf[/* ind */0] + 1 | 0;
  return /* () */0;
}

function buffer_add_string(buf, s) {
  var str_len = s.length;
  buffer_check_size(buf, str_len);
  blit$2(s, 0, buf[/* bytes */1], buf[/* ind */0], str_len);
  buf[/* ind */0] = buf[/* ind */0] + str_len | 0;
  return /* () */0;
}

function buffer_contents(buf) {
  return sub_string(buf[/* bytes */1], 0, buf[/* ind */0]);
}

function char_of_fconv(fconv) {
  switch (fconv) {
    case /* Float_f */0 :
    case /* Float_pf */1 :
    case /* Float_sf */2 :
        return /* "f" */102;
    case /* Float_e */3 :
    case /* Float_pe */4 :
    case /* Float_se */5 :
        return /* "e" */101;
    case /* Float_E */6 :
    case /* Float_pE */7 :
    case /* Float_sE */8 :
        return /* "E" */69;
    case /* Float_g */9 :
    case /* Float_pg */10 :
    case /* Float_sg */11 :
        return /* "g" */103;
    case /* Float_G */12 :
    case /* Float_pG */13 :
    case /* Float_sG */14 :
        return /* "G" */71;
    case /* Float_F */15 :
        return /* "F" */70;
    
  }
}

function bprint_fconv_flag(buf, fconv) {
  switch (fconv) {
    case /* Float_pf */1 :
    case /* Float_pe */4 :
    case /* Float_pE */7 :
    case /* Float_pg */10 :
    case /* Float_pG */13 :
        return buffer_add_char(buf, /* "+" */43);
    case /* Float_sf */2 :
    case /* Float_se */5 :
    case /* Float_sE */8 :
    case /* Float_sg */11 :
    case /* Float_sG */14 :
        return buffer_add_char(buf, /* " " */32);
    case /* Float_f */0 :
    case /* Float_e */3 :
    case /* Float_E */6 :
    case /* Float_g */9 :
    case /* Float_G */12 :
    case /* Float_F */15 :
        return /* () */0;
    
  }
}

function string_of_formatting_lit(formatting_lit) {
  if (typeof formatting_lit === "number") {
    switch (formatting_lit) {
      case /* Close_box */0 :
          return "@]";
      case /* Close_tag */1 :
          return "@}";
      case /* FFlush */2 :
          return "@?";
      case /* Force_newline */3 :
          return "@\n";
      case /* Flush_newline */4 :
          return "@.";
      case /* Escaped_at */5 :
          return "@@";
      case /* Escaped_percent */6 :
          return "@%";
      
    }
  } else {
    switch (formatting_lit.tag | 0) {
      case /* Break */0 :
      case /* Magic_size */1 :
          return formatting_lit[0];
      case /* Scan_indic */2 :
          return "@" + bytes_to_string(make(1, formatting_lit[0]));
      
    }
  }
}

function bprint_fmtty(buf, _fmtty) {
  while(true) {
    var fmtty = _fmtty;
    if (typeof fmtty === "number") {
      return /* () */0;
    } else {
      switch (fmtty.tag | 0) {
        case /* Char_ty */0 :
            buffer_add_string(buf, "%c");
            _fmtty = fmtty[0];
            continue ;
        case /* String_ty */1 :
            buffer_add_string(buf, "%s");
            _fmtty = fmtty[0];
            continue ;
        case /* Int_ty */2 :
            buffer_add_string(buf, "%i");
            _fmtty = fmtty[0];
            continue ;
        case /* Int32_ty */3 :
            buffer_add_string(buf, "%li");
            _fmtty = fmtty[0];
            continue ;
        case /* Nativeint_ty */4 :
            buffer_add_string(buf, "%ni");
            _fmtty = fmtty[0];
            continue ;
        case /* Int64_ty */5 :
            buffer_add_string(buf, "%Li");
            _fmtty = fmtty[0];
            continue ;
        case /* Float_ty */6 :
            buffer_add_string(buf, "%f");
            _fmtty = fmtty[0];
            continue ;
        case /* Bool_ty */7 :
            buffer_add_string(buf, "%B");
            _fmtty = fmtty[0];
            continue ;
        case /* Format_arg_ty */8 :
            buffer_add_string(buf, "%{");
            bprint_fmtty(buf, fmtty[0]);
            buffer_add_string(buf, "%}");
            _fmtty = fmtty[1];
            continue ;
        case /* Format_subst_ty */9 :
            buffer_add_string(buf, "%(");
            bprint_fmtty(buf, fmtty[0]);
            buffer_add_string(buf, "%)");
            _fmtty = fmtty[2];
            continue ;
        case /* Alpha_ty */10 :
            buffer_add_string(buf, "%a");
            _fmtty = fmtty[0];
            continue ;
        case /* Theta_ty */11 :
            buffer_add_string(buf, "%t");
            _fmtty = fmtty[0];
            continue ;
        case /* Any_ty */12 :
            buffer_add_string(buf, "%?");
            _fmtty = fmtty[0];
            continue ;
        case /* Reader_ty */13 :
            buffer_add_string(buf, "%r");
            _fmtty = fmtty[0];
            continue ;
        case /* Ignored_reader_ty */14 :
            buffer_add_string(buf, "%_r");
            _fmtty = fmtty[0];
            continue ;
        
      }
    }
  }}

function symm(param) {
  if (typeof param === "number") {
    return /* End_of_fmtty */0;
  } else {
    switch (param.tag | 0) {
      case /* Char_ty */0 :
          return /* Char_ty */__(0, [symm(param[0])]);
      case /* String_ty */1 :
          return /* String_ty */__(1, [symm(param[0])]);
      case /* Int_ty */2 :
          return /* Int_ty */__(2, [symm(param[0])]);
      case /* Int32_ty */3 :
          return /* Int32_ty */__(3, [symm(param[0])]);
      case /* Nativeint_ty */4 :
          return /* Nativeint_ty */__(4, [symm(param[0])]);
      case /* Int64_ty */5 :
          return /* Int64_ty */__(5, [symm(param[0])]);
      case /* Float_ty */6 :
          return /* Float_ty */__(6, [symm(param[0])]);
      case /* Bool_ty */7 :
          return /* Bool_ty */__(7, [symm(param[0])]);
      case /* Format_arg_ty */8 :
          return /* Format_arg_ty */__(8, [
                    param[0],
                    symm(param[1])
                  ]);
      case /* Format_subst_ty */9 :
          return /* Format_subst_ty */__(9, [
                    param[1],
                    param[0],
                    symm(param[2])
                  ]);
      case /* Alpha_ty */10 :
          return /* Alpha_ty */__(10, [symm(param[0])]);
      case /* Theta_ty */11 :
          return /* Theta_ty */__(11, [symm(param[0])]);
      case /* Any_ty */12 :
          return /* Any_ty */__(12, [symm(param[0])]);
      case /* Reader_ty */13 :
          return /* Reader_ty */__(13, [symm(param[0])]);
      case /* Ignored_reader_ty */14 :
          return /* Ignored_reader_ty */__(14, [symm(param[0])]);
      
    }
  }
}

function fmtty_rel_det(param) {
  if (typeof param === "number") {
    return /* tuple */[
            (function (param) {
                return /* Refl */0;
              }),
            (function (param) {
                return /* Refl */0;
              }),
            (function (param) {
                return /* Refl */0;
              }),
            (function (param) {
                return /* Refl */0;
              })
          ];
  } else {
    switch (param.tag | 0) {
      case /* Char_ty */0 :
          var match = fmtty_rel_det(param[0]);
          var af = match[1];
          var fa = match[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match[2],
                  match[3]
                ];
      case /* String_ty */1 :
          var match$1 = fmtty_rel_det(param[0]);
          var af$1 = match$1[1];
          var fa$1 = match$1[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$1, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$1, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$1[2],
                  match$1[3]
                ];
      case /* Int_ty */2 :
          var match$2 = fmtty_rel_det(param[0]);
          var af$2 = match$2[1];
          var fa$2 = match$2[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$2, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$2, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$2[2],
                  match$2[3]
                ];
      case /* Int32_ty */3 :
          var match$3 = fmtty_rel_det(param[0]);
          var af$3 = match$3[1];
          var fa$3 = match$3[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$3, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$3, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$3[2],
                  match$3[3]
                ];
      case /* Nativeint_ty */4 :
          var match$4 = fmtty_rel_det(param[0]);
          var af$4 = match$4[1];
          var fa$4 = match$4[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$4, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$4, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$4[2],
                  match$4[3]
                ];
      case /* Int64_ty */5 :
          var match$5 = fmtty_rel_det(param[0]);
          var af$5 = match$5[1];
          var fa$5 = match$5[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$5, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$5, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$5[2],
                  match$5[3]
                ];
      case /* Float_ty */6 :
          var match$6 = fmtty_rel_det(param[0]);
          var af$6 = match$6[1];
          var fa$6 = match$6[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$6, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$6, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$6[2],
                  match$6[3]
                ];
      case /* Bool_ty */7 :
          var match$7 = fmtty_rel_det(param[0]);
          var af$7 = match$7[1];
          var fa$7 = match$7[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$7, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$7, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$7[2],
                  match$7[3]
                ];
      case /* Format_arg_ty */8 :
          var match$8 = fmtty_rel_det(param[1]);
          var af$8 = match$8[1];
          var fa$8 = match$8[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$8, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$8, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$8[2],
                  match$8[3]
                ];
      case /* Format_subst_ty */9 :
          var match$9 = fmtty_rel_det(param[2]);
          var de = match$9[3];
          var ed = match$9[2];
          var af$9 = match$9[1];
          var fa$9 = match$9[0];
          var ty = trans(symm(param[0]), param[1]);
          var match$10 = fmtty_rel_det(ty);
          var jd = match$10[3];
          var dj = match$10[2];
          var ga = match$10[1];
          var ag = match$10[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$9, /* Refl */0);
                      _1(ag, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(ga, /* Refl */0);
                      _1(af$9, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(ed, /* Refl */0);
                      _1(dj, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(jd, /* Refl */0);
                      _1(de, /* Refl */0);
                      return /* Refl */0;
                    })
                ];
      case /* Alpha_ty */10 :
          var match$11 = fmtty_rel_det(param[0]);
          var af$10 = match$11[1];
          var fa$10 = match$11[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$10, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$10, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$11[2],
                  match$11[3]
                ];
      case /* Theta_ty */11 :
          var match$12 = fmtty_rel_det(param[0]);
          var af$11 = match$12[1];
          var fa$11 = match$12[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$11, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$11, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$12[2],
                  match$12[3]
                ];
      case /* Any_ty */12 :
          var match$13 = fmtty_rel_det(param[0]);
          var af$12 = match$13[1];
          var fa$12 = match$13[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$12, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$12, /* Refl */0);
                      return /* Refl */0;
                    }),
                  match$13[2],
                  match$13[3]
                ];
      case /* Reader_ty */13 :
          var match$14 = fmtty_rel_det(param[0]);
          var de$1 = match$14[3];
          var ed$1 = match$14[2];
          var af$13 = match$14[1];
          var fa$13 = match$14[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$13, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$13, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(ed$1, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(de$1, /* Refl */0);
                      return /* Refl */0;
                    })
                ];
      case /* Ignored_reader_ty */14 :
          var match$15 = fmtty_rel_det(param[0]);
          var de$2 = match$15[3];
          var ed$2 = match$15[2];
          var af$14 = match$15[1];
          var fa$14 = match$15[0];
          return /* tuple */[
                  (function (param) {
                      _1(fa$14, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(af$14, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(ed$2, /* Refl */0);
                      return /* Refl */0;
                    }),
                  (function (param) {
                      _1(de$2, /* Refl */0);
                      return /* Refl */0;
                    })
                ];
      
    }
  }
}

function trans(ty1, ty2) {
  var exit = 0;
  if (typeof ty1 === "number") {
    if (typeof ty2 === "number") {
      return /* End_of_fmtty */0;
    } else {
      switch (ty2.tag | 0) {
        case /* Format_arg_ty */8 :
            exit = 6;
            break;
        case /* Format_subst_ty */9 :
            exit = 7;
            break;
        case /* Alpha_ty */10 :
            exit = 1;
            break;
        case /* Theta_ty */11 :
            exit = 2;
            break;
        case /* Any_ty */12 :
            exit = 3;
            break;
        case /* Reader_ty */13 :
            exit = 4;
            break;
        case /* Ignored_reader_ty */14 :
            exit = 5;
            break;
        default:
          throw [
                assert_failure,
                /* tuple */[
                  "camlinternalFormat.ml",
                  816,
                  23
                ]
              ];
      }
    }
  } else {
    switch (ty1.tag | 0) {
      case /* Char_ty */0 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Char_ty */0 :
                  return /* Char_ty */__(0, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* String_ty */1 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* String_ty */1 :
                  return /* String_ty */__(1, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Int_ty */2 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Int_ty */2 :
                  return /* Int_ty */__(2, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Int32_ty */3 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Int32_ty */3 :
                  return /* Int32_ty */__(3, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Nativeint_ty */4 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Nativeint_ty */4 :
                  return /* Nativeint_ty */__(4, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Int64_ty */5 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Int64_ty */5 :
                  return /* Int64_ty */__(5, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Float_ty */6 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Float_ty */6 :
                  return /* Float_ty */__(6, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Bool_ty */7 :
          if (typeof ty2 === "number") {
            exit = 8;
          } else {
            switch (ty2.tag | 0) {
              case /* Bool_ty */7 :
                  return /* Bool_ty */__(7, [trans(ty1[0], ty2[0])]);
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  exit = 7;
                  break;
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              
            }
          }
          break;
      case /* Format_arg_ty */8 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    802,
                    26
                  ]
                ];
          } else {
            switch (ty2.tag | 0) {
              case /* Format_arg_ty */8 :
                  return /* Format_arg_ty */__(8, [
                            trans(ty1[0], ty2[0]),
                            trans(ty1[1], ty2[1])
                          ]);
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        802,
                        26
                      ]
                    ];
            }
          }
          break;
      case /* Format_subst_ty */9 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    812,
                    28
                  ]
                ];
          } else {
            switch (ty2.tag | 0) {
              case /* Format_arg_ty */8 :
                  exit = 6;
                  break;
              case /* Format_subst_ty */9 :
                  var ty = trans(symm(ty1[1]), ty2[0]);
                  var match = fmtty_rel_det(ty);
                  _1(match[1], /* Refl */0);
                  _1(match[3], /* Refl */0);
                  return /* Format_subst_ty */__(9, [
                            ty1[0],
                            ty2[1],
                            trans(ty1[2], ty2[2])
                          ]);
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  exit = 5;
                  break;
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        812,
                        28
                      ]
                    ];
            }
          }
          break;
      case /* Alpha_ty */10 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    780,
                    21
                  ]
                ];
          } else if (ty2.tag === /* Alpha_ty */10) {
            return /* Alpha_ty */__(10, [trans(ty1[0], ty2[0])]);
          } else {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    780,
                    21
                  ]
                ];
          }
      case /* Theta_ty */11 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    784,
                    21
                  ]
                ];
          } else {
            switch (ty2.tag | 0) {
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  return /* Theta_ty */__(11, [trans(ty1[0], ty2[0])]);
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        784,
                        21
                      ]
                    ];
            }
          }
          break;
      case /* Any_ty */12 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    788,
                    19
                  ]
                ];
          } else {
            switch (ty2.tag | 0) {
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  return /* Any_ty */__(12, [trans(ty1[0], ty2[0])]);
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        788,
                        19
                      ]
                    ];
            }
          }
          break;
      case /* Reader_ty */13 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    792,
                    22
                  ]
                ];
          } else {
            switch (ty2.tag | 0) {
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  return /* Reader_ty */__(13, [trans(ty1[0], ty2[0])]);
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        792,
                        22
                      ]
                    ];
            }
          }
          break;
      case /* Ignored_reader_ty */14 :
          if (typeof ty2 === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    797,
                    30
                  ]
                ];
          } else {
            switch (ty2.tag | 0) {
              case /* Alpha_ty */10 :
                  exit = 1;
                  break;
              case /* Theta_ty */11 :
                  exit = 2;
                  break;
              case /* Any_ty */12 :
                  exit = 3;
                  break;
              case /* Reader_ty */13 :
                  exit = 4;
                  break;
              case /* Ignored_reader_ty */14 :
                  return /* Ignored_reader_ty */__(14, [trans(ty1[0], ty2[0])]);
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        797,
                        30
                      ]
                    ];
            }
          }
          break;
      
    }
  }
  switch (exit) {
    case 1 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                781,
                21
              ]
            ];
    case 2 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                785,
                21
              ]
            ];
    case 3 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                789,
                19
              ]
            ];
    case 4 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                793,
                22
              ]
            ];
    case 5 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                798,
                30
              ]
            ];
    case 6 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                803,
                26
              ]
            ];
    case 7 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                813,
                28
              ]
            ];
    case 8 :
        throw [
              assert_failure,
              /* tuple */[
                "camlinternalFormat.ml",
                817,
                23
              ]
            ];
    
  }
}

var Type_mismatch = create("CamlinternalFormat.Type_mismatch");

function type_padding(pad, fmtty) {
  if (typeof pad === "number") {
    return /* Padding_fmtty_EBB */[
            /* No_padding */0,
            fmtty
          ];
  } else if (pad.tag) {
    if (typeof fmtty === "number") {
      throw Type_mismatch;
    } else if (fmtty.tag === /* Int_ty */2) {
      return /* Padding_fmtty_EBB */[
              /* Arg_padding */__(1, [pad[0]]),
              fmtty[0]
            ];
    } else {
      throw Type_mismatch;
    }
  } else {
    return /* Padding_fmtty_EBB */[
            /* Lit_padding */__(0, [
                pad[0],
                pad[1]
              ]),
            fmtty
          ];
  }
}

function type_padprec(pad, prec, fmtty) {
  var match = type_padding(pad, fmtty);
  if (typeof prec === "number") {
    if (prec !== 0) {
      var match$1 = match[1];
      if (typeof match$1 === "number") {
        throw Type_mismatch;
      } else if (match$1.tag === /* Int_ty */2) {
        return /* Padprec_fmtty_EBB */[
                match[0],
                /* Arg_precision */1,
                match$1[0]
              ];
      } else {
        throw Type_mismatch;
      }
    } else {
      return /* Padprec_fmtty_EBB */[
              match[0],
              /* No_precision */0,
              match[1]
            ];
    }
  } else {
    return /* Padprec_fmtty_EBB */[
            match[0],
            /* Lit_precision */[prec[0]],
            match[1]
          ];
  }
}

function type_ignored_param_one(ign, fmt, fmtty) {
  var match = type_format_gen(fmt, fmtty);
  return /* Fmt_fmtty_EBB */[
          /* Ignored_param */__(23, [
              ign,
              match[0]
            ]),
          match[1]
        ];
}

function type_format_gen(fmt, fmtty) {
  if (typeof fmt === "number") {
    return /* Fmt_fmtty_EBB */[
            /* End_of_format */0,
            fmtty
          ];
  } else {
    switch (fmt.tag | 0) {
      case /* Char */0 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag) {
            throw Type_mismatch;
          } else {
            var match = type_format_gen(fmt[0], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Char */__(0, [match[0]]),
                    match[1]
                  ];
          }
      case /* Caml_char */1 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag) {
            throw Type_mismatch;
          } else {
            var match$1 = type_format_gen(fmt[0], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Caml_char */__(1, [match$1[0]]),
                    match$1[1]
                  ];
          }
      case /* String */2 :
          var match$2 = type_padding(fmt[0], fmtty);
          var match$3 = match$2[1];
          if (typeof match$3 === "number") {
            throw Type_mismatch;
          } else if (match$3.tag === /* String_ty */1) {
            var match$4 = type_format_gen(fmt[1], match$3[0]);
            return /* Fmt_fmtty_EBB */[
                    /* String */__(2, [
                        match$2[0],
                        match$4[0]
                      ]),
                    match$4[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Caml_string */3 :
          var match$5 = type_padding(fmt[0], fmtty);
          var match$6 = match$5[1];
          if (typeof match$6 === "number") {
            throw Type_mismatch;
          } else if (match$6.tag === /* String_ty */1) {
            var match$7 = type_format_gen(fmt[1], match$6[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Caml_string */__(3, [
                        match$5[0],
                        match$7[0]
                      ]),
                    match$7[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Int */4 :
          var match$8 = type_padprec(fmt[1], fmt[2], fmtty);
          var match$9 = match$8[2];
          if (typeof match$9 === "number") {
            throw Type_mismatch;
          } else if (match$9.tag === /* Int_ty */2) {
            var match$10 = type_format_gen(fmt[3], match$9[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Int */__(4, [
                        fmt[0],
                        match$8[0],
                        match$8[1],
                        match$10[0]
                      ]),
                    match$10[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Int32 */5 :
          var match$11 = type_padprec(fmt[1], fmt[2], fmtty);
          var match$12 = match$11[2];
          if (typeof match$12 === "number") {
            throw Type_mismatch;
          } else if (match$12.tag === /* Int32_ty */3) {
            var match$13 = type_format_gen(fmt[3], match$12[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Int32 */__(5, [
                        fmt[0],
                        match$11[0],
                        match$11[1],
                        match$13[0]
                      ]),
                    match$13[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Nativeint */6 :
          var match$14 = type_padprec(fmt[1], fmt[2], fmtty);
          var match$15 = match$14[2];
          if (typeof match$15 === "number") {
            throw Type_mismatch;
          } else if (match$15.tag === /* Nativeint_ty */4) {
            var match$16 = type_format_gen(fmt[3], match$15[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Nativeint */__(6, [
                        fmt[0],
                        match$14[0],
                        match$14[1],
                        match$16[0]
                      ]),
                    match$16[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Int64 */7 :
          var match$17 = type_padprec(fmt[1], fmt[2], fmtty);
          var match$18 = match$17[2];
          if (typeof match$18 === "number") {
            throw Type_mismatch;
          } else if (match$18.tag === /* Int64_ty */5) {
            var match$19 = type_format_gen(fmt[3], match$18[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Int64 */__(7, [
                        fmt[0],
                        match$17[0],
                        match$17[1],
                        match$19[0]
                      ]),
                    match$19[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Float */8 :
          var match$20 = type_padprec(fmt[1], fmt[2], fmtty);
          var match$21 = match$20[2];
          if (typeof match$21 === "number") {
            throw Type_mismatch;
          } else if (match$21.tag === /* Float_ty */6) {
            var match$22 = type_format_gen(fmt[3], match$21[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Float */__(8, [
                        fmt[0],
                        match$20[0],
                        match$20[1],
                        match$22[0]
                      ]),
                    match$22[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Bool */9 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Bool_ty */7) {
            var match$23 = type_format_gen(fmt[0], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Bool */__(9, [match$23[0]]),
                    match$23[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Flush */10 :
          var match$24 = type_format_gen(fmt[0], fmtty);
          return /* Fmt_fmtty_EBB */[
                  /* Flush */__(10, [match$24[0]]),
                  match$24[1]
                ];
      case /* String_literal */11 :
          var match$25 = type_format_gen(fmt[1], fmtty);
          return /* Fmt_fmtty_EBB */[
                  /* String_literal */__(11, [
                      fmt[0],
                      match$25[0]
                    ]),
                  match$25[1]
                ];
      case /* Char_literal */12 :
          var match$26 = type_format_gen(fmt[1], fmtty);
          return /* Fmt_fmtty_EBB */[
                  /* Char_literal */__(12, [
                      fmt[0],
                      match$26[0]
                    ]),
                  match$26[1]
                ];
      case /* Format_arg */13 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Format_arg_ty */8) {
            var sub_fmtty$prime = fmtty[0];
            if (caml_notequal(/* Fmtty_EBB */[fmt[1]], /* Fmtty_EBB */[sub_fmtty$prime])) {
              throw Type_mismatch;
            }
            var match$27 = type_format_gen(fmt[2], fmtty[1]);
            return /* Fmt_fmtty_EBB */[
                    /* Format_arg */__(13, [
                        fmt[0],
                        sub_fmtty$prime,
                        match$27[0]
                      ]),
                    match$27[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Format_subst */14 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Format_subst_ty */9) {
            var sub_fmtty1 = fmtty[0];
            if (caml_notequal(/* Fmtty_EBB */[erase_rel(fmt[1])], /* Fmtty_EBB */[erase_rel(sub_fmtty1)])) {
              throw Type_mismatch;
            }
            var match$28 = type_format_gen(fmt[2], erase_rel(fmtty[2]));
            return /* Fmt_fmtty_EBB */[
                    /* Format_subst */__(14, [
                        fmt[0],
                        sub_fmtty1,
                        match$28[0]
                      ]),
                    match$28[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Alpha */15 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Alpha_ty */10) {
            var match$29 = type_format_gen(fmt[0], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Alpha */__(15, [match$29[0]]),
                    match$29[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Theta */16 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Theta_ty */11) {
            var match$30 = type_format_gen(fmt[0], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Theta */__(16, [match$30[0]]),
                    match$30[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Formatting_lit */17 :
          var match$31 = type_format_gen(fmt[1], fmtty);
          return /* Fmt_fmtty_EBB */[
                  /* Formatting_lit */__(17, [
                      fmt[0],
                      match$31[0]
                    ]),
                  match$31[1]
                ];
      case /* Formatting_gen */18 :
          var formatting_gen = fmt[0];
          var fmt0 = fmt[1];
          var fmtty0 = fmtty;
          if (formatting_gen.tag) {
            var match$32 = formatting_gen[0];
            var match$33 = type_format_gen(match$32[0], fmtty0);
            var match$34 = type_format_gen(fmt0, match$33[1]);
            return /* Fmt_fmtty_EBB */[
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              match$33[0],
                              match$32[1]
                            ]]),
                        match$34[0]
                      ]),
                    match$34[1]
                  ];
          } else {
            var match$35 = formatting_gen[0];
            var match$36 = type_format_gen(match$35[0], fmtty0);
            var match$37 = type_format_gen(fmt0, match$36[1]);
            return /* Fmt_fmtty_EBB */[
                    /* Formatting_gen */__(18, [
                        /* Open_tag */__(0, [/* Format */[
                              match$36[0],
                              match$35[1]
                            ]]),
                        match$37[0]
                      ]),
                    match$37[1]
                  ];
          }
      case /* Reader */19 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Reader_ty */13) {
            var match$38 = type_format_gen(fmt[0], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Reader */__(19, [match$38[0]]),
                    match$38[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Scan_char_set */20 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* String_ty */1) {
            var match$39 = type_format_gen(fmt[2], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Scan_char_set */__(20, [
                        fmt[0],
                        fmt[1],
                        match$39[0]
                      ]),
                    match$39[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Scan_get_counter */21 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Int_ty */2) {
            var match$40 = type_format_gen(fmt[1], fmtty[0]);
            return /* Fmt_fmtty_EBB */[
                    /* Scan_get_counter */__(21, [
                        fmt[0],
                        match$40[0]
                      ]),
                    match$40[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Ignored_param */23 :
          var ign = fmt[0];
          var fmt$1 = fmt[1];
          var fmtty$1 = fmtty;
          if (typeof ign === "number") {
            if (ign === /* Ignored_reader */3) {
              if (typeof fmtty$1 === "number") {
                throw Type_mismatch;
              } else if (fmtty$1.tag === /* Ignored_reader_ty */14) {
                var match$41 = type_format_gen(fmt$1, fmtty$1[0]);
                return /* Fmt_fmtty_EBB */[
                        /* Ignored_param */__(23, [
                            /* Ignored_reader */3,
                            match$41[0]
                          ]),
                        match$41[1]
                      ];
              } else {
                throw Type_mismatch;
              }
            } else {
              return type_ignored_param_one(ign, fmt$1, fmtty$1);
            }
          } else {
            switch (ign.tag | 0) {
              case /* Ignored_format_arg */7 :
                  return type_ignored_param_one(/* Ignored_format_arg */__(7, [
                                ign[0],
                                ign[1]
                              ]), fmt$1, fmtty$1);
              case /* Ignored_format_subst */8 :
                  var match$42 = type_ignored_format_substitution(ign[1], fmt$1, fmtty$1);
                  var match$43 = match$42[1];
                  return /* Fmt_fmtty_EBB */[
                          /* Ignored_param */__(23, [
                              /* Ignored_format_subst */__(8, [
                                  ign[0],
                                  match$42[0]
                                ]),
                              match$43[0]
                            ]),
                          match$43[1]
                        ];
              default:
                return type_ignored_param_one(ign, fmt$1, fmtty$1);
            }
          }
      case /* Scan_next_char */22 :
      case /* Custom */24 :
          throw Type_mismatch;
      
    }
  }
}

function type_ignored_format_substitution(sub_fmtty, fmt, fmtty) {
  if (typeof sub_fmtty === "number") {
    return /* Fmtty_fmt_EBB */[
            /* End_of_fmtty */0,
            type_format_gen(fmt, fmtty)
          ];
  } else {
    switch (sub_fmtty.tag | 0) {
      case /* Char_ty */0 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag) {
            throw Type_mismatch;
          } else {
            var match = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Char_ty */__(0, [match[0]]),
                    match[1]
                  ];
          }
      case /* String_ty */1 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* String_ty */1) {
            var match$1 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* String_ty */__(1, [match$1[0]]),
                    match$1[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Int_ty */2 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Int_ty */2) {
            var match$2 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Int_ty */__(2, [match$2[0]]),
                    match$2[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Int32_ty */3 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Int32_ty */3) {
            var match$3 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Int32_ty */__(3, [match$3[0]]),
                    match$3[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Nativeint_ty */4 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Nativeint_ty */4) {
            var match$4 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Nativeint_ty */__(4, [match$4[0]]),
                    match$4[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Int64_ty */5 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Int64_ty */5) {
            var match$5 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Int64_ty */__(5, [match$5[0]]),
                    match$5[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Float_ty */6 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Float_ty */6) {
            var match$6 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Float_ty */__(6, [match$6[0]]),
                    match$6[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Bool_ty */7 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Bool_ty */7) {
            var match$7 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Bool_ty */__(7, [match$7[0]]),
                    match$7[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Format_arg_ty */8 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Format_arg_ty */8) {
            var sub2_fmtty$prime = fmtty[0];
            if (caml_notequal(/* Fmtty_EBB */[sub_fmtty[0]], /* Fmtty_EBB */[sub2_fmtty$prime])) {
              throw Type_mismatch;
            }
            var match$8 = type_ignored_format_substitution(sub_fmtty[1], fmt, fmtty[1]);
            return /* Fmtty_fmt_EBB */[
                    /* Format_arg_ty */__(8, [
                        sub2_fmtty$prime,
                        match$8[0]
                      ]),
                    match$8[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Format_subst_ty */9 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Format_subst_ty */9) {
            var sub2_fmtty$prime$1 = fmtty[1];
            var sub1_fmtty$prime = fmtty[0];
            if (caml_notequal(/* Fmtty_EBB */[erase_rel(sub_fmtty[0])], /* Fmtty_EBB */[erase_rel(sub1_fmtty$prime)])) {
              throw Type_mismatch;
            }
            if (caml_notequal(/* Fmtty_EBB */[erase_rel(sub_fmtty[1])], /* Fmtty_EBB */[erase_rel(sub2_fmtty$prime$1)])) {
              throw Type_mismatch;
            }
            var sub_fmtty$prime = trans(symm(sub1_fmtty$prime), sub2_fmtty$prime$1);
            var match$9 = fmtty_rel_det(sub_fmtty$prime);
            _1(match$9[1], /* Refl */0);
            _1(match$9[3], /* Refl */0);
            var match$10 = type_ignored_format_substitution(erase_rel(sub_fmtty[2]), fmt, fmtty[2]);
            return /* Fmtty_fmt_EBB */[
                    /* Format_subst_ty */__(9, [
                        sub1_fmtty$prime,
                        sub2_fmtty$prime$1,
                        symm(match$10[0])
                      ]),
                    match$10[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Alpha_ty */10 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Alpha_ty */10) {
            var match$11 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Alpha_ty */__(10, [match$11[0]]),
                    match$11[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Theta_ty */11 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Theta_ty */11) {
            var match$12 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Theta_ty */__(11, [match$12[0]]),
                    match$12[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Any_ty */12 :
          throw Type_mismatch;
      case /* Reader_ty */13 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Reader_ty */13) {
            var match$13 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Reader_ty */__(13, [match$13[0]]),
                    match$13[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      case /* Ignored_reader_ty */14 :
          if (typeof fmtty === "number") {
            throw Type_mismatch;
          } else if (fmtty.tag === /* Ignored_reader_ty */14) {
            var match$14 = type_ignored_format_substitution(sub_fmtty[0], fmt, fmtty[0]);
            return /* Fmtty_fmt_EBB */[
                    /* Ignored_reader_ty */__(14, [match$14[0]]),
                    match$14[1]
                  ];
          } else {
            throw Type_mismatch;
          }
      
    }
  }
}

function type_format(fmt, fmtty) {
  var match = type_format_gen(fmt, fmtty);
  if (typeof match[1] === "number") {
    return match[0];
  } else {
    throw Type_mismatch;
  }
}

function recast(fmt, fmtty) {
  return type_format(fmt, erase_rel(symm(fmtty)));
}

function fix_padding(padty, width, str) {
  var len = str.length;
  var width$1 = abs(width);
  var padty$1 = width < 0 ? /* Left */0 : padty;
  if (width$1 <= len) {
    return str;
  } else {
    var res = make(width$1, padty$1 === /* Zeros */2 ? /* "0" */48 : /* " " */32);
    switch (padty$1) {
      case /* Left */0 :
          blit$2(str, 0, res, 0, len);
          break;
      case /* Right */1 :
          blit$2(str, 0, res, width$1 - len | 0, len);
          break;
      case /* Zeros */2 :
          if (len > 0 && (get(str, 0) === /* "+" */43 || get(str, 0) === /* "-" */45 || get(str, 0) === /* " " */32)) {
            res[0] = get(str, 0);
            blit$2(str, 1, res, (width$1 - len | 0) + 1 | 0, len - 1 | 0);
          } else if (len > 1 && get(str, 0) === /* "0" */48 && (get(str, 1) === /* "x" */120 || get(str, 1) === /* "X" */88)) {
            res[1] = get(str, 1);
            blit$2(str, 2, res, (width$1 - len | 0) + 2 | 0, len - 2 | 0);
          } else {
            blit$2(str, 0, res, width$1 - len | 0, len);
          }
          break;
      
    }
    return bytes_to_string(res);
  }
}

function fix_int_precision(prec, str) {
  var prec$1 = abs(prec);
  var len = str.length;
  var c = get(str, 0);
  var exit = 0;
  if (c >= 58) {
    if (c >= 71) {
      if (c > 102 || c < 97) {
        return str;
      } else {
        exit = 2;
      }
    } else if (c >= 65) {
      exit = 2;
    } else {
      return str;
    }
  } else if (c !== 32) {
    if (c >= 43) {
      switch (c - 43 | 0) {
        case 0 :
        case 2 :
            exit = 1;
            break;
        case 1 :
        case 3 :
        case 4 :
            return str;
        case 5 :
            if ((prec$1 + 2 | 0) > len && len > 1 && (get(str, 1) === /* "x" */120 || get(str, 1) === /* "X" */88)) {
              var res = make(prec$1 + 2 | 0, /* "0" */48);
              res[1] = get(str, 1);
              blit$2(str, 2, res, (prec$1 - len | 0) + 4 | 0, len - 2 | 0);
              return bytes_to_string(res);
            } else {
              exit = 2;
            }
            break;
        case 6 :
        case 7 :
        case 8 :
        case 9 :
        case 10 :
        case 11 :
        case 12 :
        case 13 :
        case 14 :
            exit = 2;
            break;
        
      }
    } else {
      return str;
    }
  } else {
    exit = 1;
  }
  switch (exit) {
    case 1 :
        if ((prec$1 + 1 | 0) > len) {
          var res$1 = make(prec$1 + 1 | 0, /* "0" */48);
          res$1[0] = c;
          blit$2(str, 1, res$1, (prec$1 - len | 0) + 2 | 0, len - 1 | 0);
          return bytes_to_string(res$1);
        } else {
          return str;
        }
    case 2 :
        if (prec$1 > len) {
          var res$2 = make(prec$1, /* "0" */48);
          blit$2(str, 0, res$2, prec$1 - len | 0, len);
          return bytes_to_string(res$2);
        } else {
          return str;
        }
    
  }
}

function string_to_caml_string(str) {
  return concat(escaped$2(str), /* :: */[
              "\"",
              /* :: */[
                "\"",
                /* [] */0
              ]
            ]);
}

function format_of_iconv(iconv) {
  switch (iconv) {
    case /* Int_d */0 :
        return "%d";
    case /* Int_pd */1 :
        return "%+d";
    case /* Int_sd */2 :
        return "% d";
    case /* Int_i */3 :
        return "%i";
    case /* Int_pi */4 :
        return "%+i";
    case /* Int_si */5 :
        return "% i";
    case /* Int_x */6 :
        return "%x";
    case /* Int_Cx */7 :
        return "%#x";
    case /* Int_X */8 :
        return "%X";
    case /* Int_CX */9 :
        return "%#X";
    case /* Int_o */10 :
        return "%o";
    case /* Int_Co */11 :
        return "%#o";
    case /* Int_u */12 :
        return "%u";
    
  }
}

function format_of_aconv(iconv, c) {
  var seps;
  switch (iconv) {
    case /* Int_d */0 :
        seps = /* :: */[
          "%",
          /* :: */[
            "d",
            /* [] */0
          ]
        ];
        break;
    case /* Int_pd */1 :
        seps = /* :: */[
          "%+",
          /* :: */[
            "d",
            /* [] */0
          ]
        ];
        break;
    case /* Int_sd */2 :
        seps = /* :: */[
          "% ",
          /* :: */[
            "d",
            /* [] */0
          ]
        ];
        break;
    case /* Int_i */3 :
        seps = /* :: */[
          "%",
          /* :: */[
            "i",
            /* [] */0
          ]
        ];
        break;
    case /* Int_pi */4 :
        seps = /* :: */[
          "%+",
          /* :: */[
            "i",
            /* [] */0
          ]
        ];
        break;
    case /* Int_si */5 :
        seps = /* :: */[
          "% ",
          /* :: */[
            "i",
            /* [] */0
          ]
        ];
        break;
    case /* Int_x */6 :
        seps = /* :: */[
          "%",
          /* :: */[
            "x",
            /* [] */0
          ]
        ];
        break;
    case /* Int_Cx */7 :
        seps = /* :: */[
          "%#",
          /* :: */[
            "x",
            /* [] */0
          ]
        ];
        break;
    case /* Int_X */8 :
        seps = /* :: */[
          "%",
          /* :: */[
            "X",
            /* [] */0
          ]
        ];
        break;
    case /* Int_CX */9 :
        seps = /* :: */[
          "%#",
          /* :: */[
            "X",
            /* [] */0
          ]
        ];
        break;
    case /* Int_o */10 :
        seps = /* :: */[
          "%",
          /* :: */[
            "o",
            /* [] */0
          ]
        ];
        break;
    case /* Int_Co */11 :
        seps = /* :: */[
          "%#",
          /* :: */[
            "o",
            /* [] */0
          ]
        ];
        break;
    case /* Int_u */12 :
        seps = /* :: */[
          "%",
          /* :: */[
            "u",
            /* [] */0
          ]
        ];
        break;
    
  }
  return concat(bytes_to_string(make(1, c)), seps);
}

function format_of_fconv(fconv, prec) {
  if (fconv === /* Float_F */15) {
    return "%.12g";
  } else {
    var prec$1 = abs(prec);
    var symb = char_of_fconv(fconv);
    var buf = /* record */[
      /* ind */0,
      /* bytes */caml_create_bytes(16)
    ];
    buffer_add_char(buf, /* "%" */37);
    bprint_fconv_flag(buf, fconv);
    buffer_add_char(buf, /* "." */46);
    buffer_add_string(buf, String(prec$1));
    buffer_add_char(buf, symb);
    return buffer_contents(buf);
  }
}

function convert_int(iconv, n) {
  return caml_format_int(format_of_iconv(iconv), n);
}

function convert_int32(iconv, n) {
  return caml_int32_format(format_of_aconv(iconv, /* "l" */108), n);
}

function convert_nativeint(iconv, n) {
  return caml_nativeint_format(format_of_aconv(iconv, /* "n" */110), n);
}

function convert_int64(iconv, n) {
  return caml_int64_format(format_of_aconv(iconv, /* "L" */76), n);
}

function convert_float(fconv, prec, x) {
  var prec$1 = abs(prec);
  var str = caml_format_float(format_of_fconv(fconv, prec$1), x);
  if (fconv !== /* Float_F */15) {
    return str;
  } else {
    var len = str.length;
    var is_valid = function (_i) {
      while(true) {
        var i = _i;
        if (i === len) {
          return false;
        } else {
          var match = get(str, i);
          var switcher = match - 46 | 0;
          if (switcher > 23 || switcher < 0) {
            if (switcher !== 55) {
              _i = i + 1 | 0;
              continue ;
            } else {
              return true;
            }
          } else if (switcher > 22 || switcher < 1) {
            return true;
          } else {
            _i = i + 1 | 0;
            continue ;
          }
        }
      }    };
    var match = classify_float(x);
    if (match !== 3) {
      if (match >= 4) {
        return "nan";
      } else if (is_valid(0)) {
        return str;
      } else {
        return str + ".";
      }
    } else if (x < 0.0) {
      return "neg_infinity";
    } else {
      return "infinity";
    }
  }
}

function format_caml_char(c) {
  return concat(escaped(c), /* :: */[
              "'",
              /* :: */[
                "'",
                /* [] */0
              ]
            ]);
}

function string_of_fmtty(fmtty) {
  var buf = /* record */[
    /* ind */0,
    /* bytes */caml_create_bytes(16)
  ];
  bprint_fmtty(buf, fmtty);
  return buffer_contents(buf);
}

function make_printf(_k, o, _acc, _fmt) {
  while(true) {
    var fmt = _fmt;
    var acc = _acc;
    var k = _k;
    if (typeof fmt === "number") {
      return _2(k, o, acc);
    } else {
      switch (fmt.tag | 0) {
        case /* Char */0 :
            var rest = fmt[0];
            return (function(k,acc,rest){
            return function (c) {
              var new_acc = /* Acc_data_char */__(5, [
                  acc,
                  c
                ]);
              return make_printf(k, o, new_acc, rest);
            }
            }(k,acc,rest));
        case /* Caml_char */1 :
            var rest$1 = fmt[0];
            return (function(k,acc,rest$1){
            return function (c) {
              var new_acc_001 = format_caml_char(c);
              var new_acc = /* Acc_data_string */__(4, [
                  acc,
                  new_acc_001
                ]);
              return make_printf(k, o, new_acc, rest$1);
            }
            }(k,acc,rest$1));
        case /* String */2 :
            return make_string_padding(k, o, acc, fmt[1], fmt[0], (function (str) {
                          return str;
                        }));
        case /* Caml_string */3 :
            return make_string_padding(k, o, acc, fmt[1], fmt[0], string_to_caml_string);
        case /* Int */4 :
            return make_int_padding_precision(k, o, acc, fmt[3], fmt[1], fmt[2], convert_int, fmt[0]);
        case /* Int32 */5 :
            return make_int_padding_precision(k, o, acc, fmt[3], fmt[1], fmt[2], convert_int32, fmt[0]);
        case /* Nativeint */6 :
            return make_int_padding_precision(k, o, acc, fmt[3], fmt[1], fmt[2], convert_nativeint, fmt[0]);
        case /* Int64 */7 :
            return make_int_padding_precision(k, o, acc, fmt[3], fmt[1], fmt[2], convert_int64, fmt[0]);
        case /* Float */8 :
            var k$1 = k;
            var o$1 = o;
            var acc$1 = acc;
            var fmt$1 = fmt[3];
            var pad = fmt[1];
            var prec = fmt[2];
            var fconv = fmt[0];
            if (typeof pad === "number") {
              if (typeof prec === "number") {
                if (prec !== 0) {
                  return (function(k$1,o$1,acc$1,fmt$1,fconv){
                  return function (p, x) {
                    var str = convert_float(fconv, p, x);
                    return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                  acc$1,
                                  str
                                ]), fmt$1);
                  }
                  }(k$1,o$1,acc$1,fmt$1,fconv));
                } else {
                  return (function(k$1,o$1,acc$1,fmt$1,fconv){
                  return function (x) {
                    var str = convert_float(fconv, 6, x);
                    return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                  acc$1,
                                  str
                                ]), fmt$1);
                  }
                  }(k$1,o$1,acc$1,fmt$1,fconv));
                }
              } else {
                var p = prec[0];
                return (function(k$1,o$1,acc$1,fmt$1,fconv,p){
                return function (x) {
                  var str = convert_float(fconv, p, x);
                  return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                acc$1,
                                str
                              ]), fmt$1);
                }
                }(k$1,o$1,acc$1,fmt$1,fconv,p));
              }
            } else if (pad.tag) {
              var padty = pad[0];
              if (typeof prec === "number") {
                if (prec !== 0) {
                  return (function(k$1,o$1,acc$1,fmt$1,fconv,padty){
                  return function (w, p, x) {
                    var str = fix_padding(padty, w, convert_float(fconv, p, x));
                    return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                  acc$1,
                                  str
                                ]), fmt$1);
                  }
                  }(k$1,o$1,acc$1,fmt$1,fconv,padty));
                } else {
                  return (function(k$1,o$1,acc$1,fmt$1,fconv,padty){
                  return function (w, x) {
                    var str = convert_float(fconv, 6, x);
                    var str$prime = fix_padding(padty, w, str);
                    return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                  acc$1,
                                  str$prime
                                ]), fmt$1);
                  }
                  }(k$1,o$1,acc$1,fmt$1,fconv,padty));
                }
              } else {
                var p$1 = prec[0];
                return (function(k$1,o$1,acc$1,fmt$1,fconv,padty,p$1){
                return function (w, x) {
                  var str = fix_padding(padty, w, convert_float(fconv, p$1, x));
                  return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                acc$1,
                                str
                              ]), fmt$1);
                }
                }(k$1,o$1,acc$1,fmt$1,fconv,padty,p$1));
              }
            } else {
              var w = pad[1];
              var padty$1 = pad[0];
              if (typeof prec === "number") {
                if (prec !== 0) {
                  return (function(k$1,o$1,acc$1,fmt$1,fconv,padty$1,w){
                  return function (p, x) {
                    var str = fix_padding(padty$1, w, convert_float(fconv, p, x));
                    return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                  acc$1,
                                  str
                                ]), fmt$1);
                  }
                  }(k$1,o$1,acc$1,fmt$1,fconv,padty$1,w));
                } else {
                  return (function(k$1,o$1,acc$1,fmt$1,fconv,padty$1,w){
                  return function (x) {
                    var str = convert_float(fconv, 6, x);
                    var str$prime = fix_padding(padty$1, w, str);
                    return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                  acc$1,
                                  str$prime
                                ]), fmt$1);
                  }
                  }(k$1,o$1,acc$1,fmt$1,fconv,padty$1,w));
                }
              } else {
                var p$2 = prec[0];
                return (function(k$1,o$1,acc$1,fmt$1,fconv,padty$1,w,p$2){
                return function (x) {
                  var str = fix_padding(padty$1, w, convert_float(fconv, p$2, x));
                  return make_printf(k$1, o$1, /* Acc_data_string */__(4, [
                                acc$1,
                                str
                              ]), fmt$1);
                }
                }(k$1,o$1,acc$1,fmt$1,fconv,padty$1,w,p$2));
              }
            }
        case /* Bool */9 :
            var rest$2 = fmt[0];
            return (function(k,acc,rest$2){
            return function (b) {
              return make_printf(k, o, /* Acc_data_string */__(4, [
                            acc,
                            b ? "true" : "false"
                          ]), rest$2);
            }
            }(k,acc,rest$2));
        case /* Flush */10 :
            _fmt = fmt[0];
            _acc = /* Acc_flush */__(7, [acc]);
            continue ;
        case /* String_literal */11 :
            _fmt = fmt[1];
            _acc = /* Acc_string_literal */__(2, [
                acc,
                fmt[0]
              ]);
            continue ;
        case /* Char_literal */12 :
            _fmt = fmt[1];
            _acc = /* Acc_char_literal */__(3, [
                acc,
                fmt[0]
              ]);
            continue ;
        case /* Format_arg */13 :
            var rest$3 = fmt[2];
            var ty = string_of_fmtty(fmt[1]);
            return (function(k,acc,rest$3,ty){
            return function (str) {
              return make_printf(k, o, /* Acc_data_string */__(4, [
                            acc,
                            ty
                          ]), rest$3);
            }
            }(k,acc,rest$3,ty));
        case /* Format_subst */14 :
            var rest$4 = fmt[2];
            var fmtty = fmt[1];
            return (function(k,acc,fmtty,rest$4){
            return function (param) {
              return make_printf(k, o, acc, concat_fmt(recast(param[0], fmtty), rest$4));
            }
            }(k,acc,fmtty,rest$4));
        case /* Alpha */15 :
            var rest$5 = fmt[0];
            return (function(k,acc,rest$5){
            return function (f, x) {
              return make_printf(k, o, /* Acc_delay */__(6, [
                            acc,
                            (function (o) {
                                return _2(f, o, x);
                              })
                          ]), rest$5);
            }
            }(k,acc,rest$5));
        case /* Theta */16 :
            var rest$6 = fmt[0];
            return (function(k,acc,rest$6){
            return function (f) {
              return make_printf(k, o, /* Acc_delay */__(6, [
                            acc,
                            f
                          ]), rest$6);
            }
            }(k,acc,rest$6));
        case /* Formatting_lit */17 :
            _fmt = fmt[1];
            _acc = /* Acc_formatting_lit */__(0, [
                acc,
                fmt[0]
              ]);
            continue ;
        case /* Formatting_gen */18 :
            var match = fmt[0];
            if (match.tag) {
              var rest$7 = fmt[1];
              var k$prime = (function(k,acc,rest$7){
              return function k$prime(koc, kacc) {
                return make_printf(k, koc, /* Acc_formatting_gen */__(1, [
                              acc,
                              /* Acc_open_box */__(1, [kacc])
                            ]), rest$7);
              }
              }(k,acc,rest$7));
              _fmt = match[0][0];
              _acc = /* End_of_acc */0;
              _k = k$prime;
              continue ;
            } else {
              var rest$8 = fmt[1];
              var k$prime$1 = (function(k,acc,rest$8){
              return function k$prime$1(koc, kacc) {
                return make_printf(k, koc, /* Acc_formatting_gen */__(1, [
                              acc,
                              /* Acc_open_tag */__(0, [kacc])
                            ]), rest$8);
              }
              }(k,acc,rest$8));
              _fmt = match[0][0];
              _acc = /* End_of_acc */0;
              _k = k$prime$1;
              continue ;
            }
        case /* Reader */19 :
            throw [
                  assert_failure,
                  /* tuple */[
                    "camlinternalFormat.ml",
                    1449,
                    4
                  ]
                ];
        case /* Scan_char_set */20 :
            var rest$9 = fmt[2];
            var new_acc = /* Acc_invalid_arg */__(8, [
                acc,
                "Printf: bad conversion %["
              ]);
            return (function(k,rest$9,new_acc){
            return function (param) {
              return make_printf(k, o, new_acc, rest$9);
            }
            }(k,rest$9,new_acc));
        case /* Scan_get_counter */21 :
            var rest$10 = fmt[1];
            return (function(k,acc,rest$10){
            return function (n) {
              var new_acc_001 = caml_format_int("%u", n);
              var new_acc = /* Acc_data_string */__(4, [
                  acc,
                  new_acc_001
                ]);
              return make_printf(k, o, new_acc, rest$10);
            }
            }(k,acc,rest$10));
        case /* Scan_next_char */22 :
            var rest$11 = fmt[0];
            return (function(k,acc,rest$11){
            return function (c) {
              var new_acc = /* Acc_data_char */__(5, [
                  acc,
                  c
                ]);
              return make_printf(k, o, new_acc, rest$11);
            }
            }(k,acc,rest$11));
        case /* Ignored_param */23 :
            var k$2 = k;
            var o$2 = o;
            var acc$2 = acc;
            var ign = fmt[0];
            var fmt$2 = fmt[1];
            if (typeof ign === "number") {
              if (ign === /* Ignored_reader */3) {
                throw [
                      assert_failure,
                      /* tuple */[
                        "camlinternalFormat.ml",
                        1517,
                        39
                      ]
                    ];
              } else {
                return make_invalid_arg(k$2, o$2, acc$2, fmt$2);
              }
            } else if (ign.tag === /* Ignored_format_subst */8) {
              return make_from_fmtty(k$2, o$2, acc$2, ign[1], fmt$2);
            } else {
              return make_invalid_arg(k$2, o$2, acc$2, fmt$2);
            }
        case /* Custom */24 :
            return make_custom(k, o, acc, fmt[2], fmt[0], _1(fmt[1], /* () */0));
        
      }
    }
  }}

function make_from_fmtty(k, o, acc, fmtty, fmt) {
  if (typeof fmtty === "number") {
    return make_invalid_arg(k, o, acc, fmt);
  } else {
    switch (fmtty.tag | 0) {
      case /* Char_ty */0 :
          var rest = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest, fmt);
            });
      case /* String_ty */1 :
          var rest$1 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$1, fmt);
            });
      case /* Int_ty */2 :
          var rest$2 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$2, fmt);
            });
      case /* Int32_ty */3 :
          var rest$3 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$3, fmt);
            });
      case /* Nativeint_ty */4 :
          var rest$4 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$4, fmt);
            });
      case /* Int64_ty */5 :
          var rest$5 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$5, fmt);
            });
      case /* Float_ty */6 :
          var rest$6 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$6, fmt);
            });
      case /* Bool_ty */7 :
          var rest$7 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$7, fmt);
            });
      case /* Format_arg_ty */8 :
          var rest$8 = fmtty[1];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$8, fmt);
            });
      case /* Format_subst_ty */9 :
          var rest$9 = fmtty[2];
          var ty = trans(symm(fmtty[0]), fmtty[1]);
          return (function (param) {
              return make_from_fmtty(k, o, acc, concat_fmtty(ty, rest$9), fmt);
            });
      case /* Alpha_ty */10 :
          var rest$10 = fmtty[0];
          return (function (param, param$1) {
              return make_from_fmtty(k, o, acc, rest$10, fmt);
            });
      case /* Theta_ty */11 :
          var rest$11 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$11, fmt);
            });
      case /* Any_ty */12 :
          var rest$12 = fmtty[0];
          return (function (param) {
              return make_from_fmtty(k, o, acc, rest$12, fmt);
            });
      case /* Reader_ty */13 :
          throw [
                assert_failure,
                /* tuple */[
                  "camlinternalFormat.ml",
                  1540,
                  31
                ]
              ];
      case /* Ignored_reader_ty */14 :
          throw [
                assert_failure,
                /* tuple */[
                  "camlinternalFormat.ml",
                  1541,
                  31
                ]
              ];
      
    }
  }
}

function make_invalid_arg(k, o, acc, fmt) {
  return make_printf(k, o, /* Acc_invalid_arg */__(8, [
                acc,
                "Printf: bad conversion %_"
              ]), fmt);
}

function make_string_padding(k, o, acc, fmt, pad, trans) {
  if (typeof pad === "number") {
    return (function (x) {
        var new_acc_001 = _1(trans, x);
        var new_acc = /* Acc_data_string */__(4, [
            acc,
            new_acc_001
          ]);
        return make_printf(k, o, new_acc, fmt);
      });
  } else if (pad.tag) {
    var padty = pad[0];
    return (function (w, x) {
        var new_acc_001 = fix_padding(padty, w, _1(trans, x));
        var new_acc = /* Acc_data_string */__(4, [
            acc,
            new_acc_001
          ]);
        return make_printf(k, o, new_acc, fmt);
      });
  } else {
    var width = pad[1];
    var padty$1 = pad[0];
    return (function (x) {
        var new_acc_001 = fix_padding(padty$1, width, _1(trans, x));
        var new_acc = /* Acc_data_string */__(4, [
            acc,
            new_acc_001
          ]);
        return make_printf(k, o, new_acc, fmt);
      });
  }
}

function make_int_padding_precision(k, o, acc, fmt, pad, prec, trans, iconv) {
  if (typeof pad === "number") {
    if (typeof prec === "number") {
      if (prec !== 0) {
        return (function (p, x) {
            var str = fix_int_precision(p, _2(trans, iconv, x));
            return make_printf(k, o, /* Acc_data_string */__(4, [
                          acc,
                          str
                        ]), fmt);
          });
      } else {
        return (function (x) {
            var str = _2(trans, iconv, x);
            return make_printf(k, o, /* Acc_data_string */__(4, [
                          acc,
                          str
                        ]), fmt);
          });
      }
    } else {
      var p = prec[0];
      return (function (x) {
          var str = fix_int_precision(p, _2(trans, iconv, x));
          return make_printf(k, o, /* Acc_data_string */__(4, [
                        acc,
                        str
                      ]), fmt);
        });
    }
  } else if (pad.tag) {
    var padty = pad[0];
    if (typeof prec === "number") {
      if (prec !== 0) {
        return (function (w, p, x) {
            var str = fix_padding(padty, w, fix_int_precision(p, _2(trans, iconv, x)));
            return make_printf(k, o, /* Acc_data_string */__(4, [
                          acc,
                          str
                        ]), fmt);
          });
      } else {
        return (function (w, x) {
            var str = fix_padding(padty, w, _2(trans, iconv, x));
            return make_printf(k, o, /* Acc_data_string */__(4, [
                          acc,
                          str
                        ]), fmt);
          });
      }
    } else {
      var p$1 = prec[0];
      return (function (w, x) {
          var str = fix_padding(padty, w, fix_int_precision(p$1, _2(trans, iconv, x)));
          return make_printf(k, o, /* Acc_data_string */__(4, [
                        acc,
                        str
                      ]), fmt);
        });
    }
  } else {
    var w = pad[1];
    var padty$1 = pad[0];
    if (typeof prec === "number") {
      if (prec !== 0) {
        return (function (p, x) {
            var str = fix_padding(padty$1, w, fix_int_precision(p, _2(trans, iconv, x)));
            return make_printf(k, o, /* Acc_data_string */__(4, [
                          acc,
                          str
                        ]), fmt);
          });
      } else {
        return (function (x) {
            var str = fix_padding(padty$1, w, _2(trans, iconv, x));
            return make_printf(k, o, /* Acc_data_string */__(4, [
                          acc,
                          str
                        ]), fmt);
          });
      }
    } else {
      var p$2 = prec[0];
      return (function (x) {
          var str = fix_padding(padty$1, w, fix_int_precision(p$2, _2(trans, iconv, x)));
          return make_printf(k, o, /* Acc_data_string */__(4, [
                        acc,
                        str
                      ]), fmt);
        });
    }
  }
}

function make_custom(k, o, acc, rest, arity, f) {
  if (arity) {
    var arity$1 = arity[0];
    return (function (x) {
        return make_custom(k, o, acc, rest, arity$1, _1(f, x));
      });
  } else {
    return make_printf(k, o, /* Acc_data_string */__(4, [
                  acc,
                  f
                ]), rest);
  }
}

function output_acc(o, _acc) {
  while(true) {
    var acc = _acc;
    var exit = 0;
    if (typeof acc === "number") {
      return /* () */0;
    } else {
      switch (acc.tag | 0) {
        case /* Acc_formatting_lit */0 :
            var s = string_of_formatting_lit(acc[1]);
            output_acc(o, acc[0]);
            return output_string(o, s);
        case /* Acc_formatting_gen */1 :
            var match = acc[1];
            var p = acc[0];
            output_acc(o, p);
            if (match.tag) {
              output_string(o, "@[");
              _acc = match[0];
              continue ;
            } else {
              output_string(o, "@{");
              _acc = match[0];
              continue ;
            }
        case /* Acc_string_literal */2 :
        case /* Acc_data_string */4 :
            exit = 1;
            break;
        case /* Acc_char_literal */3 :
        case /* Acc_data_char */5 :
            exit = 2;
            break;
        case /* Acc_delay */6 :
            output_acc(o, acc[0]);
            return _1(acc[1], o);
        case /* Acc_flush */7 :
            output_acc(o, acc[0]);
            return caml_ml_flush(o);
        case /* Acc_invalid_arg */8 :
            output_acc(o, acc[0]);
            throw [
                  invalid_argument,
                  acc[1]
                ];
        
      }
    }
    switch (exit) {
      case 1 :
          output_acc(o, acc[0]);
          return output_string(o, acc[1]);
      case 2 :
          output_acc(o, acc[0]);
          return caml_ml_output_char(o, acc[1]);
      
    }
  }}

function strput_acc(b, _acc) {
  while(true) {
    var acc = _acc;
    var exit = 0;
    if (typeof acc === "number") {
      return /* () */0;
    } else {
      switch (acc.tag | 0) {
        case /* Acc_formatting_lit */0 :
            var s = string_of_formatting_lit(acc[1]);
            strput_acc(b, acc[0]);
            return add_string(b, s);
        case /* Acc_formatting_gen */1 :
            var match = acc[1];
            var p = acc[0];
            strput_acc(b, p);
            if (match.tag) {
              add_string(b, "@[");
              _acc = match[0];
              continue ;
            } else {
              add_string(b, "@{");
              _acc = match[0];
              continue ;
            }
        case /* Acc_string_literal */2 :
        case /* Acc_data_string */4 :
            exit = 1;
            break;
        case /* Acc_char_literal */3 :
        case /* Acc_data_char */5 :
            exit = 2;
            break;
        case /* Acc_delay */6 :
            strput_acc(b, acc[0]);
            return add_string(b, _1(acc[1], /* () */0));
        case /* Acc_flush */7 :
            _acc = acc[0];
            continue ;
        case /* Acc_invalid_arg */8 :
            strput_acc(b, acc[0]);
            throw [
                  invalid_argument,
                  acc[1]
                ];
        
      }
    }
    switch (exit) {
      case 1 :
          strput_acc(b, acc[0]);
          return add_string(b, acc[1]);
      case 2 :
          strput_acc(b, acc[0]);
          return add_char(b, acc[1]);
      
    }
  }}

function failwith_message(param) {
  var buf = create$1(256);
  var k = function (param, acc) {
    strput_acc(buf, acc);
    var s = contents(buf);
    throw [
          failure,
          s
        ];
  };
  return make_printf(k, /* () */0, /* End_of_acc */0, param[0]);
}

function open_box_of_string(str) {
  if (str === "") {
    return /* tuple */[
            0,
            /* Pp_box */4
          ];
  } else {
    var len = str.length;
    var invalid_box = function (param) {
      return _1(failwith_message(/* Format */[
                      /* String_literal */__(11, [
                          "invalid box description ",
                          /* Caml_string */__(3, [
                              /* No_padding */0,
                              /* End_of_format */0
                            ])
                        ]),
                      "invalid box description %S"
                    ]), str);
    };
    var parse_spaces = function (_i) {
      while(true) {
        var i = _i;
        if (i === len) {
          return i;
        } else {
          var match = get(str, i);
          if (match !== 9) {
            if (match !== 32) {
              return i;
            } else {
              _i = i + 1 | 0;
              continue ;
            }
          } else {
            _i = i + 1 | 0;
            continue ;
          }
        }
      }    };
    var parse_lword = function (i, _j) {
      while(true) {
        var j = _j;
        if (j === len) {
          return j;
        } else {
          var match = get(str, j);
          if (match > 122 || match < 97) {
            return j;
          } else {
            _j = j + 1 | 0;
            continue ;
          }
        }
      }    };
    var parse_int = function (i, _j) {
      while(true) {
        var j = _j;
        if (j === len) {
          return j;
        } else {
          var match = get(str, j);
          if (match >= 48) {
            if (match >= 58) {
              return j;
            } else {
              _j = j + 1 | 0;
              continue ;
            }
          } else if (match !== 45) {
            return j;
          } else {
            _j = j + 1 | 0;
            continue ;
          }
        }
      }    };
    var wstart = parse_spaces(0);
    var wend = parse_lword(wstart, wstart);
    var box_name = sub$2(str, wstart, wend - wstart | 0);
    var nstart = parse_spaces(wend);
    var nend = parse_int(nstart, nstart);
    var indent;
    if (nstart === nend) {
      indent = 0;
    } else {
      try {
        indent = caml_int_of_string(sub$2(str, nstart, nend - nstart | 0));
      }
      catch (raw_exn){
        var exn = internalToOCamlException(raw_exn);
        if (exn[0] === failure) {
          indent = invalid_box(/* () */0);
        } else {
          throw exn;
        }
      }
    }
    var exp_end = parse_spaces(nend);
    if (exp_end !== len) {
      invalid_box(/* () */0);
    }
    var box_type;
    switch (box_name) {
      case "" :
      case "b" :
          box_type = /* Pp_box */4;
          break;
      case "h" :
          box_type = /* Pp_hbox */0;
          break;
      case "hov" :
          box_type = /* Pp_hovbox */3;
          break;
      case "hv" :
          box_type = /* Pp_hvbox */2;
          break;
      case "v" :
          box_type = /* Pp_vbox */1;
          break;
      default:
        box_type = invalid_box(/* () */0);
    }
    return /* tuple */[
            indent,
            box_type
          ];
  }
}
/* No side effect */

function add_queue(x, q) {
  var c = /* Cons */[/* record */[
      /* head */x,
      /* tail : Nil */0
    ]];
  var match = q[/* insert */0];
  if (match) {
    q[/* insert */0] = c;
    match[0][/* tail */1] = c;
    return /* () */0;
  } else {
    q[/* insert */0] = c;
    q[/* body */1] = c;
    return /* () */0;
  }
}

var Empty_queue = create("Format.Empty_queue");

function peek_queue(param) {
  var match = param[/* body */1];
  if (match) {
    return match[0][/* head */0];
  } else {
    throw Empty_queue;
  }
}

function take_queue(q) {
  var match = q[/* body */1];
  if (match) {
    var match$1 = match[0];
    var x = match$1[/* head */0];
    var tl = match$1[/* tail */1];
    q[/* body */1] = tl;
    if (tl === /* Nil */0) {
      q[/* insert */0] = /* Nil */0;
    }
    return x;
  } else {
    throw Empty_queue;
  }
}

function pp_enqueue(state, token) {
  state[/* pp_right_total */12] = state[/* pp_right_total */12] + token[/* length */2] | 0;
  return add_queue(token, state[/* pp_queue */26]);
}

function pp_clear_queue(state) {
  state[/* pp_left_total */11] = 1;
  state[/* pp_right_total */12] = 1;
  var q = state[/* pp_queue */26];
  q[/* insert */0] = /* Nil */0;
  q[/* body */1] = /* Nil */0;
  return /* () */0;
}

function pp_output_string(state, s) {
  return _3(state[/* pp_out_string */16], s, 0, s.length);
}

function break_new_line(state, offset, width) {
  _1(state[/* pp_out_newline */18], /* () */0);
  state[/* pp_is_new_line */10] = true;
  var indent = (state[/* pp_margin */5] - width | 0) + offset | 0;
  var real_indent = caml_int_min(state[/* pp_max_indent */7], indent);
  state[/* pp_current_indent */9] = real_indent;
  state[/* pp_space_left */8] = state[/* pp_margin */5] - state[/* pp_current_indent */9] | 0;
  return _1(state[/* pp_out_spaces */19], state[/* pp_current_indent */9]);
}

function break_same_line(state, width) {
  state[/* pp_space_left */8] = state[/* pp_space_left */8] - width | 0;
  return _1(state[/* pp_out_spaces */19], width);
}

function pp_force_break_line(state) {
  var match = state[/* pp_format_stack */1];
  if (match) {
    var match$1 = match[0];
    var width = match$1[1];
    if (width > state[/* pp_space_left */8] && (match$1[0] - 1 >>> 0) <= 3) {
      return break_new_line(state, 0, width);
    } else {
      return 0;
    }
  } else {
    return _1(state[/* pp_out_newline */18], /* () */0);
  }
}

function format_pp_token(state, size, param) {
  if (typeof param === "number") {
    switch (param) {
      case /* Pp_stab */0 :
          var match = state[/* pp_tbox_stack */2];
          if (match) {
            var tabs = match[0][0];
            var add_tab = function (n, ls) {
              if (ls) {
                var x = ls[0];
                if (caml_lessthan(n, x)) {
                  return /* :: */[
                          n,
                          ls
                        ];
                } else {
                  return /* :: */[
                          x,
                          add_tab(n, ls[1])
                        ];
                }
              } else {
                return /* :: */[
                        n,
                        /* [] */0
                      ];
              }
            };
            tabs[0] = add_tab(state[/* pp_margin */5] - state[/* pp_space_left */8] | 0, tabs[0]);
            return /* () */0;
          } else {
            return /* () */0;
          }
      case /* Pp_end */1 :
          var match$1 = state[/* pp_format_stack */1];
          if (match$1) {
            state[/* pp_format_stack */1] = match$1[1];
            return /* () */0;
          } else {
            return /* () */0;
          }
      case /* Pp_tend */2 :
          var match$2 = state[/* pp_tbox_stack */2];
          if (match$2) {
            state[/* pp_tbox_stack */2] = match$2[1];
            return /* () */0;
          } else {
            return /* () */0;
          }
      case /* Pp_newline */3 :
          var match$3 = state[/* pp_format_stack */1];
          if (match$3) {
            return break_new_line(state, 0, match$3[0][1]);
          } else {
            return _1(state[/* pp_out_newline */18], /* () */0);
          }
      case /* Pp_if_newline */4 :
          if (state[/* pp_current_indent */9] !== (state[/* pp_margin */5] - state[/* pp_space_left */8] | 0)) {
            var state$1 = state;
            var match$4 = take_queue(state$1[/* pp_queue */26]);
            var size$1 = match$4[/* elem_size */0];
            state$1[/* pp_left_total */11] = state$1[/* pp_left_total */11] - match$4[/* length */2] | 0;
            state$1[/* pp_space_left */8] = state$1[/* pp_space_left */8] + size$1 | 0;
            return /* () */0;
          } else {
            return 0;
          }
      case /* Pp_close_tag */5 :
          var match$5 = state[/* pp_mark_stack */4];
          if (match$5) {
            var marker = _1(state[/* pp_mark_close_tag */23], match$5[0]);
            pp_output_string(state, marker);
            state[/* pp_mark_stack */4] = match$5[1];
            return /* () */0;
          } else {
            return /* () */0;
          }
      
    }
  } else {
    switch (param.tag | 0) {
      case /* Pp_text */0 :
          state[/* pp_space_left */8] = state[/* pp_space_left */8] - size | 0;
          pp_output_string(state, param[0]);
          state[/* pp_is_new_line */10] = false;
          return /* () */0;
      case /* Pp_break */1 :
          var off = param[1];
          var n = param[0];
          var match$6 = state[/* pp_format_stack */1];
          if (match$6) {
            var match$7 = match$6[0];
            var width = match$7[1];
            switch (match$7[0]) {
              case /* Pp_vbox */1 :
              case /* Pp_hvbox */2 :
                  return break_new_line(state, off, width);
              case /* Pp_hovbox */3 :
                  if (size > state[/* pp_space_left */8]) {
                    return break_new_line(state, off, width);
                  } else {
                    return break_same_line(state, n);
                  }
              case /* Pp_box */4 :
                  if (state[/* pp_is_new_line */10] || !(size > state[/* pp_space_left */8] || state[/* pp_current_indent */9] > ((state[/* pp_margin */5] - width | 0) + off | 0))) {
                    return break_same_line(state, n);
                  } else {
                    return break_new_line(state, off, width);
                  }
              case /* Pp_hbox */0 :
              case /* Pp_fits */5 :
                  return break_same_line(state, n);
              
            }
          } else {
            return /* () */0;
          }
      case /* Pp_tbreak */2 :
          var insertion_point = state[/* pp_margin */5] - state[/* pp_space_left */8] | 0;
          var match$8 = state[/* pp_tbox_stack */2];
          if (match$8) {
            var tabs$1 = match$8[0][0];
            var find = function (n, _param) {
              while(true) {
                var param = _param;
                if (param) {
                  var x = param[0];
                  if (caml_greaterequal(x, n)) {
                    return x;
                  } else {
                    _param = param[1];
                    continue ;
                  }
                } else {
                  throw not_found;
                }
              }            };
            var match$9 = tabs$1[0];
            var tab;
            if (match$9) {
              try {
                tab = find(insertion_point, tabs$1[0]);
              }
              catch (exn){
                if (exn === not_found) {
                  tab = match$9[0];
                } else {
                  throw exn;
                }
              }
            } else {
              tab = insertion_point;
            }
            var offset = tab - insertion_point | 0;
            if (offset >= 0) {
              return break_same_line(state, offset + param[0] | 0);
            } else {
              return break_new_line(state, tab + param[1] | 0, state[/* pp_margin */5]);
            }
          } else {
            return /* () */0;
          }
      case /* Pp_begin */3 :
          var ty = param[1];
          var insertion_point$1 = state[/* pp_margin */5] - state[/* pp_space_left */8] | 0;
          if (insertion_point$1 > state[/* pp_max_indent */7]) {
            pp_force_break_line(state);
          }
          var offset$1 = state[/* pp_space_left */8] - param[0] | 0;
          var bl_type = ty !== 1 ? (
              size > state[/* pp_space_left */8] ? ty : /* Pp_fits */5
            ) : /* Pp_vbox */1;
          state[/* pp_format_stack */1] = /* :: */[
            /* Format_elem */[
              bl_type,
              offset$1
            ],
            state[/* pp_format_stack */1]
          ];
          return /* () */0;
      case /* Pp_tbegin */4 :
          state[/* pp_tbox_stack */2] = /* :: */[
            param[0],
            state[/* pp_tbox_stack */2]
          ];
          return /* () */0;
      case /* Pp_open_tag */5 :
          var tag_name = param[0];
          var marker$1 = _1(state[/* pp_mark_open_tag */22], tag_name);
          pp_output_string(state, marker$1);
          state[/* pp_mark_stack */4] = /* :: */[
            tag_name,
            state[/* pp_mark_stack */4]
          ];
          return /* () */0;
      
    }
  }
}

function advance_left(state) {
  try {
    var state$1 = state;
    while(true) {
      var match = peek_queue(state$1[/* pp_queue */26]);
      var size = match[/* elem_size */0];
      if (size < 0 && (state$1[/* pp_right_total */12] - state$1[/* pp_left_total */11] | 0) < state$1[/* pp_space_left */8]) {
        return 0;
      } else {
        take_queue(state$1[/* pp_queue */26]);
        format_pp_token(state$1, size < 0 ? 1000000010 : size, match[/* token */1]);
        state$1[/* pp_left_total */11] = match[/* length */2] + state$1[/* pp_left_total */11] | 0;
        continue ;
      }
    };
  }
  catch (exn){
    if (exn === Empty_queue) {
      return /* () */0;
    } else {
      throw exn;
    }
  }
}

function enqueue_advance(state, tok) {
  pp_enqueue(state, tok);
  return advance_left(state);
}

function enqueue_string_as(state, size, s) {
  return enqueue_advance(state, /* record */[
              /* elem_size */size,
              /* token : Pp_text */__(0, [s]),
              /* length */size
            ]);
}

var q_elem = /* record */[
  /* elem_size */-1,
  /* token : Pp_text */__(0, [""]),
  /* length */0
];

var scan_stack_bottom_000 = /* Scan_elem */[
  -1,
  q_elem
];

var scan_stack_bottom = /* :: */[
  scan_stack_bottom_000,
  /* [] */0
];

function set_size(state, ty) {
  var match = state[/* pp_scan_stack */0];
  if (match) {
    var match$1 = match[0];
    var queue_elem = match$1[1];
    var size = queue_elem[/* elem_size */0];
    var t = match[1];
    if (match$1[0] < state[/* pp_left_total */11]) {
      state[/* pp_scan_stack */0] = scan_stack_bottom;
      return /* () */0;
    } else {
      var tmp = queue_elem[/* token */1];
      if (typeof tmp === "number") {
        return /* () */0;
      } else {
        switch (tmp.tag | 0) {
          case /* Pp_break */1 :
          case /* Pp_tbreak */2 :
              break;
          case /* Pp_begin */3 :
              if (ty) {
                return 0;
              } else {
                queue_elem[/* elem_size */0] = state[/* pp_right_total */12] + size | 0;
                state[/* pp_scan_stack */0] = t;
                return /* () */0;
              }
          default:
            return /* () */0;
        }
      }
      if (ty) {
        queue_elem[/* elem_size */0] = state[/* pp_right_total */12] + size | 0;
        state[/* pp_scan_stack */0] = t;
        return /* () */0;
      } else {
        return 0;
      }
    }
  } else {
    return /* () */0;
  }
}

function scan_push(state, b, tok) {
  pp_enqueue(state, tok);
  if (b) {
    set_size(state, true);
  }
  state[/* pp_scan_stack */0] = /* :: */[
    /* Scan_elem */[
      state[/* pp_right_total */12],
      tok
    ],
    state[/* pp_scan_stack */0]
  ];
  return /* () */0;
}

function pp_open_box_gen(state, indent, br_ty) {
  state[/* pp_curr_depth */13] = state[/* pp_curr_depth */13] + 1 | 0;
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    var elem = /* record */[
      /* elem_size */-state[/* pp_right_total */12] | 0,
      /* token : Pp_begin */__(3, [
          indent,
          br_ty
        ]),
      /* length */0
    ];
    return scan_push(state, false, elem);
  } else if (state[/* pp_curr_depth */13] === state[/* pp_max_boxes */14]) {
    var state$1 = state;
    var s = state[/* pp_ellipsis */15];
    var len = s.length;
    return enqueue_string_as(state$1, len, s);
  } else {
    return 0;
  }
}

function pp_close_box(state, param) {
  if (state[/* pp_curr_depth */13] > 1) {
    if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
      pp_enqueue(state, /* record */[
            /* elem_size */0,
            /* token : Pp_end */1,
            /* length */0
          ]);
      set_size(state, true);
      set_size(state, false);
    }
    state[/* pp_curr_depth */13] = state[/* pp_curr_depth */13] - 1 | 0;
    return /* () */0;
  } else {
    return 0;
  }
}

function pp_open_tag(state, tag_name) {
  if (state[/* pp_print_tags */20]) {
    state[/* pp_tag_stack */3] = /* :: */[
      tag_name,
      state[/* pp_tag_stack */3]
    ];
    _1(state[/* pp_print_open_tag */24], tag_name);
  }
  if (state[/* pp_mark_tags */21]) {
    return pp_enqueue(state, /* record */[
                /* elem_size */0,
                /* token : Pp_open_tag */__(5, [tag_name]),
                /* length */0
              ]);
  } else {
    return 0;
  }
}

function pp_close_tag(state, param) {
  if (state[/* pp_mark_tags */21]) {
    pp_enqueue(state, /* record */[
          /* elem_size */0,
          /* token : Pp_close_tag */5,
          /* length */0
        ]);
  }
  if (state[/* pp_print_tags */20]) {
    var match = state[/* pp_tag_stack */3];
    if (match) {
      _1(state[/* pp_print_close_tag */25], match[0]);
      state[/* pp_tag_stack */3] = match[1];
      return /* () */0;
    } else {
      return /* () */0;
    }
  } else {
    return 0;
  }
}

function pp_set_print_tags(state, b) {
  state[/* pp_print_tags */20] = b;
  return /* () */0;
}

function pp_set_mark_tags(state, b) {
  state[/* pp_mark_tags */21] = b;
  return /* () */0;
}

function pp_get_print_tags(state, param) {
  return state[/* pp_print_tags */20];
}

function pp_get_mark_tags(state, param) {
  return state[/* pp_mark_tags */21];
}

function pp_set_tags(state, b) {
  state[/* pp_print_tags */20] = b;
  state[/* pp_mark_tags */21] = b;
  return /* () */0;
}

function pp_get_formatter_tag_functions(state, param) {
  return /* record */[
          /* mark_open_tag */state[/* pp_mark_open_tag */22],
          /* mark_close_tag */state[/* pp_mark_close_tag */23],
          /* print_open_tag */state[/* pp_print_open_tag */24],
          /* print_close_tag */state[/* pp_print_close_tag */25]
        ];
}

function pp_set_formatter_tag_functions(state, param) {
  state[/* pp_mark_open_tag */22] = param[/* mark_open_tag */0];
  state[/* pp_mark_close_tag */23] = param[/* mark_close_tag */1];
  state[/* pp_print_open_tag */24] = param[/* print_open_tag */2];
  state[/* pp_print_close_tag */25] = param[/* print_close_tag */3];
  return /* () */0;
}

function pp_rinit(state) {
  pp_clear_queue(state);
  state[/* pp_scan_stack */0] = scan_stack_bottom;
  state[/* pp_format_stack */1] = /* [] */0;
  state[/* pp_tbox_stack */2] = /* [] */0;
  state[/* pp_tag_stack */3] = /* [] */0;
  state[/* pp_mark_stack */4] = /* [] */0;
  state[/* pp_current_indent */9] = 0;
  state[/* pp_curr_depth */13] = 0;
  state[/* pp_space_left */8] = state[/* pp_margin */5];
  return pp_open_box_gen(state, 0, /* Pp_hovbox */3);
}

function pp_flush_queue(state, b) {
  while(state[/* pp_curr_depth */13] > 1) {
    pp_close_box(state);
  }  state[/* pp_right_total */12] = 1000000010;
  advance_left(state);
  if (b) {
    _1(state[/* pp_out_newline */18], /* () */0);
  }
  return pp_rinit(state);
}

function pp_print_as_size(state, size, s) {
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    return enqueue_string_as(state, size, s);
  } else {
    return 0;
  }
}

var pp_print_as = pp_print_as_size;

function pp_print_string(state, s) {
  return pp_print_as(state, s.length, s);
}

function pp_print_int(state, i) {
  return pp_print_string(state, String(i));
}

function pp_print_float(state, f) {
  return pp_print_string(state, string_of_float(f));
}

function pp_print_bool(state, b) {
  return pp_print_string(state, b ? "true" : "false");
}

function pp_print_char(state, c) {
  return pp_print_as(state, 1, bytes_to_string(make(1, c)));
}

function pp_open_hbox(state, param) {
  return pp_open_box_gen(state, 0, /* Pp_hbox */0);
}

function pp_open_vbox(state, indent) {
  return pp_open_box_gen(state, indent, /* Pp_vbox */1);
}

function pp_open_hvbox(state, indent) {
  return pp_open_box_gen(state, indent, /* Pp_hvbox */2);
}

function pp_open_hovbox(state, indent) {
  return pp_open_box_gen(state, indent, /* Pp_hovbox */3);
}

function pp_open_box(state, indent) {
  return pp_open_box_gen(state, indent, /* Pp_box */4);
}

function pp_print_newline(state, param) {
  pp_flush_queue(state, true);
  return _1(state[/* pp_out_flush */17], /* () */0);
}

function pp_print_flush(state, param) {
  pp_flush_queue(state, false);
  return _1(state[/* pp_out_flush */17], /* () */0);
}

function pp_force_newline(state, param) {
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    return enqueue_advance(state, /* record */[
                /* elem_size */0,
                /* token : Pp_newline */3,
                /* length */0
              ]);
  } else {
    return 0;
  }
}

function pp_print_if_newline(state, param) {
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    return enqueue_advance(state, /* record */[
                /* elem_size */0,
                /* token : Pp_if_newline */4,
                /* length */0
              ]);
  } else {
    return 0;
  }
}

function pp_print_break(state, width, offset) {
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    var elem = /* record */[
      /* elem_size */-state[/* pp_right_total */12] | 0,
      /* token : Pp_break */__(1, [
          width,
          offset
        ]),
      /* length */width
    ];
    return scan_push(state, true, elem);
  } else {
    return 0;
  }
}

function pp_print_space(state, param) {
  return pp_print_break(state, 1, 0);
}

function pp_print_cut(state, param) {
  return pp_print_break(state, 0, 0);
}

function pp_open_tbox(state, param) {
  state[/* pp_curr_depth */13] = state[/* pp_curr_depth */13] + 1 | 0;
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    var elem = /* record */[
      /* elem_size */0,
      /* token : Pp_tbegin */__(4, [/* Pp_tbox */[/* record */[/* contents : [] */0]]]),
      /* length */0
    ];
    return enqueue_advance(state, elem);
  } else {
    return 0;
  }
}

function pp_close_tbox(state, param) {
  if (state[/* pp_curr_depth */13] > 1 && state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    var elem = /* record */[
      /* elem_size */0,
      /* token : Pp_tend */2,
      /* length */0
    ];
    enqueue_advance(state, elem);
    state[/* pp_curr_depth */13] = state[/* pp_curr_depth */13] - 1 | 0;
    return /* () */0;
  } else {
    return 0;
  }
}

function pp_print_tbreak(state, width, offset) {
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    var elem = /* record */[
      /* elem_size */-state[/* pp_right_total */12] | 0,
      /* token : Pp_tbreak */__(2, [
          width,
          offset
        ]),
      /* length */width
    ];
    return scan_push(state, true, elem);
  } else {
    return 0;
  }
}

function pp_print_tab(state, param) {
  return pp_print_tbreak(state, 0, 0);
}

function pp_set_tab(state, param) {
  if (state[/* pp_curr_depth */13] < state[/* pp_max_boxes */14]) {
    var elem = /* record */[
      /* elem_size */0,
      /* token : Pp_stab */0,
      /* length */0
    ];
    return enqueue_advance(state, elem);
  } else {
    return 0;
  }
}

function pp_print_list(_$staropt$star, pp_v, ppf, _param) {
  while(true) {
    var param = _param;
    var $staropt$star = _$staropt$star;
    var pp_sep = $staropt$star !== undefined ? $staropt$star : pp_print_cut;
    if (param) {
      var vs = param[1];
      var v = param[0];
      if (vs) {
        _2(pp_v, ppf, v);
        _2(pp_sep, ppf, /* () */0);
        _param = vs;
        _$staropt$star = pp_sep;
        continue ;
      } else {
        return _2(pp_v, ppf, v);
      }
    } else {
      return /* () */0;
    }
  }}

function pp_print_text(ppf, s) {
  var len = s.length;
  var left = /* record */[/* contents */0];
  var right = /* record */[/* contents */0];
  var flush = function (param) {
    pp_print_string(ppf, sub$2(s, left[0], right[0] - left[0] | 0));
    right[0] = right[0] + 1 | 0;
    left[0] = right[0];
    return /* () */0;
  };
  while(right[0] !== len) {
    var match = get(s, right[0]);
    if (match !== 10) {
      if (match !== 32) {
        right[0] = right[0] + 1 | 0;
      } else {
        flush();
        pp_print_break(ppf, 1, 0);
      }
    } else {
      flush();
      pp_force_newline(ppf);
    }
  }  if (left[0] !== len) {
    return flush();
  } else {
    return 0;
  }
}

function pp_set_max_boxes(state, n) {
  if (n > 1) {
    state[/* pp_max_boxes */14] = n;
    return /* () */0;
  } else {
    return 0;
  }
}

function pp_get_max_boxes(state, param) {
  return state[/* pp_max_boxes */14];
}

function pp_over_max_boxes(state, param) {
  return state[/* pp_curr_depth */13] === state[/* pp_max_boxes */14];
}

function pp_set_ellipsis_text(state, s) {
  state[/* pp_ellipsis */15] = s;
  return /* () */0;
}

function pp_get_ellipsis_text(state, param) {
  return state[/* pp_ellipsis */15];
}

function pp_limit(n) {
  if (n < 1000000010) {
    return n;
  } else {
    return 1000000009;
  }
}

function pp_set_max_indent(state, n) {
  var state$1 = state;
  var n$1 = state[/* pp_margin */5] - n | 0;
  if (n$1 >= 1) {
    var n$2 = pp_limit(n$1);
    state$1[/* pp_min_space_left */6] = n$2;
    state$1[/* pp_max_indent */7] = state$1[/* pp_margin */5] - state$1[/* pp_min_space_left */6] | 0;
    return pp_rinit(state$1);
  } else {
    return 0;
  }
}

function pp_get_max_indent(state, param) {
  return state[/* pp_max_indent */7];
}

function pp_set_margin(state, n) {
  if (n >= 1) {
    var n$1 = pp_limit(n);
    state[/* pp_margin */5] = n$1;
    var new_max_indent = state[/* pp_max_indent */7] <= state[/* pp_margin */5] ? state[/* pp_max_indent */7] : caml_int_max(caml_int_max(state[/* pp_margin */5] - state[/* pp_min_space_left */6] | 0, state[/* pp_margin */5] / 2 | 0), 1);
    return pp_set_max_indent(state, new_max_indent);
  } else {
    return 0;
  }
}

function pp_get_margin(state, param) {
  return state[/* pp_margin */5];
}

function pp_set_formatter_out_functions(state, param) {
  state[/* pp_out_string */16] = param[/* out_string */0];
  state[/* pp_out_flush */17] = param[/* out_flush */1];
  state[/* pp_out_newline */18] = param[/* out_newline */2];
  state[/* pp_out_spaces */19] = param[/* out_spaces */3];
  return /* () */0;
}

function pp_get_formatter_out_functions(state, param) {
  return /* record */[
          /* out_string */state[/* pp_out_string */16],
          /* out_flush */state[/* pp_out_flush */17],
          /* out_newline */state[/* pp_out_newline */18],
          /* out_spaces */state[/* pp_out_spaces */19]
        ];
}

function pp_set_formatter_output_functions(state, f, g) {
  state[/* pp_out_string */16] = f;
  state[/* pp_out_flush */17] = g;
  return /* () */0;
}

function pp_get_formatter_output_functions(state, param) {
  return /* tuple */[
          state[/* pp_out_string */16],
          state[/* pp_out_flush */17]
        ];
}

function pp_set_all_formatter_output_functions(state, f, g, h, i) {
  pp_set_formatter_output_functions(state, f, g);
  state[/* pp_out_newline */18] = h;
  state[/* pp_out_spaces */19] = i;
  return /* () */0;
}

function pp_get_all_formatter_output_functions(state, param) {
  return /* tuple */[
          state[/* pp_out_string */16],
          state[/* pp_out_flush */17],
          state[/* pp_out_newline */18],
          state[/* pp_out_spaces */19]
        ];
}

function display_newline(state, param) {
  return _3(state[/* pp_out_string */16], "\n", 0, 1);
}

var blank_line = bytes_to_string(make(80, /* " " */32));

function display_blanks(state, _n) {
  while(true) {
    var n = _n;
    if (n > 0) {
      if (n <= 80) {
        return _3(state[/* pp_out_string */16], blank_line, 0, n);
      } else {
        _3(state[/* pp_out_string */16], blank_line, 0, 80);
        _n = n - 80 | 0;
        continue ;
      }
    } else {
      return 0;
    }
  }}

function pp_set_formatter_out_channel(state, os) {
  state[/* pp_out_string */16] = (function (param, param$1, param$2) {
      return output_substring(os, param, param$1, param$2);
    });
  state[/* pp_out_flush */17] = (function (param) {
      return caml_ml_flush(os);
    });
  state[/* pp_out_newline */18] = (function (param) {
      return display_newline(state);
    });
  state[/* pp_out_spaces */19] = (function (param) {
      return display_blanks(state, param);
    });
  return /* () */0;
}

function default_pp_mark_open_tag(s) {
  return "<" + (s + ">");
}

function default_pp_mark_close_tag(s) {
  return "</" + (s + ">");
}

function default_pp_print_open_tag(prim) {
  return /* () */0;
}

function default_pp_print_close_tag(prim) {
  return /* () */0;
}

function pp_make_formatter(f, g, h, i) {
  var pp_q = /* record */[
    /* insert : Nil */0,
    /* body : Nil */0
  ];
  var sys_tok = /* record */[
    /* elem_size */-1,
    /* token : Pp_begin */__(3, [
        0,
        /* Pp_hovbox */3
      ]),
    /* length */0
  ];
  add_queue(sys_tok, pp_q);
  var sys_scan_stack_000 = /* Scan_elem */[
    1,
    sys_tok
  ];
  var sys_scan_stack = /* :: */[
    sys_scan_stack_000,
    scan_stack_bottom
  ];
  return /* record */[
          /* pp_scan_stack */sys_scan_stack,
          /* pp_format_stack : [] */0,
          /* pp_tbox_stack : [] */0,
          /* pp_tag_stack : [] */0,
          /* pp_mark_stack : [] */0,
          /* pp_margin */78,
          /* pp_min_space_left */10,
          /* pp_max_indent */68,
          /* pp_space_left */78,
          /* pp_current_indent */0,
          /* pp_is_new_line */true,
          /* pp_left_total */1,
          /* pp_right_total */1,
          /* pp_curr_depth */1,
          /* pp_max_boxes */max_int$1,
          /* pp_ellipsis */".",
          /* pp_out_string */f,
          /* pp_out_flush */g,
          /* pp_out_newline */h,
          /* pp_out_spaces */i,
          /* pp_print_tags */false,
          /* pp_mark_tags */false,
          /* pp_mark_open_tag */default_pp_mark_open_tag,
          /* pp_mark_close_tag */default_pp_mark_close_tag,
          /* pp_print_open_tag */default_pp_print_open_tag,
          /* pp_print_close_tag */default_pp_print_close_tag,
          /* pp_queue */pp_q
        ];
}

function make_formatter(output, flush) {
  var ppf = pp_make_formatter(output, flush, (function (prim) {
          return /* () */0;
        }), (function (prim) {
          return /* () */0;
        }));
  ppf[/* pp_out_newline */18] = (function (param) {
      return display_newline(ppf);
    });
  ppf[/* pp_out_spaces */19] = (function (param) {
      return display_blanks(ppf, param);
    });
  return ppf;
}

function formatter_of_out_channel(oc) {
  return make_formatter((function (param, param$1, param$2) {
                return output_substring(oc, param, param$1, param$2);
              }), (function (param) {
                return caml_ml_flush(oc);
              }));
}

function formatter_of_buffer(b) {
  return make_formatter((function (param, param$1, param$2) {
                return add_substring(b, param, param$1, param$2);
              }), (function (prim) {
                return /* () */0;
              }));
}

var stdbuf = create$1(512);

var std_formatter = formatter_of_out_channel(stdout$1);

var err_formatter = formatter_of_out_channel(stderr$1);

var str_formatter = formatter_of_buffer(stdbuf);

function flush_str_formatter(param) {
  pp_flush_queue(str_formatter, false);
  var s = contents(stdbuf);
  reset(stdbuf);
  return s;
}

function flush_buf_formatter(buf, ppf) {
  pp_flush_queue(ppf, false);
  var s = contents(buf);
  reset(buf);
  return s;
}

function open_hbox(param) {
  return pp_open_hbox(std_formatter);
}

function open_vbox(param) {
  return pp_open_vbox(std_formatter, param);
}

function open_hvbox(param) {
  return pp_open_hvbox(std_formatter, param);
}

function open_hovbox(param) {
  return pp_open_hovbox(std_formatter, param);
}

function open_box(param) {
  return pp_open_box(std_formatter, param);
}

function close_box(param) {
  return pp_close_box(std_formatter);
}

function open_tag(param) {
  return pp_open_tag(std_formatter, param);
}

function close_tag(param) {
  return pp_close_tag(std_formatter);
}

function print_as(param, param$1) {
  return pp_print_as(std_formatter, param, param$1);
}

function print_string(param) {
  return pp_print_string(std_formatter, param);
}

function print_int(param) {
  return pp_print_string(std_formatter, String(param));
}

function print_float(param) {
  return pp_print_string(std_formatter, string_of_float(param));
}

function print_char(param) {
  return pp_print_char(std_formatter, param);
}

function print_bool(param) {
  return pp_print_string(std_formatter, param ? "true" : "false");
}

function print_break(param, param$1) {
  return pp_print_break(std_formatter, param, param$1);
}

function print_cut(param) {
  return pp_print_break(std_formatter, 0, 0);
}

function print_space(param) {
  return pp_print_break(std_formatter, 1, 0);
}

function force_newline(param) {
  return pp_force_newline(std_formatter);
}

function print_flush(param) {
  return pp_print_flush(std_formatter);
}

function print_newline(param) {
  return pp_print_newline(std_formatter);
}

function print_if_newline(param) {
  return pp_print_if_newline(std_formatter);
}

function open_tbox(param) {
  return pp_open_tbox(std_formatter);
}

function close_tbox(param) {
  return pp_close_tbox(std_formatter);
}

function print_tbreak(param, param$1) {
  return pp_print_tbreak(std_formatter, param, param$1);
}

function set_tab(param) {
  return pp_set_tab(std_formatter);
}

function print_tab(param) {
  return pp_print_tbreak(std_formatter, 0, 0);
}

function set_margin(param) {
  return pp_set_margin(std_formatter, param);
}

function get_margin(param) {
  return std_formatter[/* pp_margin */5];
}

function set_max_indent(param) {
  return pp_set_max_indent(std_formatter, param);
}

function get_max_indent(param) {
  return std_formatter[/* pp_max_indent */7];
}

function set_max_boxes(param) {
  return pp_set_max_boxes(std_formatter, param);
}

function get_max_boxes(param) {
  return std_formatter[/* pp_max_boxes */14];
}

function over_max_boxes(param) {
  return pp_over_max_boxes(std_formatter);
}

function set_ellipsis_text(param) {
  std_formatter[/* pp_ellipsis */15] = param;
  return /* () */0;
}

function get_ellipsis_text(param) {
  return std_formatter[/* pp_ellipsis */15];
}

function set_formatter_out_channel(param) {
  return pp_set_formatter_out_channel(std_formatter, param);
}

function set_formatter_out_functions(param) {
  return pp_set_formatter_out_functions(std_formatter, param);
}

function get_formatter_out_functions(param) {
  return pp_get_formatter_out_functions(std_formatter);
}

function set_formatter_output_functions(param, param$1) {
  return pp_set_formatter_output_functions(std_formatter, param, param$1);
}

function get_formatter_output_functions(param) {
  return pp_get_formatter_output_functions(std_formatter);
}

function set_all_formatter_output_functions(param, param$1, param$2, param$3) {
  return pp_set_all_formatter_output_functions(std_formatter, param, param$1, param$2, param$3);
}

function get_all_formatter_output_functions(param) {
  return pp_get_all_formatter_output_functions(std_formatter);
}

function set_formatter_tag_functions(param) {
  return pp_set_formatter_tag_functions(std_formatter, param);
}

function get_formatter_tag_functions(param) {
  return pp_get_formatter_tag_functions(std_formatter);
}

function set_print_tags(param) {
  std_formatter[/* pp_print_tags */20] = param;
  return /* () */0;
}

function get_print_tags(param) {
  return std_formatter[/* pp_print_tags */20];
}

function set_mark_tags(param) {
  std_formatter[/* pp_mark_tags */21] = param;
  return /* () */0;
}

function get_mark_tags(param) {
  return std_formatter[/* pp_mark_tags */21];
}

function set_tags(param) {
  return pp_set_tags(std_formatter, param);
}

function compute_tag(output, tag_acc) {
  var buf = create$1(16);
  var ppf = formatter_of_buffer(buf);
  _2(output, ppf, tag_acc);
  pp_print_flush(ppf);
  var len = buf[/* position */1];
  if (len < 2) {
    return contents(buf);
  } else {
    return sub$3(buf, 1, len - 2 | 0);
  }
}

function output_formatting_lit(ppf, fmting_lit) {
  if (typeof fmting_lit === "number") {
    switch (fmting_lit) {
      case /* Close_box */0 :
          return pp_close_box(ppf);
      case /* Close_tag */1 :
          return pp_close_tag(ppf);
      case /* FFlush */2 :
          return pp_print_flush(ppf);
      case /* Force_newline */3 :
          return pp_force_newline(ppf);
      case /* Flush_newline */4 :
          return pp_print_newline(ppf);
      case /* Escaped_at */5 :
          return pp_print_char(ppf, /* "@" */64);
      case /* Escaped_percent */6 :
          return pp_print_char(ppf, /* "%" */37);
      
    }
  } else {
    switch (fmting_lit.tag | 0) {
      case /* Break */0 :
          return pp_print_break(ppf, fmting_lit[1], fmting_lit[2]);
      case /* Magic_size */1 :
          return /* () */0;
      case /* Scan_indic */2 :
          pp_print_char(ppf, /* "@" */64);
          return pp_print_char(ppf, fmting_lit[0]);
      
    }
  }
}

function output_acc$1(ppf, acc) {
  var exit = 0;
  var p;
  var size;
  var s;
  var p$1;
  var size$1;
  var c;
  if (typeof acc === "number") {
    return /* () */0;
  } else {
    switch (acc.tag | 0) {
      case /* Acc_formatting_lit */0 :
          output_acc$1(ppf, acc[0]);
          return output_formatting_lit(ppf, acc[1]);
      case /* Acc_formatting_gen */1 :
          var match = acc[1];
          var p$2 = acc[0];
          output_acc$1(ppf, p$2);
          if (match.tag) {
            var match$1 = open_box_of_string(compute_tag(output_acc$1, match[0]));
            return pp_open_box_gen(ppf, match$1[0], match$1[1]);
          } else {
            return pp_open_tag(ppf, compute_tag(output_acc$1, match[0]));
          }
      case /* Acc_string_literal */2 :
          var p$3 = acc[0];
          if (typeof p$3 !== "number" && !p$3.tag) {
            var match$2 = p$3[1];
            if (typeof match$2 !== "number" && match$2.tag === /* Magic_size */1) {
              p = p$3[0];
              size = match$2[1];
              s = acc[1];
              exit = 1;
            }
            
          }
          output_acc$1(ppf, p$3);
          return pp_print_string(ppf, acc[1]);
      case /* Acc_char_literal */3 :
          var p$4 = acc[0];
          if (typeof p$4 !== "number" && !p$4.tag) {
            var match$3 = p$4[1];
            if (typeof match$3 !== "number" && match$3.tag === /* Magic_size */1) {
              p$1 = p$4[0];
              size$1 = match$3[1];
              c = acc[1];
              exit = 2;
            }
            
          }
          output_acc$1(ppf, p$4);
          return pp_print_char(ppf, acc[1]);
      case /* Acc_data_string */4 :
          var p$5 = acc[0];
          if (typeof p$5 !== "number" && !p$5.tag) {
            var match$4 = p$5[1];
            if (typeof match$4 !== "number" && match$4.tag === /* Magic_size */1) {
              p = p$5[0];
              size = match$4[1];
              s = acc[1];
              exit = 1;
            }
            
          }
          output_acc$1(ppf, p$5);
          return pp_print_string(ppf, acc[1]);
      case /* Acc_data_char */5 :
          var p$6 = acc[0];
          if (typeof p$6 !== "number" && !p$6.tag) {
            var match$5 = p$6[1];
            if (typeof match$5 !== "number" && match$5.tag === /* Magic_size */1) {
              p$1 = p$6[0];
              size$1 = match$5[1];
              c = acc[1];
              exit = 2;
            }
            
          }
          output_acc$1(ppf, p$6);
          return pp_print_char(ppf, acc[1]);
      case /* Acc_delay */6 :
          output_acc$1(ppf, acc[0]);
          return _1(acc[1], ppf);
      case /* Acc_flush */7 :
          output_acc$1(ppf, acc[0]);
          return pp_print_flush(ppf);
      case /* Acc_invalid_arg */8 :
          output_acc$1(ppf, acc[0]);
          throw [
                invalid_argument,
                acc[1]
              ];
      
    }
  }
  switch (exit) {
    case 1 :
        output_acc$1(ppf, p);
        return pp_print_as_size(ppf, size, s);
    case 2 :
        output_acc$1(ppf, p$1);
        return pp_print_as_size(ppf, size$1, bytes_to_string(make(1, c)));
    
  }
}

function strput_acc$1(ppf, acc) {
  var exit = 0;
  var p;
  var size;
  var s;
  var p$1;
  var size$1;
  var c;
  if (typeof acc === "number") {
    return /* () */0;
  } else {
    switch (acc.tag | 0) {
      case /* Acc_formatting_lit */0 :
          strput_acc$1(ppf, acc[0]);
          return output_formatting_lit(ppf, acc[1]);
      case /* Acc_formatting_gen */1 :
          var match = acc[1];
          var p$2 = acc[0];
          strput_acc$1(ppf, p$2);
          if (match.tag) {
            var match$1 = open_box_of_string(compute_tag(strput_acc$1, match[0]));
            return pp_open_box_gen(ppf, match$1[0], match$1[1]);
          } else {
            return pp_open_tag(ppf, compute_tag(strput_acc$1, match[0]));
          }
      case /* Acc_string_literal */2 :
          var p$3 = acc[0];
          if (typeof p$3 !== "number" && !p$3.tag) {
            var match$2 = p$3[1];
            if (typeof match$2 !== "number" && match$2.tag === /* Magic_size */1) {
              p = p$3[0];
              size = match$2[1];
              s = acc[1];
              exit = 1;
            }
            
          }
          strput_acc$1(ppf, p$3);
          return pp_print_string(ppf, acc[1]);
      case /* Acc_char_literal */3 :
          var p$4 = acc[0];
          if (typeof p$4 !== "number" && !p$4.tag) {
            var match$3 = p$4[1];
            if (typeof match$3 !== "number" && match$3.tag === /* Magic_size */1) {
              p$1 = p$4[0];
              size$1 = match$3[1];
              c = acc[1];
              exit = 2;
            }
            
          }
          strput_acc$1(ppf, p$4);
          return pp_print_char(ppf, acc[1]);
      case /* Acc_data_string */4 :
          var p$5 = acc[0];
          if (typeof p$5 !== "number" && !p$5.tag) {
            var match$4 = p$5[1];
            if (typeof match$4 !== "number" && match$4.tag === /* Magic_size */1) {
              p = p$5[0];
              size = match$4[1];
              s = acc[1];
              exit = 1;
            }
            
          }
          strput_acc$1(ppf, p$5);
          return pp_print_string(ppf, acc[1]);
      case /* Acc_data_char */5 :
          var p$6 = acc[0];
          if (typeof p$6 !== "number" && !p$6.tag) {
            var match$5 = p$6[1];
            if (typeof match$5 !== "number" && match$5.tag === /* Magic_size */1) {
              p$1 = p$6[0];
              size$1 = match$5[1];
              c = acc[1];
              exit = 2;
            }
            
          }
          strput_acc$1(ppf, p$6);
          return pp_print_char(ppf, acc[1]);
      case /* Acc_delay */6 :
          var p$7 = acc[0];
          if (typeof p$7 !== "number" && !p$7.tag) {
            var match$6 = p$7[1];
            if (typeof match$6 !== "number" && match$6.tag === /* Magic_size */1) {
              strput_acc$1(ppf, p$7[0]);
              return pp_print_as_size(ppf, match$6[1], _1(acc[1], /* () */0));
            }
            
          }
          strput_acc$1(ppf, p$7);
          return pp_print_string(ppf, _1(acc[1], /* () */0));
      case /* Acc_flush */7 :
          strput_acc$1(ppf, acc[0]);
          return pp_print_flush(ppf);
      case /* Acc_invalid_arg */8 :
          strput_acc$1(ppf, acc[0]);
          throw [
                invalid_argument,
                acc[1]
              ];
      
    }
  }
  switch (exit) {
    case 1 :
        strput_acc$1(ppf, p);
        return pp_print_as_size(ppf, size, s);
    case 2 :
        strput_acc$1(ppf, p$1);
        return pp_print_as_size(ppf, size$1, bytes_to_string(make(1, c)));
    
  }
}

function kfprintf(k, o, param) {
  return make_printf((function (o, acc) {
                output_acc$1(o, acc);
                return _1(k, o);
              }), o, /* End_of_acc */0, param[0]);
}

function ikfprintf(k, x, param) {
  return make_printf((function (param, param$1) {
                return _1(k, x);
              }), x, /* End_of_acc */0, param[0]);
}

function fprintf(ppf, fmt) {
  return kfprintf((function (prim) {
                return /* () */0;
              }), ppf, fmt);
}

function ifprintf(ppf, fmt) {
  return ikfprintf((function (prim) {
                return /* () */0;
              }), ppf, fmt);
}

function printf(fmt) {
  return fprintf(std_formatter, fmt);
}

function eprintf(fmt) {
  return fprintf(err_formatter, fmt);
}

function ksprintf(k, param) {
  var b = create$1(512);
  var ppf = formatter_of_buffer(b);
  var k$prime = function (param, acc) {
    strput_acc$1(ppf, acc);
    return _1(k, flush_buf_formatter(b, ppf));
  };
  return make_printf(k$prime, /* () */0, /* End_of_acc */0, param[0]);
}

function sprintf(fmt) {
  return ksprintf((function (s) {
                return s;
              }), fmt);
}

function asprintf(param) {
  var b = create$1(512);
  var ppf = formatter_of_buffer(b);
  var k$prime = function (ppf, acc) {
    output_acc$1(ppf, acc);
    pp_flush_queue(ppf, false);
    return flush_buf_formatter(b, ppf);
  };
  return make_printf(k$prime, ppf, /* End_of_acc */0, param[0]);
}

function bprintf(b, param) {
  var k = function (ppf, acc) {
    output_acc$1(ppf, acc);
    return pp_flush_queue(ppf, false);
  };
  return make_printf(k, formatter_of_buffer(b), /* End_of_acc */0, param[0]);
}

at_exit(print_flush);

var kprintf = ksprintf;
/* blank_line Not a pure module */

var Format = /*#__PURE__*/Object.freeze({
    __proto__: null,
    open_box: open_box,
    close_box: close_box,
    print_string: print_string,
    print_as: print_as,
    print_int: print_int,
    print_float: print_float,
    print_char: print_char,
    print_bool: print_bool,
    print_space: print_space,
    print_cut: print_cut,
    print_break: print_break,
    print_flush: print_flush,
    print_newline: print_newline,
    force_newline: force_newline,
    print_if_newline: print_if_newline,
    set_margin: set_margin,
    get_margin: get_margin,
    set_max_indent: set_max_indent,
    get_max_indent: get_max_indent,
    set_max_boxes: set_max_boxes,
    get_max_boxes: get_max_boxes,
    over_max_boxes: over_max_boxes,
    open_hbox: open_hbox,
    open_vbox: open_vbox,
    open_hvbox: open_hvbox,
    open_hovbox: open_hovbox,
    open_tbox: open_tbox,
    close_tbox: close_tbox,
    print_tbreak: print_tbreak,
    set_tab: set_tab,
    print_tab: print_tab,
    set_ellipsis_text: set_ellipsis_text,
    get_ellipsis_text: get_ellipsis_text,
    open_tag: open_tag,
    close_tag: close_tag,
    set_tags: set_tags,
    set_print_tags: set_print_tags,
    set_mark_tags: set_mark_tags,
    get_print_tags: get_print_tags,
    get_mark_tags: get_mark_tags,
    set_formatter_out_channel: set_formatter_out_channel,
    set_formatter_output_functions: set_formatter_output_functions,
    get_formatter_output_functions: get_formatter_output_functions,
    set_formatter_out_functions: set_formatter_out_functions,
    get_formatter_out_functions: get_formatter_out_functions,
    set_formatter_tag_functions: set_formatter_tag_functions,
    get_formatter_tag_functions: get_formatter_tag_functions,
    formatter_of_out_channel: formatter_of_out_channel,
    std_formatter: std_formatter,
    err_formatter: err_formatter,
    formatter_of_buffer: formatter_of_buffer,
    stdbuf: stdbuf,
    str_formatter: str_formatter,
    flush_str_formatter: flush_str_formatter,
    make_formatter: make_formatter,
    pp_open_hbox: pp_open_hbox,
    pp_open_vbox: pp_open_vbox,
    pp_open_hvbox: pp_open_hvbox,
    pp_open_hovbox: pp_open_hovbox,
    pp_open_box: pp_open_box,
    pp_close_box: pp_close_box,
    pp_open_tag: pp_open_tag,
    pp_close_tag: pp_close_tag,
    pp_print_string: pp_print_string,
    pp_print_as: pp_print_as,
    pp_print_int: pp_print_int,
    pp_print_float: pp_print_float,
    pp_print_char: pp_print_char,
    pp_print_bool: pp_print_bool,
    pp_print_break: pp_print_break,
    pp_print_cut: pp_print_cut,
    pp_print_space: pp_print_space,
    pp_force_newline: pp_force_newline,
    pp_print_flush: pp_print_flush,
    pp_print_newline: pp_print_newline,
    pp_print_if_newline: pp_print_if_newline,
    pp_open_tbox: pp_open_tbox,
    pp_close_tbox: pp_close_tbox,
    pp_print_tbreak: pp_print_tbreak,
    pp_set_tab: pp_set_tab,
    pp_print_tab: pp_print_tab,
    pp_set_tags: pp_set_tags,
    pp_set_print_tags: pp_set_print_tags,
    pp_set_mark_tags: pp_set_mark_tags,
    pp_get_print_tags: pp_get_print_tags,
    pp_get_mark_tags: pp_get_mark_tags,
    pp_set_margin: pp_set_margin,
    pp_get_margin: pp_get_margin,
    pp_set_max_indent: pp_set_max_indent,
    pp_get_max_indent: pp_get_max_indent,
    pp_set_max_boxes: pp_set_max_boxes,
    pp_get_max_boxes: pp_get_max_boxes,
    pp_over_max_boxes: pp_over_max_boxes,
    pp_set_ellipsis_text: pp_set_ellipsis_text,
    pp_get_ellipsis_text: pp_get_ellipsis_text,
    pp_set_formatter_out_channel: pp_set_formatter_out_channel,
    pp_set_formatter_output_functions: pp_set_formatter_output_functions,
    pp_get_formatter_output_functions: pp_get_formatter_output_functions,
    pp_set_formatter_tag_functions: pp_set_formatter_tag_functions,
    pp_get_formatter_tag_functions: pp_get_formatter_tag_functions,
    pp_set_formatter_out_functions: pp_set_formatter_out_functions,
    pp_get_formatter_out_functions: pp_get_formatter_out_functions,
    pp_print_list: pp_print_list,
    pp_print_text: pp_print_text,
    fprintf: fprintf,
    printf: printf,
    eprintf: eprintf,
    sprintf: sprintf,
    asprintf: asprintf,
    ifprintf: ifprintf,
    kfprintf: kfprintf,
    ikfprintf: ikfprintf,
    ksprintf: ksprintf,
    bprintf: bprintf,
    kprintf: kprintf,
    set_all_formatter_output_functions: set_all_formatter_output_functions,
    get_all_formatter_output_functions: get_all_formatter_output_functions,
    pp_set_all_formatter_output_functions: pp_set_all_formatter_output_functions,
    pp_get_all_formatter_output_functions: pp_get_all_formatter_output_functions
});

var WrongPlatform = create("AST.WrongPlatform");

function unavailable_on(target, name) {
  throw [
        WrongPlatform,
        target,
        name
      ];
}

function tOfJs(param) {
  throw [
        WrongPlatform,
        /* Native */-693027401,
        "tOfJs"
      ];
}

function expressionOfJs(param) {
  throw [
        WrongPlatform,
        /* Native */-693027401,
        "expressionOfJs"
      ];
}

function to_yojson(param) {
  throw [
        WrongPlatform,
        /* JavaScript */500616045,
        "to_yojson"
      ];
}

function of_yojson(param) {
  throw [
        WrongPlatform,
        /* JavaScript */500616045,
        "of_yojson"
      ];
}

function expression_to_yojson(param) {
  throw [
        WrongPlatform,
        /* JavaScript */500616045,
        "expression_to_yojson"
      ];
}

function expression_of_yojson(param) {
  throw [
        WrongPlatform,
        /* JavaScript */500616045,
        "expression_of_yojson"
      ];
}

function flagToJs(param) {
  return {
          name: param[/* name */0],
          payload: param[/* payload */1]
        };
}

function flagFromJs(param) {
  return /* record */[
          /* name */param.name,
          /* payload */param.payload
        ];
}

function expressionToJs(param) {
  return {
          count: param[/* count */0],
          cmd: param[/* cmd */1],
          rev_args: param[/* rev_args */2]
        };
}

function expressionFromJs(param) {
  return /* record */[
          /* count */param.count,
          /* cmd */param.cmd,
          /* rev_args */param.rev_args
        ];
}

function tToJs(param) {
  return {
          expressions: param[/* expressions */0]
        };
}

function tFromJs(param) {
  return /* record */[/* expressions */param.expressions];
}

function make_expression(count, cmd, rev_args) {
  return /* record */[
          /* count */count !== undefined ? caml_int_of_string(count) : 1,
          /* cmd */cmd,
          /* rev_args */rev_args
        ];
}

function pipe_last(from, into) {
  var match = into[/* rev_args */2];
  var new_args;
  if (match) {
    var match$1 = match[0];
    if (match$1.tag) {
      var flg = match$1[0];
      var match$2 = flg[/* payload */1];
      if (typeof match$2 === "number") {
        if (match$2 !== 0) {
          var new_flag = /* record */[
            /* name */flg[/* name */0],
            /* payload : Unresolved */0
          ];
          new_args = /* :: */[
            /* Flag */__(1, [new_flag]),
            match[1]
          ];
        } else {
          new_args = failwith("unreachable: pipe_last, unresolved-flag in last position");
        }
      } else {
        new_args = into[/* rev_args */2];
      }
    } else {
      new_args = into[/* rev_args */2];
    }
  } else {
    new_args = /* [] */0;
  }
  var new_args_000 = /* Positional */__(0, [/* Sub */__(0, [from])]);
  var new_args$1 = /* :: */[
    new_args_000,
    new_args
  ];
  return /* record */[
          /* count */into[/* count */0],
          /* cmd */into[/* cmd */1],
          /* rev_args */new_args$1
        ];
}

function copy_string_or_subexpr(sos) {
  if (sos.tag) {
    return /* Literal */__(1, [copy$1(sos[0])]);
  } else {
    return /* Sub */__(0, [copy_expression(sos[0])]);
  }
}

function copy_flag(flg) {
  var match = flg[/* payload */1];
  return /* record */[
          /* name */flg[/* name */0],
          /* payload */typeof match === "number" ? (
              match !== 0 ? /* Absent */1 : /* Unresolved */0
            ) : /* Resolved */[copy_string_or_subexpr(match[0])]
        ];
}

function copy_arg(arg) {
  if (arg.tag) {
    return /* Flag */__(1, [copy_flag(arg[0])]);
  } else {
    return /* Positional */__(0, [copy_string_or_subexpr(arg[0])]);
  }
}

function copy_expression(expr) {
  return /* record */[
          /* count */expr[/* count */0],
          /* cmd */copy_string_or_subexpr(expr[/* cmd */1]),
          /* rev_args */map(copy_arg, expr[/* rev_args */2])
        ];
}

function copy$2(ast) {
  return /* record */[/* expressions */map$1(copy_expression, ast[/* expressions */0])];
}

function pp_bs(ast) {
  var obj = tToJs(ast);
  console.log(undefined_to_opt(JSON.stringify(obj)));
  return /* () */0;
}

function pp_native(ast) {
  throw [
        WrongPlatform,
        /* JavaScript */500616045,
        "to_yojson"
      ];
}

function pp(ast) {
  try {
    return pp_bs(ast);
  }
  catch (raw_exn){
    var exn = internalToOCamlException(raw_exn);
    if (exn[0] === WrongPlatform) {
      if (exn[1] !== -693027401) {
        throw exn;
      }
      return pp_native();
    } else {
      throw exn;
    }
  }
}

function pp_expression_bs(expr) {
  var obj = expressionToJs(expr);
  console.log(undefined_to_opt(JSON.stringify(obj)));
  return /* () */0;
}

function pp_expression_native(expr) {
  throw [
        WrongPlatform,
        /* JavaScript */500616045,
        "expression_to_yojson"
      ];
}

function pp_expression(ast) {
  try {
    return pp_expression_bs(ast);
  }
  catch (raw_exn){
    var exn = internalToOCamlException(raw_exn);
    if (exn[0] === WrongPlatform) {
      if (exn[1] !== -693027401) {
        throw exn;
      }
      return pp_expression_native();
    } else {
      throw exn;
    }
  }
}

function is_literal(param) {
  if (param.tag) {
    return true;
  } else {
    return false;
  }
}

function get_literal_exn(param) {
  if (param.tag) {
    return param[0];
  } else {
    throw not_found;
  }
}

function get_sub_exn(param) {
  if (param.tag) {
    throw not_found;
  } else {
    return param[0];
  }
}
/* Format Not a pure module */

var $_AST = /*#__PURE__*/Object.freeze({
    __proto__: null,
    WrongPlatform: WrongPlatform,
    unavailable_on: unavailable_on,
    tOfJs: tOfJs,
    expressionOfJs: expressionOfJs,
    to_yojson: to_yojson,
    of_yojson: of_yojson,
    expression_to_yojson: expression_to_yojson,
    expression_of_yojson: expression_of_yojson,
    flagToJs: flagToJs,
    flagFromJs: flagFromJs,
    expressionToJs: expressionToJs,
    expressionFromJs: expressionFromJs,
    tToJs: tToJs,
    tFromJs: tFromJs,
    make_expression: make_expression,
    pipe_last: pipe_last,
    copy_string_or_subexpr: copy_string_or_subexpr,
    copy_flag: copy_flag,
    copy_arg: copy_arg,
    copy_expression: copy_expression,
    copy: copy$2,
    pp_bs: pp_bs,
    pp_native: pp_native,
    pp: pp,
    pp_expression_bs: pp_expression_bs,
    pp_expression_native: pp_expression_native,
    pp_expression: pp_expression,
    is_literal: is_literal,
    get_literal_exn: get_literal_exn,
    get_sub_exn: get_sub_exn
});

var Empty = create("Queue.Empty");
/* No side effect */

var max_int$2 = 2147483647;
/* No side effect */

var max_int$3 = /* int64 */[
  /* hi */2147483647,
  /* lo */4294967295
];
/* No side effect */

function cmn(q, a, b, x, s, t) {
  var a$1 = ((a + q | 0) + x | 0) + t | 0;
  return ((a$1 << s) | (a$1 >>> (32 - s | 0)) | 0) + b | 0;
}

function f(a, b, c, d, x, s, t) {
  return cmn(b & c | (b ^ -1) & d, a, b, x, s, t);
}

function g(a, b, c, d, x, s, t) {
  return cmn(b & d | c & (d ^ -1), a, b, x, s, t);
}

function h(a, b, c, d, x, s, t) {
  return cmn(b ^ c ^ d, a, b, x, s, t);
}

function i(a, b, c, d, x, s, t) {
  return cmn(c ^ (b | d ^ -1), a, b, x, s, t);
}

function cycle(x, k) {
  var a = x[0];
  var b = x[1];
  var c = x[2];
  var d = x[3];
  a = f(a, b, c, d, k[0], 7, -680876936);
  d = f(d, a, b, c, k[1], 12, -389564586);
  c = f(c, d, a, b, k[2], 17, 606105819);
  b = f(b, c, d, a, k[3], 22, -1044525330);
  a = f(a, b, c, d, k[4], 7, -176418897);
  d = f(d, a, b, c, k[5], 12, 1200080426);
  c = f(c, d, a, b, k[6], 17, -1473231341);
  b = f(b, c, d, a, k[7], 22, -45705983);
  a = f(a, b, c, d, k[8], 7, 1770035416);
  d = f(d, a, b, c, k[9], 12, -1958414417);
  c = f(c, d, a, b, k[10], 17, -42063);
  b = f(b, c, d, a, k[11], 22, -1990404162);
  a = f(a, b, c, d, k[12], 7, 1804603682);
  d = f(d, a, b, c, k[13], 12, -40341101);
  c = f(c, d, a, b, k[14], 17, -1502002290);
  b = f(b, c, d, a, k[15], 22, 1236535329);
  a = g(a, b, c, d, k[1], 5, -165796510);
  d = g(d, a, b, c, k[6], 9, -1069501632);
  c = g(c, d, a, b, k[11], 14, 643717713);
  b = g(b, c, d, a, k[0], 20, -373897302);
  a = g(a, b, c, d, k[5], 5, -701558691);
  d = g(d, a, b, c, k[10], 9, 38016083);
  c = g(c, d, a, b, k[15], 14, -660478335);
  b = g(b, c, d, a, k[4], 20, -405537848);
  a = g(a, b, c, d, k[9], 5, 568446438);
  d = g(d, a, b, c, k[14], 9, -1019803690);
  c = g(c, d, a, b, k[3], 14, -187363961);
  b = g(b, c, d, a, k[8], 20, 1163531501);
  a = g(a, b, c, d, k[13], 5, -1444681467);
  d = g(d, a, b, c, k[2], 9, -51403784);
  c = g(c, d, a, b, k[7], 14, 1735328473);
  b = g(b, c, d, a, k[12], 20, -1926607734);
  a = h(a, b, c, d, k[5], 4, -378558);
  d = h(d, a, b, c, k[8], 11, -2022574463);
  c = h(c, d, a, b, k[11], 16, 1839030562);
  b = h(b, c, d, a, k[14], 23, -35309556);
  a = h(a, b, c, d, k[1], 4, -1530992060);
  d = h(d, a, b, c, k[4], 11, 1272893353);
  c = h(c, d, a, b, k[7], 16, -155497632);
  b = h(b, c, d, a, k[10], 23, -1094730640);
  a = h(a, b, c, d, k[13], 4, 681279174);
  d = h(d, a, b, c, k[0], 11, -358537222);
  c = h(c, d, a, b, k[3], 16, -722521979);
  b = h(b, c, d, a, k[6], 23, 76029189);
  a = h(a, b, c, d, k[9], 4, -640364487);
  d = h(d, a, b, c, k[12], 11, -421815835);
  c = h(c, d, a, b, k[15], 16, 530742520);
  b = h(b, c, d, a, k[2], 23, -995338651);
  a = i(a, b, c, d, k[0], 6, -198630844);
  d = i(d, a, b, c, k[7], 10, 1126891415);
  c = i(c, d, a, b, k[14], 15, -1416354905);
  b = i(b, c, d, a, k[5], 21, -57434055);
  a = i(a, b, c, d, k[12], 6, 1700485571);
  d = i(d, a, b, c, k[3], 10, -1894986606);
  c = i(c, d, a, b, k[10], 15, -1051523);
  b = i(b, c, d, a, k[1], 21, -2054922799);
  a = i(a, b, c, d, k[8], 6, 1873313359);
  d = i(d, a, b, c, k[15], 10, -30611744);
  c = i(c, d, a, b, k[6], 15, -1560198380);
  b = i(b, c, d, a, k[13], 21, 1309151649);
  a = i(a, b, c, d, k[4], 6, -145523070);
  d = i(d, a, b, c, k[11], 10, -1120210379);
  c = i(c, d, a, b, k[2], 15, 718787259);
  b = i(b, c, d, a, k[9], 21, -343485551);
  x[0] = a + x[0] | 0;
  x[1] = b + x[1] | 0;
  x[2] = c + x[2] | 0;
  x[3] = d + x[3] | 0;
  return /* () */0;
}

var state = /* array */[
  1732584193,
  -271733879,
  -1732584194,
  271733878
];

var md5blk = /* array */[
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0
];

function caml_md5_string(s, start, len) {
  var s$1 = s.slice(start, len);
  var n = s$1.length;
  state[0] = 1732584193;
  state[1] = -271733879;
  state[2] = -1732584194;
  state[3] = 271733878;
  for(var i = 0; i <= 15; ++i){
    md5blk[i] = 0;
  }
  var i_end = n / 64 | 0;
  for(var i$1 = 1; i$1 <= i_end; ++i$1){
    for(var j = 0; j <= 15; ++j){
      var k = ((i$1 << 6) - 64 | 0) + (j << 2) | 0;
      md5blk[j] = ((s$1.charCodeAt(k) + (s$1.charCodeAt(k + 1 | 0) << 8) | 0) + (s$1.charCodeAt(k + 2 | 0) << 16) | 0) + (s$1.charCodeAt(k + 3 | 0) << 24) | 0;
    }
    cycle(state, md5blk);
  }
  var s_tail = s$1.slice((i_end << 6));
  for(var kk = 0; kk <= 15; ++kk){
    md5blk[kk] = 0;
  }
  var i_end$1 = s_tail.length - 1 | 0;
  for(var i$2 = 0; i$2 <= i_end$1; ++i$2){
    md5blk[i$2 / 4 | 0] = md5blk[i$2 / 4 | 0] | (s_tail.charCodeAt(i$2) << (i$2 % 4 << 3));
  }
  var i$3 = i_end$1 + 1 | 0;
  md5blk[i$3 / 4 | 0] = md5blk[i$3 / 4 | 0] | (128 << (i$3 % 4 << 3));
  if (i$3 > 55) {
    cycle(state, md5blk);
    for(var i$4 = 0; i$4 <= 15; ++i$4){
      md5blk[i$4] = 0;
    }
  }
  md5blk[14] = (n << 3);
  cycle(state, md5blk);
  return String.fromCharCode(state[0] & 255, (state[0] >> 8) & 255, (state[0] >> 16) & 255, (state[0] >> 24) & 255, state[1] & 255, (state[1] >> 8) & 255, (state[1] >> 16) & 255, (state[1] >> 24) & 255, state[2] & 255, (state[2] >> 8) & 255, (state[2] >> 16) & 255, (state[2] >> 24) & 255, state[3] & 255, (state[3] >> 8) & 255, (state[3] >> 16) & 255, (state[3] >> 24) & 255);
}
/* No side effect */

function string(str) {
  return caml_md5_string(str, 0, str.length);
}
/* No side effect */

function assign(st1, st2) {
  blit(st2[/* st */0], 0, st1[/* st */0], 0, 55);
  st1[/* idx */1] = st2[/* idx */1];
  return /* () */0;
}

function full_init(s, seed) {
  var combine = function (accu, x) {
    return string(accu + String(x));
  };
  var extract = function (d) {
    return ((get(d, 0) + (get(d, 1) << 8) | 0) + (get(d, 2) << 16) | 0) + (get(d, 3) << 24) | 0;
  };
  var seed$1 = seed.length === 0 ? /* array */[0] : seed;
  var l = seed$1.length;
  for(var i = 0; i <= 54; ++i){
    caml_array_set(s[/* st */0], i, i);
  }
  var accu = "x";
  for(var i$1 = 0 ,i_finish = 54 + (
      55 > l ? 55 : l
    ) | 0; i$1 <= i_finish; ++i$1){
    var j = i$1 % 55;
    var k = i$1 % l;
    accu = combine(accu, caml_array_get(seed$1, k));
    caml_array_set(s[/* st */0], j, (caml_array_get(s[/* st */0], j) ^ extract(accu)) & 1073741823);
  }
  s[/* idx */1] = 0;
  return /* () */0;
}

function make$2(seed) {
  var result = /* record */[
    /* st */caml_make_vect(55, 0),
    /* idx */0
  ];
  full_init(result, seed);
  return result;
}

function make_self_init(param) {
  return make$2(caml_sys_random_seed());
}

function copy$3(s) {
  var result = /* record */[
    /* st */caml_make_vect(55, 0),
    /* idx */0
  ];
  assign(result, s);
  return result;
}

function bits(s) {
  s[/* idx */1] = (s[/* idx */1] + 1 | 0) % 55;
  var curval = caml_array_get(s[/* st */0], s[/* idx */1]);
  var newval = caml_array_get(s[/* st */0], (s[/* idx */1] + 24 | 0) % 55) + (curval ^ (curval >>> 25) & 31) | 0;
  var newval30 = newval & 1073741823;
  caml_array_set(s[/* st */0], s[/* idx */1], newval30);
  return newval30;
}

function $$int(s, bound) {
  if (bound > 1073741823 || bound <= 0) {
    throw [
          invalid_argument,
          "Random.int"
        ];
  }
  var s$1 = s;
  var n = bound;
  while(true) {
    var r = bits(s$1);
    var v = r % n;
    if ((r - v | 0) > ((1073741823 - n | 0) + 1 | 0)) {
      continue ;
    } else {
      return v;
    }
  }}

function int32(s, bound) {
  if (bound <= 0) {
    throw [
          invalid_argument,
          "Random.int32"
        ];
  }
  var s$1 = s;
  var n = bound;
  while(true) {
    var b1 = bits(s$1);
    var b2 = ((bits(s$1) & 1) << 30);
    var r = b1 | b2;
    var v = r % n;
    if ((r - v | 0) > ((max_int$2 - n | 0) + 1 | 0)) {
      continue ;
    } else {
      return v;
    }
  }}

function int64(s, bound) {
  if (le(bound, /* int64 */[
          /* hi */0,
          /* lo */0
        ])) {
    throw [
          invalid_argument,
          "Random.int64"
        ];
  }
  var s$1 = s;
  var n = bound;
  while(true) {
    var b1 = of_int32(bits(s$1));
    var b2 = lsl_(of_int32(bits(s$1)), 30);
    var b3 = lsl_(of_int32(bits(s$1) & 7), 60);
    var r = or_(b1, /* int64 */[
          /* hi */b2[0] | b3[0],
          /* lo */((b2[1] | b3[1]) >>> 0)
        ]);
    var v = mod_(r, n);
    if (gt(sub(r, v), add(sub(max_int$3, n), /* int64 */[
                /* hi */0,
                /* lo */1
              ]))) {
      continue ;
    } else {
      return v;
    }
  }}

var nativeint =  (function (s, bound) {
      return int64(s, of_int32(bound))[1] | 0;
    });

function rawfloat(s) {
  var r1 = bits(s);
  var r2 = bits(s);
  return (r1 / 1073741824.0 + r2) / 1073741824.0;
}

function $$float(s, bound) {
  return rawfloat(s) * bound;
}

function bool(s) {
  return (bits(s) & 1) === 0;
}

var State = {
  make: make$2,
  make_self_init: make_self_init,
  copy: copy$3,
  bits: bits,
  $$int: $$int,
  int32: int32,
  nativeint: nativeint,
  int64: int64,
  $$float: $$float,
  bool: bool
};
/* No side effect */

var lazy_tag = 246;

var forward_tag = 250;
/* No side effect */

var caml_methods_cache = caml_make_vect(1000, 0);
/* No side effect */

// Generated by BUCKLESCRIPT, PLEASE EDIT WITH CARE

function next(gen) {
  return _1(gen, /* () */0);
}

function fold(f, _acc, gen) {
  while(true) {
    var acc = _acc;
    var match = _1(gen, /* () */0);
    if (match !== undefined) {
      _acc = _2(f, acc, valFromOption(match));
      continue ;
    } else {
      return acc;
    }
  }}

function map$2(f, gen) {
  var stop = /* record */[/* contents */false];
  return (function (param) {
      if (stop[0]) {
        return ;
      } else {
        var match = _1(gen, /* () */0);
        if (match !== undefined) {
          return some(_1(f, valFromOption(match)));
        } else {
          stop[0] = true;
          return ;
        }
      }
    });
}

function mapi(f) {
  var cnt = /* record */[/* contents */0];
  return (function (param) {
      return map$2((function (x) {
                    var i = cnt[0];
                    cnt[0] = i + 1 | 0;
                    return _2(f, i, x);
                  }), param);
    });
}

function filter_map(f, gen) {
  var next = function (_param) {
    while(true) {
      var match = _1(gen, /* () */0);
      if (match !== undefined) {
        var res = _1(f, valFromOption(match));
        if (res !== undefined) {
          return res;
        } else {
          continue ;
        }
      } else {
        return ;
      }
    }  };
  return next;
}

function of_list$1(l) {
  var l$1 = /* record */[/* contents */l];
  return (function (param) {
      var match = l$1[0];
      if (match) {
        l$1[0] = match[1];
        return some(match[0]);
      }
      
    });
}

function to_rev_list(gen) {
  return fold((function (acc, x) {
                return /* :: */[
                        x,
                        acc
                      ];
              }), /* [] */0, gen);
}

function to_list(gen) {
  return rev(to_rev_list(gen));
}

function peek(g) {
  var state = /* record */[/* contents : Start */389604418];
  var next = function (_param) {
    while(true) {
      var match = state[0];
      if (typeof match === "number") {
        if (match >= 926227490) {
          return ;
        } else {
          var match$1 = _1(g, /* () */0);
          if (match$1 !== undefined) {
            state[0] = /* `At */[
              14611,
              valFromOption(match$1)
            ];
            continue ;
          } else {
            state[0] = /* Stop */926227490;
            return ;
          }
        }
      } else {
        var x = match[1];
        var res = _1(g, /* () */0);
        if (res !== undefined) {
          state[0] = /* `At */[
            14611,
            valFromOption(res)
          ];
          return /* tuple */[
                  x,
                  res
                ];
        } else {
          state[0] = /* Stop */926227490;
          return /* tuple */[
                  x,
                  undefined
                ];
        }
      }
    }  };
  return next;
}
/* Format Not a pure module */

function kfprintf$1(k, o, param) {
  return make_printf((function (o, acc) {
                output_acc(o, acc);
                return _1(k, o);
              }), o, /* End_of_acc */0, param[0]);
}

function fprintf$1(oc, fmt) {
  return kfprintf$1((function (prim) {
                return /* () */0;
              }), oc, fmt);
}

function ksprintf$1(k, param) {
  var k$prime = function (param, acc) {
    var buf = create$1(64);
    strput_acc(buf, acc);
    return _1(k, contents(buf));
  };
  return make_printf(k$prime, /* () */0, /* End_of_acc */0, param[0]);
}

function sprintf$1(fmt) {
  return ksprintf$1((function (s) {
                return s;
              }), fmt);
}
/* No side effect */

var Undefined = create("CamlinternalLazy.Undefined");

function raise_undefined(param) {
  throw Undefined;
}

function force_lazy_block(blk) {
  var closure = blk[0];
  blk[0] = raise_undefined;
  try {
    var result = _1(closure, /* () */0);
    blk[0] = result;
    caml_obj_set_tag(blk, forward_tag);
    return result;
  }
  catch (e){
    blk[0] = (function (param) {
        throw e;
      });
    throw e;
  }
}

function force(lzv) {
  var t = lzv.tag | 0;
  if (t === forward_tag) {
    return lzv[0];
  } else if (t !== lazy_tag) {
    return lzv;
  } else {
    return force_lazy_block(lzv);
  }
}
/* No side effect */

var Empty$1 = create("Stack.Empty");
/* No side effect */

var prng = caml_lazy_make((function (param) {
        return State.make_self_init(/* () */0);
      }));
/* No side effect */

var locfmt = /* Format */[
  /* String_literal */__(11, [
      "File \"",
      /* String */__(2, [
          /* No_padding */0,
          /* String_literal */__(11, [
              "\", line ",
              /* Int */__(4, [
                  /* Int_d */0,
                  /* No_padding */0,
                  /* No_precision */0,
                  /* String_literal */__(11, [
                      ", characters ",
                      /* Int */__(4, [
                          /* Int_d */0,
                          /* No_padding */0,
                          /* No_precision */0,
                          /* Char_literal */__(12, [
                              /* "-" */45,
                              /* Int */__(4, [
                                  /* Int_d */0,
                                  /* No_padding */0,
                                  /* No_precision */0,
                                  /* String_literal */__(11, [
                                      ": ",
                                      /* String */__(2, [
                                          /* No_padding */0,
                                          /* End_of_format */0
                                        ])
                                    ])
                                ])
                            ])
                        ])
                    ])
                ])
            ])
        ])
    ]),
  "File \"%s\", line %d, characters %d-%d: %s"
];
/* No side effect */

var Format$1 = Format;
/* Format Not a pure module */

function pp_token(fmt, param) {
  if (typeof param === "number") {
    switch (param) {
      case /* SEMICOLON */0 :
          return _2(Format$1.pp_print_string, fmt, "SEMICOLON");
      case /* PIPE */1 :
          return _2(Format$1.pp_print_string, fmt, "PIPE");
      case /* PAREN_OPEN */2 :
          return _2(Format$1.pp_print_string, fmt, "PAREN_OPEN");
      case /* PAREN_CLOSE */3 :
          return _2(Format$1.pp_print_string, fmt, "PAREN_CLOSE");
      case /* FLAG_LONG_START */4 :
          return _2(Format$1.pp_print_string, fmt, "FLAG_LONG_START");
      case /* FLAGS_SHORT_START */5 :
          return _2(Format$1.pp_print_string, fmt, "FLAGS_SHORT_START");
      case /* EQUALS */6 :
          return _2(Format$1.pp_print_string, fmt, "EQUALS");
      case /* EOF */7 :
          return _2(Format$1.pp_print_string, fmt, "EOF");
      case /* COMMENT_OPEN */8 :
          return _2(Format$1.pp_print_string, fmt, "COMMENT_OPEN");
      case /* COMMENT_CLOSE */9 :
          return _2(Format$1.pp_print_string, fmt, "COMMENT_CLOSE");
      case /* COLON */10 :
          return _2(Format$1.pp_print_string, fmt, "COLON");
      case /* BARE_DOUBLE_DASH */11 :
          return _2(Format$1.pp_print_string, fmt, "BARE_DOUBLE_DASH");
      
    }
  } else {
    switch (param.tag | 0) {
      case /* URL_START */0 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "URL_START",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>URL_START@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* URL_REST */1 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "URL_REST",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>URL_REST@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* QUOTE_OPEN */2 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "QUOTE_OPEN",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>QUOTE_OPEN@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* QUOTE_ESCAPE */3 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "QUOTE_ESCAPE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>QUOTE_ESCAPE@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* QUOTE_CLOSE */4 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "QUOTE_CLOSE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>QUOTE_CLOSE@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* QUOTE_CHUNK */5 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "QUOTE_CHUNK",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>QUOTE_CHUNK@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* IDENTIFIER */6 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "IDENTIFIER",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>IDENTIFIER@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_UNEXPECTED_WHITESPACE */7 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_UNEXPECTED_WHITESPACE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_UNEXPECTED_WHITESPACE@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_UNEXPECTED_QUOTE_ESCAPE */8 :
          var a0 = param[0];
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_UNEXPECTED_QUOTE_ESCAPE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_UNEXPECTED_QUOTE_ESCAPE@ "
              ]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* End_of_format */0,
                              ""
                            ]]),
                        /* End_of_format */0
                      ])
                  ]),
                "(@["
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0[0]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "," */44,
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ]),
                ",@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0[1]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Formatting_lit */__(17, [
                    /* Close_box */0,
                    /* Char_literal */__(12, [
                        /* ")" */41,
                        /* End_of_format */0
                      ])
                  ]),
                "@])"
              ]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_UNEXPECTED_QUOTE_CLOSE */9 :
          var a0$1 = param[0];
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_UNEXPECTED_QUOTE_CLOSE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_UNEXPECTED_QUOTE_CLOSE@ "
              ]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* End_of_format */0,
                              ""
                            ]]),
                        /* End_of_format */0
                      ])
                  ]),
                "(@["
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0$1[0]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "," */44,
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ]),
                ",@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0$1[1]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Formatting_lit */__(17, [
                    /* Close_box */0,
                    /* Char_literal */__(12, [
                        /* ")" */41,
                        /* End_of_format */0
                      ])
                  ]),
                "@])"
              ]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_UNEXPECTED_COMMENT_CLOSE */10 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_UNEXPECTED_COMMENT_CLOSE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_UNEXPECTED_COMMENT_CLOSE@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_UNEXPECTED_CHARACTER */11 :
          var a0$2 = param[0];
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_UNEXPECTED_CHARACTER",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_UNEXPECTED_CHARACTER@ "
              ]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* End_of_format */0,
                              ""
                            ]]),
                        /* End_of_format */0
                      ])
                  ]),
                "(@["
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Int */__(4, [
                    /* Int_d */0,
                    /* No_padding */0,
                    /* No_precision */0,
                    /* End_of_format */0
                  ]),
                "%d"
              ], a0$2[0]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "," */44,
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ]),
                ",@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0$2[1]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Formatting_lit */__(17, [
                    /* Close_box */0,
                    /* Char_literal */__(12, [
                        /* ")" */41,
                        /* End_of_format */0
                      ])
                  ]),
                "@])"
              ]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_MISSING_DELIM_CLOSE */12 :
          var a0$3 = param[0];
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_MISSING_DELIM_CLOSE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_MISSING_DELIM_CLOSE@ "
              ]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* End_of_format */0,
                              ""
                            ]]),
                        /* End_of_format */0
                      ])
                  ]),
                "(@["
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0$3[0]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "," */44,
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ]),
                ",@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], a0$3[1]);
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Formatting_lit */__(17, [
                    /* Close_box */0,
                    /* Char_literal */__(12, [
                        /* ")" */41,
                        /* End_of_format */0
                      ])
                  ]),
                "@])"
              ]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* ERR_MISSING_COMMENT_CLOSE */13 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "ERR_MISSING_COMMENT_CLOSE",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>ERR_MISSING_COMMENT_CLOSE@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* COUNT */14 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "COUNT",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>COUNT@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      case /* COMMENT */15 :
          _2(Format$1.fprintf, fmt, /* Format */[
                /* Char_literal */__(12, [
                    /* "(" */40,
                    /* Formatting_gen */__(18, [
                        /* Open_box */__(1, [/* Format */[
                              /* String_literal */__(11, [
                                  "<2>",
                                  /* End_of_format */0
                                ]),
                              "<2>"
                            ]]),
                        /* String_literal */__(11, [
                            "COMMENT",
                            /* Formatting_lit */__(17, [
                                /* Break */__(0, [
                                    "@ ",
                                    1,
                                    0
                                  ]),
                                /* End_of_format */0
                              ])
                          ])
                      ])
                  ]),
                "(@[<2>COMMENT@ "
              ]);
          _3(Format$1.fprintf, fmt, /* Format */[
                /* Caml_string */__(3, [
                    /* No_padding */0,
                    /* End_of_format */0
                  ]),
                "%S"
              ], param[0]);
          return _2(Format$1.fprintf, fmt, /* Format */[
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* Char_literal */__(12, [
                              /* ")" */41,
                              /* End_of_format */0
                            ])
                        ]),
                      "@])"
                    ]);
      
    }
  }
}
/* Ppx_deriving_runtime Not a pure module */

var Failure = create("Stream.Failure");

var $$Error$1 = create("Stream.Error");

function fill_buff(b) {
  b[/* len */2] = input(b[/* ic */0], b[/* buff */1], 0, b[/* buff */1].length);
  b[/* ind */3] = 0;
  return /* () */0;
}

function get_data(count, _d) {
  while(true) {
    var d = _d;
    if (typeof d === "number") {
      return d;
    } else {
      switch (d.tag | 0) {
        case /* Scons */0 :
            return d;
        case /* Sapp */1 :
            var d2 = d[1];
            var match = get_data(count, d[0]);
            if (typeof match === "number") {
              _d = d2;
              continue ;
            } else if (match.tag) {
              throw [
                    assert_failure,
                    /* tuple */[
                      "stream.ml",
                      53,
                      12
                    ]
                  ];
            } else {
              return /* Scons */__(0, [
                        match[0],
                        /* Sapp */__(1, [
                            match[1],
                            d2
                          ])
                      ]);
            }
        case /* Slazy */2 :
            _d = force(d[0]);
            continue ;
        case /* Sgen */3 :
            var g = d[0];
            var match$1 = g[/* curr */0];
            if (match$1 !== undefined) {
              var match$2 = valFromOption(match$1);
              if (match$2 !== undefined) {
                g[/* curr */0] = undefined;
                return /* Scons */__(0, [
                          valFromOption(match$2),
                          d
                        ]);
              } else {
                return /* Sempty */0;
              }
            } else {
              var match$3 = _1(g[/* func */1], count);
              if (match$3 !== undefined) {
                return /* Scons */__(0, [
                          valFromOption(match$3),
                          d
                        ]);
              } else {
                g[/* curr */0] = some(undefined);
                return /* Sempty */0;
              }
            }
        case /* Sbuffio */4 :
            var b = d[0];
            if (b[/* ind */3] >= b[/* len */2]) {
              fill_buff(b);
            }
            if (b[/* len */2] === 0) {
              return /* Sempty */0;
            } else {
              var r = b[/* buff */1][b[/* ind */3]];
              b[/* ind */3] = b[/* ind */3] + 1 | 0;
              return /* Scons */__(0, [
                        r,
                        d
                      ]);
            }
        
      }
    }
  }}

function peek$1(s) {
  while(true) {
    var match = s[/* data */1];
    if (typeof match === "number") {
      return ;
    } else {
      switch (match.tag | 0) {
        case /* Scons */0 :
            return some(match[0]);
        case /* Sapp */1 :
            var d = get_data(s[/* count */0], s[/* data */1]);
            if (typeof d === "number") {
              return ;
            } else if (d.tag) {
              throw [
                    assert_failure,
                    /* tuple */[
                      "stream.ml",
                      82,
                      12
                    ]
                  ];
            } else {
              s[1] = d;
              return some(d[0]);
            }
        case /* Slazy */2 :
            s[1] = force(match[0]);
            continue ;
        case /* Sgen */3 :
            var g = match[0];
            var match$1 = g[/* curr */0];
            if (match$1 !== undefined) {
              return valFromOption(match$1);
            } else {
              var x = _1(g[/* func */1], s[/* count */0]);
              g[/* curr */0] = some(x);
              return x;
            }
        case /* Sbuffio */4 :
            var b = match[0];
            if (b[/* ind */3] >= b[/* len */2]) {
              fill_buff(b);
            }
            if (b[/* len */2] === 0) {
              s[1] = /* Sempty */0;
              return ;
            } else {
              return some(b[/* buff */1][b[/* ind */3]]);
            }
        
      }
    }
  }}

function junk(s) {
  while(true) {
    var match = s[/* data */1];
    if (typeof match !== "number") {
      switch (match.tag | 0) {
        case /* Scons */0 :
            s[0] = s[/* count */0] + 1 | 0;
            s[1] = match[1];
            return /* () */0;
        case /* Sgen */3 :
            var g = match[0];
            var match$1 = g[/* curr */0];
            if (match$1 !== undefined) {
              s[0] = s[/* count */0] + 1 | 0;
              g[/* curr */0] = undefined;
              return /* () */0;
            }
            break;
        case /* Sbuffio */4 :
            var b = match[0];
            s[0] = s[/* count */0] + 1 | 0;
            b[/* ind */3] = b[/* ind */3] + 1 | 0;
            return /* () */0;
          
      }
    }
    var match$2 = peek$1(s);
    if (match$2 !== undefined) {
      continue ;
    } else {
      return /* () */0;
    }
  }}

function next$1(s) {
  var match = peek$1(s);
  if (match !== undefined) {
    junk(s);
    return valFromOption(match);
  } else {
    throw Failure;
  }
}
/* No side effect */

// Generated by BUCKLESCRIPT, PLEASE EDIT WITH CARE

function err_not_sv(i) {
  return _1(sprintf$1(/* Format */[
                  /* Int */__(4, [
                      /* Int_X */8,
                      /* No_padding */0,
                      /* No_precision */0,
                      /* String_literal */__(11, [
                          " is not an Unicode scalar value",
                          /* End_of_format */0
                        ])
                    ]),
                  "%X is not an Unicode scalar value"
                ]), i);
}

function err_not_latin1(u) {
  return _1(sprintf$1(/* Format */[
                  /* String_literal */__(11, [
                      "U+",
                      /* Int */__(4, [
                          /* Int_X */8,
                          /* Lit_padding */__(0, [
                              /* Zeros */2,
                              4
                            ]),
                          /* No_precision */0,
                          /* String_literal */__(11, [
                              " is not a latin1 character",
                              /* End_of_format */0
                            ])
                        ])
                    ]),
                  "U+%04X is not a latin1 character"
                ]), u);
}

function succ(u) {
  if (u === 55295) {
    return 57344;
  } else if (u === 1114111) {
    return invalid_arg("U+10FFFF has no successor");
  } else {
    return u + 1 | 0;
  }
}

function pred(u) {
  if (u === 57344) {
    return 55295;
  } else if (u === 0) {
    return invalid_arg("U+0000 has no predecessor");
  } else {
    return u - 1 | 0;
  }
}

function is_valid(i) {
  if (0 <= i && i <= 55295) {
    return true;
  } else if (57344 <= i) {
    return i <= 1114111;
  } else {
    return false;
  }
}

function of_int(i) {
  if (is_valid(i)) {
    return i;
  } else {
    return invalid_arg(err_not_sv(i));
  }
}

function is_char(u) {
  return u < 256;
}

function of_char(c) {
  return c;
}

function to_char(u) {
  if (u > 255) {
    return invalid_arg(err_not_latin1(u));
  } else {
    return u;
  }
}

function unsafe_to_char(prim) {
  return prim;
}

var equal = caml_equal;

var compare = caml_compare;

function hash(prim) {
  return prim;
}

function Uchar_unsafe_of_int(prim) {
  return prim;
}

function Uchar_to_int(prim) {
  return prim;
}

var Uchar = {
  min: 0,
  max: 1114111,
  succ: succ,
  pred: pred,
  is_valid: is_valid,
  of_int: of_int,
  unsafe_of_int: Uchar_unsafe_of_int,
  to_int: Uchar_to_int,
  is_char: is_char,
  of_char: of_char,
  to_char: to_char,
  unsafe_to_char: unsafe_to_char,
  equal: equal,
  compare: compare,
  hash: hash
};
/* No side effect */

var InvalidCodepoint = create("Sedlexing.InvalidCodepoint");

var MalFormed = create("Sedlexing.MalFormed");

function gen_of_channel(chan) {
  return (function (param) {
      try {
        return input_char(chan);
      }
      catch (exn){
        if (exn === end_of_file) {
          return ;
        } else {
          throw exn;
        }
      }
    });
}

function $great$great$eq(o, f) {
  if (o !== undefined) {
    return _1(f, valFromOption(o));
  }
  
}

function gen_of_stream(stream) {
  return (function (param) {
      try {
        return some(next$1(stream));
      }
      catch (exn){
        if (exn === Failure) {
          return ;
        } else {
          throw exn;
        }
      }
    });
}

var empty_lexbuf = /* record */[
  /* refill */(function (param, param$1, param$2) {
      throw [
            assert_failure,
            /* tuple */[
              "sedlexing.ml",
              57,
              25
            ]
          ];
    }),
  /* buf : array */[],
  /* len */0,
  /* offset */0,
  /* pos */0,
  /* curr_bol */0,
  /* curr_line */0,
  /* start_pos */0,
  /* start_bol */0,
  /* start_line */0,
  /* marked_pos */0,
  /* marked_bol */0,
  /* marked_line */0,
  /* marked_val */0,
  /* filename */"",
  /* finished */false
];

function create$2(f) {
  return /* record */[
          /* refill */f,
          /* buf */caml_make_vect(512, Uchar.of_int(0)),
          /* len */empty_lexbuf[/* len */2],
          /* offset */empty_lexbuf[/* offset */3],
          /* pos */empty_lexbuf[/* pos */4],
          /* curr_bol */empty_lexbuf[/* curr_bol */5],
          /* curr_line */1,
          /* start_pos */empty_lexbuf[/* start_pos */7],
          /* start_bol */empty_lexbuf[/* start_bol */8],
          /* start_line */empty_lexbuf[/* start_line */9],
          /* marked_pos */empty_lexbuf[/* marked_pos */10],
          /* marked_bol */empty_lexbuf[/* marked_bol */11],
          /* marked_line */empty_lexbuf[/* marked_line */12],
          /* marked_val */empty_lexbuf[/* marked_val */13],
          /* filename */empty_lexbuf[/* filename */14],
          /* finished */empty_lexbuf[/* finished */15]
        ];
}

function fill_buf_from_gen(f, gen, buf, pos, len) {
  var _i = 0;
  while(true) {
    var i = _i;
    if (i >= len) {
      return len;
    } else {
      var match = _1(gen, /* () */0);
      if (match !== undefined) {
        caml_array_set(buf, pos + i | 0, _1(f, valFromOption(match)));
        _i = i + 1 | 0;
        continue ;
      } else {
        return i;
      }
    }
  }}

function from_gen(s) {
  return create$2((function (param, param$1, param$2) {
                return fill_buf_from_gen((function (id) {
                              return id;
                            }), s, param, param$1, param$2);
              }));
}

function from_int_array(a) {
  var len = a.length;
  return /* record */[
          /* refill */empty_lexbuf[/* refill */0],
          /* buf */init(len, (function (i) {
                  return Uchar.of_int(caml_array_get(a, i));
                })),
          /* len */len,
          /* offset */empty_lexbuf[/* offset */3],
          /* pos */empty_lexbuf[/* pos */4],
          /* curr_bol */empty_lexbuf[/* curr_bol */5],
          /* curr_line */empty_lexbuf[/* curr_line */6],
          /* start_pos */empty_lexbuf[/* start_pos */7],
          /* start_bol */empty_lexbuf[/* start_bol */8],
          /* start_line */empty_lexbuf[/* start_line */9],
          /* marked_pos */empty_lexbuf[/* marked_pos */10],
          /* marked_bol */empty_lexbuf[/* marked_bol */11],
          /* marked_line */empty_lexbuf[/* marked_line */12],
          /* marked_val */empty_lexbuf[/* marked_val */13],
          /* filename */empty_lexbuf[/* filename */14],
          /* finished */true
        ];
}

function refill(lexbuf) {
  if ((lexbuf[/* len */2] + 512 | 0) > lexbuf[/* buf */1].length) {
    var s = lexbuf[/* start_pos */7];
    var ls = lexbuf[/* len */2] - s | 0;
    if ((ls + 512 | 0) <= lexbuf[/* buf */1].length) {
      blit(lexbuf[/* buf */1], s, lexbuf[/* buf */1], 0, ls);
    } else {
      var newlen = ((lexbuf[/* buf */1].length + 512 | 0) << 1);
      var newbuf = caml_make_vect(newlen, Uchar.of_int(0));
      blit(lexbuf[/* buf */1], s, newbuf, 0, ls);
      lexbuf[/* buf */1] = newbuf;
    }
    lexbuf[/* len */2] = ls;
    lexbuf[/* offset */3] = lexbuf[/* offset */3] + s | 0;
    lexbuf[/* pos */4] = lexbuf[/* pos */4] - s | 0;
    lexbuf[/* marked_pos */10] = lexbuf[/* marked_pos */10] - s | 0;
    lexbuf[/* start_pos */7] = 0;
  }
  var n = _3(lexbuf[/* refill */0], lexbuf[/* buf */1], lexbuf[/* pos */4], 512);
  if (n === 0) {
    lexbuf[/* finished */15] = true;
    return /* () */0;
  } else {
    lexbuf[/* len */2] = lexbuf[/* len */2] + n | 0;
    return /* () */0;
  }
}

function new_line(lexbuf) {
  if (lexbuf[/* curr_line */6] !== 0) {
    lexbuf[/* curr_line */6] = lexbuf[/* curr_line */6] + 1 | 0;
  }
  lexbuf[/* curr_bol */5] = lexbuf[/* pos */4] + lexbuf[/* offset */3] | 0;
  return /* () */0;
}

function next$2(lexbuf) {
  if (!lexbuf[/* finished */15] && lexbuf[/* pos */4] === lexbuf[/* len */2]) {
    refill(lexbuf);
  }
  if (lexbuf[/* finished */15] && lexbuf[/* pos */4] === lexbuf[/* len */2]) {
    return ;
  } else {
    var ret = caml_array_get(lexbuf[/* buf */1], lexbuf[/* pos */4]);
    lexbuf[/* pos */4] = lexbuf[/* pos */4] + 1 | 0;
    if (caml_equal(ret, Uchar.of_int(10))) {
      new_line(lexbuf);
    }
    return some(ret);
  }
}

function mark(lexbuf, i) {
  lexbuf[/* marked_pos */10] = lexbuf[/* pos */4];
  lexbuf[/* marked_bol */11] = lexbuf[/* curr_bol */5];
  lexbuf[/* marked_line */12] = lexbuf[/* curr_line */6];
  lexbuf[/* marked_val */13] = i;
  return /* () */0;
}

function start(lexbuf) {
  lexbuf[/* start_pos */7] = lexbuf[/* pos */4];
  lexbuf[/* start_bol */8] = lexbuf[/* curr_bol */5];
  lexbuf[/* start_line */9] = lexbuf[/* curr_line */6];
  return mark(lexbuf, -1);
}

function backtrack(lexbuf) {
  lexbuf[/* pos */4] = lexbuf[/* marked_pos */10];
  lexbuf[/* curr_bol */5] = lexbuf[/* marked_bol */11];
  lexbuf[/* curr_line */6] = lexbuf[/* marked_line */12];
  return lexbuf[/* marked_val */13];
}

function rollback(lexbuf) {
  lexbuf[/* pos */4] = lexbuf[/* start_pos */7];
  lexbuf[/* curr_bol */5] = lexbuf[/* start_bol */8];
  lexbuf[/* curr_line */6] = lexbuf[/* start_line */9];
  return /* () */0;
}

function lexing_positions(lexbuf) {
  var start_p_000 = /* pos_fname */lexbuf[/* filename */14];
  var start_p_001 = /* pos_lnum */lexbuf[/* start_line */9];
  var start_p_002 = /* pos_bol */lexbuf[/* start_bol */8];
  var start_p_003 = /* pos_cnum */lexbuf[/* start_pos */7] + lexbuf[/* offset */3] | 0;
  var start_p = /* record */[
    start_p_000,
    start_p_001,
    start_p_002,
    start_p_003
  ];
  var curr_p_000 = /* pos_fname */lexbuf[/* filename */14];
  var curr_p_001 = /* pos_lnum */lexbuf[/* curr_line */6];
  var curr_p_002 = /* pos_bol */lexbuf[/* curr_bol */5];
  var curr_p_003 = /* pos_cnum */lexbuf[/* pos */4] + lexbuf[/* offset */3] | 0;
  var curr_p = /* record */[
    curr_p_000,
    curr_p_001,
    curr_p_002,
    curr_p_003
  ];
  return /* tuple */[
          start_p,
          curr_p
        ];
}

var width = caml_make_vect(256, -1);

for(var i$1 = 0; i$1 <= 127; ++i$1){
  caml_array_set(width, i$1, 1);
}

for(var i$1$1 = 192; i$1$1 <= 223; ++i$1$1){
  caml_array_set(width, i$1$1, 2);
}

for(var i$2 = 224; i$2 <= 239; ++i$2){
  caml_array_set(width, i$2, 3);
}

for(var i$3 = 240; i$3 <= 247; ++i$3){
  caml_array_set(width, i$3, 4);
}

function next$1$1(s, i) {
  var c = get(s, i);
  if (c >= 192) {
    if (c >= 240) {
      if (c >= 248) {
        throw MalFormed;
      }
      var n2 = get(s, i + 1 | 0);
      var n3 = get(s, i + 2 | 0);
      var n4 = get(s, i + 3 | 0);
      if ((n2 >>> 6) !== 2 || (n3 >>> 6) !== 2 || (n4 >>> 6) !== 2) {
        throw MalFormed;
      }
      return ((c & 7) << 18) | ((n2 & 63) << 12) | ((n3 & 63) << 6) | n4 & 63;
    } else if (c >= 224) {
      var n2$1 = get(s, i + 1 | 0);
      var n3$1 = get(s, i + 2 | 0);
      if ((n2$1 >>> 6) !== 2 || (n3$1 >>> 6) !== 2) {
        throw MalFormed;
      }
      var p = ((c & 15) << 12) | ((n2$1 & 63) << 6) | n3$1 & 63;
      if (p >= 55296 && p <= 57088) {
        throw MalFormed;
      }
      return p;
    } else {
      var n2$2 = get(s, i + 1 | 0);
      if ((n2$2 >>> 6) !== 2) {
        throw MalFormed;
      }
      return ((c & 31) << 6) | n2$2 & 63;
    }
  } else {
    if (c >= 128) {
      throw MalFormed;
    }
    return c;
  }
}

function from_gen$2(s) {
  return $great$great$eq(next(s), (function (c) {
                if (c >= 192) {
                  if (c >= 240) {
                    if (c >= 248) {
                      throw MalFormed;
                    }
                    return $great$great$eq(next(s), (function (c2) {
                                  return $great$great$eq(next(s), (function (c3) {
                                                return $great$great$eq(next(s), (function (c4) {
                                                              if ((c2 >>> 6) !== 2 || (c3 >>> 6) !== 2 || (c4 >>> 6) !== 2) {
                                                                throw MalFormed;
                                                              }
                                                              return some(Uchar.of_int(((c & 7) << 18) | ((c2 & 63) << 12) | ((c3 & 63) << 6) | c4 & 63));
                                                            }));
                                              }));
                                }));
                  } else if (c >= 224) {
                    return $great$great$eq(next(s), (function (c2) {
                                  return $great$great$eq(next(s), (function (c3) {
                                                if ((c2 >>> 6) !== 2 || (c3 >>> 6) !== 2) {
                                                  throw MalFormed;
                                                }
                                                return some(Uchar.of_int(((c & 15) << 12) | ((c2 & 63) << 6) | c3 & 63));
                                              }));
                                }));
                  } else {
                    return $great$great$eq(next(s), (function (c2) {
                                  if ((c2 >>> 6) !== 2) {
                                    throw MalFormed;
                                  }
                                  return some(Uchar.of_int(((c & 31) << 6) | c2 & 63));
                                }));
                  }
                } else {
                  if (c >= 128) {
                    throw MalFormed;
                  }
                  return some(Uchar.of_char(c));
                }
              }));
}

function compute_len(s, pos, bytes) {
  var _n = 0;
  var _i = pos;
  while(true) {
    var i = _i;
    var n = _n;
    if (i >= (pos + bytes | 0)) {
      if (i === (pos + bytes | 0)) {
        return n;
      } else {
        throw MalFormed;
      }
    } else {
      var w = caml_array_get(width, get(s, i));
      if (w > 0) {
        _i = i + w | 0;
        _n = n + 1 | 0;
        continue ;
      } else {
        throw MalFormed;
      }
    }
  }}

function blit_to_int(s, _spos, a, _apos, _n) {
  while(true) {
    var n = _n;
    var apos = _apos;
    var spos = _spos;
    if (n > 0) {
      caml_array_set(a, apos, next$1$1(s, spos));
      _n = n - 1 | 0;
      _apos = apos + 1 | 0;
      _spos = spos + caml_array_get(width, get(s, spos)) | 0;
      continue ;
    } else {
      return 0;
    }
  }}

function to_int_array(s, pos, bytes) {
  var n = compute_len(s, pos, bytes);
  var a = caml_make_vect(n, 0);
  blit_to_int(s, pos, a, 0, n);
  return a;
}

function store(b, p) {
  if (p <= 127) {
    return add_char(b, chr(p));
  } else if (p <= 2047) {
    add_char(b, chr(192 | (p >>> 6)));
    return add_char(b, chr(128 | p & 63));
  } else if (p <= 65535) {
    if (p >= 55296 && p < 57344) {
      throw MalFormed;
    }
    add_char(b, chr(224 | (p >>> 12)));
    add_char(b, chr(128 | (p >>> 6) & 63));
    return add_char(b, chr(128 | p & 63));
  } else if (p <= 1114111) {
    add_char(b, chr(240 | (p >>> 18)));
    add_char(b, chr(128 | (p >>> 12) & 63));
    add_char(b, chr(128 | (p >>> 6) & 63));
    return add_char(b, chr(128 | p & 63));
  } else {
    throw MalFormed;
  }
}

function from_channel$1(ic) {
  var partial_arg = gen_of_channel(ic);
  return from_gen((function (param) {
                return from_gen$2(partial_arg);
              }));
}

function from_gen$3(s) {
  return create$2((function (param, param$1, param$2) {
                return fill_buf_from_gen((function (id) {
                              return id;
                            }), (function (param) {
                              return from_gen$2(s);
                            }), param, param$1, param$2);
              }));
}

function from_stream$2(s) {
  return from_gen$3(gen_of_stream(s));
}

function from_string$1(s) {
  return from_int_array(to_int_array(s, 0, s.length));
}

function sub_lexeme$2(lexbuf, pos, len) {
  var a = lexbuf[/* buf */1];
  var apos = lexbuf[/* start_pos */7] + pos | 0;
  var len$1 = len;
  var b = create$1((len$1 << 2));
  var _apos = apos;
  var _len = len$1;
  while(true) {
    var len$2 = _len;
    var apos$1 = _apos;
    if (len$2 > 0) {
      store(b, Uchar.to_int(caml_array_get(a, apos$1)));
      _len = len$2 - 1 | 0;
      _apos = apos$1 + 1 | 0;
      continue ;
    } else {
      return contents(b);
    }
  }}

function lexeme$2(lexbuf) {
  return sub_lexeme$2(lexbuf, 0, lexbuf[/* pos */4] - lexbuf[/* start_pos */7] | 0);
}

var Utf8 = {
  from_gen: from_gen$3,
  from_stream: from_stream$2,
  from_channel: from_channel$1,
  from_string: from_string$1,
  lexeme: lexeme$2,
  sub_lexeme: sub_lexeme$2
};
/*  Not a pure module */

var __sedlex_table_16 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01";

var __sedlex_table_1 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x02";

var __sedlex_table_15 = "\x01\0\x01\x01\x01\x01\0\x02\x03\x01\x04\x01\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x01\x01\0\x01\0\x01\x01\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x02\0\x03\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\x04\0\x04\0\0\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\x04\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\0\x04\x04\0\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\x04\x04\0\x04\x04\0\0\x04\0\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\0\0\x04\x04\x04\0\0\0\x04\0\0\0\0\0\0\0\x04\x04\x04\x04\0\x04\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\0\x04\x04\0\x04\0\x04\x04\0\0\0\x04\x04\0\0\0\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\0\0\0\0\0\x04\x04\0\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\0\0\0\0\0\x04\x04\0\0\0\0\0\0\0\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\0\0\x04\x04\0\x04\0\0\x04\0\0\0\0\0\0\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\0\x04\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\0\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\0\x04\0\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\0\0\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\0\0\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04";

var __sedlex_table_23 = "\x01\0\x01\x01\x01\x01\0\x02\0\x01\x03\x01\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x01\x01\0\x01\0\x01\x01\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x02\0\0\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\0\x03\x03\0\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\0\x03\x03\0\0\x03\0\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\0\0\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\x03\x03\0\x03\0\x03\x03\0\0\0\x03\x03\0\0\0\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\0\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\0\0\x03\x03\0\x03\0\0\x03\0\0\0\0\0\0\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\0\x03\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\0\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\0\0\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03";

var __sedlex_table_24 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x02";

var __sedlex_table_26 = "\x01\x01\x01\x01\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01";

var __sedlex_table_10 = "\x01\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x02\0\x03\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x01\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\0\x02\x02\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\0\x02\x02\0\0\x02\0\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\x02\x02\0\x02\0\x02\x02\0\0\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\0\0\x02\x02\0\x02\0\0\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\0\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02";

var __sedlex_table_14 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01";

var __sedlex_table_12 = "\x01\0\x02\x03\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x05\0\0\0\0\0\0\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\0\0\0\0\x04\0\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\x04\0\x07\0\0\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\x04\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\b\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\0\x04\x04\0\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\0\b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\x04\x04\0\x04\x04\0\0\x04\0\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\0\0\x04\x04\x04\0\0\0\x04\0\0\0\0\0\0\0\x04\x04\x04\x04\0\x04\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\0\x04\x04\0\x04\0\x04\x04\0\0\0\x04\x04\0\0\0\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\0\0\0\0\0\x04\x04\0\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\0\0\0\0\0\0\0\x04\x04\0\0\0\0\0\0\0\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\x04\0\0\x04\x04\0\x04\0\0\x04\0\0\0\0\0\0\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\0\x04\0\0\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\0\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\b\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\0\x04\0\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\0\0\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\0\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\0\0\0\0\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\0\x04\0\x04\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\x04\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04\0\0\0\x04\x04\x04\x04\0\0\x04\x04\x04\x04\x04\x04\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\x04\x04\x04\0\x04\x04\x04\x04\x04\x04\x04";

var __sedlex_table_13 = "\x01\0\x01\x01\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x03\0\0\0\0\0\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\x02\0\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x02\0\x02\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\0\x02\x02\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\0\x02\x02\0\0\x02\0\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\x02\x02\0\x02\0\x02\x02\0\0\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\0\0\x02\x02\0\x02\0\0\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\0\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02";

var __sedlex_table_22 = "\x01\0\x02\x01\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01";

var __sedlex_table_27 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01";

var __sedlex_table_18 = "\x01\0\x02\x02\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x04\0\0\0\0\0\0\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\0\0\0\0\x03\0\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x03\0\x06\0\0\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x07\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\0\x03\x03\0\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\0\x03\x03\0\0\x03\0\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\0\0\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\x03\x03\0\x03\0\x03\x03\0\0\0\x03\x03\0\0\0\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\0\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\0\0\x03\x03\0\x03\0\0\x03\0\0\0\0\0\0\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\0\x03\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\0\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\0\0\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03";

var __sedlex_table_11 = "\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x01\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\x02\x02\0\x02\0\x02\x02\0\0\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\0\0\x02\x02\0\x02\0\0\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\0\x02\0\0\x02\x02\0\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\x02\0\0\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\0\0\0\x02\0\0\0\x02\x02\0\0\0\0\0\0\0\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02";

var __sedlex_table_6 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\0\x01\x01\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\x01\0\x01\x01\x01\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\x01\x01\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\0\0\0\x01\x01\0\x01\0\x01\x01\0\0\0\x01\x01\0\0\0\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\0\0\x01\x01\0\x01\0\0\x01\0\0\0\0\0\0\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\0\x01\0\0\x01\x01\0\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\0\0\0\x01\0\0\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\0\0\0\x01\0\0\0\x01\x01\0\0\0\0\0\0\0\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01";

var __sedlex_table_5 = "\x01\x02\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x03\0\x04\0\0\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x01\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\0\x03\x03\0\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\0\x03\x03\0\0\x03\0\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\0\0\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\0\x03\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\x03\x03\0\x03\0\x03\x03\0\0\0\x03\x03\0\0\0\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\0\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\x03\0\0\x03\x03\0\x03\0\0\x03\0\0\0\0\0\0\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\0\x03\0\0\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\0\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\0\0\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\0\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\0\0\0\0\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\0\x03\0\x03\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\x03\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03\0\0\0\x03\x03\x03\x03\0\0\x03\x03\x03\x03\x03\x03\0\0\0\0\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\x03\0\0\0\0\0\x03\x03\x03\0\x03\x03\x03\x03\x03\x03\x03";

var __sedlex_table_9 = "\x01\0\x01\x01\x01\x01\0\0\0\x01\x02\x01\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x01\x01\0\x01\0\x01\x01\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x02\0\x02\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\0\x02\x02\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\0\x02\x02\0\0\x02\0\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\x02\x02\0\x02\0\x02\x02\0\0\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\0\0\x02\x02\0\x02\0\0\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\0\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02";

var __sedlex_table_19 = "\x01\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x03\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x04";

var __sedlex_table_25 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x02\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x02\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x03";

var __sedlex_table_3 = "\x01\0\0\0\0\x02";

var __sedlex_table_4 = "\x01\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x04\0\0\0\0\0\x05\x06\x07\b\0\t\b\n\0\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\f\r\0\x0e\0\0\0\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\0\0\0\0\0\0\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\x0f\0\x10\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\x11\x12\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\x11\x13\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\x11\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\0\x11\x11\0\0\0\x11\x11\x11\0\0\0\0\0\0\0\0\x11\0\x11\x11\x11\0\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\x11\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\0\x11\x11\x11\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\0\0\0\0\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\0\x11\x11\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\0\x11\x11\x11\x11\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\0\x11\x11\x11\x11\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\x11\x11\x11\x11\x11\x11\0\0\0\x11\x11\x11\0\x11\x11\x11\x11\0\0\0\x11\x11\0\x11\0\x11\x11\0\0\0\x11\x11\0\0\0\x11\x11\x11\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\x11\0\0\x11\x11\0\x11\0\0\x11\0\0\0\0\0\0\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\0\x11\0\x11\0\0\x11\x11\0\x11\x11\x11\x11\0\x11\0\0\0\0\0\0\0\0\0\0\x11\0\0\x11\x11\x11\x11\x11\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\0\0\0\0\x11\x11\x11\x11\0\0\0\x11\0\0\0\x11\x11\0\0\0\0\0\0\0\x11\x11\x11\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\0\0\0\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\0\x11\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\0\x11\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x02\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\0\x11\x11\x11\x11\0\0\0\x11\x11\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\0\x11\0\x11\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\x11\0\0\0\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11\0\0\0\x11\x11\x11\x11\0\0\x11\x11\x11\x11\x11\x11\0\0\0\0\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\x11\0\0\0\0\0\x11\x11\x11\0\x11\x11\x11\x11\x11\x11\x11";

var __sedlex_table_17 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x01\0\x01\0\0\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\x01\0\x01\x01\0\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\0\x01\x01\x01\x01\0\0\0\0\0\0\0\0\x01\0\0\0\0\x01\x01\0\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\x01\x01\0\x01\x01\0\0\x01\0\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\0\0\x01\x01\x01\0\0\0\x01\0\0\0\0\0\0\0\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\x01\x01\0\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\0\0\0\x01\x01\0\x01\0\x01\x01\0\0\0\x01\x01\0\0\0\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\0\0\0\0\0\0\0\x01\x01\0\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\0\0\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\x01\0\0\x01\x01\0\x01\0\0\x01\0\0\0\0\0\0\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\0\x01\0\0\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\0\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\0\x01\0\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\0\0\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\0\0\0\0\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\0\x01\0\x01\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\x01\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01\0\0\0\x01\x01\x01\x01\0\0\x01\x01\x01\x01\x01\x01\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\x01\x01\x01\0\x01\x01\x01\x01\x01\x01\x01";

var __sedlex_table_20 = "\x01\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x03\x02\x02\x02\x02\x04";

var __sedlex_table_8 = "\x01\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x03\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x04";

var __sedlex_table_21 = "\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\x01\x01\x01\x01";

var __sedlex_table_2 = "\x01\x01\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x02\0\x03\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x01\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\0\x02\x02\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\0\x02\x02\0\0\x02\0\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\x02\x02\0\x02\0\x02\x02\0\0\0\x02\x02\0\0\0\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\x02\0\0\x02\x02\0\x02\0\0\x02\0\0\0\0\0\0\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\0\x02\0\0\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\x02\0\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\0\0\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\0\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\0\0\0\0\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\0\x02\0\x02\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\x02\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02\0\0\0\x02\x02\x02\x02\0\0\x02\x02\x02\x02\x02\x02\0\0\0\0\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\0\0\0\0\0\x02\x02\x02\0\x02\x02\x02\x02\x02\x02\x02";

var __sedlex_table_7 = "\x01\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\0\0\0\0\0\0\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01";

function __sedlex_partition_3(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 47) {
      return get(__sedlex_table_1, c) - 1 | 0;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_28(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 44) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_2, c - 45 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126562) {
      if (c <= 65276) {
        if (c <= 42647) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231) {
                      return 0;
                    } else if (c <= 8254) {
                      return -1;
                    } else {
                      return 1;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 1;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 19893) {
            if (c <= 12589) {
              if (c <= 12539) {
                if (c <= 12538) {
                  return 1;
                } else {
                  return 0;
                }
              } else if (c <= 12543 || c > 12548) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12592) {
              return -1;
            } else if (c <= 12730) {
              if (c <= 12686 || c > 12703) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 19967) {
            return -1;
          } else if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42539 || c > 42559) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 42611 || !(c <= 42621 || c > 42622)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 42654) {
          return -1;
        } else if (c <= 44010) {
          if (c <= 43456) {
            if (c <= 43123) {
              if (c <= 42894) {
                if (c <= 42783) {
                  if (c <= 42737 || c > 42774) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 42895) {
                return -1;
              } else if (c <= 42922) {
                if (c <= 42899 || c > 42911) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 42999 || !(c <= 43047 || c > 43071)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43135) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43225) {
                if (c <= 43204 || c > 43215) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43231 || !(c <= 43255 || c > 43258)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43263) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43309 || c > 43311) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43359 || !(c <= 43388 || c > 43391)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43470) {
            return -1;
          } else if (c <= 43741) {
            if (c <= 43609) {
              if (c <= 43574) {
                if (c <= 43481 || c > 43519) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43583 || !(c <= 43597 || c > 43599)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43615) {
              return -1;
            } else if (c <= 43643) {
              if (c <= 43638 || c > 43641) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43647 || !(c <= 43714 || c > 43738)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43743) {
            return -1;
          } else if (c <= 43790) {
            if (c <= 43766) {
              if (c <= 43759 || c > 43761) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43776 || !(c <= 43782 || c > 43784)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43792) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43798 || c > 43807) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 43815 || !(c <= 43822 || c > 43967)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 44011) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64262) {
            if (c <= 55238) {
              if (c <= 44025) {
                if (c <= 44013 || c > 44015) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 44031 || !(c <= 55203 || c > 55215)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 55242) {
              return -1;
            } else if (c <= 64109) {
              if (c <= 55291 || c > 63743) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64111 || !(c <= 64217 || c > 64255)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64274) {
            return -1;
          } else if (c <= 64316) {
            if (c <= 64296) {
              if (c <= 64279 || c > 64284) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64297 || !(c <= 64310 || c > 64311)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64317) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64318 || c > 64319) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 64322 || !(c <= 64324 || c > 64325)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 64466) {
          return -1;
        } else if (c <= 65076) {
          if (c <= 64967) {
            if (c <= 64829) {
              if (c <= 64605 || c > 64611) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64847 || !(c <= 64911 || c > 64913)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65007) {
            return -1;
          } else if (c <= 65039) {
            if (c <= 65017 || c > 65023) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65055 || !(c <= 65062 || c > 65074)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65100) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65137) {
            if (c <= 65103 || c > 65136) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65138 || !(c <= 65139 || c > 65142)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65144) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65145 || c > 65146) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 65148 || !(c <= 65149 || c > 65150)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 65295) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 67640) {
          if (c <= 65786) {
            if (c <= 65495) {
              if (c <= 65370) {
                if (c <= 65338) {
                  if (c <= 65305 || c > 65312) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 65342 || !(c <= 65343 || c > 65344)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 65381) {
                return -1;
              } else if (c <= 65479) {
                if (c <= 65470 || c > 65473) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65481 || !(c <= 65487 || c > 65489)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65497) {
              return -1;
            } else if (c <= 65594) {
              if (c <= 65547) {
                if (c <= 65500 || c > 65535) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65548 || !(c <= 65574 || c > 65575)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65595) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65597 || c > 65598) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65615 || !(c <= 65629 || c > 65663)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65855) {
            return -1;
          } else if (c <= 66499) {
            if (c <= 66256) {
              if (c <= 66045) {
                if (c <= 65908 || c > 66044) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 66303) {
              return -1;
            } else if (c <= 66378) {
              if (c <= 66334 || c > 66351) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66503) {
            return -1;
          } else if (c <= 66729) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 66719)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 67583) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 67589 || c > 67591) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 67593 || !(c <= 67637 || c > 67638)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 67643) {
          return -1;
        } else if (c <= 68437) {
          if (c <= 68102) {
            if (c <= 67897) {
              if (c <= 67669) {
                if (c <= 67644 || c > 67646) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 67839 || !(c <= 67861 || c > 67871)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 67967) {
              return -1;
            } else if (c <= 68031) {
              if (c <= 68023 || c > 68029) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68095 || !(c <= 68099 || c > 68100)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68107) {
            return -1;
          } else if (c <= 68154) {
            if (c <= 68119) {
              if (c <= 68115 || c > 68116) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68120 || !(c <= 68147 || c > 68151)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68158) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68159 || c > 68191) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 68447) {
          return -1;
        } else if (c <= 69940) {
          if (c <= 69743) {
            if (c <= 68680) {
              if (c <= 68466 || c > 68607) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 69631 || !(c <= 69702 || c > 69733)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 69759) {
            return -1;
          } else if (c <= 69864) {
            if (c <= 69818 || c > 69839) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 69871 || !(c <= 69881 || c > 69887)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 69941) {
          return -1;
        } else if (c <= 71351) {
          if (c <= 70084) {
            if (c <= 69951 || c > 70015) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 70095 || !(c <= 70105 || c > 71295)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 71359) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71369 || c > 73727) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 120538) {
        if (c <= 119974) {
          if (c <= 119170) {
            if (c <= 94111) {
              if (c <= 94020) {
                if (c <= 92728 || c > 93951) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 94031 || !(c <= 94078 || c > 94094)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 110591) {
              return -1;
            } else if (c <= 119145) {
              if (c <= 110593 || c > 119140) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119148 || !(c <= 119154 || c > 119162)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119172) {
            return -1;
          } else if (c <= 119892) {
            if (c <= 119213) {
              if (c <= 119179 || c > 119209) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119361 || !(c <= 119364 || c > 119807)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119893) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119964 || c > 119965) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 119969 || !(c <= 119970 || c > 119972)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 119976) {
          return -1;
        } else if (c <= 120092) {
          if (c <= 120003) {
            if (c <= 119993) {
              if (c <= 119980 || c > 119981) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119994 || !(c <= 119995 || c > 119996)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120004) {
            return -1;
          } else if (c <= 120074) {
            if (c <= 120069 || c > 120070) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120076 || !(c <= 120084 || c > 120085)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120093) {
          return -1;
        } else if (c <= 120134) {
          if (c <= 120126) {
            if (c <= 120121 || c > 120122) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120127 || !(c <= 120132 || c > 120133)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120137) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120144 || c > 120145) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 120487 || !(c <= 120512 || c > 120513)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 120539) {
        return -1;
      } else if (c <= 126514) {
        if (c <= 120770) {
          if (c <= 120654) {
            if (c <= 120596) {
              if (c <= 120570 || c > 120571) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120597 || !(c <= 120628 || c > 120629)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120655) {
            return -1;
          } else if (c <= 120712) {
            if (c <= 120686 || c > 120687) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120713 || !(c <= 120744 || c > 120745)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120771) {
          return -1;
        } else if (c <= 126495) {
          if (c <= 120831) {
            if (c <= 120779 || c > 120781) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126463 || !(c <= 126467 || c > 126468)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126496) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126498 || c > 126499) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126502 || !(c <= 126503 || c > 126504)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126515) {
        return -1;
      } else if (c <= 126543) {
        if (c <= 126530) {
          if (c <= 126521) {
            if (c <= 126519 || c > 126520) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126522 || !(c <= 126523 || c > 126529)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126534) {
          return -1;
        } else if (c <= 126537) {
          if (c <= 126535 || c > 126536) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126538 || !(c <= 126539 || c > 126540)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126544) {
        return -1;
      } else if (c <= 126553) {
        if (c <= 126548) {
          if (c <= 126546 || c > 126547) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126550 || !(c <= 126551 || c > 126552)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126554) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126555 || c > 126556) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126558 || !(c <= 126559 || c > 126560)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126563) {
      return -1;
    } else if (c <= 126619) {
      if (c <= 126583) {
        if (c <= 126570) {
          if (c <= 126564 || c > 126566) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126571 || !(c <= 126578 || c > 126579)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126584) {
        return -1;
      } else if (c <= 126590) {
        if (c <= 126588 || c > 126589) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126591 || !(c <= 126601 || c > 126602)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126624) {
      return -1;
    } else if (c <= 173782) {
      if (c <= 126633) {
        if (c <= 126627 || c > 126628) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126634 || !(c <= 126651 || c > 131071)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 173823) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 177972 || c > 177983) {
        return 1;
      } else {
        return -1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 1;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_22(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 41 || c > 47) {
      return -1;
    } else {
      return get(__sedlex_table_3, c - 42 | 0) - 1 | 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_17(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 8188) {
      return get(__sedlex_table_4, c - -1 | 0) - 1 | 0;
    } else if (c <= 8191 || c > 195101) {
      return -1;
    } else if (c <= 65338) {
      if (c <= 42888) {
        if (c <= 11686) {
          if (c <= 8505) {
            if (c <= 8450) {
              if (c <= 8287) {
                if (c <= 8233) {
                  if (c <= 8202 || c > 8231) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8238 || !(c <= 8239 || c > 8286)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8304) {
                return -1;
              } else if (c <= 8319) {
                if (c <= 8305 || c > 8318) {
                  return 16;
                } else {
                  return -1;
                }
              } else if (c <= 8335 || !(c <= 8348 || c > 8449)) {
                return -1;
              } else {
                return 16;
              }
            } else if (c <= 8454) {
              return -1;
            } else if (c <= 8477) {
              if (c <= 8467) {
                if (c <= 8455 || c > 8457) {
                  return 16;
                } else {
                  return -1;
                }
              } else if (c <= 8468 || !(c <= 8469 || c > 8471)) {
                return -1;
              } else {
                return 16;
              }
            } else if (c <= 8483) {
              return -1;
            } else if (c <= 8486) {
              if (c <= 8484 || c > 8485) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 8487 || !(c <= 8488 || c > 8489)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 8507) {
            return -1;
          } else if (c <= 11502) {
            if (c <= 8584) {
              if (c <= 8521) {
                if (c <= 8511 || c > 8516) {
                  return 16;
                } else {
                  return -1;
                }
              } else if (c <= 8525 || !(c <= 8526 || c > 8543)) {
                return -1;
              } else {
                return 16;
              }
            } else if (c <= 11263) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 11310 || c > 11311) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 11359 || !(c <= 11492 || c > 11498)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 11505) {
            return -1;
          } else if (c <= 11565) {
            if (c <= 11557) {
              if (c <= 11507 || c > 11519) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 11558 || !(c <= 11559 || c > 11564)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 11567) {
            return -1;
          } else if (c <= 11631) {
            if (c <= 11623 || c > 11630) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 11647 || !(c <= 11670 || c > 11679)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 11687) {
          return -1;
        } else if (c <= 12543) {
          if (c <= 12288) {
            if (c <= 11718) {
              if (c <= 11702) {
                if (c <= 11694 || c > 11695) {
                  return 16;
                } else {
                  return -1;
                }
              } else if (c <= 11703 || !(c <= 11710 || c > 11711)) {
                return -1;
              } else {
                return 16;
              }
            } else if (c <= 11719) {
              return -1;
            } else if (c <= 11734) {
              if (c <= 11726 || c > 11727) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 11735) {
              return -1;
            } else if (c <= 11742) {
              return 16;
            } else if (c <= 12287) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12292) {
            return -1;
          } else if (c <= 12348) {
            if (c <= 12329) {
              if (c <= 12295 || c > 12320) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 12336 || !(c <= 12341 || c > 12343)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 12352) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 12438 || c > 12444) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 12448 || !(c <= 12538 || c > 12539)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 12548) {
          return -1;
        } else if (c <= 42237) {
          if (c <= 12799) {
            if (c <= 12686) {
              if (c <= 12589 || c > 12592) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 12703 || !(c <= 12730 || c > 12783)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 13311) {
            return -1;
          } else if (c <= 40908) {
            if (c <= 19893 || c > 19967) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 40959 || !(c <= 42124 || c > 42191)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 42239) {
          return -1;
        } else if (c <= 42606) {
          if (c <= 42527) {
            if (c <= 42508 || c > 42511) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 42537 || !(c <= 42539 || c > 42559)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 42622) {
          return -1;
        } else if (c <= 42735) {
          if (c <= 42647 || c > 42655) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 42774 || !(c <= 42783 || c > 42785)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 42890) {
        return -1;
      } else if (c <= 43790) {
        if (c <= 43471) {
          if (c <= 43123) {
            if (c <= 43009) {
              if (c <= 42899) {
                if (c <= 42894 || c > 42895) {
                  return 16;
                } else {
                  return -1;
                }
              } else if (c <= 42911 || !(c <= 42922 || c > 42999)) {
                return -1;
              } else {
                return 16;
              }
            } else if (c <= 43010) {
              return -1;
            } else if (c <= 43018) {
              if (c <= 43013 || c > 43014) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 43019 || !(c <= 43042 || c > 43071)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 43137) {
            return -1;
          } else if (c <= 43301) {
            if (c <= 43255) {
              if (c <= 43187 || c > 43249) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 43258 || !(c <= 43259 || c > 43273)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 43311) {
            return -1;
          } else if (c <= 43388) {
            if (c <= 43334 || c > 43359) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 43395 || !(c <= 43442 || c > 43470)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 43519) {
          return -1;
        } else if (c <= 43702) {
          if (c <= 43638) {
            if (c <= 43586) {
              if (c <= 43560 || c > 43583) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 43587 || !(c <= 43595 || c > 43615)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 43641) {
            return -1;
          } else if (c <= 43695) {
            if (c <= 43642 || c > 43647) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 43696 || !(c <= 43697 || c > 43700)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 43704) {
          return -1;
        } else if (c <= 43741) {
          if (c <= 43712) {
            if (c <= 43709 || c > 43711) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 43713 || !(c <= 43714 || c > 43738)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 43743) {
          return -1;
        } else if (c <= 43764) {
          if (c <= 43754 || c > 43761) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 43776 || !(c <= 43782 || c > 43784)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 43792) {
        return -1;
      } else if (c <= 64318) {
        if (c <= 64109) {
          if (c <= 44002) {
            if (c <= 43814) {
              if (c <= 43798 || c > 43807) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 43815 || !(c <= 43822 || c > 43967)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 44031) {
            return -1;
          } else if (c <= 55238) {
            if (c <= 55203 || c > 55215) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 55242 || !(c <= 55291 || c > 63743)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 64111) {
          return -1;
        } else if (c <= 64285) {
          if (c <= 64262) {
            if (c <= 64217 || c > 64255) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 64274 || !(c <= 64279 || c > 64284)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 64286) {
          return -1;
        } else if (c <= 64310) {
          if (c <= 64296 || c > 64297) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 64311 || !(c <= 64316 || c > 64317)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 64319) {
        return -1;
      } else if (c <= 65017) {
        if (c <= 64605) {
          if (c <= 64324) {
            if (c <= 64321 || c > 64322) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 64325 || !(c <= 64433 || c > 64466)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 64611) {
          return -1;
        } else if (c <= 64911) {
          if (c <= 64829 || c > 64847) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 64913 || !(c <= 64967 || c > 65007)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 65136) {
        return -1;
      } else if (c <= 65145) {
        if (c <= 65139) {
          if (c <= 65137 || c > 65138) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 65142 || !(c <= 65143 || c > 65144)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 65146) {
        return -1;
      } else if (c <= 65149) {
        if (c <= 65147 || c > 65148) {
          return 16;
        } else {
          return -1;
        }
      } else if (c <= 65150 || !(c <= 65276 || c > 65312)) {
        return -1;
      } else {
        return 16;
      }
    } else if (c <= 65344) {
      return -1;
    } else if (c <= 119980) {
      if (c <= 67897) {
        if (c <= 66204) {
          if (c <= 65547) {
            if (c <= 65479) {
              if (c <= 65437) {
                if (c <= 65370 || c > 65381) {
                  return 16;
                } else {
                  return -1;
                }
              } else if (c <= 65439 || !(c <= 65470 || c > 65473)) {
                return -1;
              } else {
                return 16;
              }
            } else if (c <= 65481) {
              return -1;
            } else if (c <= 65495) {
              if (c <= 65487 || c > 65489) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 65497 || !(c <= 65500 || c > 65535)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 65548) {
            return -1;
          } else if (c <= 65613) {
            if (c <= 65594) {
              if (c <= 65574 || c > 65575) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 65595 || !(c <= 65597 || c > 65598)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 65615) {
            return -1;
          } else if (c <= 65786) {
            if (c <= 65629 || c > 65663) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 65855 || !(c <= 65908 || c > 66175)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 66207) {
          return -1;
        } else if (c <= 66717) {
          if (c <= 66461) {
            if (c <= 66334) {
              if (c <= 66256 || c > 66303) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 66351 || !(c <= 66378 || c > 66431)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 66463) {
            return -1;
          } else if (c <= 66511) {
            if (c <= 66499 || c > 66503) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 66512 || !(c <= 66517 || c > 66559)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 67583) {
          return -1;
        } else if (c <= 67640) {
          if (c <= 67592) {
            if (c <= 67589 || c > 67591) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 67593 || !(c <= 67637 || c > 67638)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 67643) {
          return -1;
        } else if (c <= 67669) {
          if (c <= 67644 || c > 67646) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 67839 || !(c <= 67861 || c > 67871)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 67967) {
        return -1;
      } else if (c <= 70066) {
        if (c <= 68405) {
          if (c <= 68115) {
            if (c <= 68031) {
              if (c <= 68023 || c > 68029) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 68095 || !(c <= 68096 || c > 68111)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 68116) {
            return -1;
          } else if (c <= 68147) {
            if (c <= 68119 || c > 68120) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 68191 || !(c <= 68220 || c > 68351)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 68415) {
          return -1;
        } else if (c <= 69687) {
          if (c <= 68466) {
            if (c <= 68437 || c > 68447) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 68607 || !(c <= 68680 || c > 69634)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 69762) {
          return -1;
        } else if (c <= 69864) {
          if (c <= 69807 || c > 69839) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 69890 || !(c <= 69926 || c > 70018)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 70080) {
        return -1;
      } else if (c <= 94032) {
        if (c <= 74850) {
          if (c <= 71338) {
            if (c <= 70084 || c > 71295) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 73727 || !(c <= 74606 || c > 74751)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 77823) {
          return -1;
        } else if (c <= 92728) {
          if (c <= 78894 || c > 92159) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 93951 || !(c <= 94020 || c > 94031)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 94098) {
        return -1;
      } else if (c <= 119964) {
        if (c <= 110593) {
          if (c <= 94111 || c > 110591) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 119807 || !(c <= 119892 || c > 119893)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 119965) {
        return -1;
      } else if (c <= 119970) {
        if (c <= 119967 || c > 119969) {
          return 16;
        } else {
          return -1;
        }
      } else if (c <= 119972 || !(c <= 119974 || c > 119976)) {
        return -1;
      } else {
        return 16;
      }
    } else if (c <= 119981) {
      return -1;
    } else if (c <= 126521) {
      if (c <= 120570) {
        if (c <= 120121) {
          if (c <= 120069) {
            if (c <= 119995) {
              if (c <= 119993 || c > 119994) {
                return 16;
              } else {
                return -1;
              }
            } else if (c <= 119996 || !(c <= 120003 || c > 120004)) {
              return -1;
            } else {
              return 16;
            }
          } else if (c <= 120070) {
            return -1;
          } else if (c <= 120084) {
            if (c <= 120074 || c > 120076) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 120085 || !(c <= 120092 || c > 120093)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 120122) {
          return -1;
        } else if (c <= 120144) {
          if (c <= 120132) {
            if (c <= 120126 || c > 120127) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 120133 || !(c <= 120134 || c > 120137)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 120145) {
          return -1;
        } else if (c <= 120512) {
          if (c <= 120485 || c > 120487) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 120513 || !(c <= 120538 || c > 120539)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 120571) {
        return -1;
      } else if (c <= 120779) {
        if (c <= 120686) {
          if (c <= 120628) {
            if (c <= 120596 || c > 120597) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 120629 || !(c <= 120654 || c > 120655)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 120687) {
          return -1;
        } else if (c <= 120744) {
          if (c <= 120712 || c > 120713) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 120745 || !(c <= 120770 || c > 120771)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 126463) {
        return -1;
      } else if (c <= 126500) {
        if (c <= 126495) {
          if (c <= 126467 || c > 126468) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 126496 || !(c <= 126498 || c > 126499)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 126502) {
        return -1;
      } else if (c <= 126514) {
        if (c <= 126503 || c > 126504) {
          return 16;
        } else {
          return -1;
        }
      } else if (c <= 126515 || !(c <= 126519 || c > 126520)) {
        return -1;
      } else {
        return 16;
      }
    } else if (c <= 126522) {
      return -1;
    } else if (c <= 126570) {
      if (c <= 126548) {
        if (c <= 126537) {
          if (c <= 126530) {
            if (c <= 126523 || c > 126529) {
              return 16;
            } else {
              return -1;
            }
          } else if (c <= 126534 || !(c <= 126535 || c > 126536)) {
            return -1;
          } else {
            return 16;
          }
        } else if (c <= 126538) {
          return -1;
        } else if (c <= 126543) {
          if (c <= 126539 || c > 126540) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 126544 || !(c <= 126546 || c > 126547)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 126550) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126553) {
          if (c <= 126551 || c > 126552) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 126554 || !(c <= 126555 || c > 126556)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 126558) {
        return -1;
      } else if (c <= 126562) {
        if (c <= 126559 || c > 126560) {
          return 16;
        } else {
          return -1;
        }
      } else if (c <= 126563 || !(c <= 126564 || c > 126566)) {
        return -1;
      } else {
        return 16;
      }
    } else if (c <= 126571) {
      return -1;
    } else if (c <= 126633) {
      if (c <= 126590) {
        if (c <= 126583) {
          if (c <= 126578 || c > 126579) {
            return 16;
          } else {
            return -1;
          }
        } else if (c <= 126584 || !(c <= 126588 || c > 126589)) {
          return -1;
        } else {
          return 16;
        }
      } else if (c <= 126591) {
        return -1;
      } else if (c <= 126619) {
        if (c <= 126601 || c > 126602) {
          return 16;
        } else {
          return -1;
        }
      } else if (c <= 126624 || !(c <= 126627 || c > 126628)) {
        return -1;
      } else {
        return 16;
      }
    } else if (c <= 126634) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 173782) {
        if (c <= 126651 || c > 131071) {
          return 16;
        } else {
          return -1;
        }
      } else if (c <= 173823 || !(c <= 177972 || c > 177983)) {
        return -1;
      } else {
        return 16;
      }
    } else if (c <= 194559) {
      return -1;
    } else {
      return 16;
    }
  } else {
    return get(__sedlex_table_4, 0) - 1 | 0;
  }
}

function __sedlex_partition_27(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 44) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_5, c - 45 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126562) {
      if (c <= 65276) {
        if (c <= 42647) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231) {
                      return 0;
                    } else if (c <= 8254) {
                      return -1;
                    } else {
                      return 2;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 2;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 19893) {
            if (c <= 12589) {
              if (c <= 12539) {
                if (c <= 12538) {
                  return 2;
                } else {
                  return 0;
                }
              } else if (c <= 12543 || c > 12548) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12592) {
              return -1;
            } else if (c <= 12730) {
              if (c <= 12686 || c > 12703) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 19967) {
            return -1;
          } else if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42539 || c > 42559) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 42611 || !(c <= 42621 || c > 42622)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 42654) {
          return -1;
        } else if (c <= 44010) {
          if (c <= 43456) {
            if (c <= 43123) {
              if (c <= 42894) {
                if (c <= 42783) {
                  if (c <= 42737 || c > 42774) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 42895) {
                return -1;
              } else if (c <= 42922) {
                if (c <= 42899 || c > 42911) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 42999 || !(c <= 43047 || c > 43071)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43135) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43225) {
                if (c <= 43204 || c > 43215) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43231 || !(c <= 43255 || c > 43258)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43263) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43309 || c > 43311) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43359 || !(c <= 43388 || c > 43391)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43470) {
            return -1;
          } else if (c <= 43741) {
            if (c <= 43609) {
              if (c <= 43574) {
                if (c <= 43481 || c > 43519) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43583 || !(c <= 43597 || c > 43599)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43615) {
              return -1;
            } else if (c <= 43643) {
              if (c <= 43638 || c > 43641) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43647 || !(c <= 43714 || c > 43738)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43743) {
            return -1;
          } else if (c <= 43790) {
            if (c <= 43766) {
              if (c <= 43759 || c > 43761) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43776 || !(c <= 43782 || c > 43784)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43792) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43798 || c > 43807) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 43815 || !(c <= 43822 || c > 43967)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 44011) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64262) {
            if (c <= 55238) {
              if (c <= 44025) {
                if (c <= 44013 || c > 44015) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 44031 || !(c <= 55203 || c > 55215)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 55242) {
              return -1;
            } else if (c <= 64109) {
              if (c <= 55291 || c > 63743) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64111 || !(c <= 64217 || c > 64255)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 64274) {
            return -1;
          } else if (c <= 64316) {
            if (c <= 64296) {
              if (c <= 64279 || c > 64284) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64297 || !(c <= 64310 || c > 64311)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 64317) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64318 || c > 64319) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 64322 || !(c <= 64324 || c > 64325)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 64466) {
          return -1;
        } else if (c <= 65076) {
          if (c <= 64967) {
            if (c <= 64829) {
              if (c <= 64605 || c > 64611) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64847 || !(c <= 64911 || c > 64913)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 65007) {
            return -1;
          } else if (c <= 65039) {
            if (c <= 65017 || c > 65023) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 65055 || !(c <= 65062 || c > 65074)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 65100) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65137) {
            if (c <= 65103 || c > 65136) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 65138 || !(c <= 65139 || c > 65142)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 65144) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65145 || c > 65146) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 65148 || !(c <= 65149 || c > 65150)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 65295) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 67640) {
          if (c <= 65786) {
            if (c <= 65495) {
              if (c <= 65370) {
                if (c <= 65338) {
                  if (c <= 65305 || c > 65312) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 65342 || !(c <= 65343 || c > 65344)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 65381) {
                return -1;
              } else if (c <= 65479) {
                if (c <= 65470 || c > 65473) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 65481 || !(c <= 65487 || c > 65489)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 65497) {
              return -1;
            } else if (c <= 65594) {
              if (c <= 65547) {
                if (c <= 65500 || c > 65535) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 65548 || !(c <= 65574 || c > 65575)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 65595) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65597 || c > 65598) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 65615 || !(c <= 65629 || c > 65663)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 65855) {
            return -1;
          } else if (c <= 66499) {
            if (c <= 66256) {
              if (c <= 66045) {
                if (c <= 65908 || c > 66044) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 66303) {
              return -1;
            } else if (c <= 66378) {
              if (c <= 66334 || c > 66351) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 66503) {
            return -1;
          } else if (c <= 66729) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 66719)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 67583) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 67589 || c > 67591) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 67593 || !(c <= 67637 || c > 67638)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 67643) {
          return -1;
        } else if (c <= 68437) {
          if (c <= 68102) {
            if (c <= 67897) {
              if (c <= 67669) {
                if (c <= 67644 || c > 67646) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 67839 || !(c <= 67861 || c > 67871)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 67967) {
              return -1;
            } else if (c <= 68031) {
              if (c <= 68023 || c > 68029) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 68095 || !(c <= 68099 || c > 68100)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 68107) {
            return -1;
          } else if (c <= 68154) {
            if (c <= 68119) {
              if (c <= 68115 || c > 68116) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 68120 || !(c <= 68147 || c > 68151)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 68158) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68159 || c > 68191) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 68447) {
          return -1;
        } else if (c <= 69940) {
          if (c <= 69743) {
            if (c <= 68680) {
              if (c <= 68466 || c > 68607) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 69631 || !(c <= 69702 || c > 69733)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 69759) {
            return -1;
          } else if (c <= 69864) {
            if (c <= 69818 || c > 69839) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 69871 || !(c <= 69881 || c > 69887)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 69941) {
          return -1;
        } else if (c <= 71351) {
          if (c <= 70084) {
            if (c <= 69951 || c > 70015) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 70095 || !(c <= 70105 || c > 71295)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 71359) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71369 || c > 73727) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 120538) {
        if (c <= 119974) {
          if (c <= 119170) {
            if (c <= 94111) {
              if (c <= 94020) {
                if (c <= 92728 || c > 93951) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 94031 || !(c <= 94078 || c > 94094)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 110591) {
              return -1;
            } else if (c <= 119145) {
              if (c <= 110593 || c > 119140) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119148 || !(c <= 119154 || c > 119162)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 119172) {
            return -1;
          } else if (c <= 119892) {
            if (c <= 119213) {
              if (c <= 119179 || c > 119209) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119361 || !(c <= 119364 || c > 119807)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 119893) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119964 || c > 119965) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 119969 || !(c <= 119970 || c > 119972)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 119976) {
          return -1;
        } else if (c <= 120092) {
          if (c <= 120003) {
            if (c <= 119993) {
              if (c <= 119980 || c > 119981) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119994 || !(c <= 119995 || c > 119996)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 120004) {
            return -1;
          } else if (c <= 120074) {
            if (c <= 120069 || c > 120070) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120076 || !(c <= 120084 || c > 120085)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120093) {
          return -1;
        } else if (c <= 120134) {
          if (c <= 120126) {
            if (c <= 120121 || c > 120122) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120127 || !(c <= 120132 || c > 120133)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120137) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120144 || c > 120145) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 120487 || !(c <= 120512 || c > 120513)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 120539) {
        return -1;
      } else if (c <= 126514) {
        if (c <= 120770) {
          if (c <= 120654) {
            if (c <= 120596) {
              if (c <= 120570 || c > 120571) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 120597 || !(c <= 120628 || c > 120629)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 120655) {
            return -1;
          } else if (c <= 120712) {
            if (c <= 120686 || c > 120687) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120713 || !(c <= 120744 || c > 120745)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120771) {
          return -1;
        } else if (c <= 126495) {
          if (c <= 120831) {
            if (c <= 120779 || c > 120781) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 126463 || !(c <= 126467 || c > 126468)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126496) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126498 || c > 126499) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126502 || !(c <= 126503 || c > 126504)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126515) {
        return -1;
      } else if (c <= 126543) {
        if (c <= 126530) {
          if (c <= 126521) {
            if (c <= 126519 || c > 126520) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 126522 || !(c <= 126523 || c > 126529)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126534) {
          return -1;
        } else if (c <= 126537) {
          if (c <= 126535 || c > 126536) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126538 || !(c <= 126539 || c > 126540)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126544) {
        return -1;
      } else if (c <= 126553) {
        if (c <= 126548) {
          if (c <= 126546 || c > 126547) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126550 || !(c <= 126551 || c > 126552)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126554) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126555 || c > 126556) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126558 || !(c <= 126559 || c > 126560)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 126563) {
      return -1;
    } else if (c <= 126619) {
      if (c <= 126583) {
        if (c <= 126570) {
          if (c <= 126564 || c > 126566) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126571 || !(c <= 126578 || c > 126579)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126584) {
        return -1;
      } else if (c <= 126590) {
        if (c <= 126588 || c > 126589) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126591 || !(c <= 126601 || c > 126602)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 126624) {
      return -1;
    } else if (c <= 173782) {
      if (c <= 126633) {
        if (c <= 126627 || c > 126628) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126634 || !(c <= 126651 || c > 131071)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 173823) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 177972 || c > 177983) {
        return 2;
      } else {
        return -1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 2;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_16(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 64) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_6, c - 65 | 0) - 1 | 0;
    } else if (c <= 8304 || c > 195101) {
      return -1;
    } else if (c <= 65487) {
      if (c <= 43013) {
        if (c <= 11718) {
          if (c <= 8584) {
            if (c <= 8477) {
              if (c <= 8450) {
                if (c <= 8319) {
                  if (c <= 8305 || c > 8318) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 8335 || !(c <= 8348 || c > 8449)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 8454) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8455 || c > 8457) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 8468 || !(c <= 8469 || c > 8471)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 8483) {
              return -1;
            } else if (c <= 8505) {
              if (c <= 8486) {
                if (c <= 8484 || c > 8485) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 8487 || !(c <= 8488 || c > 8489)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 8507) {
              return -1;
            } else if (c <= 8521) {
              if (c <= 8511 || c > 8516) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 8525 || !(c <= 8526 || c > 8543)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 11263) {
            return -1;
          } else if (c <= 11565) {
            if (c <= 11502) {
              if (c <= 11358) {
                if (c <= 11310 || c > 11311) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 11359 || !(c <= 11492 || c > 11498)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 11505) {
              return -1;
            } else if (c <= 11557) {
              if (c <= 11507 || c > 11519) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 11558 || !(c <= 11559 || c > 11564)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 11567) {
            return -1;
          } else if (c <= 11686) {
            if (c <= 11631) {
              if (c <= 11623 || c > 11630) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 11647 || !(c <= 11670 || c > 11679)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 11687) {
            return -1;
          } else if (c <= 11702) {
            if (c <= 11694 || c > 11695) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 11703 || !(c <= 11710 || c > 11711)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 11719) {
          return -1;
        } else if (c <= 19893) {
          if (c <= 12438) {
            if (c <= 12295) {
              if (c <= 11734) {
                if (c <= 11726 || c > 11727) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 11735 || !(c <= 11742 || c > 12292)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 12320) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12329 || c > 12336) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 12343 || !(c <= 12348 || c > 12352)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 12444) {
            return -1;
          } else if (c <= 12589) {
            if (c <= 12538) {
              if (c <= 12447 || c > 12448) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 12539 || !(c <= 12543 || c > 12548)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 12592) {
            return -1;
          } else if (c <= 12730) {
            if (c <= 12686 || c > 12703) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 19967) {
          return -1;
        } else if (c <= 42647) {
          if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42539) {
            if (c <= 42527 || c > 42537) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 42559 || !(c <= 42606 || c > 42622)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 42655) {
          return -1;
        } else if (c <= 42894) {
          if (c <= 42783) {
            if (c <= 42735 || c > 42774) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 42895) {
          return -1;
        } else if (c <= 42922) {
          if (c <= 42899 || c > 42911) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 42999 || !(c <= 43009 || c > 43010)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 43014) {
        return -1;
      } else if (c <= 55203) {
        if (c <= 43642) {
          if (c <= 43334) {
            if (c <= 43187) {
              if (c <= 43042) {
                if (c <= 43018 || c > 43019) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 43071 || !(c <= 43123 || c > 43137)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 43249) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43255 || c > 43258) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 43273 || !(c <= 43301 || c > 43311)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 43359) {
            return -1;
          } else if (c <= 43560) {
            if (c <= 43442) {
              if (c <= 43388 || c > 43395) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43471 || c > 43519)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43595) {
            if (c <= 43586 || c > 43587) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 43647) {
          return -1;
        } else if (c <= 43754) {
          if (c <= 43709) {
            if (c <= 43697) {
              if (c <= 43695 || c > 43696) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 43700 || !(c <= 43702 || c > 43704)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 43711) {
            return -1;
          } else if (c <= 43714) {
            if (c <= 43712 || c > 43713) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 43738 || !(c <= 43741 || c > 43743)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 43761) {
          return -1;
        } else if (c <= 43798) {
          if (c <= 43782) {
            if (c <= 43764 || c > 43776) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 43784 || !(c <= 43790 || c > 43792)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 43807) {
          return -1;
        } else if (c <= 43822) {
          if (c <= 43814 || c > 43815) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 43967 || !(c <= 44002 || c > 44031)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 55215) {
        return -1;
      } else if (c <= 64829) {
        if (c <= 64296) {
          if (c <= 64217) {
            if (c <= 55291) {
              if (c <= 55238 || c > 55242) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 63743 || !(c <= 64109 || c > 64111)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 64255) {
            return -1;
          } else if (c <= 64279) {
            if (c <= 64262 || c > 64274) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 64284 || !(c <= 64285 || c > 64286)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 64297) {
          return -1;
        } else if (c <= 64321) {
          if (c <= 64316) {
            if (c <= 64310 || c > 64311) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 64322) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64324 || c > 64325) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 64847) {
        return -1;
      } else if (c <= 65147) {
        if (c <= 65137) {
          if (c <= 64967) {
            if (c <= 64911 || c > 64913) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 65007 || !(c <= 65017 || c > 65136)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65139 || c > 65142) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 65148) {
        return -1;
      } else if (c <= 65370) {
        if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 65312 || !(c <= 65338 || c > 65344)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 65381) {
        return -1;
      } else if (c <= 65470) {
        if (c <= 65437 || c > 65439) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 65473 || !(c <= 65479 || c > 65481)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 65489) {
      return -1;
    } else if (c <= 120074) {
      if (c <= 68119) {
        if (c <= 66499) {
          if (c <= 65629) {
            if (c <= 65574) {
              if (c <= 65500) {
                if (c <= 65495 || c > 65497) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 65535 || !(c <= 65547 || c > 65548)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 65575) {
              return -1;
            } else if (c <= 65597) {
              if (c <= 65594 || c > 65595) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 65598 || !(c <= 65613 || c > 65615)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 65663) {
            return -1;
          } else if (c <= 66256) {
            if (c <= 65908) {
              if (c <= 65786 || c > 65855) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 66303) {
            return -1;
          } else if (c <= 66378) {
            if (c <= 66334 || c > 66351) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 66503) {
          return -1;
        } else if (c <= 67644) {
          if (c <= 67589) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 67583)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 67591) {
            return -1;
          } else if (c <= 67637) {
            if (c <= 67592 || c > 67593) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 67638 || !(c <= 67640 || c > 67643)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 67646) {
          return -1;
        } else if (c <= 68023) {
          if (c <= 67861) {
            if (c <= 67669 || c > 67839) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 67871 || !(c <= 67897 || c > 67967)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 68029) {
          return -1;
        } else if (c <= 68096) {
          if (c <= 68031 || c > 68095) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 68111 || !(c <= 68115 || c > 68116)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 68120) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 69807) {
          if (c <= 68437) {
            if (c <= 68220) {
              if (c <= 68147 || c > 68191) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 68447) {
            return -1;
          } else if (c <= 68680) {
            if (c <= 68466 || c > 68607) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 69634 || !(c <= 69687 || c > 69762)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 69839) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69926) {
            if (c <= 69864 || c > 69890) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 70018 || !(c <= 70066 || c > 70080)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 71295) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71338 || c > 73727) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 119967) {
        if (c <= 94111) {
          if (c <= 94020) {
            if (c <= 92728 || c > 93951) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 94031 || !(c <= 94032 || c > 94098)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 110591) {
          return -1;
        } else if (c <= 119892) {
          if (c <= 110593 || c > 119807) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 119969) {
        return -1;
      } else if (c <= 119993) {
        if (c <= 119974) {
          if (c <= 119970 || c > 119972) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 119994) {
        return -1;
      } else if (c <= 120003) {
        if (c <= 119995 || c > 119996) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 120076) {
      return -1;
    } else if (c <= 126539) {
      if (c <= 120712) {
        if (c <= 120485) {
          if (c <= 120126) {
            if (c <= 120092) {
              if (c <= 120084 || c > 120085) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 120127) {
            return -1;
          } else if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120596) {
          if (c <= 120538) {
            if (c <= 120512 || c > 120513) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 120597) {
          return -1;
        } else if (c <= 120654) {
          if (c <= 120628 || c > 120629) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 120713) {
        return -1;
      } else if (c <= 126503) {
        if (c <= 126467) {
          if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 126463)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 126468) {
          return -1;
        } else if (c <= 126498) {
          if (c <= 126495 || c > 126496) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126499 || !(c <= 126500 || c > 126502)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126504) {
        return -1;
      } else if (c <= 126523) {
        if (c <= 126519) {
          if (c <= 126514 || c > 126515) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126520 || !(c <= 126521 || c > 126522)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126529) {
        return -1;
      } else if (c <= 126535) {
        if (c <= 126530 || c > 126534) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 126536 || !(c <= 126537 || c > 126538)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 126540) {
      return -1;
    } else if (c <= 126601) {
      if (c <= 126559) {
        if (c <= 126551) {
          if (c <= 126546) {
            if (c <= 126543 || c > 126544) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 126547 || !(c <= 126548 || c > 126550)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 126552) {
          return -1;
        } else if (c <= 126555) {
          if (c <= 126553 || c > 126554) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126556 || !(c <= 126557 || c > 126558)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126560) {
        return -1;
      } else if (c <= 126578) {
        if (c <= 126564) {
          if (c <= 126562 || c > 126563) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126566 || !(c <= 126570 || c > 126571)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126579) {
        return -1;
      } else if (c <= 126588) {
        if (c <= 126583 || c > 126584) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 126589 || !(c <= 126590 || c > 126591)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 126602) {
      return -1;
    } else if (c <= 126651) {
      if (c <= 126627) {
        if (c <= 126619 || c > 126624) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 126628 || !(c <= 126633 || c > 126634)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 131071) {
      return -1;
    } else if (c <= 177972) {
      if (c <= 173782 || c > 173823) {
        return 0;
      } else {
        return -1;
      }
    } else if (c <= 177983 || !(c <= 178205 || c > 194559)) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_20(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 42 || c > 122) {
      return -1;
    } else {
      return get(__sedlex_table_7, c - 43 | 0) - 1 | 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_7(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 92) {
      return get(__sedlex_table_8, c - -1 | 0) - 1 | 0;
    } else {
      return 1;
    }
  } else {
    return get(__sedlex_table_8, 0) - 1 | 0;
  }
}

function __sedlex_partition_24(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 47 || c > 57) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_11(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 32) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_9, c - 33 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126570) {
      if (c <= 65338) {
        if (c <= 42783) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231 || c > 8254) {
                      return 1;
                    } else {
                      return -1;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 1;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 42124) {
            if (c <= 12730) {
              if (c <= 12589) {
                if (c <= 12543 || c > 12548) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 12592 || !(c <= 12686 || c > 12703)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12783) {
              return -1;
            } else if (c <= 19893) {
              if (c <= 12799 || c > 13311) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 19967 || !(c <= 40908 || c > 40959)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42191) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42508) {
              if (c <= 42237 || c > 42239) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 42511 || !(c <= 42539 || c > 42559)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42611) {
            return -1;
          } else if (c <= 42647) {
            if (c <= 42621 || c > 42622) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 42654 || !(c <= 42737 || c > 42774)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 42785) {
          return -1;
        } else if (c <= 44025) {
          if (c <= 43574) {
            if (c <= 43225) {
              if (c <= 42922) {
                if (c <= 42894) {
                  if (c <= 42888 || c > 42890) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 42895 || !(c <= 42899 || c > 42911)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 42999) {
                return -1;
              } else if (c <= 43123) {
                if (c <= 43047 || c > 43071) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43135 || !(c <= 43204 || c > 43215)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43231) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43259) {
                if (c <= 43255 || c > 43258) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43263 || !(c <= 43309 || c > 43311)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43359) {
              return -1;
            } else if (c <= 43456) {
              if (c <= 43388 || c > 43391) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43481 || c > 43519)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43766) {
            if (c <= 43643) {
              if (c <= 43609) {
                if (c <= 43597 || c > 43599) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43647) {
              return -1;
            } else if (c <= 43741) {
              if (c <= 43714 || c > 43738) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43743 || !(c <= 43759 || c > 43761)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43776) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43790) {
              if (c <= 43782 || c > 43784) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43792 || !(c <= 43798 || c > 43807)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43815) {
            return -1;
          } else if (c <= 44010) {
            if (c <= 43822 || c > 43967) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 44011 || !(c <= 44013 || c > 44015)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 44031) {
          return -1;
        } else if (c <= 64829) {
          if (c <= 64296) {
            if (c <= 64109) {
              if (c <= 55238) {
                if (c <= 55203 || c > 55215) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 55242 || !(c <= 55291 || c > 63743)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 64111) {
              return -1;
            } else if (c <= 64262) {
              if (c <= 64217 || c > 64255) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64274 || !(c <= 64279 || c > 64284)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64297) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64316) {
              if (c <= 64310 || c > 64311) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64322) {
            return -1;
          } else if (c <= 64433) {
            if (c <= 64324 || c > 64325) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 64847) {
          return -1;
        } else if (c <= 65137) {
          if (c <= 65039) {
            if (c <= 64967) {
              if (c <= 64911 || c > 64913) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65007 || !(c <= 65017 || c > 65023)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65055) {
            return -1;
          } else if (c <= 65076) {
            if (c <= 65062 || c > 65074) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65100 || !(c <= 65103 || c > 65136)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65143) {
            if (c <= 65139 || c > 65142) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65148) {
          return -1;
        } else if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 65295 || !(c <= 65305 || c > 65312)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 65342) {
        return -1;
      } else if (c <= 94020) {
        if (c <= 67669) {
          if (c <= 66045) {
            if (c <= 65547) {
              if (c <= 65479) {
                if (c <= 65370) {
                  if (c <= 65343 || c > 65344) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 65381 || !(c <= 65470 || c > 65473)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 65481) {
                return -1;
              } else if (c <= 65495) {
                if (c <= 65487 || c > 65489) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65497 || !(c <= 65500 || c > 65535)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65548) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65594) {
                if (c <= 65574 || c > 65575) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65595 || !(c <= 65597 || c > 65598)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65615) {
              return -1;
            } else if (c <= 65786) {
              if (c <= 65629 || c > 65663) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65855 || !(c <= 65908 || c > 66044)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66175) {
            return -1;
          } else if (c <= 66517) {
            if (c <= 66378) {
              if (c <= 66256) {
                if (c <= 66204 || c > 66207) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 66303 || !(c <= 66334 || c > 66351)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 66431) {
              return -1;
            } else if (c <= 66499) {
              if (c <= 66461 || c > 66463) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66503 || !(c <= 66511 || c > 66512)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66559) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 66729) {
              if (c <= 66717 || c > 66719) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 67583 || !(c <= 67589 || c > 67591)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 67593) {
            return -1;
          } else if (c <= 67640) {
            if (c <= 67637 || c > 67638) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 67643 || !(c <= 67644 || c > 67646)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 67839) {
          return -1;
        } else if (c <= 68680) {
          if (c <= 68119) {
            if (c <= 68031) {
              if (c <= 67897) {
                if (c <= 67861 || c > 67871) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 67967 || !(c <= 68023 || c > 68029)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 68095) {
              return -1;
            } else if (c <= 68102) {
              if (c <= 68099 || c > 68100) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68107 || !(c <= 68115 || c > 68116)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68120) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68154) {
              if (c <= 68147 || c > 68151) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68158 || !(c <= 68159 || c > 68191)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68351) {
            return -1;
          } else if (c <= 68437) {
            if (c <= 68405 || c > 68415) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 68447 || !(c <= 68466 || c > 68607)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 69631) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69864) {
            if (c <= 69743) {
              if (c <= 69702 || c > 69733) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 69759 || !(c <= 69818 || c > 69839)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 69871) {
            return -1;
          } else if (c <= 69940) {
            if (c <= 69881 || c > 69887) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 69941 || !(c <= 69951 || c > 70015)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 70095) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71351) {
            if (c <= 70105 || c > 71295) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 71359 || !(c <= 71369 || c > 73727)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 74751) {
          return -1;
        } else if (c <= 78894) {
          if (c <= 74850 || c > 77823) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 92159 || !(c <= 92728 || c > 93951)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 94031) {
        return -1;
      } else if (c <= 120596) {
        if (c <= 119993) {
          if (c <= 119213) {
            if (c <= 119145) {
              if (c <= 94111) {
                if (c <= 94078 || c > 94094) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 110591 || !(c <= 110593 || c > 119140)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 119148) {
              return -1;
            } else if (c <= 119170) {
              if (c <= 119154 || c > 119162) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119172 || !(c <= 119179 || c > 119209)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119361) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119892) {
              if (c <= 119364 || c > 119807) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119969) {
            return -1;
          } else if (c <= 119974) {
            if (c <= 119970 || c > 119972) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 119994) {
          return -1;
        } else if (c <= 120126) {
          if (c <= 120074) {
            if (c <= 120003) {
              if (c <= 119995 || c > 119996) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120076) {
            return -1;
          } else if (c <= 120092) {
            if (c <= 120084 || c > 120085) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120127) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120538) {
          if (c <= 120512 || c > 120513) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 120597) {
        return -1;
      } else if (c <= 126521) {
        if (c <= 120831) {
          if (c <= 120712) {
            if (c <= 120654) {
              if (c <= 120628 || c > 120629) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120713) {
            return -1;
          } else if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 120781)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126463) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126495) {
            if (c <= 126467 || c > 126468) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126496 || !(c <= 126498 || c > 126499)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126502) {
          return -1;
        } else if (c <= 126514) {
          if (c <= 126503 || c > 126504) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126515 || !(c <= 126519 || c > 126520)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126522) {
        return -1;
      } else if (c <= 126548) {
        if (c <= 126537) {
          if (c <= 126530) {
            if (c <= 126523 || c > 126529) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126534 || !(c <= 126535 || c > 126536)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126538) {
          return -1;
        } else if (c <= 126543) {
          if (c <= 126539 || c > 126540) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126544 || !(c <= 126546 || c > 126547)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126550) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126553) {
          if (c <= 126551 || c > 126552) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126554 || !(c <= 126555 || c > 126556)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126558) {
        return -1;
      } else if (c <= 126562) {
        if (c <= 126559 || c > 126560) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126563 || !(c <= 126564 || c > 126566)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126571) {
      return -1;
    } else if (c <= 126633) {
      if (c <= 126590) {
        if (c <= 126583) {
          if (c <= 126578 || c > 126579) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126584 || !(c <= 126588 || c > 126589)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126591) {
        return -1;
      } else if (c <= 126619) {
        if (c <= 126601 || c > 126602) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126624 || !(c <= 126627 || c > 126628)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126634) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 173782) {
        if (c <= 126651 || c > 131071) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 173823 || !(c <= 177972 || c > 177983)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 1;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_14(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 44) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_10, c - 45 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126562) {
      if (c <= 65276) {
        if (c <= 42647) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231) {
                      return 0;
                    } else if (c <= 8254) {
                      return -1;
                    } else {
                      return 1;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 1;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 19893) {
            if (c <= 12589) {
              if (c <= 12539) {
                if (c <= 12538) {
                  return 1;
                } else {
                  return 0;
                }
              } else if (c <= 12543 || c > 12548) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12592) {
              return -1;
            } else if (c <= 12730) {
              if (c <= 12686 || c > 12703) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 19967) {
            return -1;
          } else if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42539 || c > 42559) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 42611 || !(c <= 42621 || c > 42622)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 42654) {
          return -1;
        } else if (c <= 44010) {
          if (c <= 43456) {
            if (c <= 43123) {
              if (c <= 42894) {
                if (c <= 42783) {
                  if (c <= 42737 || c > 42774) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 42895) {
                return -1;
              } else if (c <= 42922) {
                if (c <= 42899 || c > 42911) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 42999 || !(c <= 43047 || c > 43071)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43135) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43225) {
                if (c <= 43204 || c > 43215) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43231 || !(c <= 43255 || c > 43258)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43263) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43309 || c > 43311) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43359 || !(c <= 43388 || c > 43391)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43470) {
            return -1;
          } else if (c <= 43741) {
            if (c <= 43609) {
              if (c <= 43574) {
                if (c <= 43481 || c > 43519) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43583 || !(c <= 43597 || c > 43599)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43615) {
              return -1;
            } else if (c <= 43643) {
              if (c <= 43638 || c > 43641) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43647 || !(c <= 43714 || c > 43738)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43743) {
            return -1;
          } else if (c <= 43790) {
            if (c <= 43766) {
              if (c <= 43759 || c > 43761) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43776 || !(c <= 43782 || c > 43784)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43792) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43798 || c > 43807) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 43815 || !(c <= 43822 || c > 43967)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 44011) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64262) {
            if (c <= 55238) {
              if (c <= 44025) {
                if (c <= 44013 || c > 44015) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 44031 || !(c <= 55203 || c > 55215)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 55242) {
              return -1;
            } else if (c <= 64109) {
              if (c <= 55291 || c > 63743) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64111 || !(c <= 64217 || c > 64255)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64274) {
            return -1;
          } else if (c <= 64316) {
            if (c <= 64296) {
              if (c <= 64279 || c > 64284) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64297 || !(c <= 64310 || c > 64311)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64317) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64318 || c > 64319) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 64322 || !(c <= 64324 || c > 64325)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 64466) {
          return -1;
        } else if (c <= 65076) {
          if (c <= 64967) {
            if (c <= 64829) {
              if (c <= 64605 || c > 64611) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64847 || !(c <= 64911 || c > 64913)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65007) {
            return -1;
          } else if (c <= 65039) {
            if (c <= 65017 || c > 65023) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65055 || !(c <= 65062 || c > 65074)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65100) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65137) {
            if (c <= 65103 || c > 65136) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65138 || !(c <= 65139 || c > 65142)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65144) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65145 || c > 65146) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 65148 || !(c <= 65149 || c > 65150)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 65295) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 67640) {
          if (c <= 65786) {
            if (c <= 65495) {
              if (c <= 65370) {
                if (c <= 65338) {
                  if (c <= 65305 || c > 65312) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 65342 || !(c <= 65343 || c > 65344)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 65381) {
                return -1;
              } else if (c <= 65479) {
                if (c <= 65470 || c > 65473) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65481 || !(c <= 65487 || c > 65489)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65497) {
              return -1;
            } else if (c <= 65594) {
              if (c <= 65547) {
                if (c <= 65500 || c > 65535) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65548 || !(c <= 65574 || c > 65575)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65595) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65597 || c > 65598) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65615 || !(c <= 65629 || c > 65663)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65855) {
            return -1;
          } else if (c <= 66499) {
            if (c <= 66256) {
              if (c <= 66045) {
                if (c <= 65908 || c > 66044) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 66303) {
              return -1;
            } else if (c <= 66378) {
              if (c <= 66334 || c > 66351) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66503) {
            return -1;
          } else if (c <= 66729) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 66719)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 67583) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 67589 || c > 67591) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 67593 || !(c <= 67637 || c > 67638)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 67643) {
          return -1;
        } else if (c <= 68437) {
          if (c <= 68102) {
            if (c <= 67897) {
              if (c <= 67669) {
                if (c <= 67644 || c > 67646) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 67839 || !(c <= 67861 || c > 67871)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 67967) {
              return -1;
            } else if (c <= 68031) {
              if (c <= 68023 || c > 68029) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68095 || !(c <= 68099 || c > 68100)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68107) {
            return -1;
          } else if (c <= 68154) {
            if (c <= 68119) {
              if (c <= 68115 || c > 68116) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68120 || !(c <= 68147 || c > 68151)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68158) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68159 || c > 68191) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 68447) {
          return -1;
        } else if (c <= 69940) {
          if (c <= 69743) {
            if (c <= 68680) {
              if (c <= 68466 || c > 68607) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 69631 || !(c <= 69702 || c > 69733)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 69759) {
            return -1;
          } else if (c <= 69864) {
            if (c <= 69818 || c > 69839) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 69871 || !(c <= 69881 || c > 69887)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 69941) {
          return -1;
        } else if (c <= 71351) {
          if (c <= 70084) {
            if (c <= 69951 || c > 70015) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 70095 || !(c <= 70105 || c > 71295)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 71359) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71369 || c > 73727) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 120538) {
        if (c <= 119974) {
          if (c <= 119170) {
            if (c <= 94111) {
              if (c <= 94020) {
                if (c <= 92728 || c > 93951) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 94031 || !(c <= 94078 || c > 94094)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 110591) {
              return -1;
            } else if (c <= 119145) {
              if (c <= 110593 || c > 119140) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119148 || !(c <= 119154 || c > 119162)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119172) {
            return -1;
          } else if (c <= 119892) {
            if (c <= 119213) {
              if (c <= 119179 || c > 119209) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119361 || !(c <= 119364 || c > 119807)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119893) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119964 || c > 119965) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 119969 || !(c <= 119970 || c > 119972)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 119976) {
          return -1;
        } else if (c <= 120092) {
          if (c <= 120003) {
            if (c <= 119993) {
              if (c <= 119980 || c > 119981) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119994 || !(c <= 119995 || c > 119996)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120004) {
            return -1;
          } else if (c <= 120074) {
            if (c <= 120069 || c > 120070) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120076 || !(c <= 120084 || c > 120085)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120093) {
          return -1;
        } else if (c <= 120134) {
          if (c <= 120126) {
            if (c <= 120121 || c > 120122) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120127 || !(c <= 120132 || c > 120133)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120137) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120144 || c > 120145) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 120487 || !(c <= 120512 || c > 120513)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 120539) {
        return -1;
      } else if (c <= 126514) {
        if (c <= 120770) {
          if (c <= 120654) {
            if (c <= 120596) {
              if (c <= 120570 || c > 120571) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120597 || !(c <= 120628 || c > 120629)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120655) {
            return -1;
          } else if (c <= 120712) {
            if (c <= 120686 || c > 120687) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120713 || !(c <= 120744 || c > 120745)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120771) {
          return -1;
        } else if (c <= 126495) {
          if (c <= 120831) {
            if (c <= 120779 || c > 120781) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126463 || !(c <= 126467 || c > 126468)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126496) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126498 || c > 126499) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126502 || !(c <= 126503 || c > 126504)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126515) {
        return -1;
      } else if (c <= 126543) {
        if (c <= 126530) {
          if (c <= 126521) {
            if (c <= 126519 || c > 126520) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126522 || !(c <= 126523 || c > 126529)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126534) {
          return -1;
        } else if (c <= 126537) {
          if (c <= 126535 || c > 126536) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126538 || !(c <= 126539 || c > 126540)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126544) {
        return -1;
      } else if (c <= 126553) {
        if (c <= 126548) {
          if (c <= 126546 || c > 126547) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126550 || !(c <= 126551 || c > 126552)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126554) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126555 || c > 126556) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126558 || !(c <= 126559 || c > 126560)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126563) {
      return -1;
    } else if (c <= 126619) {
      if (c <= 126583) {
        if (c <= 126570) {
          if (c <= 126564 || c > 126566) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126571 || !(c <= 126578 || c > 126579)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126584) {
        return -1;
      } else if (c <= 126590) {
        if (c <= 126588 || c > 126589) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126591 || !(c <= 126601 || c > 126602)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126624) {
      return -1;
    } else if (c <= 173782) {
      if (c <= 126633) {
        if (c <= 126627 || c > 126628) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126634 || !(c <= 126651 || c > 131071)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 173823) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 177972 || c > 177983) {
        return 1;
      } else {
        return -1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 1;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_13(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 33) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_11, c - 34 | 0) - 1 | 0;
    } else if (c <= 8304 || c > 195101) {
      return -1;
    } else if (c <= 65487) {
      if (c <= 43013) {
        if (c <= 11718) {
          if (c <= 8584) {
            if (c <= 8477) {
              if (c <= 8450) {
                if (c <= 8319) {
                  if (c <= 8305 || c > 8318) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8335 || !(c <= 8348 || c > 8449)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8454) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8455 || c > 8457) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 8468 || !(c <= 8469 || c > 8471)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 8483) {
              return -1;
            } else if (c <= 8505) {
              if (c <= 8486) {
                if (c <= 8484 || c > 8485) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 8487 || !(c <= 8488 || c > 8489)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 8507) {
              return -1;
            } else if (c <= 8521) {
              if (c <= 8511 || c > 8516) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 8525 || !(c <= 8526 || c > 8543)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11263) {
            return -1;
          } else if (c <= 11565) {
            if (c <= 11502) {
              if (c <= 11358) {
                if (c <= 11310 || c > 11311) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11359 || !(c <= 11492 || c > 11498)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11505) {
              return -1;
            } else if (c <= 11557) {
              if (c <= 11507 || c > 11519) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 11558 || !(c <= 11559 || c > 11564)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11567) {
            return -1;
          } else if (c <= 11686) {
            if (c <= 11631) {
              if (c <= 11623 || c > 11630) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 11647 || !(c <= 11670 || c > 11679)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11687) {
            return -1;
          } else if (c <= 11702) {
            if (c <= 11694 || c > 11695) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 11703 || !(c <= 11710 || c > 11711)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 11719) {
          return -1;
        } else if (c <= 19893) {
          if (c <= 12438) {
            if (c <= 12295) {
              if (c <= 11734) {
                if (c <= 11726 || c > 11727) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11735 || !(c <= 11742 || c > 12292)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12320) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12329 || c > 12336) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12343 || !(c <= 12348 || c > 12352)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12444) {
            return -1;
          } else if (c <= 12589) {
            if (c <= 12538) {
              if (c <= 12447 || c > 12448) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12539 || !(c <= 12543 || c > 12548)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12592) {
            return -1;
          } else if (c <= 12730) {
            if (c <= 12686 || c > 12703) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 19967) {
          return -1;
        } else if (c <= 42647) {
          if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42539) {
            if (c <= 42527 || c > 42537) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 42559 || !(c <= 42606 || c > 42622)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 42655) {
          return -1;
        } else if (c <= 42894) {
          if (c <= 42783) {
            if (c <= 42735 || c > 42774) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 42895) {
          return -1;
        } else if (c <= 42922) {
          if (c <= 42899 || c > 42911) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 42999 || !(c <= 43009 || c > 43010)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 43014) {
        return -1;
      } else if (c <= 55203) {
        if (c <= 43642) {
          if (c <= 43334) {
            if (c <= 43187) {
              if (c <= 43042) {
                if (c <= 43018 || c > 43019) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43071 || !(c <= 43123 || c > 43137)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43249) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43255 || c > 43258) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43273 || !(c <= 43301 || c > 43311)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43359) {
            return -1;
          } else if (c <= 43560) {
            if (c <= 43442) {
              if (c <= 43388 || c > 43395) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43471 || c > 43519)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43595) {
            if (c <= 43586 || c > 43587) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 43647) {
          return -1;
        } else if (c <= 43754) {
          if (c <= 43709) {
            if (c <= 43697) {
              if (c <= 43695 || c > 43696) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43700 || !(c <= 43702 || c > 43704)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43711) {
            return -1;
          } else if (c <= 43714) {
            if (c <= 43712 || c > 43713) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 43738 || !(c <= 43741 || c > 43743)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 43761) {
          return -1;
        } else if (c <= 43798) {
          if (c <= 43782) {
            if (c <= 43764 || c > 43776) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 43784 || !(c <= 43790 || c > 43792)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 43807) {
          return -1;
        } else if (c <= 43822) {
          if (c <= 43814 || c > 43815) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 43967 || !(c <= 44002 || c > 44031)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 55215) {
        return -1;
      } else if (c <= 64829) {
        if (c <= 64296) {
          if (c <= 64217) {
            if (c <= 55291) {
              if (c <= 55238 || c > 55242) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 63743 || !(c <= 64109 || c > 64111)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64255) {
            return -1;
          } else if (c <= 64279) {
            if (c <= 64262 || c > 64274) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 64284 || !(c <= 64285 || c > 64286)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 64297) {
          return -1;
        } else if (c <= 64321) {
          if (c <= 64316) {
            if (c <= 64310 || c > 64311) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 64322) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64324 || c > 64325) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 64847) {
        return -1;
      } else if (c <= 65147) {
        if (c <= 65137) {
          if (c <= 64967) {
            if (c <= 64911 || c > 64913) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65007 || !(c <= 65017 || c > 65136)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65139 || c > 65142) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 65148) {
        return -1;
      } else if (c <= 65370) {
        if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 65312 || !(c <= 65338 || c > 65344)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 65381) {
        return -1;
      } else if (c <= 65470) {
        if (c <= 65437 || c > 65439) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 65473 || !(c <= 65479 || c > 65481)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 65489) {
      return -1;
    } else if (c <= 120074) {
      if (c <= 68119) {
        if (c <= 66499) {
          if (c <= 65629) {
            if (c <= 65574) {
              if (c <= 65500) {
                if (c <= 65495 || c > 65497) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65535 || !(c <= 65547 || c > 65548)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65575) {
              return -1;
            } else if (c <= 65597) {
              if (c <= 65594 || c > 65595) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65598 || !(c <= 65613 || c > 65615)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65663) {
            return -1;
          } else if (c <= 66256) {
            if (c <= 65908) {
              if (c <= 65786 || c > 65855) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66303) {
            return -1;
          } else if (c <= 66378) {
            if (c <= 66334 || c > 66351) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 66503) {
          return -1;
        } else if (c <= 67644) {
          if (c <= 67589) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 67583)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 67591) {
            return -1;
          } else if (c <= 67637) {
            if (c <= 67592 || c > 67593) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 67638 || !(c <= 67640 || c > 67643)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 67646) {
          return -1;
        } else if (c <= 68023) {
          if (c <= 67861) {
            if (c <= 67669 || c > 67839) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 67871 || !(c <= 67897 || c > 67967)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 68029) {
          return -1;
        } else if (c <= 68096) {
          if (c <= 68031 || c > 68095) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 68111 || !(c <= 68115 || c > 68116)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 68120) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 69807) {
          if (c <= 68437) {
            if (c <= 68220) {
              if (c <= 68147 || c > 68191) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68447) {
            return -1;
          } else if (c <= 68680) {
            if (c <= 68466 || c > 68607) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 69634 || !(c <= 69687 || c > 69762)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 69839) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69926) {
            if (c <= 69864 || c > 69890) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 70018 || !(c <= 70066 || c > 70080)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 71295) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71338 || c > 73727) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 119967) {
        if (c <= 94111) {
          if (c <= 94020) {
            if (c <= 92728 || c > 93951) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 94031 || !(c <= 94032 || c > 94098)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 110591) {
          return -1;
        } else if (c <= 119892) {
          if (c <= 110593 || c > 119807) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 119969) {
        return -1;
      } else if (c <= 119993) {
        if (c <= 119974) {
          if (c <= 119970 || c > 119972) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 119994) {
        return -1;
      } else if (c <= 120003) {
        if (c <= 119995 || c > 119996) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 120076) {
      return -1;
    } else if (c <= 126539) {
      if (c <= 120712) {
        if (c <= 120485) {
          if (c <= 120126) {
            if (c <= 120092) {
              if (c <= 120084 || c > 120085) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120127) {
            return -1;
          } else if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120596) {
          if (c <= 120538) {
            if (c <= 120512 || c > 120513) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120597) {
          return -1;
        } else if (c <= 120654) {
          if (c <= 120628 || c > 120629) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 120713) {
        return -1;
      } else if (c <= 126503) {
        if (c <= 126467) {
          if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 126463)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126468) {
          return -1;
        } else if (c <= 126498) {
          if (c <= 126495 || c > 126496) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126499 || !(c <= 126500 || c > 126502)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126504) {
        return -1;
      } else if (c <= 126523) {
        if (c <= 126519) {
          if (c <= 126514 || c > 126515) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126520 || !(c <= 126521 || c > 126522)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126529) {
        return -1;
      } else if (c <= 126535) {
        if (c <= 126530 || c > 126534) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126536 || !(c <= 126537 || c > 126538)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126540) {
      return -1;
    } else if (c <= 126601) {
      if (c <= 126559) {
        if (c <= 126551) {
          if (c <= 126546) {
            if (c <= 126543 || c > 126544) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126547 || !(c <= 126548 || c > 126550)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126552) {
          return -1;
        } else if (c <= 126555) {
          if (c <= 126553 || c > 126554) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126556 || !(c <= 126557 || c > 126558)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126560) {
        return -1;
      } else if (c <= 126578) {
        if (c <= 126564) {
          if (c <= 126562 || c > 126563) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126566 || !(c <= 126570 || c > 126571)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126579) {
        return -1;
      } else if (c <= 126588) {
        if (c <= 126583 || c > 126584) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126589 || !(c <= 126590 || c > 126591)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126602) {
      return -1;
    } else if (c <= 126651) {
      if (c <= 126627) {
        if (c <= 126619 || c > 126624) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126628 || !(c <= 126633 || c > 126634)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 131071) {
      return -1;
    } else if (c <= 177972) {
      if (c <= 173782 || c > 173823) {
        return 1;
      } else {
        return -1;
      }
    } else if (c <= 177983 || !(c <= 178205 || c > 194559)) {
      return -1;
    } else {
      return 1;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_25(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 42) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_12, c - 43 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126562) {
      if (c <= 65276) {
        if (c <= 42647) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231) {
                      return 7;
                    } else if (c <= 8254) {
                      return -1;
                    } else {
                      return 3;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 3;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 19893) {
            if (c <= 12589) {
              if (c <= 12539) {
                if (c <= 12538) {
                  return 3;
                } else {
                  return 7;
                }
              } else if (c <= 12543 || c > 12548) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 12592) {
              return -1;
            } else if (c <= 12730) {
              if (c <= 12686 || c > 12703) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 19967) {
            return -1;
          } else if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42539 || c > 42559) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 42611 || !(c <= 42621 || c > 42622)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 42654) {
          return -1;
        } else if (c <= 44010) {
          if (c <= 43456) {
            if (c <= 43123) {
              if (c <= 42894) {
                if (c <= 42783) {
                  if (c <= 42737 || c > 42774) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 42895) {
                return -1;
              } else if (c <= 42922) {
                if (c <= 42899 || c > 42911) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 42999 || !(c <= 43047 || c > 43071)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 43135) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43225) {
                if (c <= 43204 || c > 43215) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 43231 || !(c <= 43255 || c > 43258)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 43263) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43309 || c > 43311) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 43359 || !(c <= 43388 || c > 43391)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 43470) {
            return -1;
          } else if (c <= 43741) {
            if (c <= 43609) {
              if (c <= 43574) {
                if (c <= 43481 || c > 43519) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 43583 || !(c <= 43597 || c > 43599)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 43615) {
              return -1;
            } else if (c <= 43643) {
              if (c <= 43638 || c > 43641) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 43647 || !(c <= 43714 || c > 43738)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 43743) {
            return -1;
          } else if (c <= 43790) {
            if (c <= 43766) {
              if (c <= 43759 || c > 43761) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 43776 || !(c <= 43782 || c > 43784)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 43792) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43798 || c > 43807) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 43815 || !(c <= 43822 || c > 43967)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 44011) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64262) {
            if (c <= 55238) {
              if (c <= 44025) {
                if (c <= 44013 || c > 44015) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 44031 || !(c <= 55203 || c > 55215)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 55242) {
              return -1;
            } else if (c <= 64109) {
              if (c <= 55291 || c > 63743) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 64111 || !(c <= 64217 || c > 64255)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 64274) {
            return -1;
          } else if (c <= 64316) {
            if (c <= 64296) {
              if (c <= 64279 || c > 64284) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 64297 || !(c <= 64310 || c > 64311)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 64317) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64318 || c > 64319) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 64322 || !(c <= 64324 || c > 64325)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 64466) {
          return -1;
        } else if (c <= 65076) {
          if (c <= 64967) {
            if (c <= 64829) {
              if (c <= 64605 || c > 64611) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 64847 || !(c <= 64911 || c > 64913)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 65007) {
            return -1;
          } else if (c <= 65039) {
            if (c <= 65017 || c > 65023) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 65055 || !(c <= 65062 || c > 65074)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 65100) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65137) {
            if (c <= 65103 || c > 65136) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 65138 || !(c <= 65139 || c > 65142)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 65144) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65145 || c > 65146) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 65148 || !(c <= 65149 || c > 65150)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 65295) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 67640) {
          if (c <= 65786) {
            if (c <= 65495) {
              if (c <= 65370) {
                if (c <= 65338) {
                  if (c <= 65305 || c > 65312) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 65342 || !(c <= 65343 || c > 65344)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 65381) {
                return -1;
              } else if (c <= 65479) {
                if (c <= 65470 || c > 65473) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 65481 || !(c <= 65487 || c > 65489)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 65497) {
              return -1;
            } else if (c <= 65594) {
              if (c <= 65547) {
                if (c <= 65500 || c > 65535) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 65548 || !(c <= 65574 || c > 65575)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 65595) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65597 || c > 65598) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 65615 || !(c <= 65629 || c > 65663)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 65855) {
            return -1;
          } else if (c <= 66499) {
            if (c <= 66256) {
              if (c <= 66045) {
                if (c <= 65908 || c > 66044) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 66303) {
              return -1;
            } else if (c <= 66378) {
              if (c <= 66334 || c > 66351) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 66503) {
            return -1;
          } else if (c <= 66729) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 66719)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 67583) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 67589 || c > 67591) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 67593 || !(c <= 67637 || c > 67638)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 67643) {
          return -1;
        } else if (c <= 68437) {
          if (c <= 68102) {
            if (c <= 67897) {
              if (c <= 67669) {
                if (c <= 67644 || c > 67646) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 67839 || !(c <= 67861 || c > 67871)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 67967) {
              return -1;
            } else if (c <= 68031) {
              if (c <= 68023 || c > 68029) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 68095 || !(c <= 68099 || c > 68100)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 68107) {
            return -1;
          } else if (c <= 68154) {
            if (c <= 68119) {
              if (c <= 68115 || c > 68116) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 68120 || !(c <= 68147 || c > 68151)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 68158) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68159 || c > 68191) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 68447) {
          return -1;
        } else if (c <= 69940) {
          if (c <= 69743) {
            if (c <= 68680) {
              if (c <= 68466 || c > 68607) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 69631 || !(c <= 69702 || c > 69733)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 69759) {
            return -1;
          } else if (c <= 69864) {
            if (c <= 69818 || c > 69839) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 69871 || !(c <= 69881 || c > 69887)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 69941) {
          return -1;
        } else if (c <= 71351) {
          if (c <= 70084) {
            if (c <= 69951 || c > 70015) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 70095 || !(c <= 70105 || c > 71295)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 71359) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71369 || c > 73727) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 120538) {
        if (c <= 119974) {
          if (c <= 119170) {
            if (c <= 94111) {
              if (c <= 94020) {
                if (c <= 92728 || c > 93951) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 94031 || !(c <= 94078 || c > 94094)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 110591) {
              return -1;
            } else if (c <= 119145) {
              if (c <= 110593 || c > 119140) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 119148 || !(c <= 119154 || c > 119162)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 119172) {
            return -1;
          } else if (c <= 119892) {
            if (c <= 119213) {
              if (c <= 119179 || c > 119209) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 119361 || !(c <= 119364 || c > 119807)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 119893) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119964 || c > 119965) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 119969 || !(c <= 119970 || c > 119972)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 119976) {
          return -1;
        } else if (c <= 120092) {
          if (c <= 120003) {
            if (c <= 119993) {
              if (c <= 119980 || c > 119981) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 119994 || !(c <= 119995 || c > 119996)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 120004) {
            return -1;
          } else if (c <= 120074) {
            if (c <= 120069 || c > 120070) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 120076 || !(c <= 120084 || c > 120085)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 120093) {
          return -1;
        } else if (c <= 120134) {
          if (c <= 120126) {
            if (c <= 120121 || c > 120122) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 120127 || !(c <= 120132 || c > 120133)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 120137) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120144 || c > 120145) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 120487 || !(c <= 120512 || c > 120513)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 120539) {
        return -1;
      } else if (c <= 126514) {
        if (c <= 120770) {
          if (c <= 120654) {
            if (c <= 120596) {
              if (c <= 120570 || c > 120571) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 120597 || !(c <= 120628 || c > 120629)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 120655) {
            return -1;
          } else if (c <= 120712) {
            if (c <= 120686 || c > 120687) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 120713 || !(c <= 120744 || c > 120745)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 120771) {
          return -1;
        } else if (c <= 126495) {
          if (c <= 120831) {
            if (c <= 120779 || c > 120781) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 126463 || !(c <= 126467 || c > 126468)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 126496) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126498 || c > 126499) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126502 || !(c <= 126503 || c > 126504)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126515) {
        return -1;
      } else if (c <= 126543) {
        if (c <= 126530) {
          if (c <= 126521) {
            if (c <= 126519 || c > 126520) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 126522 || !(c <= 126523 || c > 126529)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 126534) {
          return -1;
        } else if (c <= 126537) {
          if (c <= 126535 || c > 126536) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126538 || !(c <= 126539 || c > 126540)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126544) {
        return -1;
      } else if (c <= 126553) {
        if (c <= 126548) {
          if (c <= 126546 || c > 126547) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126550 || !(c <= 126551 || c > 126552)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126554) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126555 || c > 126556) {
          return 3;
        } else {
          return -1;
        }
      } else if (c <= 126558 || !(c <= 126559 || c > 126560)) {
        return -1;
      } else {
        return 3;
      }
    } else if (c <= 126563) {
      return -1;
    } else if (c <= 126619) {
      if (c <= 126583) {
        if (c <= 126570) {
          if (c <= 126564 || c > 126566) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126571 || !(c <= 126578 || c > 126579)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126584) {
        return -1;
      } else if (c <= 126590) {
        if (c <= 126588 || c > 126589) {
          return 3;
        } else {
          return -1;
        }
      } else if (c <= 126591 || !(c <= 126601 || c > 126602)) {
        return -1;
      } else {
        return 3;
      }
    } else if (c <= 126624) {
      return -1;
    } else if (c <= 173782) {
      if (c <= 126633) {
        if (c <= 126627 || c > 126628) {
          return 3;
        } else {
          return -1;
        }
      } else if (c <= 126634 || !(c <= 126651 || c > 131071)) {
        return -1;
      } else {
        return 3;
      }
    } else if (c <= 173823) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 177972 || c > 177983) {
        return 3;
      } else {
        return -1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 3;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_26(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 42) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_13, c - 43 | 0) - 1 | 0;
    } else if (c <= 8254 || c > 917999) {
      return -1;
    } else if (c <= 126570) {
      if (c <= 65338) {
        if (c <= 42783) {
          if (c <= 11686) {
            if (c <= 8488) {
              if (c <= 8432) {
                if (c <= 8319) {
                  if (c <= 8276) {
                    if (c <= 8256 || c > 8275) {
                      return 1;
                    } else {
                      return -1;
                    }
                  } else if (c <= 8304 || !(c <= 8305 || c > 8318)) {
                    return -1;
                  } else {
                    return 1;
                  }
                } else if (c <= 8335) {
                  return -1;
                } else if (c <= 8412) {
                  if (c <= 8348 || c > 8399) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8416 || !(c <= 8417 || c > 8420)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8449) {
                return -1;
              } else if (c <= 8469) {
                if (c <= 8455) {
                  if (c <= 8450 || c > 8454) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8457 || !(c <= 8467 || c > 8468)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8471) {
                return -1;
              } else if (c <= 8484) {
                if (c <= 8477 || c > 8483) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 8485 || !(c <= 8486 || c > 8487)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 8489) {
              return -1;
            } else if (c <= 11492) {
              if (c <= 8526) {
                if (c <= 8511) {
                  if (c <= 8505 || c > 8507) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 8516 || !(c <= 8521 || c > 8525)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 8543) {
                return -1;
              } else if (c <= 11310) {
                if (c <= 8584 || c > 11263) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11311 || !(c <= 11358 || c > 11359)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11498) {
              return -1;
            } else if (c <= 11565) {
              if (c <= 11557) {
                if (c <= 11507 || c > 11519) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11558 || !(c <= 11559 || c > 11564)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 11567) {
              return -1;
            } else if (c <= 11631) {
              if (c <= 11623 || c > 11630) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 11646 || !(c <= 11670 || c > 11679)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 11687) {
            return -1;
          } else if (c <= 12538) {
            if (c <= 11775) {
              if (c <= 11718) {
                if (c <= 11702) {
                  if (c <= 11694 || c > 11695) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 11703 || !(c <= 11710 || c > 11711)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 11719) {
                return -1;
              } else if (c <= 11734) {
                if (c <= 11726 || c > 11727) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 11735 || !(c <= 11742 || c > 11743)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12292) {
              return -1;
            } else if (c <= 12348) {
              if (c <= 12335) {
                if (c <= 12295 || c > 12320) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 12336 || !(c <= 12341 || c > 12343)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12352) {
              return -1;
            } else if (c <= 12442) {
              if (c <= 12438 || c > 12440) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 12444 || !(c <= 12447 || c > 12448)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 12539) {
            return -1;
          } else if (c <= 42124) {
            if (c <= 12730) {
              if (c <= 12589) {
                if (c <= 12543 || c > 12548) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 12592 || !(c <= 12686 || c > 12703)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 12783) {
              return -1;
            } else if (c <= 19893) {
              if (c <= 12799 || c > 13311) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 19967 || !(c <= 40908 || c > 40959)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42191) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42508) {
              if (c <= 42237 || c > 42239) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 42511 || !(c <= 42539 || c > 42559)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 42611) {
            return -1;
          } else if (c <= 42647) {
            if (c <= 42621 || c > 42622) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 42654 || !(c <= 42737 || c > 42774)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 42785) {
          return -1;
        } else if (c <= 44025) {
          if (c <= 43574) {
            if (c <= 43225) {
              if (c <= 42922) {
                if (c <= 42894) {
                  if (c <= 42888 || c > 42890) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 42895 || !(c <= 42899 || c > 42911)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 42999) {
                return -1;
              } else if (c <= 43123) {
                if (c <= 43047 || c > 43071) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43135 || !(c <= 43204 || c > 43215)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43231) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43259) {
                if (c <= 43255 || c > 43258) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43263 || !(c <= 43309 || c > 43311)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43359) {
              return -1;
            } else if (c <= 43456) {
              if (c <= 43388 || c > 43391) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43481 || c > 43519)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43766) {
            if (c <= 43643) {
              if (c <= 43609) {
                if (c <= 43597 || c > 43599) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 43647) {
              return -1;
            } else if (c <= 43741) {
              if (c <= 43714 || c > 43738) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43743 || !(c <= 43759 || c > 43761)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43776) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43790) {
              if (c <= 43782 || c > 43784) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 43792 || !(c <= 43798 || c > 43807)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 43815) {
            return -1;
          } else if (c <= 44010) {
            if (c <= 43822 || c > 43967) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 44011 || !(c <= 44013 || c > 44015)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 44031) {
          return -1;
        } else if (c <= 64829) {
          if (c <= 64296) {
            if (c <= 64109) {
              if (c <= 55238) {
                if (c <= 55203 || c > 55215) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 55242 || !(c <= 55291 || c > 63743)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 64111) {
              return -1;
            } else if (c <= 64262) {
              if (c <= 64217 || c > 64255) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64274 || !(c <= 64279 || c > 64284)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64297) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64316) {
              if (c <= 64310 || c > 64311) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 64322) {
            return -1;
          } else if (c <= 64433) {
            if (c <= 64324 || c > 64325) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 64847) {
          return -1;
        } else if (c <= 65137) {
          if (c <= 65039) {
            if (c <= 64967) {
              if (c <= 64911 || c > 64913) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65007 || !(c <= 65017 || c > 65023)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 65055) {
            return -1;
          } else if (c <= 65076) {
            if (c <= 65062 || c > 65074) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65100 || !(c <= 65103 || c > 65136)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65143) {
            if (c <= 65139 || c > 65142) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 65148) {
          return -1;
        } else if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 65295 || !(c <= 65305 || c > 65312)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 65342) {
        return -1;
      } else if (c <= 94020) {
        if (c <= 67669) {
          if (c <= 66045) {
            if (c <= 65547) {
              if (c <= 65479) {
                if (c <= 65370) {
                  if (c <= 65343 || c > 65344) {
                    return 1;
                  } else {
                    return -1;
                  }
                } else if (c <= 65381 || !(c <= 65470 || c > 65473)) {
                  return -1;
                } else {
                  return 1;
                }
              } else if (c <= 65481) {
                return -1;
              } else if (c <= 65495) {
                if (c <= 65487 || c > 65489) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65497 || !(c <= 65500 || c > 65535)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65548) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65594) {
                if (c <= 65574 || c > 65575) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 65595 || !(c <= 65597 || c > 65598)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 65615) {
              return -1;
            } else if (c <= 65786) {
              if (c <= 65629 || c > 65663) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 65855 || !(c <= 65908 || c > 66044)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66175) {
            return -1;
          } else if (c <= 66517) {
            if (c <= 66378) {
              if (c <= 66256) {
                if (c <= 66204 || c > 66207) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 66303 || !(c <= 66334 || c > 66351)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 66431) {
              return -1;
            } else if (c <= 66499) {
              if (c <= 66461 || c > 66463) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 66503 || !(c <= 66511 || c > 66512)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 66559) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 66729) {
              if (c <= 66717 || c > 66719) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 67583 || !(c <= 67589 || c > 67591)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 67593) {
            return -1;
          } else if (c <= 67640) {
            if (c <= 67637 || c > 67638) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 67643 || !(c <= 67644 || c > 67646)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 67839) {
          return -1;
        } else if (c <= 68680) {
          if (c <= 68119) {
            if (c <= 68031) {
              if (c <= 67897) {
                if (c <= 67861 || c > 67871) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 67967 || !(c <= 68023 || c > 68029)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 68095) {
              return -1;
            } else if (c <= 68102) {
              if (c <= 68099 || c > 68100) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68107 || !(c <= 68115 || c > 68116)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68120) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68154) {
              if (c <= 68147 || c > 68151) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 68158 || !(c <= 68159 || c > 68191)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 68351) {
            return -1;
          } else if (c <= 68437) {
            if (c <= 68405 || c > 68415) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 68447 || !(c <= 68466 || c > 68607)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 69631) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69864) {
            if (c <= 69743) {
              if (c <= 69702 || c > 69733) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 69759 || !(c <= 69818 || c > 69839)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 69871) {
            return -1;
          } else if (c <= 69940) {
            if (c <= 69881 || c > 69887) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 69941 || !(c <= 69951 || c > 70015)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 70095) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71351) {
            if (c <= 70105 || c > 71295) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 71359 || !(c <= 71369 || c > 73727)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 74751) {
          return -1;
        } else if (c <= 78894) {
          if (c <= 74850 || c > 77823) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 92159 || !(c <= 92728 || c > 93951)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 94031) {
        return -1;
      } else if (c <= 120596) {
        if (c <= 119993) {
          if (c <= 119213) {
            if (c <= 119145) {
              if (c <= 94111) {
                if (c <= 94078 || c > 94094) {
                  return 1;
                } else {
                  return -1;
                }
              } else if (c <= 110591 || !(c <= 110593 || c > 119140)) {
                return -1;
              } else {
                return 1;
              }
            } else if (c <= 119148) {
              return -1;
            } else if (c <= 119170) {
              if (c <= 119154 || c > 119162) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119172 || !(c <= 119179 || c > 119209)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119361) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119892) {
              if (c <= 119364 || c > 119807) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 119969) {
            return -1;
          } else if (c <= 119974) {
            if (c <= 119970 || c > 119972) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 119994) {
          return -1;
        } else if (c <= 120126) {
          if (c <= 120074) {
            if (c <= 120003) {
              if (c <= 119995 || c > 119996) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120076) {
            return -1;
          } else if (c <= 120092) {
            if (c <= 120084 || c > 120085) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120127) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120538) {
          if (c <= 120512 || c > 120513) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 120597) {
        return -1;
      } else if (c <= 126521) {
        if (c <= 120831) {
          if (c <= 120712) {
            if (c <= 120654) {
              if (c <= 120628 || c > 120629) {
                return 1;
              } else {
                return -1;
              }
            } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
              return -1;
            } else {
              return 1;
            }
          } else if (c <= 120713) {
            return -1;
          } else if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 120781)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126463) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126495) {
            if (c <= 126467 || c > 126468) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126496 || !(c <= 126498 || c > 126499)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126502) {
          return -1;
        } else if (c <= 126514) {
          if (c <= 126503 || c > 126504) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126515 || !(c <= 126519 || c > 126520)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126522) {
        return -1;
      } else if (c <= 126548) {
        if (c <= 126537) {
          if (c <= 126530) {
            if (c <= 126523 || c > 126529) {
              return 1;
            } else {
              return -1;
            }
          } else if (c <= 126534 || !(c <= 126535 || c > 126536)) {
            return -1;
          } else {
            return 1;
          }
        } else if (c <= 126538) {
          return -1;
        } else if (c <= 126543) {
          if (c <= 126539 || c > 126540) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126544 || !(c <= 126546 || c > 126547)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126550) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126553) {
          if (c <= 126551 || c > 126552) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126554 || !(c <= 126555 || c > 126556)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126558) {
        return -1;
      } else if (c <= 126562) {
        if (c <= 126559 || c > 126560) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126563 || !(c <= 126564 || c > 126566)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126571) {
      return -1;
    } else if (c <= 126633) {
      if (c <= 126590) {
        if (c <= 126583) {
          if (c <= 126578 || c > 126579) {
            return 1;
          } else {
            return -1;
          }
        } else if (c <= 126584 || !(c <= 126588 || c > 126589)) {
          return -1;
        } else {
          return 1;
        }
      } else if (c <= 126591) {
        return -1;
      } else if (c <= 126619) {
        if (c <= 126601 || c > 126602) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 126624 || !(c <= 126627 || c > 126628)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 126634) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 173782) {
        if (c <= 126651 || c > 131071) {
          return 1;
        } else {
          return -1;
        }
      } else if (c <= 173823 || !(c <= 177972 || c > 177983)) {
        return -1;
      } else {
        return 1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 1;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_6(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 186) {
      return get(__sedlex_table_14, c) - 1 | 0;
    } else if (c <= 187) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_12(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 32) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_15, c - 33 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126570) {
      if (c <= 65338) {
        if (c <= 42783) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231 || c > 8254) {
                      return 3;
                    } else {
                      return -1;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 3;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 42124) {
            if (c <= 12730) {
              if (c <= 12589) {
                if (c <= 12543 || c > 12548) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 12592 || !(c <= 12686 || c > 12703)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 12783) {
              return -1;
            } else if (c <= 19893) {
              if (c <= 12799 || c > 13311) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 19967 || !(c <= 40908 || c > 40959)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 42191) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42508) {
              if (c <= 42237 || c > 42239) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 42511 || !(c <= 42539 || c > 42559)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 42611) {
            return -1;
          } else if (c <= 42647) {
            if (c <= 42621 || c > 42622) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 42654 || !(c <= 42737 || c > 42774)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 42785) {
          return -1;
        } else if (c <= 44025) {
          if (c <= 43574) {
            if (c <= 43225) {
              if (c <= 42922) {
                if (c <= 42894) {
                  if (c <= 42888 || c > 42890) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 42895 || !(c <= 42899 || c > 42911)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 42999) {
                return -1;
              } else if (c <= 43123) {
                if (c <= 43047 || c > 43071) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 43135 || !(c <= 43204 || c > 43215)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 43231) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43259) {
                if (c <= 43255 || c > 43258) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 43263 || !(c <= 43309 || c > 43311)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 43359) {
              return -1;
            } else if (c <= 43456) {
              if (c <= 43388 || c > 43391) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43481 || c > 43519)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43766) {
            if (c <= 43643) {
              if (c <= 43609) {
                if (c <= 43597 || c > 43599) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 43647) {
              return -1;
            } else if (c <= 43741) {
              if (c <= 43714 || c > 43738) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 43743 || !(c <= 43759 || c > 43761)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 43776) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43790) {
              if (c <= 43782 || c > 43784) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 43792 || !(c <= 43798 || c > 43807)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 43815) {
            return -1;
          } else if (c <= 44010) {
            if (c <= 43822 || c > 43967) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 44011 || !(c <= 44013 || c > 44015)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 44031) {
          return -1;
        } else if (c <= 64829) {
          if (c <= 64296) {
            if (c <= 64109) {
              if (c <= 55238) {
                if (c <= 55203 || c > 55215) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 55242 || !(c <= 55291 || c > 63743)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 64111) {
              return -1;
            } else if (c <= 64262) {
              if (c <= 64217 || c > 64255) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 64274 || !(c <= 64279 || c > 64284)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 64297) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64316) {
              if (c <= 64310 || c > 64311) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 64322) {
            return -1;
          } else if (c <= 64433) {
            if (c <= 64324 || c > 64325) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 64847) {
          return -1;
        } else if (c <= 65137) {
          if (c <= 65039) {
            if (c <= 64967) {
              if (c <= 64911 || c > 64913) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 65007 || !(c <= 65017 || c > 65023)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 65055) {
            return -1;
          } else if (c <= 65076) {
            if (c <= 65062 || c > 65074) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 65100 || !(c <= 65103 || c > 65136)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65143) {
            if (c <= 65139 || c > 65142) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 65148) {
          return -1;
        } else if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 65295 || !(c <= 65305 || c > 65312)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 65342) {
        return -1;
      } else if (c <= 94020) {
        if (c <= 67669) {
          if (c <= 66045) {
            if (c <= 65547) {
              if (c <= 65479) {
                if (c <= 65370) {
                  if (c <= 65343 || c > 65344) {
                    return 3;
                  } else {
                    return -1;
                  }
                } else if (c <= 65381 || !(c <= 65470 || c > 65473)) {
                  return -1;
                } else {
                  return 3;
                }
              } else if (c <= 65481) {
                return -1;
              } else if (c <= 65495) {
                if (c <= 65487 || c > 65489) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 65497 || !(c <= 65500 || c > 65535)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 65548) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65594) {
                if (c <= 65574 || c > 65575) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 65595 || !(c <= 65597 || c > 65598)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 65615) {
              return -1;
            } else if (c <= 65786) {
              if (c <= 65629 || c > 65663) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 65855 || !(c <= 65908 || c > 66044)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 66175) {
            return -1;
          } else if (c <= 66517) {
            if (c <= 66378) {
              if (c <= 66256) {
                if (c <= 66204 || c > 66207) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 66303 || !(c <= 66334 || c > 66351)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 66431) {
              return -1;
            } else if (c <= 66499) {
              if (c <= 66461 || c > 66463) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 66503 || !(c <= 66511 || c > 66512)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 66559) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 66729) {
              if (c <= 66717 || c > 66719) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 67583 || !(c <= 67589 || c > 67591)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 67593) {
            return -1;
          } else if (c <= 67640) {
            if (c <= 67637 || c > 67638) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 67643 || !(c <= 67644 || c > 67646)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 67839) {
          return -1;
        } else if (c <= 68680) {
          if (c <= 68119) {
            if (c <= 68031) {
              if (c <= 67897) {
                if (c <= 67861 || c > 67871) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 67967 || !(c <= 68023 || c > 68029)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 68095) {
              return -1;
            } else if (c <= 68102) {
              if (c <= 68099 || c > 68100) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 68107 || !(c <= 68115 || c > 68116)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 68120) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68154) {
              if (c <= 68147 || c > 68151) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 68158 || !(c <= 68159 || c > 68191)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 68351) {
            return -1;
          } else if (c <= 68437) {
            if (c <= 68405 || c > 68415) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 68447 || !(c <= 68466 || c > 68607)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 69631) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69864) {
            if (c <= 69743) {
              if (c <= 69702 || c > 69733) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 69759 || !(c <= 69818 || c > 69839)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 69871) {
            return -1;
          } else if (c <= 69940) {
            if (c <= 69881 || c > 69887) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 69941 || !(c <= 69951 || c > 70015)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 70095) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71351) {
            if (c <= 70105 || c > 71295) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 71359 || !(c <= 71369 || c > 73727)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 74751) {
          return -1;
        } else if (c <= 78894) {
          if (c <= 74850 || c > 77823) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 92159 || !(c <= 92728 || c > 93951)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 94031) {
        return -1;
      } else if (c <= 120596) {
        if (c <= 119993) {
          if (c <= 119213) {
            if (c <= 119145) {
              if (c <= 94111) {
                if (c <= 94078 || c > 94094) {
                  return 3;
                } else {
                  return -1;
                }
              } else if (c <= 110591 || !(c <= 110593 || c > 119140)) {
                return -1;
              } else {
                return 3;
              }
            } else if (c <= 119148) {
              return -1;
            } else if (c <= 119170) {
              if (c <= 119154 || c > 119162) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 119172 || !(c <= 119179 || c > 119209)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 119361) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119892) {
              if (c <= 119364 || c > 119807) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 119969) {
            return -1;
          } else if (c <= 119974) {
            if (c <= 119970 || c > 119972) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 119994) {
          return -1;
        } else if (c <= 120126) {
          if (c <= 120074) {
            if (c <= 120003) {
              if (c <= 119995 || c > 119996) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 120076) {
            return -1;
          } else if (c <= 120092) {
            if (c <= 120084 || c > 120085) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 120127) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120538) {
          if (c <= 120512 || c > 120513) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 120597) {
        return -1;
      } else if (c <= 126521) {
        if (c <= 120831) {
          if (c <= 120712) {
            if (c <= 120654) {
              if (c <= 120628 || c > 120629) {
                return 3;
              } else {
                return -1;
              }
            } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
              return -1;
            } else {
              return 3;
            }
          } else if (c <= 120713) {
            return -1;
          } else if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 120781)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 126463) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126495) {
            if (c <= 126467 || c > 126468) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 126496 || !(c <= 126498 || c > 126499)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 126502) {
          return -1;
        } else if (c <= 126514) {
          if (c <= 126503 || c > 126504) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126515 || !(c <= 126519 || c > 126520)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126522) {
        return -1;
      } else if (c <= 126548) {
        if (c <= 126537) {
          if (c <= 126530) {
            if (c <= 126523 || c > 126529) {
              return 3;
            } else {
              return -1;
            }
          } else if (c <= 126534 || !(c <= 126535 || c > 126536)) {
            return -1;
          } else {
            return 3;
          }
        } else if (c <= 126538) {
          return -1;
        } else if (c <= 126543) {
          if (c <= 126539 || c > 126540) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126544 || !(c <= 126546 || c > 126547)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126550) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126553) {
          if (c <= 126551 || c > 126552) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126554 || !(c <= 126555 || c > 126556)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126558) {
        return -1;
      } else if (c <= 126562) {
        if (c <= 126559 || c > 126560) {
          return 3;
        } else {
          return -1;
        }
      } else if (c <= 126563 || !(c <= 126564 || c > 126566)) {
        return -1;
      } else {
        return 3;
      }
    } else if (c <= 126571) {
      return -1;
    } else if (c <= 126633) {
      if (c <= 126590) {
        if (c <= 126583) {
          if (c <= 126578 || c > 126579) {
            return 3;
          } else {
            return -1;
          }
        } else if (c <= 126584 || !(c <= 126588 || c > 126589)) {
          return -1;
        } else {
          return 3;
        }
      } else if (c <= 126591) {
        return -1;
      } else if (c <= 126619) {
        if (c <= 126601 || c > 126602) {
          return 3;
        } else {
          return -1;
        }
      } else if (c <= 126624 || !(c <= 126627 || c > 126628)) {
        return -1;
      } else {
        return 3;
      }
    } else if (c <= 126634) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 173782) {
        if (c <= 126651 || c > 131071) {
          return 3;
        } else {
          return -1;
        }
      } else if (c <= 173823 || !(c <= 177972 || c > 177983)) {
        return -1;
      } else {
        return 3;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 3;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_23(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 12) {
      return get(__sedlex_table_16, c) - 1 | 0;
    } else if (c <= 13) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_15(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 47) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_17, c - 48 | 0) - 1 | 0;
    } else if (c <= 8254 || c > 917999) {
      return -1;
    } else if (c <= 126570) {
      if (c <= 65338) {
        if (c <= 42783) {
          if (c <= 11686) {
            if (c <= 8488) {
              if (c <= 8432) {
                if (c <= 8319) {
                  if (c <= 8276) {
                    if (c <= 8256 || c > 8275) {
                      return 0;
                    } else {
                      return -1;
                    }
                  } else if (c <= 8304 || !(c <= 8305 || c > 8318)) {
                    return -1;
                  } else {
                    return 0;
                  }
                } else if (c <= 8335) {
                  return -1;
                } else if (c <= 8412) {
                  if (c <= 8348 || c > 8399) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 8416 || !(c <= 8417 || c > 8420)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 8449) {
                return -1;
              } else if (c <= 8469) {
                if (c <= 8455) {
                  if (c <= 8450 || c > 8454) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 8457 || !(c <= 8467 || c > 8468)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 8471) {
                return -1;
              } else if (c <= 8484) {
                if (c <= 8477 || c > 8483) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 8485 || !(c <= 8486 || c > 8487)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 8489) {
              return -1;
            } else if (c <= 11492) {
              if (c <= 8526) {
                if (c <= 8511) {
                  if (c <= 8505 || c > 8507) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 8516 || !(c <= 8521 || c > 8525)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 8543) {
                return -1;
              } else if (c <= 11310) {
                if (c <= 8584 || c > 11263) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 11311 || !(c <= 11358 || c > 11359)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 11498) {
              return -1;
            } else if (c <= 11565) {
              if (c <= 11557) {
                if (c <= 11507 || c > 11519) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 11558 || !(c <= 11559 || c > 11564)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 11567) {
              return -1;
            } else if (c <= 11631) {
              if (c <= 11623 || c > 11630) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 11646 || !(c <= 11670 || c > 11679)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 11687) {
            return -1;
          } else if (c <= 12538) {
            if (c <= 11775) {
              if (c <= 11718) {
                if (c <= 11702) {
                  if (c <= 11694 || c > 11695) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 11703 || !(c <= 11710 || c > 11711)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 11719) {
                return -1;
              } else if (c <= 11734) {
                if (c <= 11726 || c > 11727) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 11735 || !(c <= 11742 || c > 11743)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 12292) {
              return -1;
            } else if (c <= 12348) {
              if (c <= 12335) {
                if (c <= 12295 || c > 12320) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 12336 || !(c <= 12341 || c > 12343)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 12352) {
              return -1;
            } else if (c <= 12442) {
              if (c <= 12438 || c > 12440) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 12444 || !(c <= 12447 || c > 12448)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 12539) {
            return -1;
          } else if (c <= 42124) {
            if (c <= 12730) {
              if (c <= 12589) {
                if (c <= 12543 || c > 12548) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 12592 || !(c <= 12686 || c > 12703)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 12783) {
              return -1;
            } else if (c <= 19893) {
              if (c <= 12799 || c > 13311) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 19967 || !(c <= 40908 || c > 40959)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 42191) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42508) {
              if (c <= 42237 || c > 42239) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 42511 || !(c <= 42539 || c > 42559)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 42611) {
            return -1;
          } else if (c <= 42647) {
            if (c <= 42621 || c > 42622) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 42654 || !(c <= 42737 || c > 42774)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 42785) {
          return -1;
        } else if (c <= 44025) {
          if (c <= 43574) {
            if (c <= 43225) {
              if (c <= 42922) {
                if (c <= 42894) {
                  if (c <= 42888 || c > 42890) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 42895 || !(c <= 42899 || c > 42911)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 42999) {
                return -1;
              } else if (c <= 43123) {
                if (c <= 43047 || c > 43071) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 43135 || !(c <= 43204 || c > 43215)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 43231) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43259) {
                if (c <= 43255 || c > 43258) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 43263 || !(c <= 43309 || c > 43311)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 43359) {
              return -1;
            } else if (c <= 43456) {
              if (c <= 43388 || c > 43391) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43481 || c > 43519)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43766) {
            if (c <= 43643) {
              if (c <= 43609) {
                if (c <= 43597 || c > 43599) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 43647) {
              return -1;
            } else if (c <= 43741) {
              if (c <= 43714 || c > 43738) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 43743 || !(c <= 43759 || c > 43761)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 43776) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43790) {
              if (c <= 43782 || c > 43784) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 43792 || !(c <= 43798 || c > 43807)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 43815) {
            return -1;
          } else if (c <= 44010) {
            if (c <= 43822 || c > 43967) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 44011 || !(c <= 44013 || c > 44015)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 44031) {
          return -1;
        } else if (c <= 64829) {
          if (c <= 64296) {
            if (c <= 64109) {
              if (c <= 55238) {
                if (c <= 55203 || c > 55215) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 55242 || !(c <= 55291 || c > 63743)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 64111) {
              return -1;
            } else if (c <= 64262) {
              if (c <= 64217 || c > 64255) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 64274 || !(c <= 64279 || c > 64284)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 64297) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64316) {
              if (c <= 64310 || c > 64311) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 64322) {
            return -1;
          } else if (c <= 64433) {
            if (c <= 64324 || c > 64325) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 64847) {
          return -1;
        } else if (c <= 65137) {
          if (c <= 65039) {
            if (c <= 64967) {
              if (c <= 64911 || c > 64913) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 65007 || !(c <= 65017 || c > 65023)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 65055) {
            return -1;
          } else if (c <= 65076) {
            if (c <= 65062 || c > 65074) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 65100 || !(c <= 65103 || c > 65136)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65143) {
            if (c <= 65139 || c > 65142) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 65148) {
          return -1;
        } else if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 65295 || !(c <= 65305 || c > 65312)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 65342) {
        return -1;
      } else if (c <= 94020) {
        if (c <= 67669) {
          if (c <= 66045) {
            if (c <= 65547) {
              if (c <= 65479) {
                if (c <= 65370) {
                  if (c <= 65343 || c > 65344) {
                    return 0;
                  } else {
                    return -1;
                  }
                } else if (c <= 65381 || !(c <= 65470 || c > 65473)) {
                  return -1;
                } else {
                  return 0;
                }
              } else if (c <= 65481) {
                return -1;
              } else if (c <= 65495) {
                if (c <= 65487 || c > 65489) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 65497 || !(c <= 65500 || c > 65535)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 65548) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65594) {
                if (c <= 65574 || c > 65575) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 65595 || !(c <= 65597 || c > 65598)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 65615) {
              return -1;
            } else if (c <= 65786) {
              if (c <= 65629 || c > 65663) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 65855 || !(c <= 65908 || c > 66044)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 66175) {
            return -1;
          } else if (c <= 66517) {
            if (c <= 66378) {
              if (c <= 66256) {
                if (c <= 66204 || c > 66207) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 66303 || !(c <= 66334 || c > 66351)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 66431) {
              return -1;
            } else if (c <= 66499) {
              if (c <= 66461 || c > 66463) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 66503 || !(c <= 66511 || c > 66512)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 66559) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 66729) {
              if (c <= 66717 || c > 66719) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 67583 || !(c <= 67589 || c > 67591)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 67593) {
            return -1;
          } else if (c <= 67640) {
            if (c <= 67637 || c > 67638) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 67643 || !(c <= 67644 || c > 67646)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 67839) {
          return -1;
        } else if (c <= 68680) {
          if (c <= 68119) {
            if (c <= 68031) {
              if (c <= 67897) {
                if (c <= 67861 || c > 67871) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 67967 || !(c <= 68023 || c > 68029)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 68095) {
              return -1;
            } else if (c <= 68102) {
              if (c <= 68099 || c > 68100) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 68107 || !(c <= 68115 || c > 68116)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 68120) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68154) {
              if (c <= 68147 || c > 68151) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 68158 || !(c <= 68159 || c > 68191)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 68351) {
            return -1;
          } else if (c <= 68437) {
            if (c <= 68405 || c > 68415) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 68447 || !(c <= 68466 || c > 68607)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 69631) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69864) {
            if (c <= 69743) {
              if (c <= 69702 || c > 69733) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 69759 || !(c <= 69818 || c > 69839)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 69871) {
            return -1;
          } else if (c <= 69940) {
            if (c <= 69881 || c > 69887) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 69941 || !(c <= 69951 || c > 70015)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 70095) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71351) {
            if (c <= 70105 || c > 71295) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 71359 || !(c <= 71369 || c > 73727)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 74751) {
          return -1;
        } else if (c <= 78894) {
          if (c <= 74850 || c > 77823) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 92159 || !(c <= 92728 || c > 93951)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 94031) {
        return -1;
      } else if (c <= 120596) {
        if (c <= 119993) {
          if (c <= 119213) {
            if (c <= 119145) {
              if (c <= 94111) {
                if (c <= 94078 || c > 94094) {
                  return 0;
                } else {
                  return -1;
                }
              } else if (c <= 110591 || !(c <= 110593 || c > 119140)) {
                return -1;
              } else {
                return 0;
              }
            } else if (c <= 119148) {
              return -1;
            } else if (c <= 119170) {
              if (c <= 119154 || c > 119162) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 119172 || !(c <= 119179 || c > 119209)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 119361) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119892) {
              if (c <= 119364 || c > 119807) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 119969) {
            return -1;
          } else if (c <= 119974) {
            if (c <= 119970 || c > 119972) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 119994) {
          return -1;
        } else if (c <= 120126) {
          if (c <= 120074) {
            if (c <= 120003) {
              if (c <= 119995 || c > 119996) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 120076) {
            return -1;
          } else if (c <= 120092) {
            if (c <= 120084 || c > 120085) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 120127) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120538) {
          if (c <= 120512 || c > 120513) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 120597) {
        return -1;
      } else if (c <= 126521) {
        if (c <= 120831) {
          if (c <= 120712) {
            if (c <= 120654) {
              if (c <= 120628 || c > 120629) {
                return 0;
              } else {
                return -1;
              }
            } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
              return -1;
            } else {
              return 0;
            }
          } else if (c <= 120713) {
            return -1;
          } else if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 120781)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 126463) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126495) {
            if (c <= 126467 || c > 126468) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 126496 || !(c <= 126498 || c > 126499)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 126502) {
          return -1;
        } else if (c <= 126514) {
          if (c <= 126503 || c > 126504) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126515 || !(c <= 126519 || c > 126520)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126522) {
        return -1;
      } else if (c <= 126548) {
        if (c <= 126537) {
          if (c <= 126530) {
            if (c <= 126523 || c > 126529) {
              return 0;
            } else {
              return -1;
            }
          } else if (c <= 126534 || !(c <= 126535 || c > 126536)) {
            return -1;
          } else {
            return 0;
          }
        } else if (c <= 126538) {
          return -1;
        } else if (c <= 126543) {
          if (c <= 126539 || c > 126540) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126544 || !(c <= 126546 || c > 126547)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126550) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126553) {
          if (c <= 126551 || c > 126552) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126554 || !(c <= 126555 || c > 126556)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126558) {
        return -1;
      } else if (c <= 126562) {
        if (c <= 126559 || c > 126560) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 126563 || !(c <= 126564 || c > 126566)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 126571) {
      return -1;
    } else if (c <= 126633) {
      if (c <= 126590) {
        if (c <= 126583) {
          if (c <= 126578 || c > 126579) {
            return 0;
          } else {
            return -1;
          }
        } else if (c <= 126584 || !(c <= 126588 || c > 126589)) {
          return -1;
        } else {
          return 0;
        }
      } else if (c <= 126591) {
        return -1;
      } else if (c <= 126619) {
        if (c <= 126601 || c > 126602) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 126624 || !(c <= 126627 || c > 126628)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 126634) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 173782) {
        if (c <= 126651 || c > 131071) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 173823 || !(c <= 177972 || c > 177983)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_29(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 42) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_18, c - 43 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126562) {
      if (c <= 65276) {
        if (c <= 42647) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231) {
                      return 6;
                    } else if (c <= 8254) {
                      return -1;
                    } else {
                      return 2;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 2;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 19893) {
            if (c <= 12589) {
              if (c <= 12539) {
                if (c <= 12538) {
                  return 2;
                } else {
                  return 6;
                }
              } else if (c <= 12543 || c > 12548) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12592) {
              return -1;
            } else if (c <= 12730) {
              if (c <= 12686 || c > 12703) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12783 || !(c <= 12799 || c > 13311)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 19967) {
            return -1;
          } else if (c <= 42508) {
            if (c <= 42124) {
              if (c <= 40908 || c > 40959) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 42191 || !(c <= 42237 || c > 42239)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 42511) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42539 || c > 42559) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 42611 || !(c <= 42621 || c > 42622)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 42654) {
          return -1;
        } else if (c <= 44010) {
          if (c <= 43456) {
            if (c <= 43123) {
              if (c <= 42894) {
                if (c <= 42783) {
                  if (c <= 42737 || c > 42774) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 42785 || !(c <= 42888 || c > 42890)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 42895) {
                return -1;
              } else if (c <= 42922) {
                if (c <= 42899 || c > 42911) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 42999 || !(c <= 43047 || c > 43071)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43135) {
              return -1;
            } else if (c <= 43259) {
              if (c <= 43225) {
                if (c <= 43204 || c > 43215) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43231 || !(c <= 43255 || c > 43258)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43263) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43309 || c > 43311) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43359 || !(c <= 43388 || c > 43391)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43470) {
            return -1;
          } else if (c <= 43741) {
            if (c <= 43609) {
              if (c <= 43574) {
                if (c <= 43481 || c > 43519) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43583 || !(c <= 43597 || c > 43599)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43615) {
              return -1;
            } else if (c <= 43643) {
              if (c <= 43638 || c > 43641) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43647 || !(c <= 43714 || c > 43738)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43743) {
            return -1;
          } else if (c <= 43790) {
            if (c <= 43766) {
              if (c <= 43759 || c > 43761) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43776 || !(c <= 43782 || c > 43784)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43792) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43798 || c > 43807) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 43815 || !(c <= 43822 || c > 43967)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 44011) {
          return -1;
        } else if (c <= 64433) {
          if (c <= 64262) {
            if (c <= 55238) {
              if (c <= 44025) {
                if (c <= 44013 || c > 44015) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 44031 || !(c <= 55203 || c > 55215)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 55242) {
              return -1;
            } else if (c <= 64109) {
              if (c <= 55291 || c > 63743) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64111 || !(c <= 64217 || c > 64255)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 64274) {
            return -1;
          } else if (c <= 64316) {
            if (c <= 64296) {
              if (c <= 64279 || c > 64284) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64297 || !(c <= 64310 || c > 64311)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 64317) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64318 || c > 64319) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 64322 || !(c <= 64324 || c > 64325)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 64466) {
          return -1;
        } else if (c <= 65076) {
          if (c <= 64967) {
            if (c <= 64829) {
              if (c <= 64605 || c > 64611) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64847 || !(c <= 64911 || c > 64913)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 65007) {
            return -1;
          } else if (c <= 65039) {
            if (c <= 65017 || c > 65023) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 65055 || !(c <= 65062 || c > 65074)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 65100) {
          return -1;
        } else if (c <= 65143) {
          if (c <= 65137) {
            if (c <= 65103 || c > 65136) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 65138 || !(c <= 65139 || c > 65142)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 65144) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65145 || c > 65146) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 65148 || !(c <= 65149 || c > 65150)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 65295) {
        return -1;
      } else if (c <= 78894) {
        if (c <= 67640) {
          if (c <= 65786) {
            if (c <= 65495) {
              if (c <= 65370) {
                if (c <= 65338) {
                  if (c <= 65305 || c > 65312) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 65342 || !(c <= 65343 || c > 65344)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 65381) {
                return -1;
              } else if (c <= 65479) {
                if (c <= 65470 || c > 65473) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 65481 || !(c <= 65487 || c > 65489)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 65497) {
              return -1;
            } else if (c <= 65594) {
              if (c <= 65547) {
                if (c <= 65500 || c > 65535) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 65548 || !(c <= 65574 || c > 65575)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 65595) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65597 || c > 65598) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 65615 || !(c <= 65629 || c > 65663)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 65855) {
            return -1;
          } else if (c <= 66499) {
            if (c <= 66256) {
              if (c <= 66045) {
                if (c <= 65908 || c > 66044) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 66175 || !(c <= 66204 || c > 66207)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 66303) {
              return -1;
            } else if (c <= 66378) {
              if (c <= 66334 || c > 66351) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 66431 || !(c <= 66461 || c > 66463)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 66503) {
            return -1;
          } else if (c <= 66729) {
            if (c <= 66517) {
              if (c <= 66511 || c > 66512) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 66559 || !(c <= 66717 || c > 66719)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 67583) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 67589 || c > 67591) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 67593 || !(c <= 67637 || c > 67638)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 67643) {
          return -1;
        } else if (c <= 68437) {
          if (c <= 68102) {
            if (c <= 67897) {
              if (c <= 67669) {
                if (c <= 67644 || c > 67646) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 67839 || !(c <= 67861 || c > 67871)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 67967) {
              return -1;
            } else if (c <= 68031) {
              if (c <= 68023 || c > 68029) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 68095 || !(c <= 68099 || c > 68100)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 68107) {
            return -1;
          } else if (c <= 68154) {
            if (c <= 68119) {
              if (c <= 68115 || c > 68116) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 68120 || !(c <= 68147 || c > 68151)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 68158) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68159 || c > 68191) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 68351 || !(c <= 68405 || c > 68415)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 68447) {
          return -1;
        } else if (c <= 69940) {
          if (c <= 69743) {
            if (c <= 68680) {
              if (c <= 68466 || c > 68607) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 69631 || !(c <= 69702 || c > 69733)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 69759) {
            return -1;
          } else if (c <= 69864) {
            if (c <= 69818 || c > 69839) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 69871 || !(c <= 69881 || c > 69887)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 69941) {
          return -1;
        } else if (c <= 71351) {
          if (c <= 70084) {
            if (c <= 69951 || c > 70015) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 70095 || !(c <= 70105 || c > 71295)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 71359) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71369 || c > 73727) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 74751 || !(c <= 74850 || c > 77823)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 92159) {
        return -1;
      } else if (c <= 120538) {
        if (c <= 119974) {
          if (c <= 119170) {
            if (c <= 94111) {
              if (c <= 94020) {
                if (c <= 92728 || c > 93951) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 94031 || !(c <= 94078 || c > 94094)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 110591) {
              return -1;
            } else if (c <= 119145) {
              if (c <= 110593 || c > 119140) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119148 || !(c <= 119154 || c > 119162)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 119172) {
            return -1;
          } else if (c <= 119892) {
            if (c <= 119213) {
              if (c <= 119179 || c > 119209) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119361 || !(c <= 119364 || c > 119807)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 119893) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119964 || c > 119965) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 119969 || !(c <= 119970 || c > 119972)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 119976) {
          return -1;
        } else if (c <= 120092) {
          if (c <= 120003) {
            if (c <= 119993) {
              if (c <= 119980 || c > 119981) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119994 || !(c <= 119995 || c > 119996)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 120004) {
            return -1;
          } else if (c <= 120074) {
            if (c <= 120069 || c > 120070) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120076 || !(c <= 120084 || c > 120085)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120093) {
          return -1;
        } else if (c <= 120134) {
          if (c <= 120126) {
            if (c <= 120121 || c > 120122) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120127 || !(c <= 120132 || c > 120133)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120137) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120144 || c > 120145) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 120487 || !(c <= 120512 || c > 120513)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 120539) {
        return -1;
      } else if (c <= 126514) {
        if (c <= 120770) {
          if (c <= 120654) {
            if (c <= 120596) {
              if (c <= 120570 || c > 120571) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 120597 || !(c <= 120628 || c > 120629)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 120655) {
            return -1;
          } else if (c <= 120712) {
            if (c <= 120686 || c > 120687) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120713 || !(c <= 120744 || c > 120745)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120771) {
          return -1;
        } else if (c <= 126495) {
          if (c <= 120831) {
            if (c <= 120779 || c > 120781) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 126463 || !(c <= 126467 || c > 126468)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126496) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126498 || c > 126499) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126502 || !(c <= 126503 || c > 126504)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126515) {
        return -1;
      } else if (c <= 126543) {
        if (c <= 126530) {
          if (c <= 126521) {
            if (c <= 126519 || c > 126520) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 126522 || !(c <= 126523 || c > 126529)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126534) {
          return -1;
        } else if (c <= 126537) {
          if (c <= 126535 || c > 126536) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126538 || !(c <= 126539 || c > 126540)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126544) {
        return -1;
      } else if (c <= 126553) {
        if (c <= 126548) {
          if (c <= 126546 || c > 126547) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126550 || !(c <= 126551 || c > 126552)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126554) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126555 || c > 126556) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126558 || !(c <= 126559 || c > 126560)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 126563) {
      return -1;
    } else if (c <= 126619) {
      if (c <= 126583) {
        if (c <= 126570) {
          if (c <= 126564 || c > 126566) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126571 || !(c <= 126578 || c > 126579)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126584) {
        return -1;
      } else if (c <= 126590) {
        if (c <= 126588 || c > 126589) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126591 || !(c <= 126601 || c > 126602)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 126624) {
      return -1;
    } else if (c <= 173782) {
      if (c <= 126633) {
        if (c <= 126627 || c > 126628) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126634 || !(c <= 126651 || c > 131071)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 173823) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 177972 || c > 177983) {
        return 2;
      } else {
        return -1;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 2;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_5(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 187) {
      return get(__sedlex_table_19, c - -1 | 0) - 1 | 0;
    } else {
      return 1;
    }
  } else {
    return get(__sedlex_table_19, 0) - 1 | 0;
  }
}

function __sedlex_partition_1(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 47) {
      return get(__sedlex_table_20, c - -1 | 0) - 1 | 0;
    } else {
      return 1;
    }
  } else {
    return get(__sedlex_table_20, 0) - 1 | 0;
  }
}

function __sedlex_partition_2(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 46) {
      return get(__sedlex_table_21, c) - 1 | 0;
    } else if (c <= 47) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_21(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 42 || c > 122) {
      return -1;
    } else {
      return get(__sedlex_table_22, c - 43 | 0) - 1 | 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_10(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 32) {
      return -1;
    } else if (c <= 8188) {
      return get(__sedlex_table_23, c - 33 | 0) - 1 | 0;
    } else if (c <= 8230 || c > 917999) {
      return -1;
    } else if (c <= 126570) {
      if (c <= 65338) {
        if (c <= 42783) {
          if (c <= 11670) {
            if (c <= 8486) {
              if (c <= 8417) {
                if (c <= 8305) {
                  if (c <= 8256) {
                    if (c <= 8231 || c > 8254) {
                      return 2;
                    } else {
                      return -1;
                    }
                  } else if (c <= 8275 || !(c <= 8276 || c > 8304)) {
                    return -1;
                  } else {
                    return 2;
                  }
                } else if (c <= 8318) {
                  return -1;
                } else if (c <= 8348) {
                  if (c <= 8319 || c > 8335) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8399 || !(c <= 8412 || c > 8416)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8420) {
                return -1;
              } else if (c <= 8467) {
                if (c <= 8450) {
                  if (c <= 8432 || c > 8449) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8454 || !(c <= 8455 || c > 8457)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8468) {
                return -1;
              } else if (c <= 8477) {
                if (c <= 8469 || c > 8471) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 8483 || !(c <= 8484 || c > 8485)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 8487) {
              return -1;
            } else if (c <= 11358) {
              if (c <= 8521) {
                if (c <= 8505) {
                  if (c <= 8488 || c > 8489) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 8507 || !(c <= 8511 || c > 8516)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 8525) {
                return -1;
              } else if (c <= 8584) {
                if (c <= 8526 || c > 8543) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11263 || !(c <= 11310 || c > 11311)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11359) {
              return -1;
            } else if (c <= 11559) {
              if (c <= 11507) {
                if (c <= 11492 || c > 11498) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11519 || !(c <= 11557 || c > 11558)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11564) {
              return -1;
            } else if (c <= 11623) {
              if (c <= 11565 || c > 11567) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 11630 || !(c <= 11631 || c > 11646)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 11679) {
            return -1;
          } else if (c <= 12447) {
            if (c <= 11742) {
              if (c <= 11710) {
                if (c <= 11694) {
                  if (c <= 11686 || c > 11687) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 11695 || !(c <= 11702 || c > 11703)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 11711) {
                return -1;
              } else if (c <= 11726) {
                if (c <= 11718 || c > 11719) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 11727 || !(c <= 11734 || c > 11735)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 11743) {
              return -1;
            } else if (c <= 12341) {
              if (c <= 12295) {
                if (c <= 11775 || c > 12292) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 12320 || !(c <= 12335 || c > 12336)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 12343) {
              return -1;
            } else if (c <= 12438) {
              if (c <= 12348 || c > 12352) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 12440 || !(c <= 12442 || c > 12444)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 12448) {
            return -1;
          } else if (c <= 42124) {
            if (c <= 12730) {
              if (c <= 12589) {
                if (c <= 12543 || c > 12548) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 12592 || !(c <= 12686 || c > 12703)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 12783) {
              return -1;
            } else if (c <= 19893) {
              if (c <= 12799 || c > 13311) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 19967 || !(c <= 40908 || c > 40959)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 42191) {
            return -1;
          } else if (c <= 42607) {
            if (c <= 42508) {
              if (c <= 42237 || c > 42239) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 42511 || !(c <= 42539 || c > 42559)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 42611) {
            return -1;
          } else if (c <= 42647) {
            if (c <= 42621 || c > 42622) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 42654 || !(c <= 42737 || c > 42774)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 42785) {
          return -1;
        } else if (c <= 44025) {
          if (c <= 43574) {
            if (c <= 43225) {
              if (c <= 42922) {
                if (c <= 42894) {
                  if (c <= 42888 || c > 42890) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 42895 || !(c <= 42899 || c > 42911)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 42999) {
                return -1;
              } else if (c <= 43123) {
                if (c <= 43047 || c > 43071) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43135 || !(c <= 43204 || c > 43215)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43231) {
              return -1;
            } else if (c <= 43347) {
              if (c <= 43259) {
                if (c <= 43255 || c > 43258) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43263 || !(c <= 43309 || c > 43311)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43359) {
              return -1;
            } else if (c <= 43456) {
              if (c <= 43388 || c > 43391) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43470 || !(c <= 43481 || c > 43519)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43583) {
            return -1;
          } else if (c <= 43766) {
            if (c <= 43643) {
              if (c <= 43609) {
                if (c <= 43597 || c > 43599) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 43615 || !(c <= 43638 || c > 43641)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 43647) {
              return -1;
            } else if (c <= 43741) {
              if (c <= 43714 || c > 43738) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43743 || !(c <= 43759 || c > 43761)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43776) {
            return -1;
          } else if (c <= 43814) {
            if (c <= 43790) {
              if (c <= 43782 || c > 43784) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 43792 || !(c <= 43798 || c > 43807)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 43815) {
            return -1;
          } else if (c <= 44010) {
            if (c <= 43822 || c > 43967) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 44011 || !(c <= 44013 || c > 44015)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 44031) {
          return -1;
        } else if (c <= 64829) {
          if (c <= 64296) {
            if (c <= 64109) {
              if (c <= 55238) {
                if (c <= 55203 || c > 55215) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 55242 || !(c <= 55291 || c > 63743)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 64111) {
              return -1;
            } else if (c <= 64262) {
              if (c <= 64217 || c > 64255) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64274 || !(c <= 64279 || c > 64284)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 64297) {
            return -1;
          } else if (c <= 64321) {
            if (c <= 64316) {
              if (c <= 64310 || c > 64311) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 64317 || !(c <= 64318 || c > 64319)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 64322) {
            return -1;
          } else if (c <= 64433) {
            if (c <= 64324 || c > 64325) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 64466 || !(c <= 64605 || c > 64611)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 64847) {
          return -1;
        } else if (c <= 65137) {
          if (c <= 65039) {
            if (c <= 64967) {
              if (c <= 64911 || c > 64913) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 65007 || !(c <= 65017 || c > 65023)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 65055) {
            return -1;
          } else if (c <= 65076) {
            if (c <= 65062 || c > 65074) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 65100 || !(c <= 65103 || c > 65136)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 65138) {
          return -1;
        } else if (c <= 65147) {
          if (c <= 65143) {
            if (c <= 65139 || c > 65142) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 65144 || !(c <= 65145 || c > 65146)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 65148) {
          return -1;
        } else if (c <= 65276) {
          if (c <= 65149 || c > 65150) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 65295 || !(c <= 65305 || c > 65312)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 65342) {
        return -1;
      } else if (c <= 94020) {
        if (c <= 67669) {
          if (c <= 66045) {
            if (c <= 65547) {
              if (c <= 65479) {
                if (c <= 65370) {
                  if (c <= 65343 || c > 65344) {
                    return 2;
                  } else {
                    return -1;
                  }
                } else if (c <= 65381 || !(c <= 65470 || c > 65473)) {
                  return -1;
                } else {
                  return 2;
                }
              } else if (c <= 65481) {
                return -1;
              } else if (c <= 65495) {
                if (c <= 65487 || c > 65489) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 65497 || !(c <= 65500 || c > 65535)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 65548) {
              return -1;
            } else if (c <= 65613) {
              if (c <= 65594) {
                if (c <= 65574 || c > 65575) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 65595 || !(c <= 65597 || c > 65598)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 65615) {
              return -1;
            } else if (c <= 65786) {
              if (c <= 65629 || c > 65663) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 65855 || !(c <= 65908 || c > 66044)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 66175) {
            return -1;
          } else if (c <= 66517) {
            if (c <= 66378) {
              if (c <= 66256) {
                if (c <= 66204 || c > 66207) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 66303 || !(c <= 66334 || c > 66351)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 66431) {
              return -1;
            } else if (c <= 66499) {
              if (c <= 66461 || c > 66463) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 66503 || !(c <= 66511 || c > 66512)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 66559) {
            return -1;
          } else if (c <= 67592) {
            if (c <= 66729) {
              if (c <= 66717 || c > 66719) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 67583 || !(c <= 67589 || c > 67591)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 67593) {
            return -1;
          } else if (c <= 67640) {
            if (c <= 67637 || c > 67638) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 67643 || !(c <= 67644 || c > 67646)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 67839) {
          return -1;
        } else if (c <= 68680) {
          if (c <= 68119) {
            if (c <= 68031) {
              if (c <= 67897) {
                if (c <= 67861 || c > 67871) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 67967 || !(c <= 68023 || c > 68029)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 68095) {
              return -1;
            } else if (c <= 68102) {
              if (c <= 68099 || c > 68100) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 68107 || !(c <= 68115 || c > 68116)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 68120) {
            return -1;
          } else if (c <= 68220) {
            if (c <= 68154) {
              if (c <= 68147 || c > 68151) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 68158 || !(c <= 68159 || c > 68191)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 68351) {
            return -1;
          } else if (c <= 68437) {
            if (c <= 68405 || c > 68415) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 68447 || !(c <= 68466 || c > 68607)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 69631) {
          return -1;
        } else if (c <= 70084) {
          if (c <= 69864) {
            if (c <= 69743) {
              if (c <= 69702 || c > 69733) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 69759 || !(c <= 69818 || c > 69839)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 69871) {
            return -1;
          } else if (c <= 69940) {
            if (c <= 69881 || c > 69887) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 69941 || !(c <= 69951 || c > 70015)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 70095) {
          return -1;
        } else if (c <= 74606) {
          if (c <= 71351) {
            if (c <= 70105 || c > 71295) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 71359 || !(c <= 71369 || c > 73727)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 74751) {
          return -1;
        } else if (c <= 78894) {
          if (c <= 74850 || c > 77823) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 92159 || !(c <= 92728 || c > 93951)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 94031) {
        return -1;
      } else if (c <= 120596) {
        if (c <= 119993) {
          if (c <= 119213) {
            if (c <= 119145) {
              if (c <= 94111) {
                if (c <= 94078 || c > 94094) {
                  return 2;
                } else {
                  return -1;
                }
              } else if (c <= 110591 || !(c <= 110593 || c > 119140)) {
                return -1;
              } else {
                return 2;
              }
            } else if (c <= 119148) {
              return -1;
            } else if (c <= 119170) {
              if (c <= 119154 || c > 119162) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119172 || !(c <= 119179 || c > 119209)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 119361) {
            return -1;
          } else if (c <= 119967) {
            if (c <= 119892) {
              if (c <= 119364 || c > 119807) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 119893 || !(c <= 119964 || c > 119965)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 119969) {
            return -1;
          } else if (c <= 119974) {
            if (c <= 119970 || c > 119972) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 119976 || !(c <= 119980 || c > 119981)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 119994) {
          return -1;
        } else if (c <= 120126) {
          if (c <= 120074) {
            if (c <= 120003) {
              if (c <= 119995 || c > 119996) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 120004 || !(c <= 120069 || c > 120070)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 120076) {
            return -1;
          } else if (c <= 120092) {
            if (c <= 120084 || c > 120085) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120093 || !(c <= 120121 || c > 120122)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120127) {
          return -1;
        } else if (c <= 120485) {
          if (c <= 120134) {
            if (c <= 120132 || c > 120133) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120137 || !(c <= 120144 || c > 120145)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 120487) {
          return -1;
        } else if (c <= 120538) {
          if (c <= 120512 || c > 120513) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 120539 || !(c <= 120570 || c > 120571)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 120597) {
        return -1;
      } else if (c <= 126521) {
        if (c <= 120831) {
          if (c <= 120712) {
            if (c <= 120654) {
              if (c <= 120628 || c > 120629) {
                return 2;
              } else {
                return -1;
              }
            } else if (c <= 120655 || !(c <= 120686 || c > 120687)) {
              return -1;
            } else {
              return 2;
            }
          } else if (c <= 120713) {
            return -1;
          } else if (c <= 120770) {
            if (c <= 120744 || c > 120745) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 120771 || !(c <= 120779 || c > 120781)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126463) {
          return -1;
        } else if (c <= 126500) {
          if (c <= 126495) {
            if (c <= 126467 || c > 126468) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 126496 || !(c <= 126498 || c > 126499)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126502) {
          return -1;
        } else if (c <= 126514) {
          if (c <= 126503 || c > 126504) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126515 || !(c <= 126519 || c > 126520)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126522) {
        return -1;
      } else if (c <= 126548) {
        if (c <= 126537) {
          if (c <= 126530) {
            if (c <= 126523 || c > 126529) {
              return 2;
            } else {
              return -1;
            }
          } else if (c <= 126534 || !(c <= 126535 || c > 126536)) {
            return -1;
          } else {
            return 2;
          }
        } else if (c <= 126538) {
          return -1;
        } else if (c <= 126543) {
          if (c <= 126539 || c > 126540) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126544 || !(c <= 126546 || c > 126547)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126550) {
        return -1;
      } else if (c <= 126557) {
        if (c <= 126553) {
          if (c <= 126551 || c > 126552) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126554 || !(c <= 126555 || c > 126556)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126558) {
        return -1;
      } else if (c <= 126562) {
        if (c <= 126559 || c > 126560) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126563 || !(c <= 126564 || c > 126566)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 126571) {
      return -1;
    } else if (c <= 126633) {
      if (c <= 126590) {
        if (c <= 126583) {
          if (c <= 126578 || c > 126579) {
            return 2;
          } else {
            return -1;
          }
        } else if (c <= 126584 || !(c <= 126588 || c > 126589)) {
          return -1;
        } else {
          return 2;
        }
      } else if (c <= 126591) {
        return -1;
      } else if (c <= 126619) {
        if (c <= 126601 || c > 126602) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 126624 || !(c <= 126627 || c > 126628)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 126634) {
      return -1;
    } else if (c <= 178205) {
      if (c <= 173782) {
        if (c <= 126651 || c > 131071) {
          return 2;
        } else {
          return -1;
        }
      } else if (c <= 173823 || !(c <= 177972 || c > 177983)) {
        return -1;
      } else {
        return 2;
      }
    } else if (c <= 194559 || !(c <= 195101 || c > 917759)) {
      return -1;
    } else {
      return 2;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_4(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 42) {
      return get(__sedlex_table_24, c) - 1 | 0;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_9(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 110) {
      return get(__sedlex_table_25, c) - 1 | 0;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_18(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 8) {
      return -1;
    } else if (c <= 5760) {
      return get(__sedlex_table_26, c - 9 | 0) - 1 | 0;
    } else if (c <= 8191 || c > 12288) {
      return -1;
    } else if (c <= 8287) {
      if (c <= 8233) {
        if (c <= 8202 || c > 8231) {
          return 0;
        } else {
          return -1;
        }
      } else if (c <= 8238 || !(c <= 8239 || c > 8286)) {
        return -1;
      } else {
        return 0;
      }
    } else if (c <= 12287) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_19(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= 46 || c > 47) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function __sedlex_partition_8(param) {
  if (param !== undefined) {
    var c = Uchar.to_int(valFromOption(param));
    if (c <= -1) {
      return -1;
    } else if (c <= 91) {
      return get(__sedlex_table_27, c) - 1 | 0;
    } else if (c <= 92) {
      return -1;
    } else {
      return 0;
    }
  } else {
    return -1;
  }
}

function pp_position(fmt, x) {
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_gen */__(18, [
            /* Open_box */__(1, [/* Format */[
                  /* String_literal */__(11, [
                      "<2>",
                      /* End_of_format */0
                    ]),
                  "<2>"
                ]]),
            /* String_literal */__(11, [
                "{ ",
                /* End_of_format */0
              ])
          ]),
        "@[<2>{ "
      ]);
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_gen */__(18, [
            /* Open_box */__(1, [/* Format */[
                  /* End_of_format */0,
                  ""
                ]]),
            /* String */__(2, [
                /* No_padding */0,
                /* String_literal */__(11, [
                    " =",
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ])
              ])
          ]),
        "@[%s =@ "
      ], "Lexing.pos_fname");
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Caml_string */__(3, [
            /* No_padding */0,
            /* End_of_format */0
          ]),
        "%S"
      ], x[/* pos_fname */0]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_lit */__(17, [
            /* Close_box */0,
            /* End_of_format */0
          ]),
        "@]"
      ]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Char_literal */__(12, [
            /* ";" */59,
            /* Formatting_lit */__(17, [
                /* Break */__(0, [
                    "@ ",
                    1,
                    0
                  ]),
                /* End_of_format */0
              ])
          ]),
        ";@ "
      ]);
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_gen */__(18, [
            /* Open_box */__(1, [/* Format */[
                  /* End_of_format */0,
                  ""
                ]]),
            /* String */__(2, [
                /* No_padding */0,
                /* String_literal */__(11, [
                    " =",
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ])
              ])
          ]),
        "@[%s =@ "
      ], "pos_lnum");
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Int */__(4, [
            /* Int_d */0,
            /* No_padding */0,
            /* No_precision */0,
            /* End_of_format */0
          ]),
        "%d"
      ], x[/* pos_lnum */1]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_lit */__(17, [
            /* Close_box */0,
            /* End_of_format */0
          ]),
        "@]"
      ]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Char_literal */__(12, [
            /* ";" */59,
            /* Formatting_lit */__(17, [
                /* Break */__(0, [
                    "@ ",
                    1,
                    0
                  ]),
                /* End_of_format */0
              ])
          ]),
        ";@ "
      ]);
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_gen */__(18, [
            /* Open_box */__(1, [/* Format */[
                  /* End_of_format */0,
                  ""
                ]]),
            /* String */__(2, [
                /* No_padding */0,
                /* String_literal */__(11, [
                    " =",
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ])
              ])
          ]),
        "@[%s =@ "
      ], "pos_bol");
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Int */__(4, [
            /* Int_d */0,
            /* No_padding */0,
            /* No_precision */0,
            /* End_of_format */0
          ]),
        "%d"
      ], x[/* pos_bol */2]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_lit */__(17, [
            /* Close_box */0,
            /* End_of_format */0
          ]),
        "@]"
      ]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Char_literal */__(12, [
            /* ";" */59,
            /* Formatting_lit */__(17, [
                /* Break */__(0, [
                    "@ ",
                    1,
                    0
                  ]),
                /* End_of_format */0
              ])
          ]),
        ";@ "
      ]);
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_gen */__(18, [
            /* Open_box */__(1, [/* Format */[
                  /* End_of_format */0,
                  ""
                ]]),
            /* String */__(2, [
                /* No_padding */0,
                /* String_literal */__(11, [
                    " =",
                    /* Formatting_lit */__(17, [
                        /* Break */__(0, [
                            "@ ",
                            1,
                            0
                          ]),
                        /* End_of_format */0
                      ])
                  ])
              ])
          ]),
        "@[%s =@ "
      ], "pos_cnum");
  _3(Format$1.fprintf, fmt, /* Format */[
        /* Int */__(4, [
            /* Int_d */0,
            /* No_padding */0,
            /* No_precision */0,
            /* End_of_format */0
          ]),
        "%d"
      ], x[/* pos_cnum */3]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Formatting_lit */__(17, [
            /* Close_box */0,
            /* End_of_format */0
          ]),
        "@]"
      ]);
  return _2(Format$1.fprintf, fmt, /* Format */[
              /* Formatting_lit */__(17, [
                  /* Break */__(0, [
                      "@ ",
                      1,
                      0
                    ]),
                  /* Char_literal */__(12, [
                      /* "}" */125,
                      /* Formatting_lit */__(17, [
                          /* Close_box */0,
                          /* End_of_format */0
                        ])
                    ])
                ]),
              "@ }@]"
            ]);
}

function show_position(x) {
  return _3(Format$1.asprintf, /* Format */[
              /* Alpha */__(15, [/* End_of_format */0]),
              "%a"
            ], pp_position, x);
}

function pp_located(poly_a, fmt, param) {
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Char_literal */__(12, [
            /* "(" */40,
            /* Formatting_gen */__(18, [
                /* Open_box */__(1, [/* Format */[
                      /* End_of_format */0,
                      ""
                    ]]),
                /* End_of_format */0
              ])
          ]),
        "(@["
      ]);
  _2(poly_a, fmt, param[0]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Char_literal */__(12, [
            /* "," */44,
            /* Formatting_lit */__(17, [
                /* Break */__(0, [
                    "@ ",
                    1,
                    0
                  ]),
                /* End_of_format */0
              ])
          ]),
        ",@ "
      ]);
  pp_position(fmt, param[1]);
  _2(Format$1.fprintf, fmt, /* Format */[
        /* Char_literal */__(12, [
            /* "," */44,
            /* Formatting_lit */__(17, [
                /* Break */__(0, [
                    "@ ",
                    1,
                    0
                  ]),
                /* End_of_format */0
              ])
          ]),
        ",@ "
      ]);
  pp_position(fmt, param[2]);
  return _2(Format$1.fprintf, fmt, /* Format */[
              /* Formatting_lit */__(17, [
                  /* Close_box */0,
                  /* Char_literal */__(12, [
                      /* ")" */41,
                      /* End_of_format */0
                    ])
                ]),
              "@])"
            ]);
}

function pp_loctoken(fmt) {
  return _2(pp_located, (function (fmt) {
                return (function (param) {
                    return pp_token(fmt, param);
                  });
              }), fmt);
}

function show_loctoken(x) {
  return _3(Format$1.asprintf, /* Format */[
              /* Alpha */__(15, [/* End_of_format */0]),
              "%a"
            ], pp_loctoken, x);
}

var LexError = create("Lexer.LexError");

var known_schemes = new RegExp("^(about|data?|f(eed|ile|tp)|g(eo|opher)|https?|i(nfo|rc[6s]?)|ldaps?|m(agnet|ailto)|n(ews|fs|ntp)|rsync|t(ag|elnet)|urn|view-source|wss?|xmpp|ymsgr):", "i");

var quote_balanced_open_char = "\xc2\xab";

var quote_balanced_close_char = "\xc2\xbb";

var opening_for_000 = /* tuple */[
  ")",
  "("
];

var opening_for_001 = /* :: */[
  /* tuple */[
    "]",
    "["
  ],
  /* :: */[
    /* tuple */[
      quote_balanced_close_char,
      quote_balanced_open_char
    ],
    /* [] */0
  ]
];

var opening_for = /* :: */[
  opening_for_000,
  opening_for_001
];

var closing_for_000 = /* tuple */[
  "(",
  ")"
];

var closing_for_001 = /* :: */[
  /* tuple */[
    "[",
    "]"
  ],
  /* :: */[
    /* tuple */[
      quote_balanced_open_char,
      quote_balanced_close_char
    ],
    /* [] */0
  ]
];

var closing_for = /* :: */[
  closing_for_000,
  closing_for_001
];

function buffer_of_sedlex(sedlex) {
  return /* record */[
          /* sedlex */sedlex,
          /* mode : MainIgnoringWhitespace */2
        ];
}

function sedlex_of_buffer(buf) {
  return buf[/* sedlex */0];
}

function buffer_of_string(str) {
  return /* record */[
          /* sedlex */Utf8.from_string(str),
          /* mode : MainIgnoringWhitespace */2
        ];
}

function unwrap_exn(param) {
  if (param !== undefined) {
    return valFromOption(param);
  } else {
    throw [
          invalid_argument,
          "unwrap_exn"
        ];
  }
}

function locate(buf, tok) {
  var match = lexing_positions(buf[/* sedlex */0]);
  return /* tuple */[
          tok,
          match[0],
          match[1]
        ];
}

function curr(buf) {
  return lexing_positions(buf[/* sedlex */0])[1];
}

function start$1(buf) {
  return lexing_positions(buf[/* sedlex */0])[0];
}

function unreachable(str) {
  return failwith(_1(sprintf$1(/* Format */[
                      /* String_literal */__(11, [
                          "Unreachable: ",
                          /* String */__(2, [
                              /* No_padding */0,
                              /* End_of_format */0
                            ])
                        ]),
                      "Unreachable: %s"
                    ]), str));
}

function position_fname(pos) {
  return pos[/* pos_fname */0];
}

function position_lnum(pos) {
  return pos[/* pos_lnum */1];
}

function position_bol(pos) {
  return pos[/* pos_bol */2];
}

function position_cnum(pos) {
  return pos[/* pos_cnum */3];
}

function token(tok) {
  return tok[0];
}

function start_lnum(tok) {
  return tok[1][/* pos_lnum */1];
}

function start_cnum(tok) {
  var loc = tok[1];
  return loc[/* pos_cnum */3] - loc[/* pos_bol */2] | 0;
}

function end_lnum(tok) {
  return tok[2][/* pos_lnum */1];
}

function end_cnum(tok) {
  var loc = tok[2];
  return loc[/* pos_cnum */3] - loc[/* pos_bol */2] | 0;
}

function error_loc_exn(param) {
  if (param[0] === LexError) {
    return param[1];
  } else {
    throw [
          invalid_argument,
          "error_loc_exn: expects a LexError"
        ];
  }
}

function error_desc_exn(param) {
  if (param[0] === LexError) {
    return param[2];
  } else {
    throw [
          invalid_argument,
          "error_desc_exn: expects a LexError"
        ];
  }
}

function token_is_erroneous(tok) {
  if (typeof tok === "number") {
    return false;
  } else {
    switch (tok.tag | 0) {
      case /* ERR_UNEXPECTED_WHITESPACE */7 :
      case /* ERR_UNEXPECTED_QUOTE_ESCAPE */8 :
      case /* ERR_UNEXPECTED_QUOTE_CLOSE */9 :
      case /* ERR_UNEXPECTED_COMMENT_CLOSE */10 :
      case /* ERR_UNEXPECTED_CHARACTER */11 :
      case /* ERR_MISSING_DELIM_CLOSE */12 :
      case /* ERR_MISSING_COMMENT_CLOSE */13 :
          return true;
      default:
        return false;
    }
  }
}

function show_token(tok) {
  if (typeof tok === "number") {
    switch (tok) {
      case /* SEMICOLON */0 :
          return "SEMICOLON";
      case /* PIPE */1 :
          return "PIPE";
      case /* PAREN_OPEN */2 :
          return "PAREN_OPEN";
      case /* PAREN_CLOSE */3 :
          return "PAREN_CLOSE";
      case /* FLAG_LONG_START */4 :
          return "FLAG_LONG_START";
      case /* FLAGS_SHORT_START */5 :
          return "FLAGS_SHORT_START";
      case /* EQUALS */6 :
          return "EQUALS";
      case /* EOF */7 :
          return "EOF";
      case /* COMMENT_OPEN */8 :
          return "COMMENT_OPEN";
      case /* COMMENT_CLOSE */9 :
          return "COMMENT_CLOSE";
      case /* COLON */10 :
          return "COLON";
      case /* BARE_DOUBLE_DASH */11 :
          return "BARE_DOUBLE_DASH";
      
    }
  } else {
    switch (tok.tag | 0) {
      case /* URL_START */0 :
          return "URL_START";
      case /* URL_REST */1 :
          return "URL_REST";
      case /* QUOTE_OPEN */2 :
          return "QUOTE_OPEN";
      case /* QUOTE_ESCAPE */3 :
          return "QUOTE_ESCAPE";
      case /* QUOTE_CLOSE */4 :
          return "QUOTE_CLOSE";
      case /* QUOTE_CHUNK */5 :
          return "QUOTE_CHUNK";
      case /* IDENTIFIER */6 :
          return "IDENTIFIER";
      case /* ERR_UNEXPECTED_WHITESPACE */7 :
          return "ERR_UNEXPECTED_WHITESPACE";
      case /* ERR_UNEXPECTED_QUOTE_ESCAPE */8 :
          return "ERR_UNEXPECTED_QUOTE_ESCAPE";
      case /* ERR_UNEXPECTED_QUOTE_CLOSE */9 :
          return "ERR_UNEXPECTED_QUOTE_CLOSE";
      case /* ERR_UNEXPECTED_COMMENT_CLOSE */10 :
          return "ERR_UNEXPECTED_COMMENT_CLOSE";
      case /* ERR_UNEXPECTED_CHARACTER */11 :
          return "ERR_UNEXPECTED_CHARACTER";
      case /* ERR_MISSING_DELIM_CLOSE */12 :
          return "ERR_MISSING_DELIM_CLOSE";
      case /* ERR_MISSING_COMMENT_CLOSE */13 :
          return "ERR_MISSING_COMMENT_CLOSE";
      case /* COUNT */14 :
          return "COUNT";
      case /* COMMENT */15 :
          return "COMMENT";
      
    }
  }
}

function example_of_token(tok) {
  if (typeof tok === "number") {
    switch (tok) {
      case /* SEMICOLON */0 :
          return ";";
      case /* PIPE */1 :
          return "|";
      case /* PAREN_OPEN */2 :
          return "(";
      case /* PAREN_CLOSE */3 :
          return ")";
      case /* FLAGS_SHORT_START */5 :
          return "-";
      case /* EQUALS */6 :
          return "=";
      case /* EOF */7 :
          return ;
      case /* COMMENT_OPEN */8 :
          return "/*";
      case /* COMMENT_CLOSE */9 :
          return "*/";
      case /* COLON */10 :
          return ":";
      case /* FLAG_LONG_START */4 :
      case /* BARE_DOUBLE_DASH */11 :
          return "--";
      
    }
  } else {
    switch (tok.tag | 0) {
      case /* URL_START */0 :
          var url = tok[0];
          return url !== "" ? url : "google.com";
      case /* URL_REST */1 :
          var url$1 = tok[0];
          return url$1 !== "" ? url$1 : "/search?q=tridactyl";
      case /* QUOTE_OPEN */2 :
          var ch = tok[0];
          return ch !== "" ? ch : quote_balanced_open_char;
      case /* QUOTE_ESCAPE */3 :
          var str = tok[0];
          return str !== "" ? str : "\\\\";
      case /* QUOTE_CLOSE */4 :
          var ch$1 = tok[0];
          return ch$1 !== "" ? ch$1 : quote_balanced_close_char;
      case /* QUOTE_CHUNK */5 :
          var str$1 = tok[0];
          return str$1 !== "" ? str$1 : "a quote";
      case /* IDENTIFIER */6 :
          var str$2 = tok[0];
          return str$2 !== "" ? str$2 : "ident";
      case /* COUNT */14 :
          var str$3 = tok[0];
          return str$3 !== "" ? str$3 : "2";
      case /* COMMENT */15 :
          var str$4 = tok[0];
          return str$4 !== "" ? str$4 : "a comment";
      default:
        return ;
    }
  }
}

var example_tokens = /* array */[
  /* BARE_DOUBLE_DASH */11,
  /* COLON */10,
  /* COMMENT */__(15, [unwrap_exn(example_of_token(/* COMMENT */__(15, [""])))]),
  /* COMMENT_CLOSE */9,
  /* COMMENT_OPEN */8,
  /* COUNT */__(14, [unwrap_exn(example_of_token(/* COUNT */__(14, [""])))]),
  /* EQUALS */6,
  /* IDENTIFIER */__(6, [unwrap_exn(example_of_token(/* IDENTIFIER */__(6, [""])))]),
  /* FLAG_LONG_START */4,
  /* FLAGS_SHORT_START */5,
  /* PAREN_CLOSE */3,
  /* PAREN_OPEN */2,
  /* PIPE */1,
  /* QUOTE_CHUNK */__(5, [unwrap_exn(example_of_token(/* QUOTE_CHUNK */__(5, [""])))]),
  /* QUOTE_CLOSE */__(4, [unwrap_exn(example_of_token(/* QUOTE_CLOSE */__(4, [""])))]),
  /* QUOTE_ESCAPE */__(3, [unwrap_exn(example_of_token(/* QUOTE_ESCAPE */__(3, [""])))]),
  /* QUOTE_OPEN */__(2, [unwrap_exn(example_of_token(/* QUOTE_OPEN */__(2, [""])))]),
  /* SEMICOLON */0,
  /* URL_REST */__(1, [unwrap_exn(example_of_token(/* URL_REST */__(1, [""])))]),
  /* URL_START */__(0, [unwrap_exn(example_of_token(/* URL_START */__(0, [""])))])
];

function compare_token(a, b) {
  if (caml_equal(a, b)) {
    return true;
  } else if (typeof a === "number") {
    return false;
  } else {
    switch (a.tag | 0) {
      case /* URL_START */0 :
          if (typeof b === "number" || b.tag) {
            return false;
          } else {
            return true;
          }
      case /* URL_REST */1 :
          if (typeof b === "number" || b.tag !== /* URL_REST */1) {
            return false;
          } else {
            return true;
          }
      case /* QUOTE_OPEN */2 :
          if (typeof b === "number" || b.tag !== /* QUOTE_OPEN */2) {
            return false;
          } else {
            return true;
          }
      case /* QUOTE_ESCAPE */3 :
          if (typeof b === "number" || b.tag !== /* QUOTE_ESCAPE */3) {
            return false;
          } else {
            return true;
          }
      case /* QUOTE_CLOSE */4 :
          if (typeof b === "number" || b.tag !== /* QUOTE_CLOSE */4) {
            return false;
          } else {
            return true;
          }
      case /* QUOTE_CHUNK */5 :
          if (typeof b === "number" || b.tag !== /* QUOTE_CHUNK */5) {
            return false;
          } else {
            return true;
          }
      case /* IDENTIFIER */6 :
          if (typeof b === "number" || b.tag !== /* IDENTIFIER */6) {
            return false;
          } else {
            return true;
          }
      case /* ERR_UNEXPECTED_WHITESPACE */7 :
          if (typeof b === "number" || b.tag !== /* ERR_UNEXPECTED_WHITESPACE */7) {
            return false;
          } else {
            return true;
          }
      case /* ERR_UNEXPECTED_QUOTE_ESCAPE */8 :
          if (typeof b === "number" || b.tag !== /* ERR_UNEXPECTED_QUOTE_ESCAPE */8) {
            return false;
          } else {
            return true;
          }
      case /* ERR_UNEXPECTED_QUOTE_CLOSE */9 :
          if (typeof b === "number" || b.tag !== /* ERR_UNEXPECTED_QUOTE_CLOSE */9) {
            return false;
          } else {
            return true;
          }
      case /* ERR_UNEXPECTED_COMMENT_CLOSE */10 :
          if (typeof b === "number" || b.tag !== /* ERR_UNEXPECTED_COMMENT_CLOSE */10) {
            return false;
          } else {
            return true;
          }
      case /* ERR_UNEXPECTED_CHARACTER */11 :
          if (typeof b === "number" || b.tag !== /* ERR_UNEXPECTED_CHARACTER */11) {
            return false;
          } else {
            return true;
          }
      case /* ERR_MISSING_DELIM_CLOSE */12 :
          if (typeof b === "number" || b.tag !== /* ERR_MISSING_DELIM_CLOSE */12) {
            return false;
          } else {
            return true;
          }
      case /* ERR_MISSING_COMMENT_CLOSE */13 :
          if (typeof b === "number" || b.tag !== /* ERR_MISSING_COMMENT_CLOSE */13) {
            return false;
          } else {
            return true;
          }
      case /* COUNT */14 :
          if (typeof b === "number" || b.tag !== /* COUNT */14) {
            return false;
          } else {
            return true;
          }
      case /* COMMENT */15 :
          if (typeof b === "number" || b.tag !== /* COMMENT */15) {
            return false;
          } else {
            return true;
          }
      
    }
  }
}

function token_body(tok) {
  if (typeof tok === "number") {
    return ;
  } else {
    switch (tok.tag | 0) {
      case /* URL_START */0 :
      case /* URL_REST */1 :
      case /* QUOTE_OPEN */2 :
      case /* QUOTE_ESCAPE */3 :
      case /* QUOTE_CLOSE */4 :
      case /* QUOTE_CHUNK */5 :
      case /* IDENTIFIER */6 :
      case /* COUNT */14 :
      case /* COMMENT */15 :
          return tok[0];
      default:
        return ;
    }
  }
}

function token_error_message(tok) {
  if (typeof tok === "number") {
    return ;
  } else {
    switch (tok.tag | 0) {
      case /* ERR_UNEXPECTED_QUOTE_ESCAPE */8 :
      case /* ERR_UNEXPECTED_QUOTE_CLOSE */9 :
      case /* ERR_UNEXPECTED_CHARACTER */11 :
      case /* ERR_MISSING_DELIM_CLOSE */12 :
          return tok[0][1];
      case /* ERR_UNEXPECTED_WHITESPACE */7 :
      case /* ERR_UNEXPECTED_COMMENT_CLOSE */10 :
      case /* ERR_MISSING_COMMENT_CLOSE */13 :
          return tok[0];
      default:
        return ;
    }
  }
}

function string_of_loctoken(loctok) {
  return _5(sprintf$1(/* Format */[
                  /* String */__(2, [
                      /* No_padding */0,
                      /* Char_literal */__(12, [
                          /* "@" */64,
                          /* Int */__(4, [
                              /* Int_u */12,
                              /* No_padding */0,
                              /* No_precision */0,
                              /* Char_literal */__(12, [
                                  /* ":" */58,
                                  /* Int */__(4, [
                                      /* Int_u */12,
                                      /* No_padding */0,
                                      /* No_precision */0,
                                      /* Char_literal */__(12, [
                                          /* "-" */45,
                                          /* Int */__(4, [
                                              /* Int_u */12,
                                              /* No_padding */0,
                                              /* No_precision */0,
                                              /* Char_literal */__(12, [
                                                  /* ":" */58,
                                                  /* Int */__(4, [
                                                      /* Int_u */12,
                                                      /* No_padding */0,
                                                      /* No_precision */0,
                                                      /* End_of_format */0
                                                    ])
                                                ])
                                            ])
                                        ])
                                    ])
                                ])
                            ])
                        ])
                    ]),
                  "%s@%u:%u-%u:%u"
                ]), show_token(token(loctok)), start_lnum(loctok), start_cnum(loctok), end_lnum(loctok), end_cnum(loctok));
}

function string_of_position(pos) {
  return _2(sprintf$1(/* Format */[
                  /* Int */__(4, [
                      /* Int_u */12,
                      /* No_padding */0,
                      /* No_precision */0,
                      /* Char_literal */__(12, [
                          /* ":" */58,
                          /* Int */__(4, [
                              /* Int_u */12,
                              /* No_padding */0,
                              /* No_precision */0,
                              /* End_of_format */0
                            ])
                        ])
                    ]),
                  "%u:%u"
                ]), pos[/* pos_lnum */1], pos[/* pos_cnum */3]);
}

function url_closing_fail(buf, opening, closing) {
  var msg = concat("`", /* :: */[
        "Unmatched opening ",
        /* :: */[
          opening,
          /* :: */[
            " in bare URL - delimiters must be balanced. (Did you forget a ",
            /* :: */[
              closing,
              /* :: */[
                "? If not, try enclosing the URL in quotes.)",
                /* [] */0
              ]
            ]
          ]
        ]
      ]);
  return locate(buf, /* ERR_MISSING_DELIM_CLOSE */__(12, [/* tuple */[
                  opening,
                  msg
                ]]));
}

function quote_closing_fail(buf, opening, closing) {
  var msg = concat("`", /* :: */[
        "Unmatched opening-quote ",
        /* :: */[
          opening,
          /* :: */[
            ". (Reached EOF without finding a matching ",
            /* :: */[
              closing,
              /* :: */[
                "; did you forget one?)",
                /* [] */0
              ]
            ]
          ]
        ]
      ]);
  return locate(buf, /* ERR_MISSING_DELIM_CLOSE */__(12, [/* tuple */[
                  opening,
                  msg
                ]]));
}

function comment_closing_fail(buf, opening, closing) {
  var msg = concat("`", /* :: */[
        "Unmatched opening comment-delimiter ",
        /* :: */[
          opening,
          /* :: */[
            ". (Reached EOF without finding a matching ",
            /* :: */[
              closing,
              /* :: */[
                "; did you forget one?)",
                /* [] */0
              ]
            ]
          ]
        ]
      ]);
  return locate(buf, /* ERR_MISSING_COMMENT_CLOSE */__(13, [msg]));
}

function url_pop_delim(buf, closing, xs) {
  var opening = assoc(closing, opening_for);
  if (xs) {
    var hd = xs[0];
    if (hd !== opening) {
      var missing_closing = assoc(hd, closing_for);
      return /* Error */__(1, [url_closing_fail(buf, hd, missing_closing)]);
    } else {
      return /* Ok */__(0, [xs[1]]);
    }
  } else {
    return unreachable("url_pop_delim");
  }
}

function url_no_delim(buf, orig_start, _prev_end, acc) {
  while(true) {
    var prev_end = _prev_end;
    var slbuf = buf[/* sedlex */0];
    var __sedlex_state_2 = function (slbuf) {
      while(true) {
        mark(slbuf, 0);
        var match = __sedlex_partition_11(next$2(slbuf));
        if (match !== 0) {
          if (match !== 1) {
            return backtrack(slbuf);
          } else {
            continue ;
          }
        } else {
          return __sedlex_state_1(slbuf);
        }
      }    };
    var __sedlex_state_1 = function (slbuf) {
      while(true) {
        var match = __sedlex_partition_11(next$2(slbuf));
        if (match !== 0) {
          if (match !== 1) {
            return backtrack(slbuf);
          } else {
            return __sedlex_state_2(slbuf);
          }
        } else {
          continue ;
        }
      }    };
    var __sedlex_state_0 = function (slbuf) {
      var match = __sedlex_partition_10(next$2(slbuf));
      switch (match) {
        case 0 :
            return __sedlex_state_1(slbuf);
        case 1 :
            return 1;
        case 2 :
            return __sedlex_state_2(slbuf);
        default:
          return backtrack(slbuf);
      }
    };
    start(slbuf);
    var match = __sedlex_state_0(slbuf);
    if (match !== 0) {
      if (match !== 1) {
        rollback(slbuf);
        var buf$1 = buf;
        var start$1 = orig_start;
        var curr$1 = prev_end;
        var acc$1 = acc;
        buf$1[/* mode */1] = /* MainIgnoringWhitespace */2;
        return /* tuple */[
                /* URL_REST */__(1, [contents(acc$1)]),
                start$1,
                curr$1
              ];
      } else {
        var delim = Utf8.lexeme(buf[/* sedlex */0]);
        add_string(acc, delim);
        var buf$2 = buf;
        var orig_start$1 = orig_start;
        var acc$2 = acc;
        var _open_delims = /* :: */[
          delim,
          /* [] */0
        ];
        while(true) {
          var open_delims = _open_delims;
          var slbuf$1 = buf$2[/* sedlex */0];
          var __sedlex_state_2$1 = function (slbuf) {
            while(true) {
              mark(slbuf, 0);
              var match = __sedlex_partition_11(next$2(slbuf));
              if (match !== 0) {
                if (match !== 1) {
                  return backtrack(slbuf);
                } else {
                  continue ;
                }
              } else {
                return __sedlex_state_1$1(slbuf);
              }
            }          };
          var __sedlex_state_1$1 = function (slbuf) {
            while(true) {
              var match = __sedlex_partition_11(next$2(slbuf));
              if (match !== 0) {
                if (match !== 1) {
                  return backtrack(slbuf);
                } else {
                  return __sedlex_state_2$1(slbuf);
                }
              } else {
                continue ;
              }
            }          };
          var __sedlex_state_0$1 = function (slbuf) {
            var match = __sedlex_partition_12(next$2(slbuf));
            switch (match) {
              case 0 :
                  return __sedlex_state_1$1(slbuf);
              case 1 :
                  return 1;
              case 2 :
                  return 2;
              case 3 :
                  return __sedlex_state_2$1(slbuf);
              default:
                return backtrack(slbuf);
            }
          };
          start(slbuf$1);
          var match$1 = __sedlex_state_0$1(slbuf$1);
          switch (match$1) {
            case 0 :
                add_string(acc$2, Utf8.lexeme(buf$2[/* sedlex */0]));
                continue ;
            case 1 :
                var delim$1 = Utf8.lexeme(buf$2[/* sedlex */0]);
                add_string(acc$2, delim$1);
                _open_delims = /* :: */[
                  delim$1,
                  open_delims
                ];
                continue ;
            case 2 :
                var delim$2 = Utf8.lexeme(buf$2[/* sedlex */0]);
                add_string(acc$2, delim$2);
                var match$2 = url_pop_delim(buf$2, delim$2, open_delims);
                if (match$2.tag) {
                  return match$2[0];
                } else {
                  var remaining = match$2[0];
                  if (remaining) {
                    _open_delims = remaining;
                    continue ;
                  } else {
                    return url_no_delim(buf$2, orig_start$1, curr(buf$2), acc$2);
                  }
                }
            default:
              var most_recent_opening = hd(open_delims);
              var missing_closing = assoc(most_recent_opening, closing_for);
              return url_closing_fail(buf$2, most_recent_opening, missing_closing);
          }
        }      }
    } else {
      add_string(acc, Utf8.lexeme(buf[/* sedlex */0]));
      _prev_end = curr(buf);
      continue ;
    }
  }}

function url_start(buf) {
  buf[/* mode */1] = /* BareURL */0;
  return locate(buf, /* URL_START */__(0, [Utf8.lexeme(buf[/* sedlex */0])]));
}

function main(allow_whitespace, buf) {
  while(true) {
    buf[/* mode */1] = /* MainIgnoringWhitespace */2;
    var slbuf = buf[/* sedlex */0];
    var __sedlex_state_27 = function (slbuf) {
      var match = __sedlex_partition_15(next$2(slbuf));
      if (match !== 0) {
        return backtrack(slbuf);
      } else {
        return __sedlex_state_28(slbuf);
      }
    };
    var __sedlex_state_26 = function (slbuf) {
      var match = __sedlex_partition_15(next$2(slbuf));
      if (match !== 0) {
        return backtrack(slbuf);
      } else {
        return __sedlex_state_25(slbuf);
      }
    };
    var __sedlex_state_36 = function (slbuf) {
      while(true) {
        mark(slbuf, 14);
        var match = __sedlex_partition_27(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_26(slbuf);
          case 1 :
              return __sedlex_state_27(slbuf);
          case 2 :
              continue ;
          case 3 :
              return __sedlex_state_37(slbuf);
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_37 = function (slbuf) {
      while(true) {
        mark(slbuf, 14);
        var match = __sedlex_partition_27(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_26(slbuf);
          case 1 :
              return __sedlex_state_27(slbuf);
          case 2 :
              return __sedlex_state_36(slbuf);
          case 3 :
              continue ;
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_12 = function (slbuf) {
      var match = __sedlex_partition_19(next$2(slbuf));
      if (match !== 0) {
        return backtrack(slbuf);
      } else {
        return 12;
      }
    };
    var __sedlex_state_2 = function (slbuf) {
      while(true) {
        mark(slbuf, 1);
        var match = __sedlex_partition_18(next$2(slbuf));
        switch (match) {
          case 0 :
              continue ;
          case 1 :
              return __sedlex_state_3(slbuf);
          case 2 :
              return 18;
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_3 = function (slbuf) {
      while(true) {
        mark(slbuf, 1);
        var match = __sedlex_partition_18(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_2(slbuf);
          case 1 :
              continue ;
          case 2 :
              return 18;
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_32 = function (slbuf) {
      var match = __sedlex_partition_26(next$2(slbuf));
      switch (match) {
        case 0 :
            return __sedlex_state_10(slbuf);
        case 1 :
            return __sedlex_state_28(slbuf);
        case 2 :
            return __sedlex_state_11(slbuf);
        case 3 :
            var slbuf$1 = slbuf;
            while(true) {
              mark(slbuf$1, 15);
              var match$1 = __sedlex_partition_29(next$2(slbuf$1));
              switch (match$1) {
                case 0 :
                    return __sedlex_state_10(slbuf$1);
                case 1 :
                    return __sedlex_state_32(slbuf$1);
                case 2 :
                    return __sedlex_state_28(slbuf$1);
                case 3 :
                    return __sedlex_state_11(slbuf$1);
                case 4 :
                    continue ;
                case 5 :
                    return __sedlex_state_29(slbuf$1);
                case 6 :
                    return __sedlex_state_27(slbuf$1);
                default:
                  return backtrack(slbuf$1);
              }
            }        default:
          return backtrack(slbuf);
      }
    };
    var __sedlex_state_34 = function (slbuf) {
      while(true) {
        mark(slbuf, 14);
        var match = __sedlex_partition_27(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_26(slbuf);
          case 1 :
              return __sedlex_state_27(slbuf);
          case 2 :
              continue ;
          case 3 :
              return __sedlex_state_35(slbuf);
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_10 = function (slbuf) {
      while(true) {
        var match = __sedlex_partition_20(next$2(slbuf));
        if (match !== 0) {
          if (match !== 1) {
            return backtrack(slbuf);
          } else {
            return __sedlex_state_11(slbuf);
          }
        } else {
          continue ;
        }
      }    };
    var __sedlex_state_35 = function (slbuf) {
      mark(slbuf, 14);
      var match = __sedlex_partition_27(next$2(slbuf));
      switch (match) {
        case 0 :
            return __sedlex_state_26(slbuf);
        case 1 :
            return __sedlex_state_27(slbuf);
        case 2 :
            return __sedlex_state_36(slbuf);
        case 3 :
            return __sedlex_state_37(slbuf);
        default:
          return backtrack(slbuf);
      }
    };
    var __sedlex_state_39 = function (slbuf) {
      mark(slbuf, 13);
      var match = __sedlex_partition_19(next$2(slbuf));
      if (match !== 0) {
        return backtrack(slbuf);
      } else {
        return __sedlex_state_12(slbuf);
      }
    };
    var __sedlex_state_24 = function (slbuf) {
      var match = __sedlex_partition_26(next$2(slbuf));
      switch (match) {
        case 0 :
            return __sedlex_state_10(slbuf);
        case 1 :
            return __sedlex_state_25(slbuf);
        case 2 :
            return __sedlex_state_11(slbuf);
        case 3 :
            var slbuf$1 = slbuf;
            while(true) {
              mark(slbuf$1, 14);
              var match$1 = __sedlex_partition_25(next$2(slbuf$1));
              switch (match$1) {
                case 0 :
                    return __sedlex_state_10(slbuf$1);
                case 1 :
                    return __sedlex_state_24(slbuf$1);
                case 2 :
                    return __sedlex_state_32(slbuf$1);
                case 3 :
                    return __sedlex_state_25(slbuf$1);
                case 4 :
                    return __sedlex_state_11(slbuf$1);
                case 5 :
                    continue ;
                case 6 :
                    return __sedlex_state_30(slbuf$1);
                case 7 :
                    return __sedlex_state_26(slbuf$1);
                default:
                  return backtrack(slbuf$1);
              }
            }        default:
          return backtrack(slbuf);
      }
    };
    var __sedlex_state_11 = function (slbuf) {
      var match = __sedlex_partition_19(next$2(slbuf));
      if (match !== 0) {
        return backtrack(slbuf);
      } else {
        return __sedlex_state_12(slbuf);
      }
    };
    var __sedlex_state_25 = function (slbuf) {
      while(true) {
        mark(slbuf, 14);
        var match = __sedlex_partition_27(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_26(slbuf);
          case 1 :
              return __sedlex_state_27(slbuf);
          case 2 :
              continue ;
          case 3 :
              return __sedlex_state_30(slbuf);
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_30 = function (slbuf) {
      while(true) {
        mark(slbuf, 14);
        var match = __sedlex_partition_27(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_26(slbuf);
          case 1 :
              return __sedlex_state_27(slbuf);
          case 2 :
              return __sedlex_state_25(slbuf);
          case 3 :
              continue ;
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_29 = function (slbuf) {
      while(true) {
        mark(slbuf, 15);
        var match = __sedlex_partition_28(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_27(slbuf);
          case 1 :
              return __sedlex_state_28(slbuf);
          case 2 :
              continue ;
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_28 = function (slbuf) {
      while(true) {
        mark(slbuf, 15);
        var match = __sedlex_partition_28(next$2(slbuf));
        switch (match) {
          case 0 :
              return __sedlex_state_27(slbuf);
          case 1 :
              continue ;
          case 2 :
              return __sedlex_state_29(slbuf);
          default:
            return backtrack(slbuf);
        }
      }    };
    var __sedlex_state_0 = function (slbuf) {
      var match = __sedlex_partition_17(next$2(slbuf));
      switch (match) {
        case 0 :
            return 0;
        case 1 :
            return __sedlex_state_2(slbuf);
        case 2 :
            return __sedlex_state_3(slbuf);
        case 3 :
            return 5;
        case 4 :
            return 20;
        case 5 :
            return 21;
        case 6 :
            var slbuf$1 = slbuf;
            var match$1 = __sedlex_partition_19(next$2(slbuf$1));
            if (match$1 !== 0) {
              return backtrack(slbuf$1);
            } else {
              return 4;
            }
        case 7 :
            return __sedlex_state_10(slbuf);
        case 8 :
            var slbuf$2 = slbuf;
            mark(slbuf$2, 16);
            var match$2 = __sedlex_partition_21(next$2(slbuf$2));
            switch (match$2) {
              case 0 :
                  return __sedlex_state_10(slbuf$2);
              case 1 :
                  var slbuf$3 = slbuf$2;
                  mark(slbuf$3, 17);
                  var match$3 = __sedlex_partition_20(next$2(slbuf$3));
                  if (match$3 !== 0) {
                    if (match$3 !== 1) {
                      return backtrack(slbuf$3);
                    } else {
                      return __sedlex_state_11(slbuf$3);
                    }
                  } else {
                    return __sedlex_state_10(slbuf$3);
                  }
              case 2 :
                  return __sedlex_state_11(slbuf$2);
              default:
                return backtrack(slbuf$2);
            }
        case 9 :
            var slbuf$4 = slbuf;
            var match$4 = __sedlex_partition_22(next$2(slbuf$4));
            if (match$4 !== 0) {
              if (match$4 !== 1) {
                return backtrack(slbuf$4);
              } else {
                var slbuf$5 = slbuf$4;
                while(true) {
                  mark(slbuf$5, 2);
                  var match$5 = __sedlex_partition_23(next$2(slbuf$5));
                  if (match$5 !== 0) {
                    return backtrack(slbuf$5);
                  } else {
                    continue ;
                  }
                }              }
            } else {
              return 3;
            }
        case 10 :
            var slbuf$6 = slbuf;
            while(true) {
              mark(slbuf$6, 11);
              var match$6 = __sedlex_partition_24(next$2(slbuf$6));
              if (match$6 !== 0) {
                return backtrack(slbuf$6);
              } else {
                continue ;
              }
            }        case 11 :
            var slbuf$7 = slbuf;
            mark(slbuf$7, 8);
            var match$7 = __sedlex_partition_19(next$2(slbuf$7));
            if (match$7 !== 0) {
              return backtrack(slbuf$7);
            } else {
              return __sedlex_state_12(slbuf$7);
            }
        case 12 :
            return 10;
        case 13 :
            return 19;
        case 14 :
            var slbuf$8 = slbuf;
            mark(slbuf$8, 14);
            var match$8 = __sedlex_partition_25(next$2(slbuf$8));
            switch (match$8) {
              case 0 :
                  return __sedlex_state_10(slbuf$8);
              case 1 :
                  return __sedlex_state_24(slbuf$8);
              case 2 :
                  return __sedlex_state_32(slbuf$8);
              case 3 :
                  return __sedlex_state_34(slbuf$8);
              case 4 :
                  return __sedlex_state_11(slbuf$8);
              case 5 :
                  var slbuf$9 = slbuf$8;
                  mark(slbuf$9, 14);
                  var match$9 = __sedlex_partition_25(next$2(slbuf$9));
                  switch (match$9) {
                    case 0 :
                        return __sedlex_state_10(slbuf$9);
                    case 1 :
                        return __sedlex_state_24(slbuf$9);
                    case 2 :
                        return __sedlex_state_32(slbuf$9);
                    case 3 :
                        return __sedlex_state_34(slbuf$9);
                    case 4 :
                        return __sedlex_state_39(slbuf$9);
                    case 5 :
                        var slbuf$10 = slbuf$9;
                        mark(slbuf$10, 14);
                        var match$10 = __sedlex_partition_25(next$2(slbuf$10));
                        switch (match$10) {
                          case 0 :
                              return __sedlex_state_10(slbuf$10);
                          case 1 :
                              return __sedlex_state_24(slbuf$10);
                          case 2 :
                              return __sedlex_state_32(slbuf$10);
                          case 3 :
                              return __sedlex_state_34(slbuf$10);
                          case 4 :
                              return __sedlex_state_39(slbuf$10);
                          case 5 :
                              var slbuf$11 = slbuf$10;
                              mark(slbuf$11, 14);
                              var match$11 = __sedlex_partition_25(next$2(slbuf$11));
                              switch (match$11) {
                                case 0 :
                                    return __sedlex_state_10(slbuf$11);
                                case 1 :
                                    return __sedlex_state_24(slbuf$11);
                                case 2 :
                                    return __sedlex_state_32(slbuf$11);
                                case 3 :
                                    return __sedlex_state_34(slbuf$11);
                                case 4 :
                                    return __sedlex_state_39(slbuf$11);
                                case 5 :
                                    var slbuf$12 = slbuf$11;
                                    mark(slbuf$12, 14);
                                    var match$12 = __sedlex_partition_25(next$2(slbuf$12));
                                    switch (match$12) {
                                      case 0 :
                                          return __sedlex_state_10(slbuf$12);
                                      case 1 :
                                          return __sedlex_state_24(slbuf$12);
                                      case 2 :
                                          return __sedlex_state_32(slbuf$12);
                                      case 3 :
                                          return __sedlex_state_34(slbuf$12);
                                      case 4 :
                                          return __sedlex_state_39(slbuf$12);
                                      case 5 :
                                          var slbuf$13 = slbuf$12;
                                          mark(slbuf$13, 14);
                                          var match$13 = __sedlex_partition_25(next$2(slbuf$13));
                                          switch (match$13) {
                                            case 0 :
                                                return __sedlex_state_10(slbuf$13);
                                            case 1 :
                                                return __sedlex_state_24(slbuf$13);
                                            case 2 :
                                                return __sedlex_state_32(slbuf$13);
                                            case 3 :
                                                return __sedlex_state_34(slbuf$13);
                                            case 4 :
                                                return __sedlex_state_39(slbuf$13);
                                            case 5 :
                                                var slbuf$14 = slbuf$13;
                                                while(true) {
                                                  mark(slbuf$14, 14);
                                                  var match$14 = __sedlex_partition_25(next$2(slbuf$14));
                                                  switch (match$14) {
                                                    case 0 :
                                                        return __sedlex_state_10(slbuf$14);
                                                    case 1 :
                                                        return __sedlex_state_24(slbuf$14);
                                                    case 2 :
                                                        return __sedlex_state_32(slbuf$14);
                                                    case 3 :
                                                        return __sedlex_state_34(slbuf$14);
                                                    case 4 :
                                                        return __sedlex_state_11(slbuf$14);
                                                    case 5 :
                                                        continue ;
                                                    case 6 :
                                                        return __sedlex_state_35(slbuf$14);
                                                    case 7 :
                                                        return __sedlex_state_26(slbuf$14);
                                                    default:
                                                      return backtrack(slbuf$14);
                                                  }
                                                }                                            case 6 :
                                                return __sedlex_state_35(slbuf$13);
                                            case 7 :
                                                return __sedlex_state_26(slbuf$13);
                                            default:
                                              return backtrack(slbuf$13);
                                          }
                                      case 6 :
                                          return __sedlex_state_35(slbuf$12);
                                      case 7 :
                                          return __sedlex_state_26(slbuf$12);
                                      default:
                                        return backtrack(slbuf$12);
                                    }
                                case 6 :
                                    return __sedlex_state_35(slbuf$11);
                                case 7 :
                                    return __sedlex_state_26(slbuf$11);
                                default:
                                  return backtrack(slbuf$11);
                              }
                          case 6 :
                              return __sedlex_state_35(slbuf$10);
                          case 7 :
                              return __sedlex_state_26(slbuf$10);
                          default:
                            return backtrack(slbuf$10);
                        }
                    case 6 :
                        return __sedlex_state_35(slbuf$9);
                    case 7 :
                        return __sedlex_state_26(slbuf$9);
                    default:
                      return backtrack(slbuf$9);
                  }
              case 6 :
                  return __sedlex_state_35(slbuf$8);
              case 7 :
                  return __sedlex_state_26(slbuf$8);
              default:
                return backtrack(slbuf$8);
            }
        case 15 :
            return 9;
        case 16 :
            return __sedlex_state_34(slbuf);
        case 17 :
            return 6;
        case 18 :
            return 7;
        default:
          return backtrack(slbuf);
      }
    };
    start(slbuf);
    var match = __sedlex_state_0(slbuf);
    switch (match) {
      case 0 :
          return locate(buf, /* EOF */7);
      case 1 :
          if (allow_whitespace) {
            continue ;
          } else {
            return locate(buf, /* ERR_UNEXPECTED_WHITESPACE */__(7, ["unexpected whitespace in expression"]));
          }
      case 2 :
          return locate(buf, /* COMMENT */__(15, [Utf8.lexeme(buf[/* sedlex */0])]));
      case 3 :
          buf[/* mode */1] = /* CommentBlock */__(0, [1]);
          return locate(buf, /* COMMENT_OPEN */8);
      case 4 :
          var buf$1 = buf;
          var opening = "/*";
          var closing = "*/";
          var msg = concat("`", /* :: */[
                "Unmatched closing comment-delimiter ",
                /* :: */[
                  closing,
                  /* :: */[
                    ". (Did you forget a ",
                    /* :: */[
                      opening,
                      /* :: */[
                        "?)",
                        /* [] */0
                      ]
                    ]
                  ]
                ]
              ]);
          return locate(buf$1, /* ERR_UNEXPECTED_COMMENT_CLOSE */__(10, [msg]));
      case 5 :
          buf[/* mode */1] = /* QuoteComplex */3;
          return locate(buf, /* QUOTE_OPEN */__(2, [Utf8.lexeme(buf[/* sedlex */0])]));
      case 6 :
          buf[/* mode */1] = /* QuoteBalanced */__(1, [1]);
          return locate(buf, /* QUOTE_OPEN */__(2, [Utf8.lexeme(buf[/* sedlex */0])]));
      case 7 :
          var buf$2 = buf;
          var opening$1 = quote_balanced_open_char;
          var closing$1 = quote_balanced_close_char;
          var msg$1 = concat("`", /* :: */[
                "Unmatched closing-quote ",
                /* :: */[
                  closing$1,
                  /* :: */[
                    ". (Did you forget a ",
                    /* :: */[
                      opening$1,
                      /* :: */[
                        "?)",
                        /* [] */0
                      ]
                    ]
                  ]
                ]
              ]);
          return locate(buf$2, /* ERR_UNEXPECTED_QUOTE_CLOSE */__(9, [/* tuple */[
                          closing$1,
                          msg$1
                        ]]));
      case 8 :
          return locate(buf, /* COLON */10);
      case 9 :
          return locate(buf, /* PIPE */1);
      case 10 :
          return locate(buf, /* SEMICOLON */0);
      case 11 :
          return locate(buf, /* COUNT */__(14, [Utf8.lexeme(buf[/* sedlex */0])]));
      case 13 :
          var buf$3 = buf;
          var str = Utf8.lexeme(buf$3[/* sedlex */0]);
          if (known_schemes.test(str)) {
            return url_start(buf$3);
          } else {
            rollback(buf$3[/* sedlex */0]);
            var buf$4 = buf$3;
            var slbuf$1 = buf$4[/* sedlex */0];
            var __sedlex_state_2$1 = function (slbuf) {
              var match = __sedlex_partition_15(next$2(slbuf));
              if (match !== 0) {
                return backtrack(slbuf);
              } else {
                return __sedlex_state_3$1(slbuf);
              }
            };
            var __sedlex_state_7 = function (slbuf) {
              while(true) {
                mark(slbuf, 0);
                var match = __sedlex_partition_14(next$2(slbuf));
                switch (match) {
                  case 0 :
                      return __sedlex_state_2$1(slbuf);
                  case 1 :
                      return __sedlex_state_6(slbuf);
                  case 2 :
                      continue ;
                  default:
                    return backtrack(slbuf);
                }
              }            };
            var __sedlex_state_6 = function (slbuf) {
              while(true) {
                mark(slbuf, 0);
                var match = __sedlex_partition_14(next$2(slbuf));
                switch (match) {
                  case 0 :
                      return __sedlex_state_2$1(slbuf);
                  case 1 :
                      continue ;
                  case 2 :
                      return __sedlex_state_7(slbuf);
                  default:
                    return backtrack(slbuf);
                }
              }            };
            var __sedlex_state_3$1 = function (slbuf) {
              while(true) {
                mark(slbuf, 0);
                var match = __sedlex_partition_14(next$2(slbuf));
                switch (match) {
                  case 0 :
                      return __sedlex_state_2$1(slbuf);
                  case 1 :
                      continue ;
                  case 2 :
                      var slbuf$1 = slbuf;
                      while(true) {
                        mark(slbuf$1, 0);
                        var match$1 = __sedlex_partition_14(next$2(slbuf$1));
                        switch (match$1) {
                          case 0 :
                              return __sedlex_state_2$1(slbuf$1);
                          case 1 :
                              return __sedlex_state_3$1(slbuf$1);
                          case 2 :
                              continue ;
                          default:
                            return backtrack(slbuf$1);
                        }
                      }                  default:
                    return backtrack(slbuf);
                }
              }            };
            var __sedlex_state_0$1 = function (slbuf) {
              var match = __sedlex_partition_16(next$2(slbuf));
              if (match !== 0) {
                return backtrack(slbuf);
              } else {
                var slbuf$1 = slbuf;
                while(true) {
                  mark(slbuf$1, 0);
                  var match$1 = __sedlex_partition_14(next$2(slbuf$1));
                  switch (match$1) {
                    case 0 :
                        return __sedlex_state_2$1(slbuf$1);
                    case 1 :
                        continue ;
                    case 2 :
                        var slbuf$2 = slbuf$1;
                        mark(slbuf$2, 0);
                        var match$2 = __sedlex_partition_14(next$2(slbuf$2));
                        switch (match$2) {
                          case 0 :
                              return __sedlex_state_2$1(slbuf$2);
                          case 1 :
                              return __sedlex_state_6(slbuf$2);
                          case 2 :
                              return __sedlex_state_7(slbuf$2);
                          default:
                            return backtrack(slbuf$2);
                        }
                    default:
                      return backtrack(slbuf$1);
                  }
                }              }
            };
            start(slbuf$1);
            var match$1 = __sedlex_state_0$1(slbuf$1);
            if (match$1 !== 0) {
              return unreachable("just_identifier");
            } else {
              return locate(buf$4, /* IDENTIFIER */__(6, [Utf8.lexeme(buf$4[/* sedlex */0])]));
            }
          }
      case 14 :
          return locate(buf, /* IDENTIFIER */__(6, [Utf8.lexeme(buf[/* sedlex */0])]));
      case 12 :
      case 15 :
          return url_start(buf);
      case 16 :
          buf[/* mode */1] = /* MainDisallowingWhitespace */1;
          return locate(buf, /* FLAGS_SHORT_START */5);
      case 17 :
          var buf$5 = buf;
          var slbuf$2 = buf$5[/* sedlex */0];
          var __sedlex_state_3$2 = function (slbuf) {
            var match = __sedlex_partition_15(next$2(slbuf));
            if (match !== 0) {
              return backtrack(slbuf);
            } else {
              return __sedlex_state_4(slbuf);
            }
          };
          var __sedlex_state_7$1 = function (slbuf) {
            while(true) {
              mark(slbuf, 0);
              var match = __sedlex_partition_14(next$2(slbuf));
              switch (match) {
                case 0 :
                    return __sedlex_state_3$2(slbuf);
                case 1 :
                    continue ;
                case 2 :
                    return __sedlex_state_8(slbuf);
                default:
                  return backtrack(slbuf);
              }
            }          };
          var __sedlex_state_8 = function (slbuf) {
            while(true) {
              mark(slbuf, 0);
              var match = __sedlex_partition_14(next$2(slbuf));
              switch (match) {
                case 0 :
                    return __sedlex_state_3$2(slbuf);
                case 1 :
                    return __sedlex_state_7$1(slbuf);
                case 2 :
                    continue ;
                default:
                  return backtrack(slbuf);
              }
            }          };
          var __sedlex_state_4 = function (slbuf) {
            while(true) {
              mark(slbuf, 0);
              var match = __sedlex_partition_14(next$2(slbuf));
              switch (match) {
                case 0 :
                    return __sedlex_state_3$2(slbuf);
                case 1 :
                    continue ;
                case 2 :
                    var slbuf$1 = slbuf;
                    while(true) {
                      mark(slbuf$1, 0);
                      var match$1 = __sedlex_partition_14(next$2(slbuf$1));
                      switch (match$1) {
                        case 0 :
                            return __sedlex_state_3$2(slbuf$1);
                        case 1 :
                            return __sedlex_state_4(slbuf$1);
                        case 2 :
                            continue ;
                        default:
                          return backtrack(slbuf$1);
                      }
                    }                default:
                  return backtrack(slbuf);
              }
            }          };
          var __sedlex_state_0$2 = function (slbuf) {
            var match = __sedlex_partition_13(next$2(slbuf));
            if (match !== 0) {
              if (match !== 1) {
                return backtrack(slbuf);
              } else {
                var slbuf$1 = slbuf;
                while(true) {
                  mark(slbuf$1, 0);
                  var match$1 = __sedlex_partition_14(next$2(slbuf$1));
                  switch (match$1) {
                    case 0 :
                        return __sedlex_state_3$2(slbuf$1);
                    case 1 :
                        continue ;
                    case 2 :
                        var slbuf$2 = slbuf$1;
                        mark(slbuf$2, 0);
                        var match$2 = __sedlex_partition_14(next$2(slbuf$2));
                        switch (match$2) {
                          case 0 :
                              return __sedlex_state_3$2(slbuf$2);
                          case 1 :
                              return __sedlex_state_7$1(slbuf$2);
                          case 2 :
                              return __sedlex_state_8(slbuf$2);
                          default:
                            return backtrack(slbuf$2);
                        }
                    default:
                      return backtrack(slbuf$1);
                  }
                }              }
            } else {
              return 0;
            }
          };
          start(slbuf$2);
          var match$2 = __sedlex_state_0$2(slbuf$2);
          if (match$2 !== 0) {
            rollback(slbuf$2);
            return locate(buf$5, /* BARE_DOUBLE_DASH */11);
          } else {
            rollback(slbuf$2);
            buf$5[/* mode */1] = /* MainDisallowingWhitespace */1;
            return locate(buf$5, /* FLAG_LONG_START */4);
          }
      case 18 :
          return locate(buf, /* ERR_UNEXPECTED_WHITESPACE */__(7, ["unexpected space before '='"]));
      case 19 :
          buf[/* mode */1] = /* MainDisallowingWhitespace */1;
          return locate(buf, /* EQUALS */6);
      case 20 :
          return locate(buf, /* PAREN_OPEN */2);
      case 21 :
          return locate(buf, /* PAREN_CLOSE */3);
      default:
        var match$3 = next$2(buf[/* sedlex */0]);
        if (match$3 !== undefined) {
          var buf$6 = buf;
          var c = valFromOption(match$3);
          var i = Uchar.to_int(c);
          var msg$2 = Uchar.is_char(c) ? _2(sprintf$1(/* Format */[
                      /* String_literal */__(11, [
                          "unexpected character in expression: U+",
                          /* Int */__(4, [
                              /* Int_X */8,
                              /* Lit_padding */__(0, [
                                  /* Zeros */2,
                                  4
                                ]),
                              /* No_precision */0,
                              /* String_literal */__(11, [
                                  ", '",
                                  /* Char */__(0, [/* Char_literal */__(12, [
                                          /* "'" */39,
                                          /* End_of_format */0
                                        ])])
                                ])
                            ])
                        ]),
                      "unexpected character in expression: U+%04X, '%c'"
                    ]), i, Uchar.to_char(c)) : _1(sprintf$1(/* Format */[
                      /* String_literal */__(11, [
                          "unexpected character in expression: U+",
                          /* Int */__(4, [
                              /* Int_X */8,
                              /* Lit_padding */__(0, [
                                  /* Zeros */2,
                                  4
                                ]),
                              /* No_precision */0,
                              /* End_of_format */0
                            ])
                        ]),
                      "unexpected character in expression: U+%04X"
                    ]), i);
          return locate(buf$6, /* ERR_UNEXPECTED_CHARACTER */__(11, [/* tuple */[
                          i,
                          msg$2
                        ]]));
        } else {
          return unreachable("main");
        }
    }
  }}

function next_loc(buf) {
  var match = buf[/* mode */1];
  if (typeof match === "number") {
    switch (match) {
      case /* BareURL */0 :
          var buf$1 = buf;
          var acc = create$1(256);
          return url_no_delim(buf$1, start$1(buf$1), curr(buf$1), acc);
      case /* MainDisallowingWhitespace */1 :
          return main(false, buf);
      case /* MainIgnoringWhitespace */2 :
          return main(true, buf);
      case /* QuoteComplex */3 :
          var buf$2 = buf;
          var slbuf = buf$2[/* sedlex */0];
          var __sedlex_state_0 = function (slbuf) {
            var match = __sedlex_partition_7(next$2(slbuf));
            switch (match) {
              case 0 :
                  return 5;
              case 1 :
                  var slbuf$1 = slbuf;
                  while(true) {
                    mark(slbuf$1, 0);
                    var match$1 = __sedlex_partition_8(next$2(slbuf$1));
                    if (match$1 !== 0) {
                      return backtrack(slbuf$1);
                    } else {
                      continue ;
                    }
                  }              case 2 :
                  return 4;
              case 3 :
                  var slbuf$2 = slbuf;
                  var match$2 = __sedlex_partition_9(next$2(slbuf$2));
                  switch (match$2) {
                    case 0 :
                        return 3;
                    case 1 :
                        return 1;
                    case 2 :
                        return 2;
                    default:
                      return backtrack(slbuf$2);
                  }
              default:
                return backtrack(slbuf);
            }
          };
          start(slbuf);
          var match$1 = __sedlex_state_0(slbuf);
          switch (match$1) {
            case 0 :
                return locate(buf$2, /* QUOTE_CHUNK */__(5, [Utf8.lexeme(buf$2[/* sedlex */0])]));
            case 1 :
                var whole = Utf8.lexeme(buf$2[/* sedlex */0]);
                var ch = sub$2(whole, 1, whole.length - 1 | 0);
                return locate(buf$2, /* QUOTE_ESCAPE */__(3, [ch]));
            case 2 :
                return locate(buf$2, /* QUOTE_ESCAPE */__(3, ["\n"]));
            case 3 :
                var buf$3 = buf$2;
                var delim = "\"";
                var escape_seq = Utf8.lexeme(buf$2[/* sedlex */0]);
                var msg = concat("`", /* :: */[
                      "The escape-sequence ",
                      /* :: */[
                        escape_seq,
                        /* :: */[
                          " is not understood in ",
                          /* :: */[
                            delim,
                            /* :: */[
                              " strings. (Did you forget to escape a backslash? Try ",
                              /* :: */[
                                "\\" + escape_seq,
                                /* :: */[
                                  " instead.)",
                                  /* [] */0
                                ]
                              ]
                            ]
                          ]
                        ]
                      ]
                    ]);
                return locate(buf$3, /* ERR_UNEXPECTED_QUOTE_ESCAPE */__(8, [/* tuple */[
                                escape_seq,
                                msg
                              ]]));
            case 4 :
                buf$2[/* mode */1] = /* MainIgnoringWhitespace */2;
                return locate(buf$2, /* QUOTE_CLOSE */__(4, [Utf8.lexeme(buf$2[/* sedlex */0])]));
            case 5 :
                return quote_closing_fail(buf$2, "\"", "\"");
            default:
              return unreachable("quote_complex");
          }
      
    }
  } else if (match.tag) {
    var buf$4 = buf;
    var depth = match[0];
    var slbuf$1 = buf$4[/* sedlex */0];
    var __sedlex_state_0$1 = function (slbuf) {
      var match = __sedlex_partition_5(next$2(slbuf));
      switch (match) {
        case 0 :
            return 3;
        case 1 :
            var slbuf$1 = slbuf;
            while(true) {
              mark(slbuf$1, 0);
              var match$1 = __sedlex_partition_6(next$2(slbuf$1));
              if (match$1 !== 0) {
                return backtrack(slbuf$1);
              } else {
                continue ;
              }
            }        case 2 :
            return 1;
        case 3 :
            return 2;
        default:
          return backtrack(slbuf);
      }
    };
    start(slbuf$1);
    var match$2 = __sedlex_state_0$1(slbuf$1);
    switch (match$2) {
      case 0 :
          return locate(buf$4, /* QUOTE_CHUNK */__(5, [Utf8.lexeme(buf$4[/* sedlex */0])]));
      case 1 :
          buf$4[/* mode */1] = /* QuoteBalanced */__(1, [depth + 1 | 0]);
          return locate(buf$4, /* QUOTE_OPEN */__(2, [Utf8.lexeme(buf$4[/* sedlex */0])]));
      case 2 :
          buf$4[/* mode */1] = depth === 1 ? /* MainIgnoringWhitespace */2 : /* QuoteBalanced */__(1, [depth - 1 | 0]);
          return locate(buf$4, /* QUOTE_CLOSE */__(4, [Utf8.lexeme(buf$4[/* sedlex */0])]));
      case 3 :
          return quote_closing_fail(buf$4, quote_balanced_open_char, quote_balanced_close_char);
      default:
        return unreachable("quote_balanced");
    }
  } else {
    var depth$1 = match[0];
    var buf$5 = buf;
    var slbuf$2 = buf$5[/* sedlex */0];
    var __sedlex_state_0$2 = function (slbuf) {
      var match = __sedlex_partition_1(next$2(slbuf));
      switch (match) {
        case 0 :
            return 3;
        case 1 :
            var slbuf$1 = slbuf;
            while(true) {
              mark(slbuf$1, 2);
              var match$1 = __sedlex_partition_2(next$2(slbuf$1));
              if (match$1 !== 0) {
                return backtrack(slbuf$1);
              } else {
                continue ;
              }
            }        case 2 :
            var slbuf$2 = slbuf;
            var match$2 = __sedlex_partition_3(next$2(slbuf$2));
            if (match$2 !== 0) {
              if (match$2 !== 1) {
                return backtrack(slbuf$2);
              } else {
                return 0;
              }
            } else {
              return 2;
            }
        case 3 :
            var slbuf$3 = slbuf;
            var match$3 = __sedlex_partition_4(next$2(slbuf$3));
            if (match$3 !== 0) {
              if (match$3 !== 1) {
                return backtrack(slbuf$3);
              } else {
                return 1;
              }
            } else {
              return 2;
            }
        default:
          return backtrack(slbuf);
      }
    };
    start(slbuf$2);
    var match$3 = __sedlex_state_0$2(slbuf$2);
    switch (match$3) {
      case 0 :
          buf$5[/* mode */1] = depth$1 === 1 ? /* MainIgnoringWhitespace */2 : /* CommentBlock */__(0, [depth$1 - 1 | 0]);
          return locate(buf$5, /* COMMENT_CLOSE */9);
      case 1 :
          buf$5[/* mode */1] = /* CommentBlock */__(0, [depth$1 + 1 | 0]);
          return locate(buf$5, /* COMMENT_OPEN */8);
      case 2 :
          var acc$1 = create$1(256);
          add_string(acc$1, Utf8.lexeme(buf$5[/* sedlex */0]));
          var buf$6 = buf$5;
          var orig_start = start$1(buf$5);
          var acc$2 = acc$1;
          while(true) {
            var slbuf$3 = buf$6[/* sedlex */0];
            var __sedlex_state_0$3 = function (slbuf) {
              var match = __sedlex_partition_1(next$2(slbuf));
              switch (match) {
                case 0 :
                    return 2;
                case 1 :
                    var slbuf$1 = slbuf;
                    while(true) {
                      mark(slbuf$1, 1);
                      var match$1 = __sedlex_partition_2(next$2(slbuf$1));
                      if (match$1 !== 0) {
                        return backtrack(slbuf$1);
                      } else {
                        continue ;
                      }
                    }                case 2 :
                    var slbuf$2 = slbuf;
                    var match$2 = __sedlex_partition_3(next$2(slbuf$2));
                    if (match$2 !== 0) {
                      if (match$2 !== 1) {
                        return backtrack(slbuf$2);
                      } else {
                        return 0;
                      }
                    } else {
                      return 1;
                    }
                case 3 :
                    var slbuf$3 = slbuf;
                    var match$3 = __sedlex_partition_4(next$2(slbuf$3));
                    if (match$3 !== 0) {
                      if (match$3 !== 1) {
                        return backtrack(slbuf$3);
                      } else {
                        return 0;
                      }
                    } else {
                      return 1;
                    }
                default:
                  return backtrack(slbuf);
              }
            };
            start(slbuf$3);
            var match$4 = __sedlex_state_0$3(slbuf$3);
            switch (match$4) {
              case 0 :
                  rollback(slbuf$3);
                  return /* tuple */[
                          /* COMMENT */__(15, [contents(acc$2)]),
                          orig_start,
                          curr(buf$6)
                        ];
              case 1 :
                  add_string(acc$2, Utf8.lexeme(buf$6[/* sedlex */0]));
                  continue ;
              case 2 :
                  return comment_closing_fail(buf$6, "/*", "*/");
              default:
                return unreachable("comment_block_continuing");
            }
          }      case 3 :
          return comment_closing_fail(buf$5, "/*", "*/");
      default:
        return unreachable("comment_block");
    }
  }
}

function next_loc_exn(buf) {
  var tok = next_loc(buf);
  if (token_is_erroneous(token(tok))) {
    var message = unwrap_exn(token_error_message(token(tok)));
    var buf$1 = buf;
    var s = message;
    throw [
          LexError,
          curr(buf$1),
          s
        ];
  } else {
    return tok;
  }
}

function next$3(buf) {
  return next_loc(buf)[0];
}

function next_exn(buf) {
  return next_loc_exn(buf)[0];
}

function gen_loc(buf, param) {
  var tuple = next_loc(buf);
  var match = tuple[0];
  if (typeof match === "number" && match === 7) {
    return ;
  } else {
    return tuple;
  }
}

function gen_loc_exn(buf, param) {
  var tuple = next_loc_exn(buf);
  var match = tuple[0];
  if (typeof match === "number" && match === 7) {
    return ;
  } else {
    return tuple;
  }
}

function gen(buf, param) {
  var match = next_loc(buf);
  var tok = match[0];
  if (typeof tok === "number" && tok === 7) {
    return ;
  } else {
    return tok;
  }
}

function gen_exn(buf, param) {
  var match = next_loc_exn(buf);
  var tok = match[0];
  if (typeof tok === "number" && tok === 7) {
    return ;
  } else {
    return tok;
  }
}

function tokens_loc(buf) {
  return of_list(to_list((function (param) {
                    return gen_loc(buf);
                  })));
}

function tokens_loc_exn(buf) {
  return of_list(to_list((function (param) {
                    return gen_loc_exn(buf);
                  })));
}

function tokens(buf) {
  return of_list(to_list((function (param) {
                    return gen(buf);
                  })));
}

function tokens_exn(buf) {
  return of_list(to_list((function (param) {
                    return gen_exn(buf);
                  })));
}
/* known_schemes Not a pure module */

var $_Lexer = /*#__PURE__*/Object.freeze({
    __proto__: null,
    pp_position: pp_position,
    show_position: show_position,
    LexError: LexError,
    sedlex_of_buffer: sedlex_of_buffer,
    buffer_of_sedlex: buffer_of_sedlex,
    buffer_of_string: buffer_of_string,
    token: token,
    example_tokens: example_tokens,
    compare_token: compare_token,
    show_token: show_token,
    example_of_token: example_of_token,
    token_body: token_body,
    token_is_erroneous: token_is_erroneous,
    token_error_message: token_error_message,
    start_lnum: start_lnum,
    start_cnum: start_cnum,
    end_lnum: end_lnum,
    end_cnum: end_cnum,
    error_loc_exn: error_loc_exn,
    error_desc_exn: error_desc_exn,
    position_fname: position_fname,
    position_lnum: position_lnum,
    position_bol: position_bol,
    position_cnum: position_cnum,
    next_loc: next_loc,
    next_loc_exn: next_loc_exn,
    next: next$3,
    next_exn: next_exn,
    gen_loc: gen_loc,
    gen_loc_exn: gen_loc_exn,
    gen: gen,
    gen_exn: gen_exn,
    tokens_loc: tokens_loc,
    tokens_loc_exn: tokens_loc_exn,
    tokens: tokens,
    tokens_exn: tokens_exn,
    show_loctoken: show_loctoken,
    string_of_loctoken: string_of_loctoken,
    string_of_position: string_of_position
});

var zero_pos = /* record */[
  /* pos_fname */"",
  /* pos_lnum */1,
  /* pos_bol */0,
  /* pos_cnum */0
];

function from_string(s) {
  return /* record */[
          /* refill_buff */(function (lexbuf) {
              lexbuf[/* lex_eof_reached */8] = true;
              return /* () */0;
            }),
          /* lex_buffer */of_string(s),
          /* lex_buffer_len */s.length,
          /* lex_abs_pos */0,
          /* lex_start_pos */0,
          /* lex_curr_pos */0,
          /* lex_last_pos */0,
          /* lex_last_action */0,
          /* lex_eof_reached */true,
          /* lex_mem : array */[],
          /* lex_start_p */zero_pos,
          /* lex_curr_p */zero_pos
        ];
}

var dummy_pos = /* record */[
  /* pos_fname */"",
  /* pos_lnum */0,
  /* pos_bol */0,
  /* pos_cnum */-1
];
/* No side effect */

var match = caml_sys_get_argv();

var Break = create("Sys.Break");

var argv = match[1];

var executable_name = match[0];
/* No side effect */

function traditional2revised(get_raw_token, get_startp, get_endp, parser, lexer) {
  var lexbuf = from_string("");
  var lexer$1 = function (lexbuf) {
    var token = _1(lexer, /* () */0);
    lexbuf[/* lex_start_p */10] = _1(get_startp, token);
    lexbuf[/* lex_curr_p */11] = _1(get_endp, token);
    return _1(get_raw_token, token);
  };
  return _2(parser, lexer$1, lexbuf);
}

function revised2traditional(make_token, parser, lexer, lexbuf) {
  return _1(parser, (function (param) {
                var token = _1(lexer, lexbuf);
                return _3(make_token, token, lexbuf[/* lex_start_p */10], lexbuf[/* lex_curr_p */11]);
              }));
}

function traditional2revised$1(parser) {
  return (function (param) {
      return traditional2revised((function (param) {
                    return param[0];
                  }), (function (param) {
                    return param[1];
                  }), (function (param) {
                    return param[2];
                  }), parser, param);
    });
}

function revised2traditional$1(parser) {
  return (function (param, param$1) {
      return revised2traditional((function (token, startp, endp) {
                    return /* tuple */[
                            token,
                            startp,
                            endp
                          ];
                  }), parser, param, param$1);
    });
}

var Simplified = {
  traditional2revised: traditional2revised$1,
  revised2traditional: revised2traditional$1
};

var Convert = {
  traditional2revised: traditional2revised,
  revised2traditional: revised2traditional,
  Simplified: Simplified
};

function get1(s, i) {
  var c = s.charCodeAt((i >>> 3));
  var c$1 = (c >>> (lnot(i) & 7)) | 0;
  return c$1 & 1;
}

function get$1(param, i) {
  var s = param[1];
  var k = param[0];
  switch (k) {
    case 1 :
        return get1(s, i);
    case 2 :
        var c = s.charCodeAt((i >>> 2));
        var c$1 = (c >>> ((lnot(i) & 3) << 1)) | 0;
        return c$1 & 3;
    case 4 :
        var c$2 = s.charCodeAt((i >>> 1));
        var c$3 = (c$2 >>> ((lnot(i) & 1) << 2)) | 0;
        return c$3 & 15;
    case 8 :
        return s.charCodeAt(i);
    case 3 :
    case 5 :
    case 6 :
    case 7 :
    case 9 :
    case 10 :
    case 11 :
    case 12 :
    case 13 :
    case 14 :
    case 15 :
        break;
    case 16 :
        var j = (i << 1);
        return (s.charCodeAt(j) << 8) + s.charCodeAt(j + 1 | 0) | 0;
      
  }
  if (k !== 32) {
    throw [
          assert_failure,
          /* tuple */[
            "menhirLib.ml",
            2394,
            6
          ]
        ];
  }
  var j$1 = (i << 2);
  return (((((s.charCodeAt(j$1) << 8) + s.charCodeAt(j$1 + 1 | 0) | 0) << 8) + s.charCodeAt(j$1 + 2 | 0) | 0) << 8) + s.charCodeAt(j$1 + 3 | 0) | 0;
}

function unflatten1(param, i, j) {
  return get1(param[1], imul(param[0], i) + j | 0);
}

function decode(displacement) {
  if ((displacement & 1) === 0) {
    return (displacement >>> 1);
  } else {
    return -(displacement >>> 1) | 0;
  }
}

function getget(get_displacement, get_data, param, i, j) {
  var k = decode(_2(get_displacement, param[0], i));
  return _2(get_data, param[1], k + j | 0);
}

function read_interval_via(get_data, i, j) {
  if (i === j) {
    return /* [] */0;
  } else {
    return /* :: */[
            _1(get_data, i),
            read_interval_via(get_data, i + 1 | 0, j)
          ];
  }
}

function read_row_via(get_data, get_entry, i) {
  return read_interval_via(get_data, _1(get_entry, i), _1(get_entry, i + 1 | 0));
}

function Symbols(T) {
  return { };
}

var Engine = {
  Make: (function (funarg) {
      var number = funarg.number;
      var $$Error = funarg.$$Error;
      var log = funarg.log;
      var Log = funarg.Log;
      var run = function (env, please_discard) {
        if (log) {
          _1(Log.state, env[/* current */3]);
        }
        if (please_discard) {
          return /* InputNeeded */__(0, [env]);
        } else {
          return check_for_default_reduction(env);
        }
      };
      var check_for_default_reduction = function (env) {
        return _4(funarg.default_reduction, env[/* current */3], announce_reduce, check_for_error_token, env);
      };
      var shift = function (env, please_discard, terminal, value, s$prime) {
        if (log) {
          _2(Log.shift, terminal, s$prime);
        }
        var match = env[/* triple */1];
        var stack_000 = /* state */env[/* current */3];
        var stack_002 = /* startp */match[1];
        var stack_003 = /* endp */match[2];
        var stack_004 = /* next */env[/* stack */2];
        var stack = /* record */[
          stack_000,
          /* semv */value,
          stack_002,
          stack_003,
          stack_004
        ];
        var new_env_000 = /* error */env[/* error */0];
        var new_env_001 = /* triple */env[/* triple */1];
        var new_env = /* record */[
          new_env_000,
          new_env_001,
          /* stack */stack,
          /* current */s$prime
        ];
        return /* Shifting */__(1, [
                  env,
                  new_env,
                  please_discard
                ]);
      };
      var initiate = function (env) {
        if (log) {
          _1(Log.initiating_error_handling, /* () */0);
        }
        var env_001 = /* triple */env[/* triple */1];
        var env_002 = /* stack */env[/* stack */2];
        var env_003 = /* current */env[/* current */3];
        var env$1 = /* record */[
          /* error */true,
          env_001,
          env_002,
          env_003
        ];
        return /* HandlingError */__(3, [env$1]);
      };
      var reduce = function (env, prod) {
        if (log) {
          _1(Log.reduce_or_accept, prod);
        }
        var stack;
        try {
          stack = _2(funarg.semantic_action, prod, env);
        }
        catch (exn){
          if (exn === $$Error) {
            return initiate(env);
          } else {
            throw exn;
          }
        }
        var current = _2(funarg.goto_prod, stack[/* state */0], prod);
        var env_000 = /* error */env[/* error */0];
        var env_001 = /* triple */env[/* triple */1];
        var env$1 = /* record */[
          env_000,
          env_001,
          /* stack */stack,
          /* current */current
        ];
        return run(env$1, false);
      };
      var accept = function (env, prod) {
        if (log) {
          _1(Log.reduce_or_accept, prod);
        }
        var v = env[/* stack */2][/* semv */1];
        return /* Accepted */__(4, [v]);
      };
      var announce_reduce = function (env, prod) {
        if (_1(funarg.is_start, prod)) {
          return accept(env, prod);
        } else {
          return /* AboutToReduce */__(2, [
                    env,
                    prod
                  ]);
        }
      };
      var check_for_error_token = function (env) {
        if (env[/* error */0]) {
          if (log) {
            _1(Log.resuming_error_handling, /* () */0);
          }
          return /* HandlingError */__(3, [env]);
        } else {
          var match = env[/* triple */1];
          var token = match[0];
          return _7(funarg.action, env[/* current */3], _1(funarg.token2terminal, token), _1(funarg.token2value, token), shift, announce_reduce, initiate, env);
        }
      };
      var error_fail = function (env) {
        var cell = env[/* stack */2];
        var next = cell[/* next */4];
        if (next === cell) {
          return /* Rejected */0;
        } else {
          var env_000 = /* error */env[/* error */0];
          var env_001 = /* triple */env[/* triple */1];
          var env_003 = /* current */cell[/* state */0];
          var env$1 = /* record */[
            env_000,
            env_001,
            /* stack */next,
            env_003
          ];
          return /* HandlingError */__(3, [env$1]);
        }
      };
      var error_reduce = function (env, prod) {
        if (log) {
          _1(Log.handling_error, env[/* current */3]);
        }
        return reduce(env, prod);
      };
      var error_shift = function (env, please_discard, terminal, value, s$prime) {
        if (!(caml_equal(terminal, funarg.error_terminal) && caml_equal(value, funarg.error_value))) {
          throw [
                assert_failure,
                /* tuple */[
                  "menhirLib.ml",
                  1397,
                  4
                ]
              ];
        }
        if (log) {
          _1(Log.handling_error, env[/* current */3]);
        }
        return shift(env, please_discard, terminal, value, s$prime);
      };
      var discard = function (env, triple) {
        if (log) {
          _3(Log.lookahead_token, _1(funarg.token2terminal, triple[0]), triple[1], triple[2]);
        }
        return check_for_default_reduction(/* record */[
                    /* error */false,
                    /* triple */triple,
                    /* stack */env[/* stack */2],
                    /* current */env[/* current */3]
                  ]);
      };
      var error = function (env) {
        if (!env[/* error */0]) {
          throw [
                assert_failure,
                /* tuple */[
                  "menhirLib.ml",
                  1378,
                  4
                ]
              ];
        }
        return _7(funarg.action, env[/* current */3], funarg.error_terminal, funarg.error_value, error_shift, error_reduce, error_fail, env);
      };
      var start = function (s, initial) {
        var empty = [];
        caml_update_dummy(empty, /* record */[
              /* state */s,
              /* semv */funarg.error_value,
              /* startp */initial,
              /* endp */initial,
              /* next */empty
            ]);
        var env_001 = /* triple : tuple */[
          /* () */0,
          initial,
          initial
        ];
        var env = /* record */[
          /* error */false,
          env_001,
          /* stack */empty,
          /* current */s
        ];
        return run(env, true);
      };
      var offer = function (param) {
        if (typeof param === "number" || param.tag) {
          return invalid_arg("offer expects InputNeeded");
        } else {
          var partial_arg = param[0];
          return (function (param) {
              return discard(partial_arg, param);
            });
        }
      };
      var resume = function (param) {
        if (typeof param === "number") {
          return invalid_arg("resume expects HandlingError | Shifting | AboutToReduce");
        } else {
          switch (param.tag | 0) {
            case /* Shifting */1 :
                return run(param[1], param[2]);
            case /* AboutToReduce */2 :
                return reduce(param[0], param[1]);
            case /* HandlingError */3 :
                return error(param[0]);
            default:
              return invalid_arg("resume expects HandlingError | Shifting | AboutToReduce");
          }
        }
      };
      var lexer_lexbuf_to_supplier = function (lexer, lexbuf, param) {
        var token = _1(lexer, lexbuf);
        var startp = lexbuf[/* lex_start_p */10];
        var endp = lexbuf[/* lex_curr_p */11];
        return /* tuple */[
                token,
                startp,
                endp
              ];
      };
      var loop = function (read, _checkpoint) {
        while(true) {
          var checkpoint = _checkpoint;
          if (typeof checkpoint === "number") {
            throw $$Error;
          } else {
            switch (checkpoint.tag | 0) {
              case /* InputNeeded */0 :
                  var triple = _1(read, /* () */0);
                  var checkpoint$1 = _1(offer(checkpoint), triple);
                  _checkpoint = checkpoint$1;
                  continue ;
              case /* Accepted */4 :
                  return checkpoint[0];
              default:
                var checkpoint$2 = resume(checkpoint);
                _checkpoint = checkpoint$2;
                continue ;
            }
          }
        }      };
      var entry = function (s, lexer, lexbuf) {
        var initial = lexbuf[/* lex_curr_p */11];
        return loop((function (param) {
                      return lexer_lexbuf_to_supplier(lexer, lexbuf);
                    }), start(s, initial));
      };
      var loop_handle = function (succeed, fail, read, _checkpoint) {
        while(true) {
          var checkpoint = _checkpoint;
          if (typeof checkpoint === "number") {
            return _1(fail, checkpoint);
          } else {
            switch (checkpoint.tag | 0) {
              case /* InputNeeded */0 :
                  var triple = _1(read, /* () */0);
                  var checkpoint$1 = _1(offer(checkpoint), triple);
                  _checkpoint = checkpoint$1;
                  continue ;
              case /* Shifting */1 :
              case /* AboutToReduce */2 :
                  break;
              case /* HandlingError */3 :
                  return _1(fail, checkpoint);
              case /* Accepted */4 :
                  return _1(succeed, checkpoint[0]);
              
            }
          }
          var checkpoint$2 = resume(checkpoint);
          _checkpoint = checkpoint$2;
          continue ;
        }      };
      var loop_handle_undo = function (succeed, fail, read, checkpoint) {
        var tmp;
        tmp = typeof checkpoint === "number" || checkpoint.tag ? false : true;
        if (!tmp) {
          throw [
                assert_failure,
                /* tuple */[
                  "menhirLib.ml",
                  1670,
                  4
                ]
              ];
        }
        var succeed$1 = succeed;
        var fail$1 = fail;
        var read$1 = read;
        var _param = /* tuple */[
          checkpoint,
          checkpoint
        ];
        while(true) {
          var param = _param;
          var checkpoint$1 = param[1];
          var inputneeded = param[0];
          if (typeof checkpoint$1 === "number") {
            return _2(fail$1, inputneeded, checkpoint$1);
          } else {
            switch (checkpoint$1.tag | 0) {
              case /* InputNeeded */0 :
                  var triple = _1(read$1, /* () */0);
                  var checkpoint$2 = _1(offer(checkpoint$1), triple);
                  _param = /* tuple */[
                    checkpoint$1,
                    checkpoint$2
                  ];
                  continue ;
              case /* Shifting */1 :
              case /* AboutToReduce */2 :
                  break;
              case /* HandlingError */3 :
                  return _2(fail$1, inputneeded, checkpoint$1);
              case /* Accepted */4 :
                  return _1(succeed$1, checkpoint$1[0]);
              
            }
          }
          var checkpoint$3 = resume(checkpoint$1);
          _param = /* tuple */[
            inputneeded,
            checkpoint$3
          ];
          continue ;
        }      };
      var shifts = function (_checkpoint) {
        while(true) {
          var checkpoint = _checkpoint;
          if (typeof checkpoint === "number") {
            throw [
                  assert_failure,
                  /* tuple */[
                    "menhirLib.ml",
                    1695,
                    8
                  ]
                ];
          } else {
            switch (checkpoint.tag | 0) {
              case /* Shifting */1 :
                  return checkpoint[0];
              case /* AboutToReduce */2 :
                  _checkpoint = resume(checkpoint);
                  continue ;
              case /* HandlingError */3 :
                  return ;
              default:
                throw [
                      assert_failure,
                      /* tuple */[
                        "menhirLib.ml",
                        1695,
                        8
                      ]
                    ];
            }
          }
        }      };
      var acceptable = function (checkpoint, token, pos) {
        var triple = /* tuple */[
          token,
          pos,
          pos
        ];
        var checkpoint$1 = _1(offer(checkpoint), triple);
        return shifts(checkpoint$1) !== undefined;
      };
      var stack = function (cell, current) {
        return caml_lazy_make((function (param) {
                      var next = cell[/* next */4];
                      if (next === cell) {
                        return /* Nil */0;
                      } else {
                        var element_001 = cell[/* semv */1];
                        var element_002 = cell[/* startp */2];
                        var element_003 = cell[/* endp */3];
                        var element = /* Element */[
                          current,
                          element_001,
                          element_002,
                          element_003
                        ];
                        return /* Cons */[
                                element,
                                stack(next, cell[/* state */0])
                              ];
                      }
                    }));
      };
      var stack$1 = function (env) {
        return stack(env[/* stack */2], env[/* current */3]);
      };
      var top = function (env) {
        var cell = env[/* stack */2];
        var next = cell[/* next */4];
        if (next === cell) {
          return ;
        } else {
          return /* Element */[
                  env[/* current */3],
                  cell[/* semv */1],
                  cell[/* startp */2],
                  cell[/* endp */3]
                ];
        }
      };
      var equal = function (env1, env2) {
        if (env1[/* stack */2] === env2[/* stack */2]) {
          return _1(number, env1[/* current */3]) === _1(number, env2[/* current */3]);
        } else {
          return false;
        }
      };
      var current_state_number = function (env) {
        return _1(number, env[/* current */3]);
      };
      var positions = function (param) {
        var match = param[/* triple */1];
        return /* tuple */[
                match[1],
                match[2]
              ];
      };
      var state_has_default_reduction = function (state) {
        return _4(funarg.default_reduction, state, (function (_env, _prod) {
                      return true;
                    }), (function (_env) {
                      return false;
                    }), /* () */0);
      };
      var env_has_default_reduction = function (env) {
        return state_has_default_reduction(env[/* current */3]);
      };
      var pop = function (env) {
        var cell = env[/* stack */2];
        var next = cell[/* next */4];
        if (next === cell) {
          return ;
        } else {
          return /* record */[
                  /* error */env[/* error */0],
                  /* triple */env[/* triple */1],
                  /* stack */next,
                  /* current */cell[/* state */0]
                ];
        }
      };
      var force_reduction = function (prod, env) {
        if (_2(funarg.may_reduce, env[/* current */3], prod)) {
          if (_1(funarg.is_start, prod)) {
            throw [
                  assert_failure,
                  /* tuple */[
                    "menhirLib.ml",
                    1883,
                    6
                  ]
                ];
          }
          var stack = _2(funarg.semantic_action, prod, env);
          var current = _2(funarg.goto_prod, stack[/* state */0], prod);
          return /* record */[
                  /* error */env[/* error */0],
                  /* triple */env[/* triple */1],
                  /* stack */stack,
                  /* current */current
                ];
        } else {
          return invalid_arg("force_reduction: this reduction is not permitted in this state");
        }
      };
      var input_needed = function (env) {
        return /* InputNeeded */__(0, [env]);
      };
      var pop_many = function (_i, _env) {
        while(true) {
          var env = _env;
          var i = _i;
          if (i === 0) {
            return env;
          } else {
            var match = pop(env);
            if (match !== undefined) {
              _env = match;
              _i = i - 1 | 0;
              continue ;
            } else {
              return ;
            }
          }
        }      };
      var get = function (i, env) {
        var match = pop_many(i, env);
        if (match !== undefined) {
          return top(match);
        }
        
      };
      var let_token2terminal = funarg.token2terminal;
      var let_token2value = funarg.token2value;
      var let_error_terminal = funarg.error_terminal;
      var let_error_value = funarg.error_value;
      var let_foreach_terminal = funarg.foreach_terminal;
      var let_production_index = funarg.production_index;
      var let_find_production = funarg.find_production;
      var let_default_reduction = funarg.default_reduction;
      var let_action = funarg.action;
      var let_goto_nt = funarg.goto_nt;
      var let_goto_prod = funarg.goto_prod;
      var let_maybe_goto_nt = funarg.maybe_goto_nt;
      var let_is_start = funarg.is_start;
      var let_semantic_action = funarg.semantic_action;
      var let_may_reduce = funarg.may_reduce;
      return {
              $$Error: $$Error,
              entry: entry,
              offer: offer,
              resume: resume,
              lexer_lexbuf_to_supplier: lexer_lexbuf_to_supplier,
              loop: loop,
              loop_handle: loop_handle,
              loop_handle_undo: loop_handle_undo,
              shifts: shifts,
              acceptable: acceptable,
              number: number,
              production_index: let_production_index,
              find_production: let_find_production,
              stack: stack$1,
              top: top,
              pop_many: pop_many,
              get: get,
              current_state_number: current_state_number,
              equal: equal,
              positions: positions,
              env_has_default_reduction: env_has_default_reduction,
              state_has_default_reduction: state_has_default_reduction,
              pop: pop,
              force_reduction: force_reduction,
              input_needed: input_needed,
              start: start
            };
    })
};

function InspectionTableInterpreter_Make(funarg) {
  var $$let = function (IT) {
    return (function (ET) {
        return (function (E) {
            var read_packed_linearized = function (param, i) {
              var entry = param[1];
              var data = param[0];
              return read_row_via((function (param) {
                            return get$1(data, param);
                          }), (function (param) {
                            return get$1(entry, param);
                          }), i);
            };
            var decode_symbol = function (symbol) {
              if (symbol <= 0) {
                throw [
                      assert_failure,
                      /* tuple */[
                        "menhirLib.ml",
                        3044,
                        4
                      ]
                    ];
              }
              var kind = symbol & 1;
              var symbol$1 = (symbol >>> 1);
              if (kind === 0) {
                return _1(IT.terminal, symbol$1 - 1 | 0);
              } else {
                return _1(IT.nonterminal, symbol$1);
              }
            };
            var n2i = function (nt) {
              var answer = funarg.start + nt | 0;
              if (!caml_equal(_1(IT.nonterminal, answer), /* X */[/* N */__(1, [nt])])) {
                throw [
                      assert_failure,
                      /* tuple */[
                        "menhirLib.ml",
                        3063,
                        4
                      ]
                    ];
              }
              return answer;
            };
            var t2i = function (t) {
              if (!caml_equal(_1(IT.terminal, t), /* X */[/* T */__(0, [t])])) {
                throw [
                      assert_failure,
                      /* tuple */[
                        "menhirLib.ml",
                        3069,
                        4
                      ]
                    ];
              }
              return t;
            };
            var compare_terminals = function (t1, t2) {
              return t2i(t1) - t2i(t2) | 0;
            };
            var compare_nonterminals = function (nt1, nt2) {
              return n2i(nt1) - n2i(nt2) | 0;
            };
            var compare_symbols = function (symbol1, symbol2) {
              var match = symbol1[0];
              if (match.tag) {
                var match$1 = symbol2[0];
                if (match$1.tag) {
                  return compare_nonterminals(match[0], match$1[0]);
                } else {
                  return 1;
                }
              } else {
                var match$2 = symbol2[0];
                if (match$2.tag) {
                  return -1;
                } else {
                  return compare_terminals(match[0], match$2[0]);
                }
              }
            };
            var compare_productions = function (prod1, prod2) {
              return prod1 - prod2 | 0;
            };
            var compare_items = function (param, param$1) {
              var c = param[0] - param$1[0] | 0;
              if (c !== 0) {
                return c;
              } else {
                return param[1] - param$1[1] | 0;
              }
            };
            var incoming_symbol = function (s) {
              var core = get$1(IT.lr0_core, s);
              return decode_symbol(get$1(IT.lr0_incoming, core))[0];
            };
            var lhs = function (prod) {
              return _1(IT.nonterminal, get$1(funarg.lhs, prod));
            };
            var rhs = function (prod) {
              return map(decode_symbol, read_packed_linearized(IT.rhs, prod));
            };
            var $$export = function (t) {
              return /* tuple */[
                      (t >>> 7),
                      t % 128
                    ];
            };
            var items = function (s) {
              var core = get$1(IT.lr0_core, s);
              return map($$export, read_packed_linearized(IT.lr0_items, core));
            };
            var decode_bool = function (i) {
              if (!(i === 0 || i === 1)) {
                throw [
                      assert_failure,
                      /* tuple */[
                        "menhirLib.ml",
                        3150,
                        4
                      ]
                    ];
              }
              return i === 1;
            };
            var nullable = function (nt) {
              return decode_bool(get1(IT.nullable, n2i(nt)));
            };
            var first = function (nt, t) {
              return decode_bool(unflatten1(IT.first, n2i(nt), t2i(t)));
            };
            var xfirst = function (symbol, t) {
              var match = symbol[0];
              if (match.tag) {
                return first(match[0], t);
              } else {
                return compare_terminals(t, match[0]) === 0;
              }
            };
            var foldij = function (_i, j, f, _accu) {
              while(true) {
                var accu = _accu;
                var i = _i;
                if (i === j) {
                  return accu;
                } else {
                  _accu = _2(f, i, accu);
                  _i = i + 1 | 0;
                  continue ;
                }
              }            };
            var foreach_terminal = function (f, accu) {
              var match = funarg.error;
              return foldij(0, match[0], (function (i, accu) {
                            return _2(f, _1(IT.terminal, i), accu);
                          }), accu);
            };
            var foreach_terminal_but_error = function (f, accu) {
              var match = funarg.error;
              return foldij(0, match[0], (function (i, accu) {
                            if (i === funarg.error_terminal) {
                              return accu;
                            } else {
                              return _2(f, _1(IT.terminal, i), accu);
                            }
                          }), accu);
            };
            var feed_failure = function (param) {
              return invalid_arg("feed: outgoing transition does not exist");
            };
            var feed_nonterminal = function (nt, startp, semv, endp, env) {
              var source = env[/* current */3];
              var match = _2(ET.maybe_goto_nt, source, nt);
              if (match !== undefined) {
                var stack_004 = /* next */env[/* stack */2];
                var stack = /* record */[
                  /* state */source,
                  /* semv */semv,
                  /* startp */startp,
                  /* endp */endp,
                  stack_004
                ];
                return /* record */[
                        /* error */env[/* error */0],
                        /* triple */env[/* triple */1],
                        /* stack */stack,
                        /* current */valFromOption(match)
                      ];
              } else {
                return invalid_arg("feed: outgoing transition does not exist");
              }
            };
            var reduce = function (_env, _prod) {
              return invalid_arg("feed: outgoing transition does not exist");
            };
            var initiate = function (_env) {
              return invalid_arg("feed: outgoing transition does not exist");
            };
            var feed_terminal = function (terminal, startp, semv, endp, env) {
              var source = env[/* current */3];
              return _7(ET.action, source, terminal, semv, (function (env, _please_discard, _terminal, semv, target) {
                            var stack_004 = /* next */env[/* stack */2];
                            var stack = /* record */[
                              /* state */source,
                              /* semv */semv,
                              /* startp */startp,
                              /* endp */endp,
                              stack_004
                            ];
                            return /* record */[
                                    /* error */env[/* error */0],
                                    /* triple */env[/* triple */1],
                                    /* stack */stack,
                                    /* current */target
                                  ];
                          }), reduce, initiate, env);
            };
            var feed = function (symbol, startp, semv, endp, env) {
              if (symbol.tag) {
                return feed_nonterminal(n2i(symbol[0]), startp, semv, endp, env);
              } else {
                return feed_terminal(t2i(symbol[0]), startp, semv, endp, env);
              }
            };
            return {
                    terminal: IT.terminal,
                    nonterminal: IT.nonterminal,
                    lr0_core: IT.lr0_core,
                    lr0_items: IT.lr0_items,
                    lr0_incoming: IT.lr0_incoming,
                    read_packed_linearized: read_packed_linearized,
                    decode_symbol: decode_symbol,
                    n2i: n2i,
                    t2i: t2i,
                    compare_terminals: compare_terminals,
                    compare_nonterminals: compare_nonterminals,
                    compare_symbols: compare_symbols,
                    compare_productions: compare_productions,
                    compare_items: compare_items,
                    incoming_symbol: incoming_symbol,
                    lhs: lhs,
                    rhs: rhs,
                    $$export: $$export,
                    items: items,
                    decode_bool: decode_bool,
                    nullable: nullable,
                    first: first,
                    xfirst: xfirst,
                    foldij: foldij,
                    foreach_terminal: foreach_terminal,
                    foreach_terminal_but_error: foreach_terminal_but_error,
                    feed_failure: feed_failure,
                    feed_nonterminal: feed_nonterminal,
                    reduce: reduce,
                    initiate: initiate,
                    feed_terminal: feed_terminal,
                    feed: feed
                  };
          });
      });
  };
  return (function (funarg) {
      var $$let$1 = _1($$let, funarg);
      return (function (funarg) {
          var $$let$2 = _1($$let$1, funarg);
          return (function (funarg) {
              var $$let$3 = _1($$let$2, funarg);
              return {
                      compare_terminals: $$let$3.compare_terminals,
                      compare_nonterminals: $$let$3.compare_nonterminals,
                      compare_symbols: $$let$3.compare_symbols,
                      compare_productions: $$let$3.compare_productions,
                      compare_items: $$let$3.compare_items,
                      incoming_symbol: $$let$3.incoming_symbol,
                      items: $$let$3.items,
                      lhs: $$let$3.lhs,
                      rhs: $$let$3.rhs,
                      nullable: $$let$3.nullable,
                      first: $$let$3.first,
                      xfirst: $$let$3.xfirst,
                      foreach_terminal: $$let$3.foreach_terminal,
                      foreach_terminal_but_error: $$let$3.foreach_terminal_but_error,
                      feed: $$let$3.feed
                    };
            });
        });
    });
}

var InspectionTableInterpreter = {
  Symbols: Symbols,
  Make: InspectionTableInterpreter_Make
};

var TableInterpreter = {
  MakeEngineTable: (function (funarg) {
      var number = function (s) {
        return s;
      };
      var token2terminal = funarg.token2terminal;
      var token2value = funarg.token2value;
      var error_terminal = funarg.error_terminal;
      var foldij = function (_i, j, f, _accu) {
        while(true) {
          var accu = _accu;
          var i = _i;
          if (i === j) {
            return accu;
          } else {
            _accu = _2(f, i, accu);
            _i = i + 1 | 0;
            continue ;
          }
        }      };
      var foreach_terminal = function (f, accu) {
        var match = funarg.error;
        return foldij(0, match[0], __2(f), accu);
      };
      var non_start_production = function (i) {
        if (funarg.start <= i && (i - funarg.start | 0) < funarg.semantic_action.length) {
          return 0;
        } else {
          throw [
                assert_failure,
                /* tuple */[
                  "menhirLib.ml",
                  3341,
                  4
                ]
              ];
        }
      };
      var production_index = function (i) {
        non_start_production(i);
        return i;
      };
      var find_production = function (i) {
        non_start_production(i);
        return i;
      };
      var default_reduction = function (state, defred, nodefred, env) {
        var code = get$1(funarg.default_reduction, state);
        if (code === 0) {
          return _1(nodefred, env);
        } else {
          return _2(defred, env, code - 1 | 0);
        }
      };
      var is_start = function (prod) {
        return prod < funarg.start;
      };
      var unmarshal2 = function (table, i, j) {
        return getget(get$1, get$1, table, i, j);
      };
      var action = function (state, terminal, value, shift, reduce, fail, env) {
        var c = unflatten1(funarg.error, state, terminal);
        if (c !== 1) {
          if (c !== 0) {
            throw [
                  assert_failure,
                  /* tuple */[
                    "menhirLib.ml",
                    3387,
                    8
                  ]
                ];
          }
          return _1(fail, env);
        } else {
          var action$1 = unmarshal2(funarg.action, state, terminal);
          var opcode = action$1 & 3;
          var param = (action$1 >>> 2);
          if (opcode >= 2) {
            var please_discard = opcode === 2;
            return _5(shift, env, please_discard, terminal, value, param);
          } else {
            return _2(reduce, env, param);
          }
        }
      };
      var goto_nt = function (state, nt) {
        var code = unmarshal2(funarg.$$goto, state, nt);
        return code - 1 | 0;
      };
      var goto_prod = function (state, prod) {
        return goto_nt(state, get$1(funarg.lhs, prod));
      };
      var maybe_goto_nt = function (state, nt) {
        var code = unmarshal2(funarg.$$goto, state, nt);
        if (0 > code) {
          throw [
                assert_failure,
                /* tuple */[
                  "menhirLib.ml",
                  3402,
                  4
                ]
              ];
        }
        if (code === 0) {
          return ;
        } else {
          return code - 1 | 0;
        }
      };
      var $$Error = funarg.$$Error;
      var semantic_action = function (prod) {
        return caml_array_get(funarg.semantic_action, prod - funarg.start | 0);
      };
      var may_reduce = function (state, prod) {
        return default_reduction(state, (function (param, prod$prime) {
                      return prod === prod$prime;
                    }), (function (param) {
                      return foreach_terminal((function (t, accu) {
                                    if (accu) {
                                      return true;
                                    } else {
                                      return action(state, t, /* () */0, (function (param, param$1, param$2, param$3, param$4) {
                                                    return false;
                                                  }), (function (param, prod$prime) {
                                                    return prod === prod$prime;
                                                  }), (function (param) {
                                                    return false;
                                                  }), /* () */0);
                                    }
                                  }), false);
                    }), /* () */0);
      };
      var match = funarg.trace;
      var log = match !== undefined;
      var state = function (state$1) {
        var match = funarg.trace;
        if (match !== undefined) {
          return _1(fprintf$1(stderr$1, /* Format */[
                          /* String_literal */__(11, [
                              "State ",
                              /* Int */__(4, [
                                  /* Int_d */0,
                                  /* No_padding */0,
                                  /* No_precision */0,
                                  /* String_literal */__(11, [
                                      ":\n",
                                      /* Flush */__(10, [/* End_of_format */0])
                                    ])
                                ])
                            ]),
                          "State %d:\n%!"
                        ]), state$1);
        } else {
          return /* () */0;
        }
      };
      var shift = function (terminal, state) {
        var match = funarg.trace;
        if (match !== undefined) {
          return _2(fprintf$1(stderr$1, /* Format */[
                          /* String_literal */__(11, [
                              "Shifting (",
                              /* String */__(2, [
                                  /* No_padding */0,
                                  /* String_literal */__(11, [
                                      ") to state ",
                                      /* Int */__(4, [
                                          /* Int_d */0,
                                          /* No_padding */0,
                                          /* No_precision */0,
                                          /* Char_literal */__(12, [
                                              /* "\n" */10,
                                              /* Flush */__(10, [/* End_of_format */0])
                                            ])
                                        ])
                                    ])
                                ])
                            ]),
                          "Shifting (%s) to state %d\n%!"
                        ]), caml_array_get(match[0], terminal), state);
        } else {
          return /* () */0;
        }
      };
      var reduce_or_accept = function (prod) {
        var match = funarg.trace;
        if (match !== undefined) {
          return _1(fprintf$1(stderr$1, /* Format */[
                          /* String */__(2, [
                              /* No_padding */0,
                              /* Char_literal */__(12, [
                                  /* "\n" */10,
                                  /* Flush */__(10, [/* End_of_format */0])
                                ])
                            ]),
                          "%s\n%!"
                        ]), caml_array_get(match[1], prod));
        } else {
          return /* () */0;
        }
      };
      var lookahead_token = function (token, startp, endp) {
        var match = funarg.trace;
        if (match !== undefined) {
          return _3(fprintf$1(stderr$1, /* Format */[
                          /* String_literal */__(11, [
                              "Lookahead token is now ",
                              /* String */__(2, [
                                  /* No_padding */0,
                                  /* String_literal */__(11, [
                                      " (",
                                      /* Int */__(4, [
                                          /* Int_d */0,
                                          /* No_padding */0,
                                          /* No_precision */0,
                                          /* Char_literal */__(12, [
                                              /* "-" */45,
                                              /* Int */__(4, [
                                                  /* Int_d */0,
                                                  /* No_padding */0,
                                                  /* No_precision */0,
                                                  /* String_literal */__(11, [
                                                      ")\n",
                                                      /* Flush */__(10, [/* End_of_format */0])
                                                    ])
                                                ])
                                            ])
                                        ])
                                    ])
                                ])
                            ]),
                          "Lookahead token is now %s (%d-%d)\n%!"
                        ]), caml_array_get(match[0], token), startp[/* pos_cnum */3], endp[/* pos_cnum */3]);
        } else {
          return /* () */0;
        }
      };
      var initiating_error_handling = function (param) {
        var match = funarg.trace;
        if (match !== undefined) {
          return fprintf$1(stderr$1, /* Format */[
                      /* String_literal */__(11, [
                          "Initiating error handling\n",
                          /* Flush */__(10, [/* End_of_format */0])
                        ]),
                      "Initiating error handling\n%!"
                    ]);
        } else {
          return /* () */0;
        }
      };
      var resuming_error_handling = function (param) {
        var match = funarg.trace;
        if (match !== undefined) {
          return fprintf$1(stderr$1, /* Format */[
                      /* String_literal */__(11, [
                          "Resuming error handling\n",
                          /* Flush */__(10, [/* End_of_format */0])
                        ]),
                      "Resuming error handling\n%!"
                    ]);
        } else {
          return /* () */0;
        }
      };
      var handling_error = function (state) {
        var match = funarg.trace;
        if (match !== undefined) {
          return _1(fprintf$1(stderr$1, /* Format */[
                          /* String_literal */__(11, [
                              "Handling error in state ",
                              /* Int */__(4, [
                                  /* Int_d */0,
                                  /* No_padding */0,
                                  /* No_precision */0,
                                  /* Char_literal */__(12, [
                                      /* "\n" */10,
                                      /* Flush */__(10, [/* End_of_format */0])
                                    ])
                                ])
                            ]),
                          "Handling error in state %d\n%!"
                        ]), state);
        } else {
          return /* () */0;
        }
      };
      var Log = {
        state: state,
        shift: shift,
        reduce_or_accept: reduce_or_accept,
        lookahead_token: lookahead_token,
        initiating_error_handling: initiating_error_handling,
        resuming_error_handling: resuming_error_handling,
        handling_error: handling_error
      };
      return {
              number: number,
              token2terminal: token2terminal,
              token2value: token2value,
              error_terminal: error_terminal,
              error_value: /* () */0,
              foreach_terminal: foreach_terminal,
              production_index: production_index,
              find_production: find_production,
              default_reduction: default_reduction,
              action: action,
              goto_nt: goto_nt,
              goto_prod: goto_prod,
              maybe_goto_nt: maybe_goto_nt,
              is_start: is_start,
              $$Error: $$Error,
              semantic_action: semantic_action,
              may_reduce: may_reduce,
              log: log,
              Log: Log
            };
    })
};
/* No side effect */

function hydrate(expr) {
  return expr;
}

function dehydrate(expr) {
  return expr;
}

function from_script(scpt) {
  return scpt[/* expressions */0];
}

var pp$1 = pp_expression;

function count(expr) {
  return expr[/* count */0];
}

function command(expr) {
  return expr[/* cmd */1];
}

function payload_to_opt(param) {
  if (param) {
    return param[0];
  }
  
}

function mem(key, expr) {
  var is_matching_key = function (param) {
    if (param.tag) {
      return param[0][/* name */0] === key;
    } else {
      return false;
    }
  };
  return exists(is_matching_key, expr[/* rev_args */2]);
}

function is_resolved(key, expr) {
  var is_matching_resolved_key = function (param) {
    if (param.tag) {
      var f = param[0];
      if (f[/* name */0] !== key) {
        return false;
      } else {
        var match = f[/* payload */1];
        if (typeof match === "number") {
          return match !== 0;
        } else {
          return true;
        }
      }
    } else {
      return false;
    }
  };
  return exists(is_matching_resolved_key, expr[/* rev_args */2]);
}

function has_payload(key, expr) {
  var is_matching_resolved_key_with_payload = function (param) {
    if (param.tag) {
      var f = param[0];
      if (f[/* name */0] !== key) {
        return false;
      } else {
        var match = f[/* payload */1];
        if (typeof match === "number") {
          return false;
        } else {
          return true;
        }
      }
    } else {
      return false;
    }
  };
  return exists(is_matching_resolved_key_with_payload, expr[/* rev_args */2]);
}

function flag(key, expr) {
  var result = /* record */[/* contents */undefined];
  var iterator = function (param) {
    var prior = param[1];
    var curr = param[0];
    var match = result[0];
    if (match !== undefined) {
      return curr;
    } else if (prior !== undefined) {
      var prior$1 = prior;
      var fl;
      var exit = 0;
      if (prior$1.tag) {
        var fl$1 = prior$1[0];
        var match$1 = fl$1[/* payload */1];
        if (typeof match$1 === "number") {
          if (match$1 !== 0) {
            if (curr.tag) {
              exit = 2;
            } else {
              return curr;
            }
          } else if (curr.tag) {
            exit = 2;
          } else if (key === fl$1[/* name */0]) {
            fl$1[/* payload */1] = /* Resolved */[curr[0]];
            result[0] = fl$1;
            return ;
          } else {
            return curr;
          }
        } else if (curr.tag) {
          exit = 2;
        } else {
          return curr;
        }
      } else if (curr.tag) {
        exit = 2;
      } else {
        return curr;
      }
      if (exit === 2) {
        var fl$2 = curr[0];
        var match$2 = fl$2[/* payload */1];
        if (typeof match$2 === "number" && match$2 === 0) {
          return curr;
        } else {
          fl = fl$2;
        }
      }
      if (key === fl[/* name */0]) {
        result[0] = fl;
      }
      return curr;
    } else if (curr.tag) {
      var fl$3 = curr[0];
      if (key === fl$3[/* name */0]) {
        result[0] = fl$3;
      }
      return curr;
    } else {
      return curr;
    }
  };
  expr[/* rev_args */2] = to_list(filter_map(iterator, peek(of_list$1(expr[/* rev_args */2]))));
  var match = result[0];
  if (match !== undefined) {
    var match$1 = match[/* payload */1];
    if (typeof match$1 === "number") {
      if (match$1 !== 0) {
        return /* Empty */0;
      } else {
        return failwith("Unreachable");
      }
    } else {
      return /* Payload */[match$1[0]];
    }
  }
  
}

function flag_resolving_gen(expr) {
  var iterator = function (param) {
    var prior = param[1];
    var curr = param[0];
    if (prior !== undefined) {
      var match = prior;
      if (match.tag && !curr.tag) {
        match[0][/* payload */1] = /* Resolved */[curr[0]];
        return ;
      } else {
        return curr;
      }
    } else {
      return curr;
    }
  };
  return filter_map(iterator, peek(of_list$1(expr[/* rev_args */2])));
}

function rev_iteri(f, expr) {
  var iterator = function (i, arg) {
    if (arg.tag) {
      var flag = arg[0];
      var match = flag[/* payload */1];
      if (typeof match === "number") {
        if (match !== 0) {
          _3(f, i, flag[/* name */0], /* Empty */0);
          return arg;
        } else {
          return failwith("Unreachable");
        }
      } else {
        _3(f, i, flag[/* name */0], /* Payload */[match[0]]);
        return arg;
      }
    } else {
      return arg;
    }
  };
  expr[/* rev_args */2] = to_list(mapi(iterator)(flag_resolving_gen(expr)));
  return /* () */0;
}

function iteri$1(f, expr) {
  expr[/* rev_args */2] = to_list(flag_resolving_gen(expr));
  var iterator = function (i, param) {
    if (param.tag) {
      var flag = param[0];
      var match = flag[/* payload */1];
      if (typeof match === "number") {
        if (match !== 0) {
          return _3(f, i, flag[/* name */0], /* Empty */0);
        } else {
          return failwith("Unreachable");
        }
      } else {
        return _3(f, i, flag[/* name */0], /* Payload */[match[0]]);
      }
    } else {
      return /* () */0;
    }
  };
  return iteri(iterator, rev(expr[/* rev_args */2]));
}

function iter$2(f, expr) {
  var f$1 = function (_i, a, b) {
    return _2(f, a, b);
  };
  return iteri$1(f$1, expr);
}

function positionals(expr) {
  var iterator = function (param) {
    if (param.tag) {
      var flag = param[0];
      var match = flag[/* payload */1];
      if (typeof match === "number" && match === 0) {
        flag[/* payload */1] = /* Absent */1;
        return ;
      } else {
        return ;
      }
    } else {
      return param[0];
    }
  };
  return to_rev_list(filter_map(iterator, of_list$1(expr[/* rev_args */2])));
}

function positionals_arr(expr) {
  return of_list(positionals(expr));
}

function flags(expr) {
  var iterator = function (param) {
    if (param.tag) {
      return param[0][/* name */0];
    }
    
  };
  return to_rev_list(filter_map(iterator, of_list$1(expr[/* rev_args */2])));
}

function flags_arr(expr) {
  return of_list(flags(expr));
}
/* AST Not a pure module */

var $_Expression = /*#__PURE__*/Object.freeze({
    __proto__: null,
    count: count,
    command: command,
    mem: mem,
    is_resolved: is_resolved,
    has_payload: has_payload,
    flags: flags,
    positionals: positionals,
    iter: iter$2,
    iteri: iteri$1,
    rev_iteri: rev_iteri,
    flag: flag,
    pp: pp$1,
    hydrate: hydrate,
    from_script: from_script,
    payload_to_opt: payload_to_opt,
    flags_arr: flags_arr,
    positionals_arr: positionals_arr,
    dehydrate: dehydrate
});

var $$Error$2 = create("ParserAutomaton.MenhirBasics.Error");

function token2terminal(_tok) {
  if (typeof _tok === "number") {
    switch (_tok) {
      case /* SEMICOLON */0 :
          return 3;
      case /* PIPE */1 :
          return 8;
      case /* PAREN_OPEN */2 :
          return 9;
      case /* PAREN_CLOSE */3 :
          return 10;
      case /* FLAG_LONG_START */4 :
          return 12;
      case /* FLAGS_SHORT_START */5 :
          return 13;
      case /* EQUALS */6 :
          return 21;
      case /* EOF */7 :
          return 22;
      case /* COMMENT_OPEN */8 :
          return 24;
      case /* COMMENT_CLOSE */9 :
          return 25;
      case /* COLON */10 :
          return 27;
      case /* BARE_DOUBLE_DASH */11 :
          return 28;
      
    }
  } else {
    switch (_tok.tag | 0) {
      case /* URL_START */0 :
          return 1;
      case /* URL_REST */1 :
          return 2;
      case /* QUOTE_OPEN */2 :
          return 4;
      case /* QUOTE_ESCAPE */3 :
          return 5;
      case /* QUOTE_CLOSE */4 :
          return 6;
      case /* QUOTE_CHUNK */5 :
          return 7;
      case /* IDENTIFIER */6 :
          return 11;
      case /* ERR_UNEXPECTED_WHITESPACE */7 :
          return 14;
      case /* ERR_UNEXPECTED_QUOTE_ESCAPE */8 :
          return 15;
      case /* ERR_UNEXPECTED_QUOTE_CLOSE */9 :
          return 16;
      case /* ERR_UNEXPECTED_COMMENT_CLOSE */10 :
          return 17;
      case /* ERR_UNEXPECTED_CHARACTER */11 :
          return 18;
      case /* ERR_MISSING_DELIM_CLOSE */12 :
          return 19;
      case /* ERR_MISSING_COMMENT_CLOSE */13 :
          return 20;
      case /* COUNT */14 :
          return 23;
      case /* COMMENT */15 :
          return 26;
      
    }
  }
}

function token2value(_tok) {
  if (typeof _tok === "number") {
    return /* () */0;
  } else {
    return _tok[0];
  }
}

var default_reduction = /* tuple */[
  8,
  "\0\0\x0f\f\0\x18\0-\0\0\0\r6\b\n\x000!\x1f /\x00321.\t\0\0\x13\x12\0\x03\x04\0\x05\x06\x14\x16%\0'&5\0\0\x15\x11\0)\0*7($\0\x07\0\x0b\x1a\x01\0\x02\x1c\x004\x1b\0\x1d\0\x1e"
];

var error = /* tuple */[
  29,
  "\bP\x01\x10B\x80\b\x80\0\0\0\0\0\0\0\x85\0\x10\0\0\0\0!@\0\0\0\0\0\bP\x01\x10\x05\0\0\x02\x14\0D\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\xe0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb1\xf8\x04\x12\0\0\0\0\0\0\0\0\0\0\x01\x02\0\0\0\0\0\0\0\0\0\x02\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\xac\x02\0\0\0\0\0\0\0\0\0\0\0\x05\x8f\xc0`\xa4(\0\x04\0\0\0\0\0\0\0X\xfc\x02\b\0\0\0\x16?\0\x82\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x10\0@\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\f(\x01\x88\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0!\0\x04\0\0\0\0\x04(\x01\x88\0\0\0\0"
];

var action = /* tuple */[
  /* tuple */[
    8,
    "\x96\x96\0\0\xce\0j\0\x96\t\x96\0\0\0\0\x12\0\0\0\0\0>\0\0\0\0\0*\x03\0\0\x1e\0\0J\0\0\0\0\0\xba\0\0\0\x03*\0\0V\0\x82\0\0\0\0(\0#\0\0\0\x9a\0\0\x0b\0\0(\0\x96\0"
  ],
  /* tuple */[
    16,
    "\0=\0v\0=\0=\0*\0\xeb\x002\0=\0=\0=\0=\0=\0=\0B\0F\0J\0N\x01\x07\0\0\0\x1e\0\xb6\0=\0r\0\xe2\0\x85\0\x1e\0\x82\0=\0*\0\x85\0\"\0\x85\0z\0~\0\x8a\0B\0F\0Z\0N\0\0\0\0\0\x1e\0a\0\x85\0r\0\0\0\xad\0\x1e\0\x8e\0\x96\0\0\0\xad\0\"\0\xad\0z\0\xad\0\xad\0\x1e\0\0\0\0\0\0\0\0\0\"\0\0\x006\0\xad\0r\0\0\0\xa9\0\x1e\0\0\0\x96\0\0\0\xa9\0\"\0\xa9\0z\0\xa9\0\xa9\x005\0\xe2\x005\0\0\0\0\x005\0\0\x005\0\xa9\x005\0\0\0\0\0\0\0\0\0\x96\0\0\0\0\0\x89\0e\x005\0a\x005\0\x89\0\x06\0\x89\0\x06\0~\0\x8a\0Y\0\0\0\0\0\0\0\0\0Y\0\0\0Y\0\x89\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x16"
  ]
];

var lhs = /* tuple */[
  8,
  "\x01\0\x1b\x1b\x1a\x1a\x19\x18\x18\x18\x17\x16\x16\x15\x15\x14\x14\x13\x13\x13\x13\x13\x12\x12\x11\x11\x10\x10\x0f\x0f\x0e\r\r\f\f\x0b\x0b\x0b\x0b\n\n\n\t\t\b\b\b\x07\x07\x07\x06\x05\x04\x03\x02"
];

var $$goto = /* tuple */[
  /* tuple */[
    8,
    " \x0e\0\0\x18\x004\0\0\0\x18\0\0\0\0\x07\0\0\0\0\0n\0\0\0\0\0\x07\0\0\0\n\0\0J\0\0\0\0\0 \0\0\0\0L\0\0R\0Z\0\0\0\0R\0\0\0\0\0\x14\0\0\0\0\0\\\0h\0"
  ],
  /* tuple */[
    8,
    "'(\x04\x15\x16\x10)135\x1a/\x04\x10\f?67\x04\"*\x05\n,-@AC\x03\x0f\x07\x05D\x05\x10<+\x058=\x1b',-'\x10\x10\0'\x10\x1c%/\x10\x04/\x000:/2\x18\x16E4\0<G\x19\0\0F\0\x05D"
  ]
];

var semantic_action = /* array */[
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : () */0,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Sub */__(0, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */match[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      var _v = pipe_last(match[/* semv */1], _menhir_stack[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv : [] */0,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = match[/* semv */1];
      var _v_001 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Flag */__(1, [/* record */[
            /* name */_menhir_stack[/* semv */1],
            /* payload : Absent */1
          ]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      var _v = /* Flag */__(1, [/* record */[
            /* name */match[/* semv */1],
            /* payload : Resolved */[_menhir_stack[/* semv */1]]
          ]]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = /* Literal */__(1, [match[/* semv */1] + _menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : Literal */__(1, ["--"]),
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Sub */__(0, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv */undefined,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = _menhir_stack[/* semv */1];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv */undefined,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = _menhir_stack[/* semv */1];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : [] */0,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      var _v_000 = match[/* semv */1];
      var _v_001 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = concat("", rev(match[/* semv */1]));
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv : [] */0,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = rev(_menhir_stack[/* semv */1]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = rev_append(_menhir_stack[/* semv */1], match[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v_000 = /* Positional */__(0, [_menhir_stack[/* semv */1]]);
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = /* Positional */__(0, [_menhir_stack[/* semv */1]]);
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var xs = match[/* semv */1];
      var pos = /* Positional */__(0, [_menhir_stack[/* semv */1]]);
      var _v;
      if (xs) {
        var arg = xs[0];
        if (arg.tag) {
          var flag = arg[0];
          var match$1 = flag[/* payload */1];
          _v = typeof match$1 === "number" ? (
              match$1 !== 0 ? /* :: */[
                  pos,
                  /* :: */[
                    /* Flag */__(1, [/* record */[
                          /* name */flag[/* name */0],
                          /* payload : Unresolved */0
                        ]]),
                    xs[1]
                  ]
                ] : failwith("unreachable: rev_arguments_and_positional, unresolved")
            ) : /* :: */[
              pos,
              xs
            ];
        } else {
          _v = failwith("unreachable: rev_arguments_and_positional, positional");
        }
      } else {
        _v = failwith("unreachable: rev_arguments_and_positional, empty xs");
      }
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : [] */0,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = $at(_menhir_stack[/* semv */1], match[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = $at(_menhir_stack[/* semv */1], match[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = /* record */[/* expressions */of_list(match[/* semv */1])];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var explode = function (str) {
        var last = str.length - 1 | 0;
        if (str === "") {
          return /* [] */0;
        } else {
          return /* :: */[
                  make$1(1, get(str, 0)),
                  explode(sub$2(str, 1, last))
                ];
        }
      };
      var xs = explode(_menhir_stack[/* semv */1]);
      var _v = map((function (x) {
              return /* Flag */__(1, [/* record */[
                          /* name */x,
                          /* payload : Absent */1
                        ]]);
            }), xs);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var match$1 = match[/* next */4];
      return /* record */[
              /* state */match$1[/* state */0],
              /* semv */match[/* semv */1],
              /* startp */match$1[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match$1[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var match$1 = match[/* next */4];
      var match$2 = match$1[/* next */4];
      var _v = make_expression(match$1[/* semv */1], match[/* semv */1], _menhir_stack[/* semv */1]);
      return /* record */[
              /* state */match$2[/* state */0],
              /* semv */_v,
              /* startp */match$2[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match$2[/* next */4]
            ];
    })
];

var ET = TableInterpreter.MakeEngineTable({
      token2terminal: token2terminal,
      error_terminal: 0,
      token2value: token2value,
      default_reduction: default_reduction,
      error: error,
      action: action,
      lhs: lhs,
      $$goto: $$goto,
      start: 2,
      semantic_action: semantic_action,
      $$Error: $$Error$2,
      trace: undefined
    });

var TI = Engine.Make(ET);

var entry = TI.entry;

var start$2 = TI.start;

var Symbols$1 = { };

InspectionTableInterpreter.Symbols(Symbols$1);

function terminal(t) {
  switch (t) {
    case 0 :
        return /* X */[/* T */__(0, [/* T_error */0])];
    case 1 :
        return /* X */[/* T */__(0, [/* T_URL_START */1])];
    case 2 :
        return /* X */[/* T */__(0, [/* T_URL_REST */2])];
    case 3 :
        return /* X */[/* T */__(0, [/* T_SEMICOLON */3])];
    case 4 :
        return /* X */[/* T */__(0, [/* T_QUOTE_OPEN */4])];
    case 5 :
        return /* X */[/* T */__(0, [/* T_QUOTE_ESCAPE */5])];
    case 6 :
        return /* X */[/* T */__(0, [/* T_QUOTE_CLOSE */6])];
    case 7 :
        return /* X */[/* T */__(0, [/* T_QUOTE_CHUNK */7])];
    case 8 :
        return /* X */[/* T */__(0, [/* T_PIPE */8])];
    case 9 :
        return /* X */[/* T */__(0, [/* T_PAREN_OPEN */9])];
    case 10 :
        return /* X */[/* T */__(0, [/* T_PAREN_CLOSE */10])];
    case 11 :
        return /* X */[/* T */__(0, [/* T_IDENTIFIER */11])];
    case 12 :
        return /* X */[/* T */__(0, [/* T_FLAG_LONG_START */12])];
    case 13 :
        return /* X */[/* T */__(0, [/* T_FLAGS_SHORT_START */13])];
    case 14 :
        return /* X */[/* T */__(0, [/* T_ERR_UNEXPECTED_WHITESPACE */14])];
    case 15 :
        return /* X */[/* T */__(0, [/* T_ERR_UNEXPECTED_QUOTE_ESCAPE */15])];
    case 16 :
        return /* X */[/* T */__(0, [/* T_ERR_UNEXPECTED_QUOTE_CLOSE */16])];
    case 17 :
        return /* X */[/* T */__(0, [/* T_ERR_UNEXPECTED_COMMENT_CLOSE */17])];
    case 18 :
        return /* X */[/* T */__(0, [/* T_ERR_UNEXPECTED_CHARACTER */18])];
    case 19 :
        return /* X */[/* T */__(0, [/* T_ERR_MISSING_DELIM_CLOSE */19])];
    case 20 :
        return /* X */[/* T */__(0, [/* T_ERR_MISSING_COMMENT_CLOSE */20])];
    case 21 :
        return /* X */[/* T */__(0, [/* T_EQUALS */21])];
    case 22 :
        return /* X */[/* T */__(0, [/* T_EOF */22])];
    case 23 :
        return /* X */[/* T */__(0, [/* T_COUNT */23])];
    case 24 :
        return /* X */[/* T */__(0, [/* T_COMMENT_OPEN */24])];
    case 25 :
        return /* X */[/* T */__(0, [/* T_COMMENT_CLOSE */25])];
    case 26 :
        return /* X */[/* T */__(0, [/* T_COMMENT */26])];
    case 27 :
        return /* X */[/* T */__(0, [/* T_COLON */27])];
    case 28 :
        return /* X */[/* T */__(0, [/* T_BARE_DOUBLE_DASH */28])];
    default:
      throw [
            assert_failure,
            /* tuple */[
              "parserAutomaton.ml",
              2416,
              12
            ]
          ];
  }
}

function nonterminal(nt) {
  switch (nt) {
    case 2 :
        return /* X */[/* N */__(1, [/* N_unterminated_expression */0])];
    case 3 :
        return /* X */[/* N */__(1, [/* N_subexpression */1])];
    case 4 :
        return /* X */[/* N */__(1, [/* N_short_flags */2])];
    case 5 :
        return /* X */[/* N */__(1, [/* N_script */3])];
    case 6 :
        return /* X */[/* N */__(1, [/* N_rev_subquotation */4])];
    case 7 :
        return /* X */[/* N */__(1, [/* N_rev_nonempty_subquotation */5])];
    case 8 :
        return /* X */[/* N */__(1, [/* N_rev_nonempty_quotation */6])];
    case 9 :
        return /* X */[/* N */__(1, [/* N_rev_arguments_nonempty */7])];
    case 10 :
        return /* X */[/* N */__(1, [/* N_rev_arguments_and_positional */8])];
    case 11 :
        return /* X */[/* N */__(1, [/* N_rev_arguments_and_flag */9])];
    case 12 :
        return /* X */[/* N */__(1, [/* N_rev_arguments */10])];
    case 13 :
        return /* X */[/* N */__(1, [/* N_quotation_chunk */11])];
    case 14 :
        return /* X */[/* N */__(1, [/* N_quotation */12])];
    case 15 :
        return /* X */[/* N */__(1, [/* N_optterm_nonempty_list_break_expression_chain_ */13])];
    case 16 :
        return /* X */[/* N */__(1, [/* N_optterm_list_break_expression_chain_ */14])];
    case 17 :
        return /* X */[/* N */__(1, [/* N_option_break_ */15])];
    case 18 :
        return /* X */[/* N */__(1, [/* N_option_COUNT_ */16])];
    case 19 :
        return /* X */[/* N */__(1, [/* N_noncommand_word */17])];
    case 20 :
        return /* X */[/* N */__(1, [/* N_long_flag */18])];
    case 21 :
        return /* X */[/* N */__(1, [/* N_list_COLON_ */19])];
    case 22 :
        return /* X */[/* N */__(1, [/* N_expression_chain */20])];
    case 23 :
        return /* X */[/* N */__(1, [/* N_expression */21])];
    case 24 :
        return /* X */[/* N */__(1, [/* N_command */22])];
    case 25 :
        return /* X */[/* N */__(1, [/* N_break */23])];
    case 26 :
        return /* X */[/* N */__(1, [/* N__flags_short */24])];
    case 27 :
        return /* X */[/* N */__(1, [/* N__flag_long */25])];
    default:
      throw [
            assert_failure,
            /* tuple */[
              "parserAutomaton.ml",
              2474,
              12
            ]
          ];
  }
}

var include = InspectionTableInterpreter.Make({
            token2terminal: token2terminal,
            error_terminal: 0,
            token2value: token2value,
            default_reduction: default_reduction,
            error: error,
            action: action,
            lhs: lhs,
            $$goto: $$goto,
            start: 2,
            semantic_action: semantic_action,
            $$Error: $$Error$2,
            trace: undefined
          })({
          terminal: terminal,
          nonterminal: nonterminal,
          rhs: /* tuple */[
            /* tuple */[
              8,
              "/\x0b\x1a\x18\x1a\x1d\x1c\x18\x1c\x1d\b\x18\x1d\x07-#.\x05-\x12\x058+77,'\x18\x04\x06:\x1d\x0703#\x1f-#-3\x1f\x11\x0e\x10\f\x13)\t\x13)\x13\t'\x15'\x17'\x17\x15\n\x11\x1b\x11\r\n\x0f\x1b\x0f\r\x0f\x0e!.5\x14-\x16+%1\x19"
            ],
            /* tuple */[
              8,
              "\0\x01\x02\x04\x06\b\n\x0b\f\r\x0e\x11\x12\x15\x15\x17\x18\x1b\x1c\x1e\x1f !!\"\"#$%'*,-../013568:;<=?ABDFHJKNR"
            ]
          ],
          lr0_core: /* tuple */[
            8,
            "\0\x01\x02\x03\x04\x05\x06\x07\b\t\n\x0b\f\r\x0e\x0f\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x1f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEF"
          ],
          lr0_items: /* tuple */[
            /* tuple */[
              16,
              "\0\0\x07\x01\x07\x02\x05\x81\x1b\x01\x0b\x81\x1b\x02\x16\x01\x1a\x81\x1a\x82\x06\x01\x06\x02\x06\x03\x1a\x83\x03\x81\x04\x81\x17\x01\x16\x81\x0f\x01\x17\x81\x10\x01\x0f\x02\x0f\x81\x17\x02\x19\x01\x18\x81\x18\x01\x19\x02\x18\x82\x18\x02\x16\x82\x04\x01\x1b\x03\t\x01\t\x02\b\x81\x01\x81\x01\x01\x01\x02\x01\x82\x02\x81\x02\x01\x02\x02\x02\x82\t\x81\n\x81\x12\x01\x13\x01\x12\x81\x11\x01\x13\x02\x12\x82\x1a\x01\b\x01\x07\x81\b\x02\n\x01\b\x03\x15\x81\x14\x01\x14\x02\x15\x01\x14\x81\x14\x82\x1b\x04\x13\x81\x11\x81\x06\x01\x05\x01\x03\x01\x05\x02\x05\x03\f\x81\0\x01\0\x80\0\x81\r\x81\x19\x81\x19\x82\r\x01\x0e\x81\x0e\x01\x06\x01\x0e\x02\x0e\x82\f\x81\x0e\x83"
            ],
            /* tuple */[
              8,
              "\0\x01\x02\x03\x04\x05\x06\x07\b\t\x0b\f\r\x0e\x0f\x10\x13\x14\x15\x16\x17\x18\x1b\x1c\x1d\x1e\x1f !\"#$&'(*+,-./2345789:<=?@ABCEFGHIJKLMNOPSTVW"
            ]
          ],
          lr0_incoming: /* tuple */[
            8,
            "\x008+\x05+0%\n\x14-\x12\x05\x16\x18\x07\x11\n\f\x0e\x10\r\x0f\x0e\r\x1b\x1b\x1d1\x04\x06\x18\x1a\x18\x1d\x1c\x18\x1d:\x07\t\x13\t)57,\x1d'\x15'\x17'\x19')-\b#.3/\0\x0b\x1f!.#-#3\x1f"
          ],
          nullable: "\0\b\xe4\0",
          first: /* tuple */[
            29,
            "\x18P\x03\x10B\x80\b\x82\x14\0D\0\x80\0\0\0@\0\f(\x01\x88 \0\0\x01\0\0\0\b\0\0\x02B\xe0\0R\x17\0\x02\x90\xb8\0\x14\x85\xc0\0\x82\x80\0\0 \0\0\x01\n\0\"\x18P\x01\x10\x80\0\0\0\0\0@\x90\xa0\0\x10\0\x80\0\0\0\0\b!@\x04A\n\0\"\bP\0\0\x80\0\0\0\x01\0\0\0\x10\0\0"
          ]
        })(ET)({ });

function script(lexer, lexbuf) {
  return _3(entry, 61, lexer, lexbuf);
}

function expression(lexer, lexbuf) {
  return _3(entry, 0, lexer, lexbuf);
}

function script$1(initial_position) {
  return _2(start$2, 61, initial_position);
}

function expression$1(initial_position) {
  return _2(start$2, 0, initial_position);
}

var Incremental = {
  script: script$1,
  expression: expression$1
};

var MenhirInterpreter_offer = TI.offer;

var MenhirInterpreter_resume = TI.resume;

var MenhirInterpreter_lexer_lexbuf_to_supplier = TI.lexer_lexbuf_to_supplier;

var MenhirInterpreter_loop = TI.loop;

var MenhirInterpreter_loop_handle = TI.loop_handle;

var MenhirInterpreter_loop_handle_undo = TI.loop_handle_undo;

var MenhirInterpreter_shifts = TI.shifts;

var MenhirInterpreter_acceptable = TI.acceptable;

var MenhirInterpreter_number = TI.number;

var MenhirInterpreter_production_index = TI.production_index;

var MenhirInterpreter_find_production = TI.find_production;

var MenhirInterpreter_stack = TI.stack;

var MenhirInterpreter_top = TI.top;

var MenhirInterpreter_pop_many = TI.pop_many;

var MenhirInterpreter_get = TI.get;

var MenhirInterpreter_current_state_number = TI.current_state_number;

var MenhirInterpreter_equal = TI.equal;

var MenhirInterpreter_positions = TI.positions;

var MenhirInterpreter_env_has_default_reduction = TI.env_has_default_reduction;

var MenhirInterpreter_state_has_default_reduction = TI.state_has_default_reduction;

var MenhirInterpreter_pop = TI.pop;

var MenhirInterpreter_force_reduction = TI.force_reduction;

var MenhirInterpreter_input_needed = TI.input_needed;

var MenhirInterpreter_compare_terminals = include.compare_terminals;

var MenhirInterpreter_compare_nonterminals = include.compare_nonterminals;

var MenhirInterpreter_compare_symbols = include.compare_symbols;

var MenhirInterpreter_compare_productions = include.compare_productions;

var MenhirInterpreter_compare_items = include.compare_items;

var MenhirInterpreter_incoming_symbol = include.incoming_symbol;

var MenhirInterpreter_items = include.items;

var MenhirInterpreter_lhs = include.lhs;

var MenhirInterpreter_rhs = include.rhs;

var MenhirInterpreter_nullable = include.nullable;

var MenhirInterpreter_first = include.first;

var MenhirInterpreter_xfirst = include.xfirst;

var MenhirInterpreter_foreach_terminal = include.foreach_terminal;

var MenhirInterpreter_foreach_terminal_but_error = include.foreach_terminal_but_error;

var MenhirInterpreter_feed = include.feed;

var MenhirInterpreter = {
  offer: MenhirInterpreter_offer,
  resume: MenhirInterpreter_resume,
  lexer_lexbuf_to_supplier: MenhirInterpreter_lexer_lexbuf_to_supplier,
  loop: MenhirInterpreter_loop,
  loop_handle: MenhirInterpreter_loop_handle,
  loop_handle_undo: MenhirInterpreter_loop_handle_undo,
  shifts: MenhirInterpreter_shifts,
  acceptable: MenhirInterpreter_acceptable,
  number: MenhirInterpreter_number,
  production_index: MenhirInterpreter_production_index,
  find_production: MenhirInterpreter_find_production,
  stack: MenhirInterpreter_stack,
  top: MenhirInterpreter_top,
  pop_many: MenhirInterpreter_pop_many,
  get: MenhirInterpreter_get,
  current_state_number: MenhirInterpreter_current_state_number,
  equal: MenhirInterpreter_equal,
  positions: MenhirInterpreter_positions,
  env_has_default_reduction: MenhirInterpreter_env_has_default_reduction,
  state_has_default_reduction: MenhirInterpreter_state_has_default_reduction,
  pop: MenhirInterpreter_pop,
  force_reduction: MenhirInterpreter_force_reduction,
  input_needed: MenhirInterpreter_input_needed,
  compare_terminals: MenhirInterpreter_compare_terminals,
  compare_nonterminals: MenhirInterpreter_compare_nonterminals,
  compare_symbols: MenhirInterpreter_compare_symbols,
  compare_productions: MenhirInterpreter_compare_productions,
  compare_items: MenhirInterpreter_compare_items,
  incoming_symbol: MenhirInterpreter_incoming_symbol,
  items: MenhirInterpreter_items,
  lhs: MenhirInterpreter_lhs,
  rhs: MenhirInterpreter_rhs,
  nullable: MenhirInterpreter_nullable,
  first: MenhirInterpreter_first,
  xfirst: MenhirInterpreter_xfirst,
  foreach_terminal: MenhirInterpreter_foreach_terminal,
  foreach_terminal_but_error: MenhirInterpreter_foreach_terminal_but_error,
  feed: MenhirInterpreter_feed
};
/* ET Not a pure module */

var ParseError = create("Parser.ParseError");

function error_loctoken_exn(param) {
  if (param[0] === ParseError) {
    return param[1];
  } else {
    throw [
          invalid_argument,
          "error_loctoken_exn: expects a ParseError"
        ];
  }
}

function parse($staropt$star, buf, p) {
  var exn = $staropt$star !== undefined ? $staropt$star : true;
  var parser = _1(Convert.Simplified.traditional2revised, p);
  var last_token = /* record */[/* contents : tuple */[
      /* EOF */7,
      dummy_pos,
      dummy_pos
    ]];
  var next_token = function (param) {
    var tok = next_loc(buf);
    last_token[0] = tok;
    return tok;
  };
  try {
    return some(_1(parser, next_token));
  }
  catch (raw_exn){
    var exn$1 = internalToOCamlException(raw_exn);
    if (exn$1[0] === LexError) {
      if (exn) {
        throw [
              LexError,
              exn$1[1],
              exn$1[2]
            ];
      } else {
        return ;
      }
    } else if (exn$1 === $$Error$2) {
      if (exn) {
        throw [
              ParseError,
              last_token[0]
            ];
      } else {
        return ;
      }
    } else {
      throw exn$1;
    }
  }
}

function parse_string(exn, s, p) {
  return parse(exn, buffer_of_string(s), p);
}

function script$2(exn, buf) {
  return parse(exn, buf, script);
}

function script_of_string(exn, str) {
  return parse_string(exn, str, script);
}

function expression$2(exn, buf) {
  var match = parse(exn, buf, expression);
  if (match !== undefined) {
    return some(dehydrate(match));
  }
  
}

function expression_of_string(exn, str) {
  var match = parse_string(exn, str, expression);
  if (match !== undefined) {
    return some(dehydrate(match));
  }
  
}

var script_automaton = script;

var expression_automaton = expression;
/* Lexer Not a pure module */

var $_Parser = /*#__PURE__*/Object.freeze({
    __proto__: null,
    ParseError: ParseError,
    error_loctoken_exn: error_loctoken_exn,
    script: script$2,
    script_of_string: script_of_string,
    expression: expression$2,
    expression_of_string: expression_of_string,
    script_automaton: script_automaton,
    expression_automaton: expression_automaton,
    parse: parse,
    parse_string: parse_string
});

function script$3(buf) {
  var match = lexing_positions(sedlex_of_buffer(buf));
  return /* record */[
          /* status */Incremental.script(match[1]),
          /* buf */buf
        ];
}

function script_of_string$1(s) {
  var buf = buffer_of_string(s);
  var match = lexing_positions(sedlex_of_buffer(buf));
  return /* record */[
          /* status */Incremental.script(match[1]),
          /* buf */buf
        ];
}

function expression$3(buf) {
  var match = lexing_positions(sedlex_of_buffer(buf));
  return /* record */[
          /* status */Incremental.expression(match[1]),
          /* buf */buf
        ];
}

function expression_of_string$1(s) {
  var buf = buffer_of_string(s);
  var match = lexing_positions(sedlex_of_buffer(buf));
  return /* record */[
          /* status */Incremental.expression(match[1]),
          /* buf */buf
        ];
}

var Break$1 = create("Incremental.Break");

function acceptable_token(cp) {
  var cp$1 = cp[/* status */0];
  var len = example_tokens.length;
  var accepted_token = undefined;
  try {
    for(var i = 0; i <= len; ++i){
      var tok = caml_array_get(example_tokens, i);
      if (_3(MenhirInterpreter.acceptable, cp$1, tok, dummy_pos)) {
        accepted_token = tok;
      }
      throw Break$1;
    }
  }
  catch (exn){
    if (exn !== Break$1) {
      throw exn;
    }
    
  }
  var match = accepted_token;
  if (match !== undefined) {
    return match;
  } else {
    throw not_found;
  }
}

function acceptable_tokens(cp) {
  var cp$1 = cp[/* status */0];
  var accepted_tokens = /* record */[/* contents : [] */0];
  iter$1((function (tok) {
          if (_3(MenhirInterpreter.acceptable, cp$1, tok, dummy_pos)) {
            accepted_tokens[0] = /* :: */[
              tok,
              accepted_tokens[0]
            ];
            return /* () */0;
          } else {
            return 0;
          }
        }), example_tokens);
  return of_list(accepted_tokens[0]);
}

function $$continue(accept, fail, cp) {
  var buf = cp[/* buf */1];
  var last_token = /* record */[/* contents : tuple */[
      /* EOF */7,
      dummy_pos,
      dummy_pos
    ]];
  var supplier = function (param) {
    last_token[0] = next_loc(buf);
    return last_token[0];
  };
  var fail$1 = function (cp1, cp2) {
    return _2(fail, /* record */[
                /* status */cp1,
                /* buf */buf
              ], /* record */[
                /* status */cp2,
                /* buf */buf
              ]);
  };
  return _4(MenhirInterpreter.loop_handle_undo, accept, fail$1, supplier, cp[/* status */0]);
}

function current_command(cp) {
  var menhir_cp = cp[/* status */0];
  if (typeof menhir_cp === "number" || menhir_cp.tag) {
    return ;
  } else {
    var env = menhir_cp[0];
    var _i = 0;
    while(true) {
      var i = _i;
      var match = _2(MenhirInterpreter.get, i, env);
      if (match !== undefined) {
        var match$1 = match;
        var match$2 = _1(MenhirInterpreter.incoming_symbol, match$1[0]);
        if (match$2.tag) {
          if (match$2[0] !== 22) {
            _i = i + 1 | 0;
            continue ;
          } else {
            return match$1[1];
          }
        } else {
          _i = i + 1 | 0;
          continue ;
        }
      } else {
        return ;
      }
    }  }
}

function automaton_status_str(cp) {
  var tmp = cp[/* status */0];
  if (typeof tmp === "number") {
    return "Rejected";
  } else {
    switch (tmp.tag | 0) {
      case /* InputNeeded */0 :
          return "InputNeeded";
      case /* Shifting */1 :
          return "Shifting";
      case /* AboutToReduce */2 :
          return "AboutToReduce";
      case /* HandlingError */3 :
          return "HandlingError";
      case /* Accepted */4 :
          return "Accepted";
      
    }
  }
}

function element_incoming_symbol_category_str(param) {
  var match = _1(MenhirInterpreter.incoming_symbol, param[0]);
  if (match.tag) {
    return "Nonterminal";
  } else {
    return "Terminal";
  }
}

function incoming_symbol_category_str(cp) {
  var cp$1 = cp[/* status */0];
  var the_env;
  the_env = typeof cp$1 === "number" ? failwith("incoming_symbol_category: I don't know how to handle Rejected checkpoints") : (
      cp$1.tag === /* Accepted */4 ? failwith("incoming_symbol_category: I don't know how to handle Accepted checkpoints") : cp$1[0]
    );
  var match = _1(MenhirInterpreter.top, the_env);
  if (match !== undefined) {
    return element_incoming_symbol_category_str(match);
  }
  
}

function element_incoming_symbol_desc(param) {
  var match = _1(MenhirInterpreter.incoming_symbol, param[0]);
  if (match.tag) {
    switch (match[0]) {
      case /* N_unterminated_expression */0 :
          return /* tuple */[
                  "unterminated_expression",
                  "AST.expression"
                ];
      case /* N_subexpression */1 :
          return /* tuple */[
                  "subexpression",
                  "AST.expression"
                ];
      case /* N_short_flags */2 :
          return /* tuple */[
                  "short_flags",
                  "AST.arg list"
                ];
      case /* N_script */3 :
          return /* tuple */[
                  "script",
                  "AST.t"
                ];
      case /* N_rev_subquotation */4 :
          return /* tuple */[
                  "rev_subquotation",
                  "string list"
                ];
      case /* N_rev_nonempty_subquotation */5 :
          return /* tuple */[
                  "rev_nonempty_subquotation",
                  "string list"
                ];
      case /* N_rev_nonempty_quotation */6 :
          return /* tuple */[
                  "rev_nonempty_quotation",
                  "string list"
                ];
      case /* N_rev_arguments_nonempty */7 :
          return /* tuple */[
                  "rev_arguments_nonempty",
                  "AST.arg list"
                ];
      case /* N_rev_arguments_and_positional */8 :
          return /* tuple */[
                  "rev_arguments_and_positional",
                  "AST.arg list"
                ];
      case /* N_rev_arguments_and_flag */9 :
          return /* tuple */[
                  "rev_arguments_and_flag",
                  "AST.arg list"
                ];
      case /* N_rev_arguments */10 :
          return /* tuple */[
                  "rev_arguments",
                  "AST.arg list"
                ];
      case /* N_quotation_chunk */11 :
          return /* tuple */[
                  "quotation_chunk",
                  "string"
                ];
      case /* N_quotation */12 :
          return /* tuple */[
                  "quotation",
                  "string"
                ];
      case /* N_optterm_nonempty_list_break_expression_chain_ */13 :
          return /* tuple */[
                  "optterm_nonempty_list_break_expression_chain_",
                  "AST.expression list"
                ];
      case /* N_optterm_list_break_expression_chain_ */14 :
          return /* tuple */[
                  "optterm_list_break_expression_chain_",
                  "AST.expression list"
                ];
      case /* N_option_break_ */15 :
          return /* tuple */[
                  "option_break_",
                  "unit option"
                ];
      case /* N_option_COUNT_ */16 :
          return /* tuple */[
                  "option_COUNT_",
                  "string option"
                ];
      case /* N_noncommand_word */17 :
          return /* tuple */[
                  "noncommand_word",
                  "string AST.or_subexpr"
                ];
      case /* N_long_flag */18 :
          return /* tuple */[
                  "long_flag",
                  "AST.arg"
                ];
      case /* N_list_COLON_ */19 :
          return /* tuple */[
                  "list_COLON_",
                  "unit list"
                ];
      case /* N_expression_chain */20 :
          return /* tuple */[
                  "expression_chain",
                  "AST.expression"
                ];
      case /* N_expression */21 :
          return /* tuple */[
                  "expression",
                  "AST.expression"
                ];
      case /* N_command */22 :
          return /* tuple */[
                  "command",
                  "string AST.or_subexpr"
                ];
      case /* N_break */23 :
          return /* tuple */[
                  "break",
                  "unit"
                ];
      case /* N__flags_short */24 :
          return /* tuple */[
                  "_flags_short",
                  "string"
                ];
      case /* N__flag_long */25 :
          return /* tuple */[
                  "_flag_long",
                  "string"
                ];
      
    }
  } else {
    switch (match[0]) {
      case /* T_error */0 :
          return /* tuple */[
                  "error",
                  "unit"
                ];
      case /* T_URL_START */1 :
          return /* tuple */[
                  "URL_START",
                  "string"
                ];
      case /* T_URL_REST */2 :
          return /* tuple */[
                  "URL_REST",
                  "string"
                ];
      case /* T_SEMICOLON */3 :
          return /* tuple */[
                  "SEMICOLON",
                  "unit"
                ];
      case /* T_QUOTE_OPEN */4 :
          return /* tuple */[
                  "QUOTE_OPEN",
                  "string"
                ];
      case /* T_QUOTE_ESCAPE */5 :
          return /* tuple */[
                  "QUOTE_ESCAPE",
                  "string"
                ];
      case /* T_QUOTE_CLOSE */6 :
          return /* tuple */[
                  "QUOTE_CLOSE",
                  "string"
                ];
      case /* T_QUOTE_CHUNK */7 :
          return /* tuple */[
                  "QUOTE_CHUNK",
                  "string"
                ];
      case /* T_PIPE */8 :
          return /* tuple */[
                  "PIPE",
                  "unit"
                ];
      case /* T_PAREN_OPEN */9 :
          return /* tuple */[
                  "PAREN_OPEN",
                  "unit"
                ];
      case /* T_PAREN_CLOSE */10 :
          return /* tuple */[
                  "PAREN_CLOSE",
                  "unit"
                ];
      case /* T_IDENTIFIER */11 :
          return /* tuple */[
                  "IDENTIFIER",
                  "string"
                ];
      case /* T_FLAG_LONG_START */12 :
          return /* tuple */[
                  "FLAG_LONG_START",
                  "string"
                ];
      case /* T_FLAGS_SHORT_START */13 :
          return /* tuple */[
                  "FLAGS_SHORT_START",
                  "string"
                ];
      case /* T_ERR_UNEXPECTED_WHITESPACE */14 :
          return /* tuple */[
                  "ERR_UNEXPECTED_WHITESPACE",
                  "string"
                ];
      case /* T_ERR_UNEXPECTED_QUOTE_ESCAPE */15 :
          return /* tuple */[
                  "ERR_UNEXPECTED_QUOTE_ESCAPE",
                  "string * string"
                ];
      case /* T_ERR_UNEXPECTED_QUOTE_CLOSE */16 :
          return /* tuple */[
                  "ERR_UNEXPECTED_QUOTE_CLOSE",
                  "string * string"
                ];
      case /* T_ERR_UNEXPECTED_COMMENT_CLOSE */17 :
          return /* tuple */[
                  "ERR_UNEXPECTED_COMMENT_CLOSE",
                  "string"
                ];
      case /* T_ERR_UNEXPECTED_CHARACTER */18 :
          return /* tuple */[
                  "ERR_UNEXPECTED_CHARACTER",
                  "int * string"
                ];
      case /* T_ERR_MISSING_DELIM_CLOSE */19 :
          return /* tuple */[
                  "ERR_MISSING_DELIM_CLOSE",
                  "string * string"
                ];
      case /* T_ERR_MISSING_COMMENT_CLOSE */20 :
          return /* tuple */[
                  "ERR_MISSING_COMMENT_CLOSE",
                  "string"
                ];
      case /* T_EQUALS */21 :
          return /* tuple */[
                  "EQUALS",
                  "unit"
                ];
      case /* T_EOF */22 :
          return /* tuple */[
                  "EOF",
                  "unit"
                ];
      case /* T_COUNT */23 :
          return /* tuple */[
                  "COUNT",
                  "string"
                ];
      case /* T_COMMENT_OPEN */24 :
          return /* tuple */[
                  "COMMENT_OPEN",
                  "unit"
                ];
      case /* T_COMMENT_CLOSE */25 :
          return /* tuple */[
                  "COMMENT_CLOSE",
                  "unit"
                ];
      case /* T_COMMENT */26 :
          return /* tuple */[
                  "COMMENT",
                  "string"
                ];
      case /* T_COLON */27 :
          return /* tuple */[
                  "COLON",
                  "unit"
                ];
      case /* T_BARE_DOUBLE_DASH */28 :
          return /* tuple */[
                  "BARE_DOUBLE_DASH",
                  "unit"
                ];
      
    }
  }
}

function element_incoming_symbol_type_str(el) {
  return element_incoming_symbol_desc(el)[1];
}

function incoming_symbol_type_str(cp) {
  var cp$1 = cp[/* status */0];
  var the_env;
  the_env = typeof cp$1 === "number" ? failwith("incoming_symbol_type: I don't know how to handle Rejected checkpoints") : (
      cp$1.tag === /* Accepted */4 ? failwith("incoming_symbol_type: I don't know how to handle Accepted checkpoints") : cp$1[0]
    );
  var match = _1(MenhirInterpreter.top, the_env);
  if (match !== undefined) {
    return element_incoming_symbol_type_str(match);
  }
  
}

function element_incoming_symbol_str(el) {
  return element_incoming_symbol_desc(el)[0];
}

function incoming_symbol_str(cp) {
  var cp$1 = cp[/* status */0];
  var the_env;
  the_env = typeof cp$1 === "number" ? failwith("incoming_symbol: I don't know how to handle Rejected checkpoints") : (
      cp$1.tag === /* Accepted */4 ? failwith("incoming_symbol: I don't know how to handle Accepted checkpoints") : cp$1[0]
    );
  var match = _1(MenhirInterpreter.top, the_env);
  if (match !== undefined) {
    return element_incoming_symbol_str(match);
  }
  
}

function element_incoming_symbol_desc_str(el) {
  var cat = element_incoming_symbol_category_str(el);
  var match = element_incoming_symbol_desc(el);
  return concat("", /* :: */[
              match[0],
              /* :: */[
                " : (",
                /* :: */[
                  match[1],
                  /* :: */[
                    ") ",
                    /* :: */[
                      cat,
                      /* [] */0
                    ]
                  ]
                ]
              ]
            ]);
}

function debug_checkpoint(cp) {
  var menhir_cp = cp[/* status */0];
  if (typeof menhir_cp === "number" || menhir_cp.tag) {
    return failwith("supposed to be InputNeeded");
  } else {
    var env = menhir_cp[0];
    var _i = 0;
    while(true) {
      var i = _i;
      var match = _2(MenhirInterpreter.get, i, env);
      if (match !== undefined) {
        console.log(element_incoming_symbol_desc_str(match));
        _i = i + 1 | 0;
        continue ;
      } else {
        return /* () */0;
      }
    }  }
}

function get_before(cp, idx) {
  var cp$1 = cp[/* status */0];
  var the_env;
  the_env = typeof cp$1 === "number" ? failwith("get_before: I don't know how to handle Rejected checkpoints") : (
      cp$1.tag === /* Accepted */4 ? failwith("get_before: I don't know how to handle Accepted checkpoints") : cp$1[0]
    );
  return _2(MenhirInterpreter.get, idx, the_env);
}

function get_after(cp, idx) {
  var cp$1 = cp[/* status */0];
  var the_env;
  the_env = typeof cp$1 === "number" || cp$1.tag !== /* Shifting */1 ? failwith("get_after: This function is only relevant for Shifting checkpoints") : cp$1[1];
  return _2(MenhirInterpreter.get, idx, the_env);
}
/* Lexer Not a pure module */

var $_Incremental = /*#__PURE__*/Object.freeze({
    __proto__: null,
    script: script$3,
    script_of_string: script_of_string$1,
    expression: expression$3,
    expression_of_string: expression_of_string$1,
    $$continue: $$continue,
    acceptable_token: acceptable_token,
    acceptable_tokens: acceptable_tokens,
    current_command: current_command,
    automaton_status_str: automaton_status_str,
    element_incoming_symbol_category_str: element_incoming_symbol_category_str,
    incoming_symbol_category_str: incoming_symbol_category_str,
    element_incoming_symbol_type_str: element_incoming_symbol_type_str,
    incoming_symbol_type_str: incoming_symbol_type_str,
    element_incoming_symbol_str: element_incoming_symbol_str,
    incoming_symbol_str: incoming_symbol_str,
    get_before: get_before,
    get_after: get_after,
    debug_checkpoint: debug_checkpoint
});

/** @hidden */
const $AST = mapExposedFunctionsThruErrorTrampoline($_AST);
/** @hidden */
const $Lexer = mapExposedFunctionsThruErrorTrampoline($_Lexer);
/** @hidden */
const $Parser = mapExposedFunctionsThruErrorTrampoline($_Parser);
/** @hidden */
const $Expression = mapExposedFunctionsThruErrorTrampoline($_Expression);
/** @hidden */
const $Incremental = mapExposedFunctionsThruErrorTrampoline($_Incremental);
/** @hidden */
const INTERNAL = Symbol();
// Errors
class OCamlError extends Error {
    /** @hidden */
    constructor($exn, message) {
        // FIXME: This is fragile; I'm depending on the BuckleScript runtime-repr of `exn`, here ...
        console.assert(Array.isArray($exn) && Array.isArray($exn[0]) && typeof $exn[0][0] === 'string');
        const [[error_variant, _], __] = $exn;
        if (typeof message === 'string' && message.length > 0) {
            super(message);
        }
        else if (typeof error_variant === 'string') {
            super('OCaml exception: ' + error_variant);
        }
        else {
            super('Unknown OCaml exception.');
        }
        this.$exn = $exn;
        // Set the prototype explicitly. See:
        //    <https://github.com/Microsoft/TypeScript/wiki/Breaking-Changes#extending-built-ins-like-error-array-and-map-may-no-longer-work>
        Object.setPrototypeOf(this, OCamlError.prototype);
    }
}
class LexError$1 extends OCamlError {
    /** @hidden */
    constructor($exn) {
        const [[$error_variant, _], $pos, $message] = $exn, message = fromFakeUTF8String($message), pos = new Position(INTERNAL, $pos);
        let print;
        if (typeof message === 'string' && message.length > 0) {
            print = `${message} (${pos.filename}:${pos.line}:${pos.character})`;
        }
        else {
            print = `Unknown LexError (${pos.filename}:${pos.line}:${pos.character})`;
        }
        super($exn, print);
        this.name = 'LexError';
        this.pos = pos;
        Object.setPrototypeOf(this, LexError$1.prototype);
    }
}
class ParseError$1 extends OCamlError {
    /** @hidden */
    constructor($exn) {
        const [[$error_variant, _], $loctok] = $exn;
        super($exn);
        this.name = 'ParseError';
        this.token = new LocatedToken(INTERNAL, $loctok);
        Object.setPrototypeOf(this, ParseError$1.prototype);
    }
}
/** @hidden */
const errorMap = {
    'Lexer.LexError': LexError$1,
    'Parser.ParseError': ParseError$1,
};
// Helpers
/** @hidden */
function isOCamlExn($exn) {
    return Array.isArray($exn) && Array.isArray($exn[0]) && typeof $exn[0][0] === 'string';
}
/**
 * Call a BuckleScript-generated OCaml function, catch OCaml `exn`-type exceptions, attempt to wrap
 * them in a JavaScript-side `Error`-descendant, and then throw them. Naturally, *this function*
 * will show up in the stack-trace — that is perfectly fine, as OCaml `exn`s *don't actually
 * maintain a stack*, as a performance trade-off; thus, no information is being lost here.
 *
 * @hidden
 */
function buckleScriptErrorTrampoline(bs_function, ...args) {
    try {
        return bs_function.apply(null, args);
    }
    catch ($exn) {
        if (isOCamlExn($exn)) {
            const [[error_variant]] = $exn;
            if (error_variant === 'Caml_js_exceptions.Error') {
                const orig_error = $exn[1];
                throw orig_error;
            }
            else {
                const ErrorConstructor = errorMap[error_variant] || OCamlError;
                throw new ErrorConstructor($exn);
            }
        }
        else {
            throw $exn;
        }
    }
}
/**
 * Meta-programmatic nonsense to translate all errors occuring in BuckleScript-land.
 *
 * TYPEME: This is less type-safe than it should/could be. See:
 *         <https://stackoverflow.com/questions/59914385>
 *
 * @hidden
 */
function mapExposedFunctionsThruErrorTrampoline($module) {
    const replacement = {};
    Object.getOwnPropertyNames($module).forEach(function (arg) {
        const key = arg;
        const $val = $module[key];
        if ($val instanceof Function) {
            replacement[key] = buckleScriptErrorTrampoline.bind(null, $val);
        }
        else {
            replacement[key] = $val;
        }
    });
    return replacement;
}
/** @hidden */
function fromFakeUTF8StringOption($str) {
    if (typeof $str === 'undefined') {
        return undefined;
    }
    else {
        return fromFakeUTF8String($str);
    }
}
/**
 * Yes, this is basically a no-op; but I like to be explicit. >,>
 * @hidden
 */
function fromFlagPayloadOption($payloadOpt) {
    if (typeof $payloadOpt === 'undefined') {
        // `None`
        return undefined;
    }
    else {
        const $payload = $Expression.payload_to_opt($payloadOpt);
        if (typeof $payload === 'undefined') {
            // `Some Empty`
            return undefined;
        }
        else {
            // `Some (Payload (string or_subexpr))`
            return $payload;
        }
    }
}
// Helper to generate a JavaScript-friendly shape for an `AST.or_subexpr`
/** @hidden */
function fromOrSubexpr($x) {
    if ($AST.is_literal($x)) {
        let $val = $AST.get_literal_exn($x);
        return { type: 'literal', value: fromFakeUTF8String($val) };
    }
    else {
        let $expr = $AST.get_sub_exn($x);
        return { type: 'subexpression', expr: new Expression(INTERNAL, $expr) };
    }
}
/** @hidden */
function reduceOrSubexprWithEval(evl, $x) {
    if ($AST.is_literal($x)) {
        let $val = $AST.get_literal_exn($x);
        return fromFakeUTF8String($val);
    }
    else {
        let $expr = $AST.get_sub_exn($x), expr = new ExpressionEval(INTERNAL, $expr, evl);
        return evl.call(null, expr);
    }
}
// Wrapper for Parser.script
function script$4(lexbuf, options = {}) {
    console.assert(lexbuf instanceof LexBuffer);
    const $scpt = $Parser.script(options.throwException, lexbuf.$buf);
    if (typeof $scpt === 'undefined') {
        return undefined;
    }
    else {
        return new Script(INTERNAL, $scpt);
    }
}
// Equivalent of Parser.script_of_string
function scriptOfString(str, options = {}) {
    const lexbuf = LexBuffer.ofString(str);
    return script$4(lexbuf, options);
}
// Wrapper for Incremental.script
function startScript(lexbuf) {
    console.assert(lexbuf instanceof LexBuffer);
    const $cp = $Incremental.script(lexbuf.$buf);
    return new Checkpoint(INTERNAL, $cp, 'script');
}
// Equivalent of Incremental.script_of_string
function startScriptWithString(str) {
    const lexbuf = LexBuffer.ofString(str);
    return startScript(lexbuf);
}
function expression$4(lexbuf, options = {}) {
    console.assert(lexbuf instanceof LexBuffer);
    const $expr = $Parser.expression(options.throwException, lexbuf.$buf);
    if (typeof $expr === 'undefined') {
        return undefined;
    }
    else {
        return new Expression(INTERNAL, $expr);
    }
}
function expressionOfString(str, options = {}) {
    const lexbuf = LexBuffer.ofString(str);
    return expression$4(lexbuf, options);
}
// Wrapper for Incremental.script
function startExpression(lexbuf) {
    console.assert(lexbuf instanceof LexBuffer);
    const $cp = $Incremental.expression(lexbuf.$buf);
    return new Checkpoint(INTERNAL, $cp, 'expression');
}
// Equivalent of Incremental.script_of_string
function startExpressionWithString(str) {
    const lexbuf = LexBuffer.ofString(str);
    return startExpression(lexbuf);
}
const Parser = {
    script: script$4,
    scriptOfString,
    startScript,
    startScriptWithString,
    expression: expression$4,
    expressionOfString,
    startExpression,
    startExpressionWithString,
};
// Wrapper for `AST.t`.
class Script {
    /** @hidden */
    constructor(isInternal, $scpt) {
        if (isInternal !== INTERNAL)
            throw new Error('`Script` can only be constructed by `Excmd.script()` and friends.');
        this.$scpt = $scpt;
        this.$expressions = $Expression.from_script(this.$scpt);
    }
    get expressions() {
        return this.$expressions.map($expr => new Expression(INTERNAL, $expr));
    }
}
class ExpressionCommon {
    /** @hidden */
    constructor(isInternal, $expr) {
        if (isInternal !== INTERNAL)
            throw new Error('`Expression` can only be constructed by `Excmd.script()` and friends.');
        this.$expr = $expr;
    }
    get count() {
        return $Expression.count(this.$expr);
    }
    get flags() {
        return $Expression.flags_arr(this.$expr).map(fromFakeUTF8String);
    }
    // Wrapper for `Expression.mem`
    hasFlag(flag) {
        console.assert(typeof flag === 'string');
        let $flag = toFakeUTF8String(flag);
        return $Expression.mem($flag, this.$expr);
    }
}
/**
 * The core type of my AST, this data-structure represents a single (sub-)command in an excmd
 * script; and is the product of entry-points like [[Parser.expressionOfString]].
 *
 * ### Construction
 * This JavaScript class, like most in my interface, cannot be constructed directly (i.e. `new
 * Expression()` is going to throw an error); instead, you must invoke the parser via the functions
 * in the exported [[Parser]] module.
 *
 * ### Evaluation
 * The language accepted by this parser allows for "sub-expressions" — runs of code that may remain
 * unevaluated, to be executed at a later point.
 *
 * The most direct method of interacting with these, is manually testing whether a particular method
 * has produced a [[Literal]] or a [[Sub]]-expression, and proceeding as appropriate:
 *
 * ```typescript
 * const expr = Parser.expressionOfString('(echo test_cmd) arg'),
 *    cmd = expr.command
 *
 * switch (cmd.type) {
 *    case 'literal': console.log(cmd.value) // ... use stringish val,
 *    case 'subexpression': handleSubexpr(cmd.expr) // or evaluate.
 * }
 * ```
 *
 * However, this can be tedious, if you only wish to evaluate simple expressions. For these
 * situations, I provide a simplified "recursive evaluation" interface: by inverting control, you
 * can allow the parser to become responsible for recursively evaluating [[Sub]] and [[Literal]]
 * values into simple `string`s, as long as you can provide the parser with a simplified
 * handler-callback that will attempt to reduce a single, given sub-expression into a `string`.
 *
 * The entry-point to this auto-evaluation interface is either [[cloneWithEvaluator]], or as a
 * further convenience, the various `eval*` methods below: [[evalCommand]], [[evalPositionals]], and
 * so on.
 *
 * Each of these takes a function — matching the [["index".evaluator | evaluator]] signature — that
 * takes an expression, and mechanistically reduces it into a simple string:
 *
 * ```typescript
 * const expr = Parser.expressionOfString('(echo test_cmd) arg')
 *
 * function handleSubexpr(expr) {
 *    if (expr.command === 'echo') {
 *       return expr.positionals.join(' ')
 *    }
 * }
 *
 * console.log("Command:", expr.evalCommand(handleSubexpr))
 * //=> prints "Command: test_cmd"
 * ```
 *
 * (Note, additionally, that within the body of the evaluator above, I've only had to compare
 * `expr.command` to a string, directly. As evaluators receive [[ExpressionEval]]s instead of plain
 * expressions, their bodies need no further shenanigans; any requested expression-properties will
 * recursively evaluate further subexpressions as-needed.)
 *
 * Finally, if you want to access multiple elements of an expression thusly, it may be easier to
 * pre-associate an evaluator with the expression using [[cloneWithEvaluator]], producing an
 * [[ExpressionEval]] directly:
 *
 * ```typescript
 * function handleSubexpr(expr) {
 *    if (expr.command === 'echo') {
 *       return expr.positionals.join(' ')
 *    }
 * }
 *
 * const expr = Parser.expressionOfString('(echo test_cmd) arg'),
 *    ee = expr.cloneWithEvaluator(handleSubexpr)
 *
 * console.log(`Command: ${ee.command}, args: ${ee.positionals.join(' ')}`)
 * //=> prints "Command: test_cmd, args: arg"
 * ```
 *
 * ### Mutation
 * Importantly, these `Expression`s are *mutable* views onto the underlying AST. They're designed to
 * ensure you don't access the data-structure in an unsafe way. In particular, a given `word` in the
 * original input-string can only be *either* a flag-payload, *or* a positional argument — not both.
 *
 * Consider the following:
 *
 * ```typescript
 * const expr = Parser.expressionOfString('hello -f world')
 * ```
 *
 * Does that command have one flag, with the payload `world`? Or an empty (boolean) flag, and a
 * single positional-argument, `world`? My answer, in this interface, is “whichever you observe
 * first”. To be more specific, any method of either [[Expression]] or [[ExpressionEval]] that
 * produces flag-payloads or positional arguments, will *mutate* the data-structure such that
 * subsequent accesses don't see an inconsistent state.
 *
 * Let's look at some examples:
 *
 * ```typescript
 * const expr1 = Parser.expressionOfString('hello -f world')
 *
 * expr1.getFlag('f').value //=> returs 'world';
 * expr1.getPositionals() //=> returns []
 * ```
 *
 * Here, [[getFlag]] mutated `expr1`; and so a subsequent [[getPositionals]] produced a consistent
 * result: there were no remaining positional arguments.
 *
 * ```typescript
 * const expr2 = Parser.expressionOfString('hello -f world')
 *
 * expr2.getPositionals() //=> returns one arg, [{ value: 'world' }]
 * expr2.getFlag('f') //=> returs undefined; because `-f` has no payload
 * ```
 *
 * Here, [[getPositionals]] mutated `expr2`; and so a subsequent [[getFlag]], *again*, produced a
 * consistent result: there was no value available to become the payload of `-f`.
 *
 * This interface is intended to be used in a form wherein the invocations of these methods acts as
 * the specification of the parser's behaviour. For example, one command might expect a flag `-d` or
 * `--dest`, and demand a payload for that flag; whereas another might use `-d` as a boolean, and
 * expect positionals. This way, the behaviour of the parser is flexible enough to handle both of
 * those situations.
 *
 * Finally, note that at least for flags, there's also non-mutative accessors: you can always check
 * whether a flag *exists* using [[hasFlag]].
 */
class Expression extends ExpressionCommon {
    clone() {
        let $new = $AST.copy_expression(this.$expr);
        return new Expression(INTERNAL, $new);
    }
    cloneWithEvaluator(handleSubexpr) {
        let $new = $AST.copy_expression(this.$expr);
        return new ExpressionEval(INTERNAL, $new, handleSubexpr);
    }
    get command() {
        let $command = $Expression.command(this.$expr);
        return fromOrSubexpr($command);
    }
    evalCommand(handleSubexpr) {
        let ee = new ExpressionEval(INTERNAL, this.$expr, handleSubexpr);
        return ee.command;
    }
    // Wrapper for `Expression.positionals`
    getPositionals() {
        let $positionals = $Expression.positionals_arr(this.$expr);
        return $positionals.map(fromOrSubexpr);
    }
    evalPositionals(handleSubexpr) {
        let ee = new ExpressionEval(INTERNAL, this.$expr, handleSubexpr);
        return ee.getPositionals();
    }
    // Wrapper for `Expression.iter`
    forEachFlag(f) {
        const flagMapper = function (idx, $name, $payloadOpt) {
            const name = fromFakeUTF8String($name), $payload = fromFlagPayloadOption($payloadOpt), payload = typeof $payload === 'undefined' ? undefined : fromOrSubexpr($payload);
            f.call(null, name, payload, idx);
        };
        $Expression.iteri(flagMapper, this.$expr);
    }
    evalEachFlag(handleSubexpr, f) {
        let ee = new ExpressionEval(INTERNAL, this.$expr, handleSubexpr);
        return ee.forEachFlag(f);
    }
    // Wrapper for `Expression.flag`
    // TODO: Rename to something clearer, like getPayload
    getFlag(flag) {
        console.assert(typeof flag === 'string');
        const $flag = toFakeUTF8String(flag), $payloadOpt = $Expression.flag($flag, this.$expr), $payload = fromFlagPayloadOption($payloadOpt);
        return typeof $payload === 'undefined' ? undefined : fromOrSubexpr($payload);
    }
    evalFlag(handleSubexpr, flag) {
        let ee = new ExpressionEval(INTERNAL, this.$expr, handleSubexpr);
        return ee.getFlag(flag);
    }
}
// `Expression.t`, with recursive evaluation of subexpressions
class ExpressionEval extends ExpressionCommon {
    /** @hidden */
    constructor(isInternal, $expr, handleSubexpr) {
        if (isInternal !== INTERNAL)
            throw new Error('`ExpressionEval` can only be constructed by `Expression#evalPositionals()` and similar.');
        super(isInternal, $expr);
        console.assert(typeof handleSubexpr === 'function');
        this.evaluator = handleSubexpr;
    }
    clone() {
        let $new = $AST.copy_expression(this.$expr);
        return new ExpressionEval(INTERNAL, $new, this.evaluator);
    }
    get command() {
        let $command = $Expression.command(this.$expr);
        return reduceOrSubexprWithEval(this.evaluator, $command);
    }
    // Wrapper for `Expression.positionals`
    getPositionals() {
        let $positionals = $Expression.positionals_arr(this.$expr);
        // My kingdom for better functional tooling in JavaScript ;_;
        return $positionals.map(reduceOrSubexprWithEval.bind(null, this.evaluator));
    }
    // Wrapper for `Expression.iter`
    forEachFlag(f) {
        const self = this, flagMapper = function (idx, $name, $payloadOpt) {
            const name = fromFakeUTF8String($name), $payload = fromFlagPayloadOption($payloadOpt), payload = typeof $payload === 'undefined'
                ? undefined
                : reduceOrSubexprWithEval(self.evaluator, $payload);
            f.call(null, name, payload, idx);
        };
        $Expression.iteri(flagMapper, this.$expr);
    }
    // Wrapper for `Expression.flag`
    getFlag(flag) {
        console.assert(typeof flag === 'string');
        const $flag = toFakeUTF8String(flag), $payloadOpt = $Expression.flag($flag, this.$expr), $payload = fromFlagPayloadOption($payloadOpt);
        return typeof $payload === 'undefined'
            ? undefined
            : reduceOrSubexprWithEval(this.evaluator, $payload);
    }
}
class LexBuffer {
    /** @hidden */
    constructor(isInternal, $buf) {
        if (isInternal !== INTERNAL)
            throw new Error('`Buffer` must be constructed with `LexBuffer.ofString()` et al.');
        this.$buf = $buf;
    }
    static ofString(str) {
        console.assert(typeof str === 'string');
        const $utf8 = toFakeUTF8String(str), $buf = $Lexer.buffer_of_string($utf8);
        return new LexBuffer(INTERNAL, $buf);
    }
    next() {
        const $loctok = $Lexer.next_loc(this.$buf);
        return new LocatedToken(INTERNAL, $loctok);
    }
    rest() {
        return $Lexer
            .tokens_loc(this.$buf)
            .map($loctok => new LocatedToken(INTERNAL, $loctok));
    }
}
class Position {
    /** @hidden */
    constructor(isInternal, $pos) {
        if (isInternal !== INTERNAL)
            throw new Error('`Position` cannot be constructed');
        this.$pos = $pos;
    }
    get filename() {
        const $fname = $Lexer.position_fname(this.$pos);
        return fromFakeUTF8String($fname);
    }
    get line() {
        return $Lexer.position_lnum(this.$pos);
    }
    get byte() {
        return $Lexer.position_cnum(this.$pos);
    }
    get character() {
        return $Lexer.position_bol(this.$pos);
    }
}
class LocatedToken {
    /** @hidden */
    constructor(isInternal, $loctok) {
        if (isInternal !== INTERNAL)
            throw new Error('`LocatedToken` cannot be constructed');
        this.$loctok = $loctok;
    }
    /** @hidden */
    get $token() {
        return $Lexer.token(this.$loctok);
    }
    get token() {
        return new Token(INTERNAL, this.$token);
    }
    get id() {
        return Symbol.for($Lexer.show_token(this.$token));
    }
    get startLine() {
        return $Lexer.start_lnum(this.$loctok);
    }
    get startIdx() {
        return $Lexer.start_cnum(this.$loctok);
    }
    get endLine() {
        return $Lexer.end_lnum(this.$loctok);
    }
    get endIdx() {
        return $Lexer.end_cnum(this.$loctok);
    }
    get body() {
        return new Token(INTERNAL, this.$token).body;
    }
}
class Token {
    /** @hidden */
    constructor(isInternal, $tok) {
        if (isInternal !== INTERNAL)
            throw new Error('`Token` cannot be constructed');
        this.$token = $tok;
    }
    get id() {
        return Symbol.for($Lexer.show_token(this.$token));
    }
    get body() {
        let $body = $Lexer.token_body(this.$token);
        return fromFakeUTF8StringOption($body);
    }
    compare(other) {
        console.assert(other instanceof Token);
        return $Lexer.compare_token(this.$token, other.$token);
    }
}
// Wrapper for Incremental.checkpoint.
class Checkpoint {
    /** @hidden */
    constructor(isInternal, $cp, type) {
        if (isInternal !== INTERNAL)
            throw new Error('`Checkpoint` can only be constructed by `Excmd.startScript()` and friends.');
        this.$cp = $cp;
        this.type = type;
    }
    /** @hidden */
    producesScript() {
        return this.type === 'script';
    }
    /** @hidden */
    producesExpression() {
        return this.type === 'expression';
    }
    continue(opts = {}) {
        const self = this;
        let acceptMapper;
        if (typeof opts.onAccept === 'undefined')
            acceptMapper = function () { };
        else if (this.producesScript())
            acceptMapper = function wrapScript($scpt) {
                const scpt = new Script(INTERNAL, $scpt), onAccept = opts.onAccept;
                return onAccept(scpt);
            };
        else
            acceptMapper = function wrapExpression($expr) {
                const expr = new Expression(INTERNAL, $expr), onAccept = opts.onAccept;
                return onAccept(expr);
            };
        const onFail = opts.onFail;
        let failMapper;
        if (typeof onFail === 'undefined')
            failMapper = function () { };
        else
            failMapper = function ($lastGood, $errorAt) {
                const lastGood = new Checkpoint(INTERNAL, $lastGood, self.type), errorAt = new Checkpoint(INTERNAL, $errorAt, self.type);
                return onFail(lastGood, errorAt);
            };
        // (BuckleScript mangles `continue` due to that being a reserved word in JavaScript.)
        return $Incremental.$$continue(acceptMapper, failMapper, this.$cp);
    }
    // FIXME: This, and some of these others, have constraints on the *state* of the checkpoint
    //        before they make sense (i.e. 'this must be in the InputNeeded state' or similar.) I'd
    //        like to raise the errors on the JavaScript side, in a JavaScript-friendly way, with
    //        the option of returning an optional instead of allowing for runtime exceptions ...
    get acceptable_token() {
        const $tok = $Incremental.acceptable_token(this.$cp);
        return new Token(INTERNAL, $tok);
    }
    get acceptable_tokens() {
        const $toks = $Incremental.acceptable_tokens(this.$cp);
        return $toks.map($tok => new Token(INTERNAL, $tok));
    }
    get command() {
        const $command = $Incremental.current_command(this.$cp);
        return typeof $command === 'undefined' ? undefined : fromOrSubexpr($command);
    }
    // FIXME: More accessors
    get automaton_status() {
        const $str = $Incremental.automaton_status_str(this.$cp);
        if (typeof $str === 'undefined') {
            return undefined;
        }
        else {
            return $str;
        }
    }
    get incoming_symbol_category() {
        const $str = $Incremental.incoming_symbol_category_str(this.$cp);
        if (typeof $str === 'undefined') {
            return undefined;
        }
        else {
            return $str;
        }
    }
    get incoming_symbol_type() {
        return $Incremental.incoming_symbol_type_str(this.$cp);
    }
    get incoming_symbol() {
        return $Incremental.incoming_symbol_str(this.$cp);
    }
    get beforeStack() {
        return new AutomatonStack(INTERNAL, this, false);
    }
    get afterStack() {
        return new AutomatonStack(INTERNAL, this, true);
    }
}
class AutomatonStack {
    /** @hidden */
    constructor(isInternal, cp, isAfterStack) {
        if (isInternal !== INTERNAL)
            throw new Error('`AutomatonStack` can only be obtained via `Checkpoint::beforeStack()` and friends.');
        this.cp = cp;
        this.isAfterStack = isAfterStack;
    }
    *[Symbol.iterator]() {
        const $cp = this.cp.$cp;
        const $get = this.isAfterStack ? $Incremental.get_after : $Incremental.get_before;
        // Translated, "while get_whichever() isn't None." Yeah, it's a mess.
        for (let $el, idx = 0; ($el = $get($cp, idx)); idx++) {
            yield new AutomatonElement(INTERNAL, $el);
        }
    }
}
class AutomatonElement {
    /** @hidden */
    constructor(isInternal, $el) {
        if (isInternal !== INTERNAL)
            throw new Error('`AutomatonElement` can only be obtained by iterating over `Checkpoint::stackBefore()` and friends.');
        this.$el = $el;
    }
    get incoming_symbol_category() {
        return $Incremental.element_incoming_symbol_category_str(this.$el);
    }
    get incoming_symbol_type() {
        return $Incremental.element_incoming_symbol_type_str(this.$el);
    }
    get incoming_symbol() {
        return $Incremental.element_incoming_symbol_str(this.$el);
    }
}

export { AutomatonElement, AutomatonStack, Checkpoint, Expression, ExpressionEval, LexBuffer, LexError$1 as LexError, LocatedToken, OCamlError, ParseError$1 as ParseError, Parser, Position, Script, Token };
